@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -9,6 +9,9 @@
 *****************************************************************/
 
 #include "AppContext.h"
+#include "ProjectModel.h"
+#include "DBXRefRegistry.h"
+#include "MainWindow.h"
 
 namespace GB2 {
 
