@@ -12,7 +12,6 @@
 #define _GB2_APPCONTEXT_H_
 
 #include "core_api.h"
-#include <QtScript>
 
 namespace GB2 {
 
@@ -42,13 +41,24 @@ class SubstMatrixRegistry;
 class SmithWatermanTaskFactoryRegistry;
 class MolecularSurfaceFactoryRegistry;
 class SWResultFilterRegistry;
-class GScriptRunner;
 class MSAColorSchemeRegistry;
-class GScriptModuleRegistry;
-class SecStructPredcitAlgRegistry;
+class SecStructPredictAlgRegistry;
 class CudaGpuRegistry;
 class AtiStreamGpuRegistry;
 class RecentlyDownloadedCache;
+class LocalTaskFactoryRegistry;
+class LocalTaskManager;
+class ProtocolInfoRegistry;
+class RemoteMachineMonitor;
+class PhyTreeGeneratorRegistry;
+class CMDLineRegistry;
+class MSAConsensusAlgorithmRegistry;
+class PWMConversionAlgorithmRegistry;
+class VirtualFileSystemRegistry;
+class DnaAssemblyAlgRegistry;
+class AppGlobalObject;
+class DataBaseRegistry;
+class RepeatFinderTaskFactoryRegistry;
 
 class GB2_COREAPI_EXPORT AppContext  : public QObject {
     Q_OBJECT
@@ -114,21 +124,49 @@ public:
 
     static SWResultFilterRegistry* getSWResultFilterRegistry() {return getInstance()->_getSWResultFilterRegistry();}
 
-    static GScriptRunner* getScriptRunner() {return getInstance()->_getScriptRunner();}
-
     static MSAColorSchemeRegistry* getMSAColorSchemeRegistry() { return getInstance()->_getMSAColorSchemeRegistry();}
 
-    static GScriptModuleRegistry* getScriptModuleRegistry() {return getInstance()->_getScriptModuleRegistry();}
-
-    static SecStructPredcitAlgRegistry* getSecStructPredictAlgRegistry() { return getInstance()->_getSecStructPredictAlgRegistry(); }
+    static SecStructPredictAlgRegistry* getSecStructPredictAlgRegistry() { return getInstance()->_getSecStructPredictAlgRegistry(); }
 
     static CudaGpuRegistry * getCudaGpuRegistry() { return getInstance()->_getCudaGpuRegistry(); }
 
     static AtiStreamGpuRegistry * getAtiStreamGpuRegistry() { return getInstance()->_getAtiStreamGpuRegistry(); }
     
-    static RecentlyDownloadedCache* getRecentlyDownloadedCache() { return getInstance()->_getRecentlyDownloadedCache(); }
+    static RecentlyDownloadedCache* getRecentlyDownloadedCache() { return getInstance()->_getRecentlyDownloadedCache(); }   
+
+    static LocalTaskFactoryRegistry * getLocalTaskFactoryRegistry() { return getInstance()->_getLocalTaskFactoryRegistry(); }
+
+    static LocalTaskManager *   getLocalTaskManager() { return getInstance()->_getLocalTaskManager(); }
+
+    static ProtocolInfoRegistry * getProtocolInfoRegistry() { return getInstance()->_getProtocolInfoRegistry(); }
+
+    static RemoteMachineMonitor * getRemoteMachineMonitor() { return getInstance()->_getRemoteMachineMonitor(); }
+	
+    static PhyTreeGeneratorRegistry *getPhyTreeGeneratorRegistry() {return getInstance()->_getPhyTreeGeneratorRegistry();}
+
+    static CMDLineRegistry* getCMDLineRegistry() {return getInstance()->_getCMDLineRegistry();}
+
+    static MSAConsensusAlgorithmRegistry* getMSAConsensusAlgorithmRegistry() {return getInstance()->_getMSAConsensusAlgorithmRegistry(); }
+
+    static PWMConversionAlgorithmRegistry* getPWMConversionAlgorithmRegistry() {return getInstance()->_getPWMConversionAlgorithmRegistry(); }
+    
+    static VirtualFileSystemRegistry * getVirtualFileSystemRegistry() { return getInstance()->_getVirtualFileSystemRegistry(); }
+
+    static DnaAssemblyAlgRegistry* getDnaAssemblyAlgRegistry() { return getInstance()->_getDnaAssemblyAlgRegistry(); }
+
+	static RepeatFinderTaskFactoryRegistry* getRepeatFinderTaskFactoryRegistry() {return getInstance()->_getRepeatFinderTaskFactoryRegistry();}
+
+    /** Registers application global resource */
+    static void registerGlobalObject(AppGlobalObject* obj) {return getInstance()->_registerGlobalObject(obj);}
+
+    /** Unregisters application global resource */
+    static void unregisterGlobalObject(const QString& id) {return getInstance()->_unregisterGlobalObject(id);}
+
+    /** Finds application global resource */
+    static AppGlobalObject* getGlobalObjectById(const QString& id) {return getInstance()->_getGlobalObjectById(id);}
+   
+	static DataBaseRegistry *getDataBaseRegistry() {return getInstance()->_getDataBaseRegistry();}
 
-    static void setupToEngine(QScriptEngine *engine) {return getInstance()->_setupToEngine(engine);}
 
 protected:
     static AppContext* getInstance() {assert(instance); return instance;}
@@ -158,18 +196,33 @@ protected:
 	virtual DBXRefRegistry*             _getDBXRefRegistry() const = 0;
 	virtual SubstMatrixRegistry*		_getSubstMatrixRegistry() const = 0;
 	virtual SmithWatermanTaskFactoryRegistry*	_getSmithWatermanTaskFactoryRegistry() const = 0;
-        virtual MolecularSurfaceFactoryRegistry* _getMolecularSurfaceFactoryRegistry()const = 0;
+    virtual MolecularSurfaceFactoryRegistry* _getMolecularSurfaceFactoryRegistry()const = 0;
     virtual SWResultFilterRegistry*     _getSWResultFilterRegistry() const = 0;
-    virtual GScriptRunner*	            _getScriptRunner() const = 0;
     virtual MSAColorSchemeRegistry*     _getMSAColorSchemeRegistry() const = 0;
-    virtual SecStructPredcitAlgRegistry* _getSecStructPredictAlgRegistry() const = 0;
-    virtual CudaGpuRegistry *            _getCudaGpuRegistry() const = 0;
+    virtual SecStructPredictAlgRegistry* _getSecStructPredictAlgRegistry() const = 0;
+    virtual CudaGpuRegistry *           _getCudaGpuRegistry() const = 0;
     virtual AtiStreamGpuRegistry *       _getAtiStreamGpuRegistry() const = 0;
-    virtual GScriptModuleRegistry*      _getScriptModuleRegistry() const = 0;
     virtual RecentlyDownloadedCache*    _getRecentlyDownloadedCache() const = 0;
-    virtual void                        _setupToEngine(QScriptEngine *engine);
+    virtual LocalTaskFactoryRegistry *  _getLocalTaskFactoryRegistry() const = 0;
+    virtual LocalTaskManager *          _getLocalTaskManager() const = 0;
+    virtual ProtocolInfoRegistry *      _getProtocolInfoRegistry() const = 0;
+    virtual RemoteMachineMonitor *      _getRemoteMachineMonitor() const = 0;
+    virtual PhyTreeGeneratorRegistry *  _getPhyTreeGeneratorRegistry() const = 0;
+    virtual CMDLineRegistry*            _getCMDLineRegistry() const  = 0;
+	virtual MSAConsensusAlgorithmRegistry* _getMSAConsensusAlgorithmRegistry() const = 0;
+    virtual PWMConversionAlgorithmRegistry* _getPWMConversionAlgorithmRegistry() const = 0;
+    virtual VirtualFileSystemRegistry * _getVirtualFileSystemRegistry() const = 0;
+    virtual DnaAssemblyAlgRegistry*    _getDnaAssemblyAlgRegistry() const = 0;
+	virtual DataBaseRegistry *			_getDataBaseRegistry() const = 0;
+	virtual RepeatFinderTaskFactoryRegistry*	_getRepeatFinderTaskFactoryRegistry() const = 0;
+
+    virtual void _registerGlobalObject(AppGlobalObject* go) = 0;
+    virtual void _unregisterGlobalObject(const QString& id) = 0;
+    virtual AppGlobalObject* _getGlobalObjectById(const QString& id) = 0;
+    
     static AppContext* instance;
 };
 
 }//namespace
+
 #endif
