@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -17,12 +17,13 @@ namespace GB2 {
 
 class NetworkConfiguration;
 class UserAppsSettings;
+class AppResourcePool;
 
 /** A collection for all settings used in app that have C++ model description */
 
 class GB2_COREAPI_EXPORT AppSettings {
 public:
-    AppSettings() : nc(NULL), userAppsSettings(NULL){}
+    AppSettings() : nc(NULL), userAppsSettings(NULL), ri(NULL){}
 
     virtual ~AppSettings(){}
 
@@ -30,9 +31,12 @@ public:
 
     UserAppsSettings* getUserAppsSettings() const {return userAppsSettings;}
 
+    AppResourcePool* getAppResourcePool() const {return ri;}
+
 protected:
     NetworkConfiguration*   nc;
     UserAppsSettings*       userAppsSettings;
+    AppResourcePool*        ri;
 };
 
 }//namespace
