@@ -24,11 +24,23 @@ enum DNATranslationType {
 	DNATranslationType_NUCL_2_COMPLNUCL,
 	DNATranslationType_NUCL_2_AMINO,
 	DNATranslationType_AMINO_2_AMINO,
+    DNATranslationType_AMINO_2_NUCL,
 	DNATranslationType_RAW_2_NUCL,
 	DNATranslationType_RAW_2_AMINO
 };
 
+class GB2_COREAPI_EXPORT BaseDNATranslationIds: public QObject	{
+public:
+    static const QString NUCL_DNA_DEFAULT_COMPLEMENT;
+    static const QString NUCL_RNA_DEFAULT_COMPLEMENT;
+
+    static const QString NUCL_DNA_EXTENDED_COMPLEMENT;
+    static const QString NUCL_RNA_EXTENDED_COMPLEMENT;
+};
+
+
 #define DNATranslationID(n) "NCBI-GenBank #"#n
+#define DNABackTranslationID(type, name) "BackTranslation/"#type"/"#name
 #define AMINO_TT_GOBJECT_HINT "AminoTT"
 
 class GB2_COREAPI_EXPORT DNATranslation {
@@ -51,6 +63,8 @@ public:
 	virtual bool isOne2One() const {return false;}
     
     virtual bool isThree2One() const {return false;}
+
+   	virtual bool isOne2Three() const {return false;}
 	
 	virtual QByteArray getOne2OneMapper() const {
 		assert(0); return QByteArray(256, 0);
@@ -59,7 +73,12 @@ public:
     virtual char translate3to1(char c1, char c2, char c3) const {
         Q_UNUSED(c1); Q_UNUSED(c2); Q_UNUSED(c3);
         assert(0); return 0;
-    };
+    }
+
+    virtual char* translate1to3(char c) const {
+        Q_UNUSED(c);
+        assert(0); return NULL;
+    }
 
 protected:
 	DNATranslationType type;
