@@ -26,6 +26,9 @@ const DocumentFormatId BaseDocumentFormats::NEWICK("newick");
 const DocumentFormatId BaseDocumentFormats::INDEX("index");
 const DocumentFormatId BaseDocumentFormats::FASTQ("fastq");
 const DocumentFormatId BaseDocumentFormats::PLAIN_ASN("mmdb");
-
+const DocumentFormatId BaseDocumentFormats::MSF("msf");
+const DocumentFormatId BaseDocumentFormats::GFF("gff");
+const DocumentFormatId BaseDocumentFormats::SRF("srfasta");
+const DocumentFormatId BaseDocumentFormats::SAM("sam");
 
 }//namespace
