@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -28,8 +28,13 @@ public:
     static const DocumentFormatId STOCKHOLM;
     static const DocumentFormatId NEWICK;
 	static const DocumentFormatId PLAIN_PDB; 
-	
-
+	static const DocumentFormatId INDEX;
+    static const DocumentFormatId FASTQ;
+    static const DocumentFormatId PLAIN_ASN;
+    static const DocumentFormatId MSF;
+    static const DocumentFormatId GFF;
+    static const DocumentFormatId SRF;
+	static const DocumentFormatId SAM;
 };
 
 
