@@ -14,12 +14,16 @@
 #include <core_api/IOAdapter.h>
 #include <core_api/GHints.h>
 #include <core_api/Log.h>
+#include <core_api/L10n.h>
+#include <core_api/GUrlUtils.h>
 
 #include <gobjects/GObjectUtils.h>
 #include <gobjects/UnloadedObject.h>
 
 #include <QtCore/QFileInfo>
 
+#include <memory>
+
 /* TRANSLATOR GB2::DocumentFormat */
 
 namespace GB2 {
@@ -30,19 +34,20 @@ const QString DocumentMimeData::MIME_TYPE("application/x-ugene-document-mime");
 
 static LogCategory log(ULOG_CAT_CORE_SERVICES);
 
-Document* DocumentFormat::createNewDocument(IOAdapterFactory* io, const QString& url, const QVariantMap& hints) {
+Document* DocumentFormat::createNewDocument(IOAdapterFactory* io, const GUrl& url, const QVariantMap& hints) {
     Document* d = new Document(this, io, url, QList<UnloadedObjectInfo>(), hints);
     d->setLoaded(true);
     return d;
 }
 
-Document* DocumentFormat::loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs ) {
-    assert( NULL != io );
-    assert( io->isOpen() );
-    IOAdapterFactory* io_factory = io->getFactory();
-    QString url = io->getUrl();
-    io->close();
-    return loadExistingDocument( io_factory, url, ti, fs );
+Document* DocumentFormat::loadDocument(IOAdapterFactory* iof, const GUrl& url, TaskStateInfo& ti, const QVariantMap& hints) {
+    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
+    if (!io->open(url, IOAdapterMode_Read)) {
+        ti.setError(L10N::errorOpeningFileRead(url));
+        return NULL;
+    }
+    Document * doc = loadDocument(io.get(), ti, hints, DocumentLoadMode_Whole);
+    return doc;
 }
 
 void DocumentFormat::storeDocument( Document* , TaskStateInfo& ts, IOAdapter* ) {
@@ -50,37 +55,109 @@ void DocumentFormat::storeDocument( Document* , TaskStateInfo& ts, IOAdapter* )
     ts.setError(tr("Writing is not supported for this format (%1). Feel free to send a feature request though.").arg(getFormatName()));
 }
 
-void DocumentFormat::storeDocument( Document* , TaskStateInfo& ts, IOAdapterFactory* , const QString& ) {
-    assert(0);
-    ts.setError(tr("Writing is not supported for this format (%1). Feel free to send a feature request though.").arg(getFormatName()));
+void DocumentFormat::storeDocument(Document* doc, TaskStateInfo& ti, IOAdapterFactory* iof, const GUrl& newDocURL) {
+    if (!formatFlags.testFlag(DocumentFormatFlag_SupportWriting)) {
+        assert(0);
+        ti.setError(tr("Writing is not supported for this format (%1). Feel free to send a feature request though.").arg(getFormatName()));
+        return;
+    }
+    
+    assert(doc->getDocumentModLock(DocumentModLock_FORMAT_AS_INSTANCE) == NULL);
+    if (iof == NULL) {
+        iof = doc->getIOAdapterFactory();
+    }
+    
+    //prepare URL
+    GUrl url = newDocURL.isEmpty() ? doc->getURL() : newDocURL;
+    if (url.isLocalFile()) {
+        QString error;
+        QString res = GUrlUtils::prepareFileLocation(url.getURLString(), error);
+        if (!error.isEmpty()) {
+            ti.setError(error);
+            return;
+        }
+        Q_UNUSED(res);
+        assert(res == url.getURLString()); //ensure that GUrls are always canonical
+    }
+    
+    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
+    if (!io->open(url, IOAdapterMode_Write)) {
+        ti.setError(L10N::errorOpeningFileWrite(url));
+        return;
+    }
+    
+    storeDocument(doc, ti, io.get());
 }
+
+bool DocumentFormat::checkConstraints(const DocumentFormatConstraints& c) const {
+    assert(!supportedObjectTypes.isEmpty()); //extra check for DF state validation
+
+    if (!checkFlags(c.flagsToSupport)) {
+        return false; //requested to support writing or streaming but doesn't
+    }
+
+	if ((int(c.flagsToExclude) & int(formatFlags)) != 0) {
+		return false; // filtered by exclude flags
+	}
+
+    if (c.checkRawData && !checkRawData(c.rawData)) {
+        return false; //raw data is not matched
+    }
+
+    foreach (GObjectType objType, c.supportedObjectTypes) {
+        if (!supportedObjectTypes.contains(objType)) { // the object type is not in the supported list
+            return false;
+        }
+    }
+    
+    return true;
+}
+
+bool DocumentFormat::isObjectOpSupported(const Document* d, DocObjectOp op, GObjectType t) const {
+	assert(d->getDocumentFormat() == this);
+
+    if (!supportedObjectTypes.contains(t)) {
+        return false;
+    }
+    
+	if (!checkFlags(DocumentFormatFlag_SupportWriting)) {
+        return false;
+    }
+	
+	if (op == DocObjectOp_Add) {
+		int nObjects = d->getObjects().size();
+		if (nObjects != 0 && checkFlags(DocumentFormatFlag_SingleObjectFormat)) {
+			return false;
+		}
+	}
+    return true;
+}
+
 //////////////////////////////////////////////////////////////////////////
 ///Document
 
-Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const QString& _url, const QList<UnloadedObjectInfo>& unloadedObjects,
+Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, const QList<UnloadedObjectInfo>& unloadedObjects,
                    const QVariantMap& hints, const QString& instanceModLockDesc)
 : StateLockableTreeItem(), df(_df), io(_io), url(_url)
 {
     ctxState = new GHintsDefaultImpl(hints);
 
-    QFileInfo fi(url);
-    name = fi.fileName();
-    std::fill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);    
+    name = url.fileName();
+    qFill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);    
     
     addUnloadedObjects(unloadedObjects);
     initModLocks(instanceModLockDesc, false);
     checkUnloadedState();
 }
 
-Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const QString& _url, 
+Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, 
                    const QList<GObject*>& _objects, const QVariantMap& hints, const QString& instanceModLockDesc)
 : StateLockableTreeItem(), df(_df), io(_io), url(_url)
 {
     ctxState = new GHintsDefaultImpl(hints);
-    QFileInfo fi(url);
-    name = fi.fileName();
+    name = url.fileName();
     
-    std::fill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);
+    qFill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);
 
     foreach(GObject* o, _objects) {
         _addObject(o);
@@ -149,6 +226,8 @@ void Document::_removeObject(GObject* obj, bool ignoreLocks) {
 
     assert(objects.size() == getChildItems().size());
     emit si_objectRemoved(obj);
+    
+    delete obj;
 }
 
 
@@ -303,9 +382,7 @@ void Document::initModLocks(const QString& instanceModLockDesc, bool loaded) {
     }
 
     // must be locked for modifications if not document format does not support writes
-    DocumentFormatConstraints c;
-    c.mustSupportWrite = true;
-    if (!df->checkConstraints(c)) {
+    if (!df->checkFlags(DocumentFormatFlag_SupportWriting)) {
         modLocks[DocumentModLock_FORMAT_AS_CLASS] = new StateLock(tr("document_format_does_not_support_writes"));
         lockState(modLocks[DocumentModLock_FORMAT_AS_CLASS]);
     }
@@ -324,7 +401,7 @@ void Document::setName(const QString& newName) {
     emit si_nameChanged();
 }
 
-void Document::setURL(const QString& newUrl) {
+void Document::setURL(const GUrl& newUrl) {
     assert(!isLoaded() || !isStateLocked());
     if (url == newUrl) {
         return;
