@@ -15,7 +15,6 @@
 #include <gobjects/GObjectTypes.h>
 #include <gobjects/UnloadedObject.h>
 
-#define RELATED_OBJECTS_KEY "related_objs"
 
 namespace GB2 {
 
@@ -128,7 +127,7 @@ bool GObject::isUnloaded() const {
 
 GObjectReference::GObjectReference(const GObject* obj, bool deriveLoadedType) {
     assert(obj!=NULL && obj->getDocument()!=NULL);
-    docUrl = obj->getDocument()->getURL();
+    docUrl = obj->getDocument()->getURLString();
     objName = obj->getGObjectName();
     if (obj->isUnloaded() && deriveLoadedType) {
         const UnloadedObject* uo = qobject_cast<const UnloadedObject*>(obj);
