@@ -32,9 +32,18 @@ public:
 
     bool operator ==(const GObjectReference& o) const;
 
-    QString     docUrl;
+	/** GObject reference keeps only string path of the document url. 
+	    This must be enough to find document in the project 
+	    while allows not to keep a complete url data here (for example username/password, etc...)
+	*/
+    QString		docUrl;
+
+	/** The name of the object */
     QString     objName;
+
+	/** The type of the object */
     GObjectType objType;
+
 private:
     static bool registerMeta;
 };
@@ -52,6 +61,8 @@ public:
 
     bool operator ==(const GObjectRelation& o) const;
 
+	const QString& getDocURL() const {return ref.docUrl;}
+
     GObjectReference ref;
     QString         role;
     QString         data;
