@@ -20,27 +20,26 @@ const IOAdapterId BaseIOAdapters::LOCAL_FILE("local_file");
 const IOAdapterId BaseIOAdapters::GZIPPED_LOCAL_FILE("local_file_gzip");
 const IOAdapterId BaseIOAdapters::HTTP_FILE( "http_file" );
 const IOAdapterId BaseIOAdapters::GZIPPED_HTTP_FILE( "http_file_gzip" );
-const IOAdapterId BaseIOAdapters::MEMORY_BUF( "memory_buffer" );
+const IOAdapterId BaseIOAdapters::VFS_FILE( "memory_buffer" );
 
 
-static bool isHyperLink( const QString & str ) {
-    return str.startsWith("http://") || str.startsWith("https://");
-}
-
-IOAdapterId BaseIOAdapters::url2io(const QString& url) {
-    if( isHyperLink(url) ) {
-        if( url.endsWith(".gz") ) {
+IOAdapterId BaseIOAdapters::url2io(const GUrl& url) {
+    if( url.isVFSFile() ) {
+        return BaseIOAdapters::VFS_FILE;
+    }
+    if( url.isHyperLink() ) {
+        if( url.lastFileSuffix() == "gz") {
             return BaseIOAdapters::GZIPPED_HTTP_FILE;
         }
         return BaseIOAdapters::HTTP_FILE;
     }
-    if( url.endsWith(".gz") ) {
+    if( url.lastFileSuffix() == "gz") {
         return BaseIOAdapters::GZIPPED_LOCAL_FILE;
     }
     return BaseIOAdapters::LOCAL_FILE;
 }
 
-QByteArray BaseIOAdapters::readFileHeader(const QString& url, int size) {
+QByteArray BaseIOAdapters::readFileHeader(const GUrl& url, int size) {
     QByteArray data;
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(url));
     std::auto_ptr<IOAdapter> adapter(iof->createIOAdapter());
@@ -81,64 +80,6 @@ QByteArray BaseIOAdapters::readFileHeader( IOAdapter* io, int sz ) {
     return data;
 }
 
-QUrl BaseIOAdapters::str2url( const QString& str )
-{
-    if (str.startsWith("http://") || str.startsWith("https://") || str.startsWith("file://")) {
-        return str;
-    } else {
-        return QUrl("file:///" + QFileInfo(str).absoluteFilePath());
-    }
-}
-
-QList<QUrl> BaseIOAdapters::str2urlList( const QStringList& lst )
-{
-    QList<QUrl> urls;
-    for (int i = 0; i < lst.size(); ++i) {
-        urls << str2url(lst.at(i));
-    }
-    return urls;
-}
-
-#if 0
-qint64 IOAdapter::readUntil(char* buff, qint64 maxSize, 
-							const QBitArray& readTerminators, 
-							TerminatorHandling th,  bool* terminatorFound) 
-{
-	int i = 0;
-	for(; i < maxSize; i++) {
-		char c;
-		bool eof = !getChar(&c);
-		if (eof) {
-			break;
-		}
-		if (readTerminators[(uchar)c]) {
-			if (terminatorFound!=NULL) {
-				*terminatorFound = true;
-			}
-			if (th == Term_Include) {
-				buff[i] = c;
-				while (++i < maxSize) {
-					eof = !getChar(&c);
-					if (eof) {
-						break;
-					}
-					if (!readTerminators[(uchar)c]) {
-						break;
-					}
-					buff[i] = c;
-				}
-			} 
-			if (!eof) {
-				//f->ungetChar(c);
-				skip(-1);
-			}
-			break;
-		}
-		buff[i] = c;
-	}
-	return i;
-}
-#else
 qint64 IOAdapter::readUntil(char* buf, qint64 maxSize, 
 							const QBitArray& readTerminators, 
 							TerminatorHandling th,  bool* terminatorFound) 
@@ -218,6 +159,4 @@ qint64 IOAdapter::readLine( char* buff, qint64 maxSize, bool* terminatorFound /*
     return len;
 }
 
-#endif
-
 }//namespace
