@@ -11,7 +11,8 @@
 #ifndef _GB2_IOADAPTER_H_
 #define _GB2_IOADAPTER_H_
 
-#include "core_api.h"
+#include <core_api/core_api.h>
+#include <core_api/GUrl.h>
 
 #include <QtCore/QtCore>
 
@@ -37,7 +38,7 @@ public:
 
 	virtual bool isIOModeSupported(IOAdapterMode m) const = 0;
 
-    virtual TriState exists(const QString& url) const {Q_UNUSED(url); return TriState_Unknown;}
+    virtual TriState isResourceAvailable(const GUrl& url) const = 0;
 
 };
 
@@ -57,7 +58,7 @@ public:
 
 	IOAdapterFactory* getFactory() const {return factory;}
 
-	virtual bool open(const QString& url, IOAdapterMode m) = 0;
+	virtual bool open(const GUrl& url, IOAdapterMode m) = 0;
 	
 	virtual bool isOpen() const = 0;
 
@@ -101,7 +102,9 @@ public:
     
     virtual qint64 bytesRead() const { return -1; }
     
-    virtual QString getUrl() const { return QString::null; }
+    virtual GUrl getURL() const = 0;
+	
+	virtual QString toString() const {return getURL().getURLString();}
     
 private:
 	IOAdapterFactory* factory;
@@ -126,13 +129,11 @@ public:
 	static const IOAdapterId GZIPPED_LOCAL_FILE;
     static const IOAdapterId HTTP_FILE;
     static const IOAdapterId GZIPPED_HTTP_FILE;
-    static const IOAdapterId MEMORY_BUF;
+    static const IOAdapterId VFS_FILE;
 
-    static QUrl str2url(const QString& str);
-    static QList<QUrl> str2urlList(const QStringList& lst);
+    static IOAdapterId url2io(const GUrl& url);
 
-    static IOAdapterId url2io(const QString& url);
-    static QByteArray readFileHeader(const QString& url, int size = 256);
+	static QByteArray readFileHeader(const GUrl& url, int size = 256);
     
     // io - opened ioadapter. before and after the call pos in file the same
     static QByteArray readFileHeader( IOAdapter* io, int size = 256 );
