@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -9,9 +9,11 @@
 *****************************************************************/
 
 #include "Log.h"
+#include "Timer.h"
 
 namespace GB2 {
 
+
 LogServer::LogServer() {
 	qRegisterMetaType<LogMessage>("LogMessage");
 }
@@ -27,8 +29,10 @@ LogCategory::LogCategory(const QString& name) : categoryName(name) {
 }
 
 LogCategory::~LogCategory() {
-	LogServer* s = LogServer::getInstance();
-	s->categories.removeOne(this);
+// TODO possible race condition at shutdown -> log service could already be destroyed
+//	LogServer* s = LogServer::getInstance();
+//	s->categories.removeOne(this);
+    categoryName.clear();
 }
 
 void LogCategory::message(LogLevel level, const QString& msg)  {
@@ -36,4 +40,10 @@ void LogCategory::message(LogLevel level, const QString& msg)  {
 	LogServer::getInstance()->message(m);
 }
 
+LogMessage::LogMessage(const QString& cat, LogLevel l, const QString& m) 
+: category(cat), level(l), text(m), time(GTimer::currentTimeMicros()) 
+{
+}
+
+
 }//namespace
