@@ -289,9 +289,8 @@ QString GObjectViewUtils::genUniqueStateName(const QString& stateName) {
 }
 
 QString GObjectViewUtils::genUniqueViewName(const Document* doc, const GObject* obj) {
-	QFileInfo fi(doc->getURL());
 	QString objName = obj->getGObjectName();
-	QString viewName = fi.baseName() + " " + objName;
+	QString viewName = doc->getURL().baseFileName() + " " + objName;
 	return genUniqueViewName(viewName);
 }
 
@@ -420,12 +419,18 @@ void GObjectViewWindowContext::init() {
 
 GObjectViewWindowContext::~GObjectViewWindowContext() {
     assert(initialzed);
-    foreach(QList<QObject*> list, viewResources.values()) {
-        foreach(QObject* a, list) {
-            delete a;
+    MWMDIManager* mdi = AppContext::getMainWindow()->getMDIManager();
+    if (mdi == NULL) { //TODO: disconnect context on view removal and assert (mdi!=NULL) here.
+        return;
+    }
+    foreach(MWMDIWindow* w, mdi->getWindows()) {
+        GObjectViewWindow* ow = qobject_cast<GObjectViewWindow*>(w);
+        if (ow == NULL || (!id.isEmpty() && ow->getViewFactoryId() != id)) {
+            continue;
         }
+        GObjectView* v = ow->getObjectView();
+        disconnectView(v);
     }
-    viewResources.clear();
 }
 
 void GObjectViewWindowContext::sl_windowAdded(MWMDIWindow* w) {
@@ -450,6 +455,10 @@ void GObjectViewWindowContext::sl_windowClosing(MWMDIWindow* w) {
         return;
     }
     GObjectView* v = ow->getObjectView();
+    disconnectView(v);
+}
+
+void GObjectViewWindowContext::disconnectView(GObjectView* v) {
     QList<QObject*> resources = viewResources[v];
     foreach(QObject* a, resources) {
         delete a;
@@ -467,16 +476,30 @@ void GObjectViewWindowContext::addViewResource(GObjectView* v, QObject* r) {
     viewResources[v] = resources;
 }
 
+
 QList<GObjectViewAction*> GObjectViewWindowContext::getViewActions(GObjectView* v) const {
-    QList<GObjectViewAction*> res;
+    QList<GObjectViewAction*> actions;
     QList<QObject*> resources = viewResources[v];
     foreach(QObject* obj, resources) {
         GObjectViewAction* a = qobject_cast<GObjectViewAction*>(obj);
         if (a!=NULL) {
-            res.append(a);
+            actions.append(a);
         }
     }
-    return res;
+    return actions;
+}
+
+//////////////////////////////////////////////////////////////////////////
+// GObjectViewAction
+void GObjectViewAction::addToMenuWithOrder(QMenu* menu) {
+	foreach(QAction* action, menu->actions()) {
+		GObjectViewAction* viewAction = qobject_cast<GObjectViewAction*>(action);
+		if (viewAction != NULL && viewAction->getActionOrder() > actionOrder) {
+			menu->insertAction(action, this);
+			return;
+		}
+	}
+	menu->addAction(this);
 }
 
 }//namespace
