@@ -17,6 +17,7 @@
 #include <QtCore/QMap>
 #include <QtCore/QVariantMap>
 #include <QtGui/QAction>
+#include <QtGui/QMenu>
 
 namespace GB2 {
 
@@ -112,7 +113,7 @@ class GB2_COREAPI_EXPORT GObjectView : public QObject {
 	Q_OBJECT
 public:
 	GObjectView(GObjectViewFactoryId factoryId, const QString& viewName, QObject* p=NULL);
-    
+        
     GObjectViewFactoryId getFactoryId() const {return factoryId;}
     
     const QString& getName() const {return viewName;}
@@ -155,7 +156,7 @@ protected:
 protected:
     virtual void _removeObject(GObject* o);
 	virtual QWidget* createWidget() = 0;
-
+    
 signals:
 	void si_buildPopupMenu(GObjectView* v, QMenu* m);
 	void si_buildStaticMenu(GObjectView* v, QMenu* m);
@@ -262,13 +263,24 @@ public:
     static QList<GObjectViewState*> selectStates(GObjectViewFactory* f, const MultiGSelection& ms, const QList<GObjectViewState*>& states);
 };
 
+#define GObjectViewAction_DefaultOrder 100
 class GB2_COREAPI_EXPORT GObjectViewAction : public QAction {
     Q_OBJECT
 public:
-    GObjectViewAction(QObject* p, GObjectView* v, const QString& text):  QAction(text, p), view(v) {}
-    GObjectView* getObjectView() const {return view;}
+    GObjectViewAction(QObject* p, GObjectView* v, const QString& text, int order = GObjectViewAction_DefaultOrder)
+		:  QAction(text, p), view(v), actionOrder(order) {}
+    
+	GObjectView* getObjectView() const {return view;}
+	
+	int getActionOrder() const {return actionOrder;}
+
+	void addToMenuWithOrder(QMenu* menu);
+
 private:
     GObjectView* view;
+	
+	// Action order can be used to set-up relative action position in GUI elements
+	int actionOrder;
 };
 
 
@@ -279,7 +291,6 @@ public:
 
     virtual void onObjectAdded(GObjectView* v, GObject* obj) {Q_UNUSED(v); Q_UNUSED(obj);}
     virtual void onObjectRemoved(GObjectView* v, GObject* obj) {Q_UNUSED(v); Q_UNUSED(obj);}
-
 };
 
 class GB2_COREAPI_EXPORT GObjectViewWindowContext : public QObject, public GObjectViewObjectHandler {
@@ -287,7 +298,7 @@ class GB2_COREAPI_EXPORT GObjectViewWindowContext : public QObject, public GObje
 
 public:
     GObjectViewWindowContext(QObject* p, const GObjectViewFactoryId& id);
-    ~GObjectViewWindowContext();
+    virtual ~GObjectViewWindowContext();
     void init();
 
     QList<GObjectViewAction*> getViewActions(GObjectView* view) const;
@@ -306,6 +317,8 @@ protected slots:
 
 protected:    
     virtual void buildMenu(GObjectView* v, QMenu* m){Q_UNUSED(v); Q_UNUSED(m);}
+    virtual void disconnectView(GObjectView* v);
+
 
     QMap<GObjectView*, QList<QObject*> > viewResources;
     GObjectViewFactoryId id;
