@@ -16,6 +16,8 @@
 #include "ServiceTypes.h"
 #include "StateLockableDataModel.h"
 
+#define CURRENT_PROJECT_VERSION "1.0"
+
 namespace GB2 {
 
 class GObjectViewState;
@@ -30,7 +32,8 @@ class Task;
 class GB2_COREAPI_EXPORT ProjectLoader  : public QObject {
 public:
 	virtual Task* openProjectTask(const QString& file, bool closeActiveProject) = 0;
-    virtual Task* openProjectTask(const QList<QUrl>& urls, bool closeActiveProject) = 0;
+    virtual Task* openProjectTask(const QList<GUrl>& urls, bool closeActiveProject) = 0;
+    virtual Project* createProject(const QString& name, const QString& url, QList<Document*>& documents, QList<GObjectViewState*>& states) = 0;
 };
 
 enum SaveProjectTaskKind {
@@ -77,6 +80,8 @@ public:
 
 	Q_INVOKABLE virtual Document* findDocumentByURL(const QString& url) const  = 0;
 
+	Q_INVOKABLE virtual Document* findDocumentByURL(const GUrl& url) const  = 0;
+
 	virtual const QList<GObjectViewState*>& getGObjectViewStates() const =0;
 
 	virtual void addGObjectViewState(GObjectViewState* s) = 0;
