@@ -11,24 +11,13 @@
 #ifndef _GB2_SW_RESULT_FILTER_REGISTRY_H_
 #define _GB2_SW_RESULT_FILTER_REGISTRY_H_
 
-#include <QList>
-#include <QString>
-#include <QStringList>
-
-#include <QMutex>
+#include <QtCore/QStringList>
+#include <QtCore/QMutex>
 
 #include <util_smith_waterman/SmithWatermanResultFilters.h>
 
-namespace GB2 {
 
-struct NamedSWResultFilter {
-    NamedSWResultFilter():
-        id_filter(""), filter(0) 
-    {}
-    
-    QString id_filter;
-    SmithWatermanResultFilter* filter;
-};
+namespace GB2 {
 
 class GB2_COREAPI_EXPORT SWResultFilterRegistry: public QObject {
     Q_OBJECT
@@ -36,18 +25,20 @@ public:
     SWResultFilterRegistry(QObject* pOwn = 0);
     ~SWResultFilterRegistry();
     
-    QStringList getFiltersNames() const;
-    SmithWatermanResultFilter* getFilterByName(const QString& id_filter);
-    bool hadRegistered(const QString& id_filter);
-    bool registerFilter(SmithWatermanResultFilter* filter, 
-                        const QString& id_filter);
+    QStringList getFiltersIds() const;
+    
+    SmithWatermanResultFilter* getFilter(const QString& id);
+    
+    bool isRegistered(const QString& id) const;
+    
+    bool registerFilter( SmithWatermanResultFilter* filter );
+
+    const QString& getDefaultFilterId() {return defaultFilterId;}
+
 private:
-
-    QList<NamedSWResultFilter>::iterator findFilter(const QString& id_filter);
-
-    QList<NamedSWResultFilter> filter_list;
-
     QMutex mutex;
+    QHash<QString, SmithWatermanResultFilter*> filters;   
+    QString defaultFilterId;
 };
 
 } // namespace
