@@ -23,11 +23,11 @@ namespace GB2 {
 class SecStructPredictTaskFactory;
 class SecStructPredictTask;
 
-class GB2_COREAPI_EXPORT SecStructPredcitAlgRegistry : public QObject {
+class GB2_COREAPI_EXPORT SecStructPredictAlgRegistry : public QObject {
 	Q_OBJECT
 public:	
-	SecStructPredcitAlgRegistry(QObject* pOwn = 0);
-	~SecStructPredcitAlgRegistry();
+	SecStructPredictAlgRegistry(QObject* pOwn = 0);
+	~SecStructPredictAlgRegistry();
 	bool registerAlgorithm(SecStructPredictTaskFactory* alg, const QString& algId);
     bool hadRegistered(const QString& algId);
     SecStructPredictTaskFactory* getAlgorithm(const QString& algId);
@@ -36,8 +36,8 @@ private:
 	QMutex mutex;
 	QMap<QString, SecStructPredictTaskFactory*> algMap;
     // Copy prohibition
-    SecStructPredcitAlgRegistry(const SecStructPredcitAlgRegistry& m);
-	SecStructPredcitAlgRegistry& operator=(const SecStructPredcitAlgRegistry& m);
+    SecStructPredictAlgRegistry(const SecStructPredictAlgRegistry& m);
+	SecStructPredictAlgRegistry& operator=(const SecStructPredictAlgRegistry& m);
 };
 
 } // namespace
