@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -16,8 +16,8 @@
 namespace GB2 {
 
 
-Service::Service(Plugin* p, ServiceType t, const QString& _name, const QString& _desc, const QList<ServiceType>& _parentServices)
-: QObject(p), plugin(p), type(t), name(_name), description(_desc), parentServices(_parentServices), state(ServiceState_Disabled_New)
+Service::Service(ServiceType t, const QString& _name, const QString& _desc, const QList<ServiceType>& _parentServices, ServiceFlags f)
+: type(t), name(_name), description(_desc), parentServices(_parentServices), state(ServiceState_Disabled_New), flags(f)
 {
 }
 
