@@ -11,7 +11,7 @@
 #ifndef _GB2_SMITH_WATERMAN_ALG_REGISTRY_H_
 #define _GB2_SMITH_WATERMAN_ALG_REGISTRY_H_
 
-#include <QList>
+#include <QHash>
 #include <QString>
 #include <QMutex>
 #include <QObject>
@@ -19,12 +19,8 @@
 #include <core_api/core_api.h>
 #include <util_smith_waterman/SmithWatermanTaskFactory.h>
 
-namespace GB2 {
 
-struct NamedSmithWatermanTaskFactory {
-	QString alg_id;
-	SmithWatermanTaskFactory* alg;
-};
+namespace GB2 {
 
 class GB2_COREAPI_EXPORT SmithWatermanTaskFactoryRegistry: public QObject {
 	Q_OBJECT
@@ -32,18 +28,14 @@ public:
 	SmithWatermanTaskFactoryRegistry(QObject* pOwn = 0);
 	~SmithWatermanTaskFactoryRegistry();
 
-	bool registerAlgorithm(SmithWatermanTaskFactory* alg, const QString& alg_id);
-    bool hadRegistered(const QString& alg_id);
-	SmithWatermanTaskFactory* getAlgorithm(const QString& alg_id);
-	QStringList getListAlgNames();
+	bool registerFactory(SmithWatermanTaskFactory* factory, const QString& factoryId);
+    bool hadRegistered(const QString& factoryId);
+	SmithWatermanTaskFactory* getFactory(const QString& factoryId);
+	QStringList getListFactoryNames();
+
 private:
-	QMutex mutex;
-	QList<NamedSmithWatermanTaskFactory> alg_list;
-
-	SmithWatermanTaskFactoryRegistry(const SmithWatermanTaskFactoryRegistry& m);
-	SmithWatermanTaskFactoryRegistry& operator=(const SmithWatermanTaskFactoryRegistry& m);
-
-	QList<NamedSmithWatermanTaskFactory>::iterator findAlgorithm(const QString& alg_id);
+    QMutex mutex;
+	QHash<QString, SmithWatermanTaskFactory*> factories;
 };
 
 } // namespace
