@@ -68,7 +68,7 @@ public:
 
 #define MAX_PARALLEL_SUBTASKS_AUTO   0
 #define MAX_PARALLEL_SUBTASKS_SERIAL 1
-
+    
 enum TaskFlag {
     TaskFlag_None = 0,
 
@@ -185,7 +185,7 @@ public:
 
     // When called for a finished task it must deallocate all resources it keeps.
     // ATTENTION: this method WILL NOT be called by Task Scheduler automatically.
-    // It is guaranteed that only tests runned by TestRunnerTask will be cleaned up.
+    // It is guaranteed that only tests run by TestRunnerTask will be cleaned up.
     // So, if any task provides 'cleanup' method, it still MUST correctly clean up 
     // its resources in destructor.
     virtual void cleanup();
@@ -210,6 +210,8 @@ public:
 
     virtual void setReportingEnabled(bool v) {assert(isReportingSupported()); setFlag(TaskFlag_ReportingIsEnabled, v);}
 
+    virtual void setNoAutoDelete( bool v ) { setFlag( TaskFlag_NoAutoDelete, v ); }
+
     virtual QString generateReport() const {assert(0); return QString();}
    
     float getSubtaskProgressWeight() const {return progressWeightAsSubtask;}
@@ -291,6 +293,8 @@ public:
 
     virtual const QList<Task*>& getTopLevelTasks() const = 0;
 
+    virtual Task * getTopLevelTaskById( qint64 id ) const = 0;
+
     virtual QDateTime estimatedFinishTime(Task*) const = 0;
 
     virtual void cancelAllTasks() = 0;
