@@ -83,7 +83,7 @@ void UserAppsSettings::setVisualStyle(const QString& newStyle) {
 
 QString UserAppsSettings::getDownloadDirPath() const
 {
-    return AppContext::getSettings()->getValue(SETTINGS_ROOT + DOWNLOAD_DIR, QDir::homePath()+"/UGENE_downloaded").toString();
+    return AppContext::getSettings()->getValue(SETTINGS_ROOT + DOWNLOAD_DIR, QDir::homePath()+"/.UGENE_downloaded").toString();
 }
 
 void UserAppsSettings::setDownloadDirPath(const QString& newPath) const
