@@ -22,6 +22,8 @@ namespace GB2 {
 
 
 class GB2_COREAPI_EXPORT Qualifier {
+    friend QDataStream& operator>>(QDataStream& dataStream, Qualifier& q);
+    friend QDataStream& operator<<(QDataStream& dataStream, const Qualifier& q);
 public:
     Qualifier(){}
     Qualifier(const QString& _name, const QString& _val) : name(_name), val(_val) {}
@@ -59,6 +61,12 @@ public:
 
 typedef QSharedDataPointer<AnnotationData> SharedAnnotationData;
 
+QDataStream& operator>>(QDataStream& dataStream, TriState& state);
+QDataStream& operator<<(QDataStream& dataStream, const TriState& state);
+QDataStream& operator>>(QDataStream& dataStream, Qualifier& q);
+QDataStream& operator<<(QDataStream& dataStream, const Qualifier& q);
+QDataStream& operator>>(QDataStream& dataStream, AnnotationData& data);
+QDataStream& operator<<(QDataStream& dataStream, const AnnotationData& data);
 
 AnnotationData& AnnotationData::operator= ( const AnnotationData & a ) { 
     name = a.name; 
