@@ -15,7 +15,7 @@ namespace GB2 {
 
 static LogCategory log(ULOG_CAT_IO);
     
-QString BioStruct3D::MoleculeAnnotationTag("chain_");
+QString BioStruct3D::MoleculeAnnotationTag("chain_info");
 QString BioStruct3D::AlphaHelixAnnotationTag("alpha_helix");
 QString BioStruct3D::BetaStrandAnnotationTag("beta_strand");
 QString BioStruct3D::TurnAnnotationTag("turn");
@@ -81,9 +81,10 @@ void BioStruct3D::generateChainAnnotations()
     
     QMap<int, SharedMolecule>::iterator iter = moleculeMap.begin();
     while (iter != moleculeMap.end()) {
+        int length = iter.value()->residueMap.size();
         SharedAnnotationData sd( new AnnotationData);
-        sd->location.append(LRegion(0,0));
-        sd->name = BioStruct3D::MoleculeAnnotationTag + QString("%1").arg(iter.key()) + "_info";
+        sd->location.append(LRegion(0,length));
+        sd->name = BioStruct3D::MoleculeAnnotationTag;
         sd->qualifiers.append(Qualifier(ChainIdQualifierName, QString("%1").arg(iter.key()) ));
         sd->qualifiers.append(Qualifier(molNameQualifier, (*iter)->name));
         
