@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -12,12 +12,11 @@
 
 namespace GB2 {
     
-DNASequence::DNASequence(const QByteArray& s, DNAAlphabet* a) : seq(s), alphabet(a) {
-//    printf("created");
+DNASequence::DNASequence(const QString& name, const QByteArray& s, DNAAlphabet* a) : seq(s), alphabet(a) {
+    if (!name.isEmpty()) {
+        info.insert(DNAInfo::ID, name);
+    }
 }
 
-DNASequence::~DNASequence() {
-//    printf("removed");
-}
 
 } //namespace
