@@ -13,6 +13,7 @@
 
 #include <core_api/core_api.h>
 #include "DNAInfo.h"
+#include "DNAQuality.h"
 
 #include <QtCore/QByteArray>
 
@@ -23,16 +24,17 @@ class DNAAlphabet;
 class GB2_COREAPI_EXPORT DNASequence {
 public:
     DNASequence(const QString& name, const QByteArray& s = QByteArray(), DNAAlphabet* a = NULL);
-    DNASequence(const QByteArray& s = QByteArray(), DNAAlphabet* a = NULL) : seq(s), alphabet(a) {}
-    ~DNASequence();
-
+    DNASequence(const QByteArray& s = QByteArray(), DNAAlphabet* a = NULL) : seq(s), alphabet(a), quality(NULL) {}
+ 
     QVariantMap     info;
     QByteArray      seq;
     DNAAlphabet*    alphabet;
+    DNAQuality      quality;
 
     QString getName() const {return DNAInfo::getName(info);}
     bool isNull() const {return !alphabet && seq.length() == 0;}
     int length() const {return seq.length();}
+    bool hasQualityScores() const {return (!quality.isEmpty()); }
     const char* constData() const {return seq.constData();}
 };
 
