@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -14,6 +14,8 @@
 #include <core_api/core_api.h>
 
 #include <QtCore/QSet>
+#include <QtCore/QMap>
+#include <QtCore/QVector>
 #include <QtCore/QSharedData>
 
 namespace GB2 {
@@ -25,8 +27,10 @@ class GB2_COREAPI_EXPORT PhyTreeData : public QSharedData {
 public:
     PhyTreeData();
     PhyTreeData(const PhyTreeData& other);
-
+    ~PhyTreeData();
+    QList<const PhyNode*> collectNodes() const;
     void validate() const;
+	void print();
 
     PhyNode* rootNode;
 };
@@ -47,7 +51,10 @@ public:
 
     QString             name;
     QList<PhyBranch*>   branches;
-
+    bool equals(PhyNode* other);
+    void print(QList<PhyNode*>& nodes, int distance, int tab);
+    void dumpBranches() const;
+    ~PhyNode();
 };
 
 class GB2_COREAPI_EXPORT PhyBranch {
@@ -59,6 +66,11 @@ public:
     double   distance;
 };
 
+class GB2_COREAPI_EXPORT PhyTreeUtils {
+public:
+    static int getNumSeqsFromNode(const PhyNode *node, const QSet<QString>& names);
+};
+
 }//namespace
 
 #endif
