@@ -16,6 +16,7 @@
 #include <core_api/IOAdapter.h>
 #include <core_api/DNAAlphabet.h>
 #include <core_api/GObjectReference.h>
+#include <core_api/L10n.h>
 #include <datatype/DNAInfo.h>
 #include <gobjects/DNASequenceObject.h>
 #include <gobjects/GObjectTypes.h>
@@ -24,8 +25,6 @@
 #include <gobjects/TextObject.h>
 
 #include <util_text/TextUtils.h>
-#include <util_gui/GUIUtils.h>
-#include <memory>
 
 #include <time.h>
 
@@ -33,19 +32,18 @@
 
 namespace GB2 {
 
-ABIFormat::ABIFormat(QObject* p) : DocumentFormat(p)
+ABIFormat::ABIFormat(QObject* p) : DocumentFormat(p, DocumentFormatFlags(0), QStringList() << "ab1" << "abi" << "abif")
 {
 	formatName = tr("ABIF");
+    supportedObjectTypes+=GObjectTypes::SEQUENCE;
+    supportedObjectTypes+=GObjectTypes::CHROMATOGRAM;
 }
 
-QStringList ABIFormat::getSupportedDocumentFileExtensions() {
-	QStringList l;
-	l<<"ab1"<<"abi"<<"abif";
-	return l;
-}
+bool ABIFormat::checkRawData(const QByteArray& rawData) const {
+    const char* data = rawData.constData();
+    int size = rawData.size();
 
-bool ABIFormat::isDataFormatSupported(const char* data, int size) const {
-	if (size <= 4 || data[0]!='A' || data[1]!='B' || data[2]!='I' || data[3]!='F') {
+    if (size <= 4 || data[0]!='A' || data[1]!='B' || data[2]!='I' || data[3]!='F') {
         /*
         * Maybe we've got a file in MacBinary format in which case 
         * we'll have an extra offset 128 bytes to add.
@@ -56,53 +54,21 @@ bool ABIFormat::isDataFormatSupported(const char* data, int size) const {
             return false;
         }
 	}
-	return TextUtils::contains(TextUtils::BINARY, data, size);
+	bool hasBinaryBlocks = TextUtils::contains(TextUtils::BINARY, data, size);
+    return hasBinaryBlocks ? true : false;
 }
 
-bool ABIFormat::isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const {
-    Q_UNUSED(d); Q_UNUSED(op);
-    return (t == GObjectTypes::DNA_SEQUENCE || t == GObjectTypes::DNA_CHROMATOGRAM); 
-}
-
-
-bool ABIFormat::checkConstraints(const DocumentFormatConstraints& c) const {
-	foreach (GObjectType t, c.supportedObjectTypes) {
-		if (t!=GObjectTypes::DNA_SEQUENCE) {
-			return false;
-		}
-	}
-	if (c.checkRawData) {
-		return isDataFormatSupported(c.rawData.constData(), c.rawData.size());
-	}
-
-    if (c.mustSupportWrite) {
-        return false;
-    }
-    if( c.supportsStreamingRead ) {
-        return false;
-    }
-	return true;
-}
-
-Document* ABIFormat::loadExistingDocument(IOAdapterFactory* iof, const QString& url, TaskStateInfo& ti, const QVariantMap& fs) {
-    // read in the file
-    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-    bool ok = io->open(url, IOAdapterMode_Read);
-    if (!ok) {
-        ti.setError(Translations::errorOpeningFileRead(url));
-        return NULL;
-    }
+Document* ABIFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode) {
     QByteArray readBuff;
     QByteArray block(BUFF_SIZE, 0);
     quint64 len = 0;
     while ((len=io->readBlock(block.data(),BUFF_SIZE)) > 0) {
         readBuff.append(QByteArray(block.data(), len));
         if (readBuff.size()>CHECK_MB) {
-            ti.setError(Translations::errorFileTooLarge(url)); 
+            ti.setError(L10N::errorFileTooLarge(io->getURL())); 
             break;
         }
     }
-    io->close();
     if (ti.hasErrors()) {
         return NULL;
     }
@@ -111,9 +77,9 @@ Document* ABIFormat::loadExistingDocument(IOAdapterFactory* iof, const QString&
     sf.head = readBuff.constData();
     sf.pos = 0;
     sf.size = readBuff.size();
-    Document* doc = parseABI(&sf, iof, url, fs);
+    Document* doc = parseABI(&sf, io, fs);
     if (doc == NULL && !ti.hasErrors()) {
-        ti.setError(tr("Not a valid ABIF file: %1").arg(url));
+        ti.setError(tr("Not a valid ABIF file: %1").arg(io->toString()));
     }
     return doc;
 }
@@ -422,7 +388,7 @@ static void replace_nl(char *string) {
     }
 }
 
-Document* ABIFormat::parseABI(SeekableBuf* fp, IOAdapterFactory* iof, const QString& url, const QVariantMap& fs) {
+Document* ABIFormat::parseABI(SeekableBuf* fp, IOAdapter* io, const QVariantMap& fs) {
 
     float fspacing;		/* average base spacing */
     uint numPoints, numBases;
@@ -849,7 +815,7 @@ skip_bases:
     DNAChromatogramObject* chromObj = new DNAChromatogramObject(cd, "Chromatogram");
     objects.append(chromObj);
     objects.append(new TextObject(sequenceComment, "Info"));
-    Document* doc = new Document(this, iof, url, objects, fs);
+    Document* doc = new Document(this, io->getFactory(), io->getURL(), objects, fs);
     chromObj->addObjectRelation(GObjectRelation(GObjectReference(seqObj), GObjectRelationRole::SEQUENCE));
     return doc;
 }
