@@ -28,18 +28,12 @@ public:
 
 	virtual const QString& getFormatName() const {return formatName;}
 
-	virtual QStringList getSupportedDocumentFileExtensions();
-
-	virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
-
-	virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-	    
-    virtual bool isDataFormatSupported(const char* data, int size) const;
-
-	virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
+    virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
 
+    virtual bool checkRawData(const QByteArray& rawData) const;
+    
 private:
-    Document* parseABI(SeekableBuf*, IOAdapterFactory* io, const QString& url, const QVariantMap& fs);
+    Document* parseABI(SeekableBuf*, IOAdapter* io, const QVariantMap& fs);
 	QString formatName;
 };
 
