@@ -14,6 +14,7 @@
 #include <core_api/IOAdapter.h>
 #include <core_api/AppContext.h>
 #include <core_api/Log.h>
+#include <core_api/L10n.h>
 
 #include <gobjects/GObjectTypes.h>
 #include <gobjects/BioStruct3DObject.h>
@@ -22,9 +23,7 @@
 #include <gobjects/GObjectRelationRoles.h>
 #include <gobjects/GObjectUtils.h>
 #include <util_text/TextUtils.h>
-#include <util_gui/GUIUtils.h>
 #include <time.h>
-#include <memory>
 
 #include "DocumentFormatUtils.h"
 #include "ASNFormat.h"
@@ -39,77 +38,34 @@ static LogCategory log(ULOG_CAT_IO);
 static LogCategory logPerf(ULOG_CAT_PERFORMANCE);
 
 
-ASNFormat::ASNFormat( QObject* p ) : DocumentFormat(p)
+ASNFormat::ASNFormat( QObject* p ) : DocumentFormat(p, DocumentFormatFlag(0), QStringList() << "prt")
 {
     formatName = tr("MMDB");
-//    localDictionary = NULL;
+    supportedObjectTypes+=GObjectTypes::BIOSTRUCTURE_3D;
+    supportedObjectTypes+=GObjectTypes::SEQUENCE;
+    supportedObjectTypes+=GObjectTypes::ANNOTATION_TABLE;
 }
 
-QStringList ASNFormat::getSupportedDocumentFileExtensions()
-{
-    QStringList l;
-    l << "prt";
-    return l;
-}
 
-bool ASNFormat::isDataFormatSupported( const char* data, int size ) const
-{
+bool ASNFormat::checkRawData(const QByteArray& rawData) const {
     static const char* formatTag = "Ncbi-mime-asn1 ::= strucseq";
     
-    QByteArray rawData(data, size);
     if (!rawData.startsWith(formatTag)) {
         return false;
     }
 
-    return !TextUtils::contains(TextUtils::BINARY, data, size);
+    bool textOnly = !TextUtils::contains(TextUtils::BINARY, rawData.constData(), rawData.size());
+    return textOnly ? true : false;
 }
 
-bool ASNFormat::isObjectOpSupported( const Document* d , DocumentFormat::DocObjectOp op, GObjectType t ) const
-{
-    Q_UNUSED(d); Q_UNUSED(op);
-    return (t == GObjectTypes::BIOSTRUCTURE_3D); 
-}
 
-bool ASNFormat::checkConstraints( const DocumentFormatConstraints& c ) const
-{
-    foreach (GObjectType t, c.supportedObjectTypes) {
-        if ((t!=GObjectTypes::BIOSTRUCTURE_3D) && (t!=GObjectTypes::DNA_SEQUENCE) && (t!=GObjectTypes::ANNOTATION_TABLE))  {
-            return false;
-        }
-    }
-
-    if (c.mustSupportWrite) {
-        return false;
-    }
-
-    if (c.checkRawData) {
-        return isDataFormatSupported(c.rawData.constData(), c.rawData.size());
-    }
-    if( c.supportsStreamingRead ) {
-        return false;
-    }
-
-    return true;
-}
-
-Document* ASNFormat::loadExistingDocument( IOAdapterFactory* iof, const QString& url, TaskStateInfo& ti, const QVariantMap& fs )
-{
-     std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
- 
-     bool ok = io->open(url, IOAdapterMode_Read);
-     if (!ok) {
-         ti.setError(Translations::errorOpeningFileRead(url));
-        return NULL;
-    }
-    
+Document* ASNFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode) {
     BioStruct3D bioStruct;
-
-
     
-    AsnParser asnParser(io.get(), ti);
-    log.trace("Parsing: " +url);
+    AsnParser asnParser(io, ti);
+    log.trace("ASN: Parsing: " +io->toString());
     AsnNode* rootElem = asnParser.loadAsnTree();
-    log.trace(QString("ASN tree for %1 was built").arg(url));
+    log.trace(QString("ASN tree for %1 was built").arg(io->toString()));
     ti.progress = 30;
     if (rootElem != NULL) {
         BioStructLoader ldr;
@@ -121,20 +77,20 @@ Document* ASNFormat::loadExistingDocument( IOAdapterFactory* iof, const QString&
         ldr.loadBioStructFromAsnTree(rootElem, bioStruct, ti);
     }
     ti.progress = 80;
-    io->close();
+    
     if (ti.hasErrors() || ti.cancelFlag) {
         return NULL;
     }
-    log.trace(QString("BioStruct3D loaded from ASN tree (%1)").arg(url));
+    log.trace(QString("BioStruct3D loaded from ASN tree (%1)").arg(io->toString()));
     delete rootElem;
     
     bioStruct.calcCenterAndMaxDistance();
     bioStruct.generateAnnotations();
     ti.progress = 90;
     
-    Document* doc = PDBFormat::createDocumentFromBioStruct3D(bioStruct, this, iof, url, ti, fs);
+    Document* doc = PDBFormat::createDocumentFromBioStruct3D(bioStruct, this, io->getFactory(), io->toString(), ti, fs);
     
-    log.trace("Parsing finished: " + url);
+    log.trace("ASN Parsing finished: " + io->toString());
     ti.progress = 100;
 
     return doc;
@@ -199,11 +155,11 @@ void ASNFormat::BioStructLoader::loadBioStructPdbId( AsnNode* rootNode, BioStruc
 void ASNFormat::BioStructLoader::loadBioStructFromAsnTree( AsnNode* rootNode, BioStruct3D& struc, TaskStateInfo& ti )
 {
     /*
-        id			    SEQUENCE OF Biostruc-id,
-        descr			SEQUENCE OF Biostruc-descr OPTIONAL,
-        chemical-graph	Biostruc-graph,
-        features		SEQUENCE OF Biostruc-feature-set OPTIONAL,
-        model			SEQUENCE OF Biostruc-model OPTIONAL }
+        id              SEQUENCE OF Biostruc-id,
+        descr           SEQUENCE OF Biostruc-descr OPTIONAL,
+        chemical-graph  Biostruc-graph,
+        features        SEQUENCE OF Biostruc-feature-set OPTIONAL,
+        model           SEQUENCE OF Biostruc-model OPTIONAL }
     */
 
     try {
@@ -267,25 +223,25 @@ void ASNFormat::BioStructLoader::loadModelCoordsFromNode( AsnNode* modelNode, At
 {
     /*
         Atomic-coordinates ::= SEQUENCE {
-            number-of-points	INTEGER,
-            atoms			Atom-pntrs,
-            sites			Model-space-points,
-            temperature-factors	Atomic-temperature-factors OPTIONAL,
-            occupancies		Atomic-occupancies OPTIONAL, 
-            alternate-conf-ids	Alternate-conformation-ids OPTIONAL,
-            conf-ensembles		SEQUENCE OF Conformation-ensemble OPTIONAL } 
+            number-of-points    INTEGER,
+            atoms           Atom-pntrs,
+            sites           Model-space-points,
+            temperature-factors Atomic-temperature-factors OPTIONAL,
+            occupancies     Atomic-occupancies OPTIONAL, 
+            alternate-conf-ids  Alternate-conformation-ids OPTIONAL,
+            conf-ensembles      SEQUENCE OF Conformation-ensemble OPTIONAL } 
         
         Model-space-points ::= SEQUENCE {
-            scale-factor		INTEGER,
-            x			SEQUENCE OF INTEGER,	
-            y			SEQUENCE OF INTEGER,
-            z			SEQUENCE OF INTEGER }  
+            scale-factor        INTEGER,
+            x           SEQUENCE OF INTEGER,    
+            y           SEQUENCE OF INTEGER,
+            z           SEQUENCE OF INTEGER }  
 
         Atom-pntrs ::= SEQUENCE {
-            number-of-ptrs		INTEGER,
-            molecule-ids		SEQUENCE OF Molecule-id,
-            residue-ids		    SEQUENCE OF Residue-id,
-            atom-ids		    SEQUENCE OF Atom-id } 
+            number-of-ptrs      INTEGER,
+            molecule-ids        SEQUENCE OF Molecule-id,
+            residue-ids         SEQUENCE OF Residue-id,
+            atom-ids            SEQUENCE OF Atom-id } 
     
     */
 
@@ -346,18 +302,18 @@ const StdResidue ASNFormat::BioStructLoader::loadResidueFromNode(AsnNode* resNod
 {
     /*
         Residue ::= SEQUENCE {
-            id			Residue-id,
-            name			VisibleString OPTIONAL,
-            residue-graph		Residue-graph-pntr }
+            id          Residue-id,
+            name            VisibleString OPTIONAL,
+            residue-graph       Residue-graph-pntr }
         
         Residue-graph-pntr ::= CHOICE {
-            local			Residue-graph-id,
-            biostruc		Biostruc-graph-pntr,
-            standard		Biostruc-residue-graph-set-pntr } 
+            local           Residue-graph-id,
+            biostruc        Biostruc-graph-pntr,
+            standard        Biostruc-residue-graph-set-pntr } 
 
         Biostruc-residue-graph-set-pntr ::= SEQUENCE {
-            biostruc-residue-graph-set-id	Biostruc-id,
-            residue-graph-id		Residue-graph-id }  
+            biostruc-residue-graph-set-id   Biostruc-id,
+            residue-graph-id        Residue-graph-id }  
 
     */
 
@@ -387,15 +343,15 @@ void ASNFormat::BioStructLoader::loadMoleculeFromNode(AsnNode* moleculeNode, Mol
 
     /*
         Molecule-graph ::= SEQUENCE {
-            id			Molecule-id,
-            descr			SEQUENCE OF Biomol-descr OPTIONAL,
-            seq-id			Seq-id OPTIONAL,
-            residue-sequence	SEQUENCE OF Residue,
-            inter-residue-bonds	SEQUENCE OF Inter-residue-bond OPTIONAL, 
+            id          Molecule-id,
+            descr           SEQUENCE OF Biomol-descr OPTIONAL,
+            seq-id          Seq-id OPTIONAL,
+            residue-sequence    SEQUENCE OF Residue,
+            inter-residue-bonds SEQUENCE OF Inter-residue-bond OPTIONAL, 
             sid                     PCSubstance-id OPTIONAL } 
 
         Residue ::= SEQUENCE {
-            id			Residue-id,
+            id          Residue-id,
             ... }
 
     */
@@ -422,11 +378,11 @@ void ASNFormat::BioStructLoader::loadBioStructModels( QList<AsnNode*> modelNodes
 {
     /*
         Biostruc-model ::= SEQUENCE {
-            id			Model-id,
-            type			Model-type,
-            descr			SEQUENCE OF Model-descr OPTIONAL,
-            model-space		Model-space OPTIONAL,
-            model-coordinates	SEQUENCE OF Model-coordinate-set OPTIONAL } 
+            id          Model-id,
+            type            Model-type,
+            descr           SEQUENCE OF Model-descr OPTIONAL,
+            model-space     Model-space OPTIONAL,
+            model-coordinates   SEQUENCE OF Model-coordinate-set OPTIONAL } 
     */
 
     Q_ASSERT(modelNodes.count() != 0);
@@ -453,19 +409,19 @@ void ASNFormat::BioStructLoader::loadBioStructGraph( AsnNode* graphNode, BioStru
 {
     /*
         Biostruc-graph ::= SEQUENCE {
-            descr			SEQUENCE OF Biomol-descr OPTIONAL,
-            molecule-graphs		SEQUENCE OF Molecule-graph,
-            inter-molecule-bonds	SEQUENCE OF Inter-residue-bond OPTIONAL,
-            residue-graphs		SEQUENCE OF Residue-graph OPTIONAL } 
+            descr           SEQUENCE OF Biomol-descr OPTIONAL,
+            molecule-graphs     SEQUENCE OF Molecule-graph,
+            inter-molecule-bonds    SEQUENCE OF Inter-residue-bond OPTIONAL,
+            residue-graphs      SEQUENCE OF Residue-graph OPTIONAL } 
         
         Molecule-graph ::= SEQUENCE {
-            id			Molecule-id,
-            descr			SEQUENCE OF Biomol-descr OPTIONAL,
+            id          Molecule-id,
+            descr           SEQUENCE OF Biomol-descr OPTIONAL,
             ...
 
        Biomol-descr ::= CHOICE {
-            name			VisibleString,
-            molecule-type	INTEGER {	dna(1),
+            name            VisibleString,
+            molecule-type   INTEGER {   dna(1),
             rna(2),
             protein(3),
             other-biopolymer(4),
@@ -502,15 +458,15 @@ void ASNFormat::BioStructLoader::loadBioStructSecondaryStruct( AsnNode* setsNode
 {
     /*
         Biostruc-feature-set ::= SEQUENCE {
-            id		Biostruc-feature-set-id,
-            descr		SEQUENCE OF Biostruc-feature-set-descr OPTIONAL,
-            features	SEQUENCE OF Biostruc-feature }
+            id      Biostruc-feature-set-id,
+            descr       SEQUENCE OF Biostruc-feature-set-descr OPTIONAL,
+            features    SEQUENCE OF Biostruc-feature }
         
         Biostruc-feature-set-descr ::= CHOICE {
-            name			VisibleString,
-            pdb-comment		VisibleString,
-            other-comment		VisibleString,
-            attribution		Pub } 
+            name            VisibleString,
+            pdb-comment     VisibleString,
+            other-comment       VisibleString,
+            attribution     Pub } 
             
    */
 
@@ -533,27 +489,27 @@ void ASNFormat::BioStructLoader::loadBioStructFeature( AsnNode* featureNode, Bio
 {
     /*
         Biostruc-feature ::= SEQUENCE {
-            id		Biostruc-feature-id OPTIONAL,
-            name		VisibleString OPTIONAL,
-            type	INTEGER {	helix(1),
+            id      Biostruc-feature-id OPTIONAL,
+            name        VisibleString OPTIONAL,
+            type    INTEGER {   helix(1),
                                 strand(2),
                                 sheet(3),
                                 turn(4),
                                 site(5),
                                 ...
             other(255) } OPTIONAL,
-            property	CHOICE { 
+            property    CHOICE { 
                                 ... } OPTIONAL,
-            location	CHOICE {subgraph	Chem-graph-pntrs,
-                                region		Region-pntrs,   
-                                alignment	Chem-graph-alignment,
-                                similarity	Region-similarity, 
-                                indirect	Other-feature } OPTIONAL }
+            location    CHOICE {subgraph    Chem-graph-pntrs,
+                                region      Region-pntrs,   
+                                alignment   Chem-graph-alignment,
+                                similarity  Region-similarity, 
+                                indirect    Other-feature } OPTIONAL }
          
         Residue-interval-pntr ::= SEQUENCE {
-            molecule-id		Molecule-id,
-            from			Residue-id,
-            to			    Residue-id } 
+            molecule-id     Molecule-id,
+            from            Residue-id,
+            to              Residue-id } 
 
     */
 
@@ -615,7 +571,7 @@ void ASNFormat::BioStructLoader::loadIntraResidueBonds( BioStruct3D& struc )
                 }
                 const AtomCoordSet& atomSet = atomSetCache.value(index); 
                 Q_ASSERT(!atomSet.isEmpty());
-                foreach (const StdBond bond, residue.bonds) {
+                foreach (const StdBond& bond, residue.bonds) {
                     if ( (atomSet.contains(bond.atom1Id)) && (atomSet.contains(bond.atom2Id)) ) {
                         const SharedAtom a1 = atomSet.value(bond.atom1Id);
                         const SharedAtom a2 = atomSet.value(bond.atom2Id);
@@ -706,32 +662,26 @@ void ASNFormat::AsnParser::parseNextElement( AsnNode* node )
 
     while (!curState.atEnd) {
         if (readNextElement()) {
-            
-            AsnNode* child = new AsnNode(curElementName, curElementKind);
-            
             if (curElementKind == ASN_VALUE) {
-               child->value = curElementValue;
-               node->children.append(child);
-            }
-
-            else if (curElementKind == ASN_SEQ) {
+                AsnNode* child = new AsnNode(curElementName, curElementKind);
+                child->value = curElementValue;
+                node->children.append(child);
+            } else if (curElementKind == ASN_SEQ) {
                 saveState();
+                AsnNode* child = new AsnNode(curElementName, curElementKind);
                 parseNextElement(child);
                 restoreState();
                 node->children.append(child);
             }
-
         } else if (fileAtEnd) {
             break;
         } 
 
     }
-
-    
 }
 
 bool ASNFormat::AsnParser::readNextElement()
- {
+{
     Q_ASSERT(insideRoot);
     buffer.clear();
 
