@@ -13,12 +13,30 @@
 
 #include <util_text/TextUtils.h>
 
+#include <core_api/AppContext.h>
+#include <core_api/Settings.h>
+
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+
+#include <QtCore/QXmlStreamReader>
+
 namespace GB2 {
 
+const QString BaseDNATranslationIds::NUCL_DNA_DEFAULT_COMPLEMENT("NUCL_DNA_DEFAULT_COMPLEMENT");
+const QString BaseDNATranslationIds::NUCL_RNA_DEFAULT_COMPLEMENT("NUCL_RNA_DEFAULT_COMPLEMENT");
+
+const QString BaseDNATranslationIds::NUCL_DNA_EXTENDED_COMPLEMENT("NUCL_DNA_EXTENDED_COMPLEMENT");
+const QString BaseDNATranslationIds::NUCL_RNA_EXTENDED_COMPLEMENT("NUCL_RNA_EXTENDED_COMPLEMENT");
+
+#define DATA_DIR_KEY                QString("back_translation")
+#define DATA_FILE_KEY               QString("back_translation/lastFile")
+#define DEFAULT_ORGANISM_FILE       QString("tables.xml")
 
 static void fill3To1(QList<Mapping3To1<char> >& map, QMap<DNATranslationRole,QList<Triplet> >& codons, 
-                     const DNAAlphabet* srcAl, const DNAAlphabet* dstAl,
-                     const char* amino, const char* role, const char* n1, const char* n2, const char* n3)
+    const DNAAlphabet* srcAl, const DNAAlphabet* dstAl,
+    const char* amino, const char* role, const char* n1, const char* n2, const char* n3)
 {
     assert(srcAl->isNucleic()); Q_UNUSED(srcAl);
     assert(dstAl->isAmino()); Q_UNUSED(dstAl);
@@ -43,8 +61,97 @@ static void fill3To1(QList<Mapping3To1<char> >& map, QMap<DNATranslationRole,QLi
     }
 }
 
+static void fill1To3(BackTranslationRules& map, 
+    const DNAAlphabet* srcAl, const DNAAlphabet* dstAl,
+    const char* amino, const int* prob, 
+    const char* n1, const char* n2, const char* n3)
+{
+    assert(srcAl->isAmino()); Q_UNUSED(srcAl);
+    assert(dstAl->isNucleic()); Q_UNUSED(dstAl);
+
+    TripletP t('N', 'N', 'N', 100);
+    map.map.append(t);
+    map.index['-'] = map.map.size();
+    TripletP dash('-', '-', '-', 100);
+    map.map.append(dash);
+    int len = strlen(amino);
+    assert(len == (int)strlen(n1) && len == (int)strlen(n2) && len == (int)strlen(n3));
+
+    QByteArray alph = srcAl->getAlphabetChars();
+    QList<TripletP> v;
+    int sump;
+    foreach (char c, alph) {
+        v.clear();
+        sump = 0;
+        for(int i=0; i<len; i++) {
+            if (amino[i] != c) continue;
+            char c1 = n1[i];
+            char c2 = n2[i];
+            char c3 = n3[i];
+            int p = prob[i];
+            sump += p;
+#ifdef DEBUG
+            char src = amino[i];
+            assert(srcAl->contains(src));
+            assert(dstAl->contains(c1));
+            assert(dstAl->contains(c2));
+            assert(dstAl->contains(c3));
+            assert((0 <= p) && (p <= 100));
+#endif
+            TripletP t(c1, c2, c3, p);
+            v.append(t);
+        }
+        if (v.empty()) {
+            if (c != '-') {
+                map.index[c] = 0;
+                map.index[c] = 1;
+            }
+        } else {
+            map.index[c] = map.map.size();
+            qSort(v);
+            v.first().p += (100 - sump);
+            foreach (TripletP t, v) {
+                map.map.append(t);
+            }
+        }
+    }
+}
+
+static bool parseCutFile(const QString& url, char* amino, int* prob, char* n1, char* n2, char* n3) {
+    QFile organismFile(url);
+    if (organismFile.open(QFile::ReadOnly)) {
+        QTextStream data(&organismFile);
+        QString line;
+        QStringList parsedData;
+        QByteArray buf(4, '\0');
+        int pos = 0;
+        bool ok = true;
+        do {
+            line = data.readLine();
+            if (line.isEmpty() || line.startsWith("#")) continue;
+            parsedData = line.split(QRegExp("\\s"), QString::SkipEmptyParts);
+            if ( parsedData.size() != 5 ) return false;
+            if ( parsedData[0].length() != 3 ) return false;
+            buf = parsedData[0].toAscii();
+            n1[pos] = buf[0];
+            n2[pos] = buf[1];
+            n3[pos] = buf[2];
+            if ( parsedData[1].length() != 1 ) return false;
+            buf = parsedData[1].toAscii();
+            amino[pos] = buf[0];
+            double pr = parsedData[2].toDouble(&ok);
+            if (!ok) return false;
+            prob[pos] = qRound(pr);
+            pos++;
+            amino[pos] = n1[pos] = n2[pos] = n3[pos] = '\0';
+        } while (!line.isNull());
+        return true;
+    }
+    return false;
+}
+
 void DNAAlphabetRegistryImpl::reg4tables(const char* amino, const char* role, const char* n1, const char* n2, const char* n3,
-                       const QString& id, const QString& name) 
+    const QString& id, const QString& name) 
 {
     {
         DNAAlphabet* srcAlphabet = findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT);
@@ -105,32 +212,50 @@ void DNAAlphabetRegistryImpl::reg4tables(const char* amino, const char* role, co
     }
 }
 
+void DNAAlphabetRegistryImpl::regPtables(const char* amino, const int* prob, const char* n1, const char* n2, const char* n3,
+    const QString& id, const QString& name) 
+{
+    {
+        DNAAlphabet* srcAlphabet = findById(BaseDNAAlphabetIds::AMINO_DEFAULT);
+        DNAAlphabet* dstAlphabet = findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT);
+
+        BackTranslationRules map;
+        fill1To3(map, srcAlphabet, dstAlphabet, amino, prob, n1, n2, n3);
+
+        DNATranslation* t = new DNATranslation1to3Impl(id, name, 
+            srcAlphabet, dstAlphabet, map);
+        treg->registerDNATranslation(t);
+    }
+}
+
 #define CASE_OFFSET ('a'-'A')
 #define MAP(a, b) \
-	map[int(a)] = b; \
-	if (!srcAlphabet->isCaseSensitive()) { \
-		map[int(a) + CASE_OFFSET]=(b)+CASE_OFFSET; \
-	}
+map[int(a)] = b; \
+if (!srcAlphabet->isCaseSensitive()) { \
+map[int(a) + CASE_OFFSET]=(b)+CASE_OFFSET; \
+}
 
 
 void DNAAlphabetRegistryImpl::initBaseTranslations() {
 
-	//default NUCL DNA complement
-	{
-		DNAAlphabet* srcAlphabet = findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT);
-		DNAAlphabet* dstAlphabet = srcAlphabet;
+    //default NUCL DNA complement
+    {
+        DNAAlphabet* srcAlphabet = findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT);
+        DNAAlphabet* dstAlphabet = srcAlphabet;
 
-		QByteArray map = TextUtils::createMap(srcAlphabet->getMap(), 'N');
-		
-		MAP('A','T');
-		MAP('C','G');
-		MAP('G','C');
-		MAP('T','A');
+        QByteArray map = TextUtils::createMap(srcAlphabet->getMap(), 'N');
+
+        MAP('A','T');
+        MAP('C','G');
+        MAP('G','C');
+        MAP('T','A');
+
+        DNATranslation* t = new DNATranslation1to1Impl(BaseDNATranslationIds::NUCL_DNA_DEFAULT_COMPLEMENT, 
+            tr("nucl_dna_default_to_nucl_compl"), 
+            srcAlphabet, dstAlphabet, map);
+        treg->registerDNATranslation(t);
+    }
 
-		DNATranslation* t = new DNATranslation1to1Impl(tr("nucl_dna_default_to_nucl_compl"), srcAlphabet, dstAlphabet, map);
-		treg->registerDNATranslation(t);
-	}
-	
     //default NUCL RNA complement
     {
         DNAAlphabet* srcAlphabet = findById(BaseDNAAlphabetIds::NUCL_RNA_DEFAULT);
@@ -143,7 +268,9 @@ void DNAAlphabetRegistryImpl::initBaseTranslations() {
         MAP('G','C');
         MAP('U','A');
 
-        DNATranslation* t = new DNATranslation1to1Impl(tr("nucl_rna_default_to_nucl_compl"), srcAlphabet, dstAlphabet, map);
+        DNATranslation* t = new DNATranslation1to1Impl(BaseDNATranslationIds::NUCL_RNA_DEFAULT_COMPLEMENT,
+            tr("nucl_rna_default_to_nucl_compl"), 
+            srcAlphabet, dstAlphabet, map);
         treg->registerDNATranslation(t);
     }
 
@@ -170,7 +297,9 @@ void DNAAlphabetRegistryImpl::initBaseTranslations() {
         MAP('D','H');
         MAP('B','V');
 
-        DNATranslation* t = new DNATranslation1to1Impl(tr("nucl_dna_extended_to_nucl_compl"), srcAlphabet, dstAlphabet, map);
+        DNATranslation* t = new DNATranslation1to1Impl(BaseDNATranslationIds::NUCL_DNA_EXTENDED_COMPLEMENT, 
+            tr("nucl_dna_extended_to_nucl_compl"), 
+            srcAlphabet, dstAlphabet, map);
         treg->registerDNATranslation(t);
     }
 
@@ -197,18 +326,20 @@ void DNAAlphabetRegistryImpl::initBaseTranslations() {
         MAP('D','H');
         MAP('B','V');
 
-        DNATranslation* t = new DNATranslation1to1Impl(tr("nucl_rna_extended_to_nucl_compl"), srcAlphabet, dstAlphabet, map);
+        DNATranslation* t = new DNATranslation1to1Impl(BaseDNATranslationIds::NUCL_RNA_EXTENDED_COMPLEMENT,
+            tr("nucl_rna_extended_to_nucl_compl"), 
+            srcAlphabet, dstAlphabet, map);
         treg->registerDNATranslation(t);
     }
 
     // source: http://www.ncbi.nlm.nih.gov/Taxonomy/Utils/wprintgc.cgi
     // 1. The Standard Code (transl_table=1)
     reg4tables(
-		"FFLLSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG",
-		"---L---------------L---------------M----------------------------",
-		"TTTTTTTTTTTTTTTTCCCCCCCCCCCCCCCCAAAAAAAAAAAAAAAAGGGGGGGGGGGGGGGG",
-		"TTTTCCCCAAAAGGGGTTTTCCCCAAAAGGGGTTTTCCCCAAAAGGGGTTTTCCCCAAAAGGGG",
-		"TCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAG",
+        "FFLLSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG",
+        "---L---------------L---------------M----------------------------",
+        "TTTTTTTTTTTTTTTTCCCCCCCCCCCCCCCCAAAAAAAAAAAAAAAAGGGGGGGGGGGGGGGG",
+        "TTTTCCCCAAAAGGGGTTTTCCCCAAAAGGGGTTTTCCCCAAAAGGGGTTTTCCCCAAAAGGGG",
+        "TCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAGTCAG",
         DNATranslationID(1),
         tr("dna2amino 1 Standard"));
 
@@ -374,6 +505,53 @@ void DNAAlphabetRegistryImpl::initBaseTranslations() {
         DNATranslationID(23),
         tr("dna2amino 23 Thraustochytrium Mitochondrial"));
 
+    char amino[65], n1[65], n2[65], n3[65];
+    int prob[64];
+
+    QString dir = QDir::searchPaths( PATH_PREFIX_DATA ).first() + "/back_translation/";
+    QString lastOrganismFile = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
+    if (lastOrganismFile.isEmpty() || !QFile::exists(lastOrganismFile)) {
+        lastOrganismFile = dir + DEFAULT_ORGANISM_FILE;
+        AppContext::getSettings()->setValue(DATA_FILE_KEY, lastOrganismFile);
+    }
+    QXmlStreamReader xml;
+    QFile file(lastOrganismFile);
+    if (!file.open(QFile::ReadOnly | QFile::Text)) {
+        return;
+    }
+    xml.setDevice(&file);
+    QString currentType;
+    QString currentName;
+    QString fileName;
+    QString readableName;
+
+    while (!xml.atEnd() && !xml.hasError()) {
+        QXmlStreamReader::TokenType tt = xml.readNext();
+        if (tt == QXmlStreamReader::StartDocument) {
+            continue;
+        }
+        if (tt == QXmlStreamReader::StartElement) {
+            if (xml.name() == "CodonFrequencyTableList") {
+                continue;
+            }
+            if (xml.name() == "Folder" && xml.attributes().value("name") == "Codon Frequency Tables") {
+                continue;
+            }
+            if (xml.name() == "Folder") {
+                currentType = xml.attributes().value("name").toString();
+                continue;
+            }
+            if (xml.name() == "CodonFrequencyTable") {
+                currentName = xml.attributes().value("name").toString();
+                QStringList buf = currentName.split(".");
+                buf.removeLast();
+                readableName = buf.join(".").replace("_", " ");
+                fileName = currentType + "/" + currentName;
+                if (parseCutFile(dir + fileName, amino, prob, n1, n2, n3))
+                    regPtables(amino, prob, n1, n2, n3, "BackTranslation/" + fileName, readableName);
+            }
+        }
+    } 
 }
 
 } //namespace
