@@ -11,13 +11,20 @@
 #include "ClustalWAlnFormat.h"
 
 #include <document_format/DocumentFormatUtils.h>
+
+#include <core_api/AppContext.h>
 #include <core_api/Task.h>
 #include <core_api/IOAdapter.h>
+#include <core_api/L10n.h>
 #include <gobjects/GObjectTypes.h>
 #include <gobjects/MAlignmentObject.h>
 #include <util_text/TextUtils.h>
 #include <util_algorithm/MSAUtils.h>
-#include <util_gui/GUIUtils.h>
+
+#include <util_msa_consensus/MSAConsensusUtils.h>
+#include <util_msa_consensus/MSAConsensusAlgorithmRegistry.h>
+#include <util_msa_consensus/BuiltInConsensusAlgorithms.h>
+
 #include <memory>
 
 namespace GB2 {
@@ -25,60 +32,23 @@ namespace GB2 {
 /* TRANSLATOR GB2::ClustalWAlnFormat */    
 /* TRANSLATOR GB2::IOAdapter */    
 
-const QByteArray ClustalWAlnFormat::CLUSTAL_HEADER = "CLUSTAL ";
+const QByteArray ClustalWAlnFormat::CLUSTAL_HEADER = "CLUSTAL";
 
-ClustalWAlnFormat::ClustalWAlnFormat(QObject* p) : DocumentFormat(p) 
+ClustalWAlnFormat::ClustalWAlnFormat(QObject* p) : DocumentFormat(p, DocumentFormatFlags_SW, QStringList("aln")) 
 {
     formatName = tr("CLUSTALW");
+	supportedObjectTypes+=GObjectTypes::MULTIPLE_ALIGNMENT;
 }
 
-QStringList ClustalWAlnFormat::getSupportedDocumentFileExtensions() {
-    QStringList l;
-    l<<"aln";
-    return l;
-}
-
-
-//todo: code duplication with MAlignment::checkModel
-static bool checkModel(const MAlignment& al, TaskStateInfo& ti) {
-    //check that all sequences are of equal size
-    int size = 0;
-    for (int i=0, n = al.getNumSequences(); i<n; i++) {
-        const MAlignmentItem& item = al.alignedSeqs[i];
-        if (i == 0) {
-            size = item.sequence.size();
-        } else {
-            int itemSize = item.sequence.size();
-            if (size!=itemSize) {
-                ti.setError( ClustalWAlnFormat::tr("found_sequences_of_different_size"));
-                return false;
-            }
-        }
-    }
-    if (size == 0) {
-        ti.setError( ClustalWAlnFormat::tr("model_of_0_size"));
-        return false;
-    } 
-    return true;
-}
-
-static QString getFilename( IOAdapter* io ) {
-    assert( NULL != io );
-    QString url = io->getUrl();
-    assert( !url.isEmpty() );
-    return QFileInfo( url ).baseName();
-}
 
 void ClustalWAlnFormat::load(IOAdapter* io, QList<GObject*>& objects, TaskStateInfo& ti) {
     static int READ_BUFF_SIZE = 1024;
     QByteArray readBuffer(READ_BUFF_SIZE, '\0');
     char* buff  = readBuffer.data();
 
-    MAlignmentItem consensus;
-
     const QBitArray& LINE_BREAKS = TextUtils::LINE_BREAKS;
     const QBitArray& WHITES = TextUtils::WHITES;
-    MAlignment al( getFilename( io ) );
+	MAlignment al( io->getURL().baseFileName());
     bool lineOk = false;
     bool firstBlock = true;
     int sequenceIdx = 0;
@@ -87,8 +57,8 @@ void ClustalWAlnFormat::load(IOAdapter* io, QList<GObject*>& objects, TaskStateI
 
     //1 skip first line
     int len = io->readUntil(buff, READ_BUFF_SIZE, LINE_BREAKS, IOAdapter::Term_Include, &lineOk);
-    if (!lineOk || len < 40 || !readBuffer.startsWith( CLUSTAL_HEADER )) {
-        ti.setError( ClustalWAlnFormat::tr("illegal_header_line"));
+    if (!lineOk || !readBuffer.startsWith( CLUSTAL_HEADER )) {
+        ti.setError( ClustalWAlnFormat::tr("Illegal header line"));
     }
 
     //read data
@@ -105,7 +75,7 @@ void ClustalWAlnFormat::load(IOAdapter* io, QList<GObject*>& objects, TaskStateI
             len--;
         }
         if (len == 0) {
-            if (al.getNumSequences() == 0) {
+            if (al.getNumRows() == 0) {
                 continue;//initial empty lines
             }
             ti.setError( ClustalWAlnFormat::tr("error_parsing_file"));
@@ -140,40 +110,42 @@ void ClustalWAlnFormat::load(IOAdapter* io, QList<GObject*>& objects, TaskStateI
         QByteArray name = line.left(valStartPos).trimmed();
         QByteArray value = line.mid(valStartPos, valEndPos - valStartPos);
                 
-        int seqsInModel = al.getNumSequences();
+        int seqsInModel = al.getNumRows();
         bool lastBlockLine = (!firstBlock && sequenceIdx == seqsInModel) 
             || numNs >=2
             || name.isEmpty()
             || value.contains(' ') || value.contains(':') || value.contains('.');
 
         if (firstBlock) {
-            if (lastBlockLine) {
-                consensus.name = name;
-                consensus.sequence = value;
+            if (lastBlockLine && name.isEmpty()) { //if name is not empty -> this is a sequence but consensus (for Clustal files without consensus)
+                // this is consensus line - skip it
             } else {
-                assert(al.alignedSeqs.size() == sequenceIdx);
-                al.alignedSeqs.append(MAlignmentItem(name, value));
+                assert(al.getNumRows() == sequenceIdx);
+                al.addRow(MAlignmentRow(name, value));
             }
         } else {
-            MAlignmentItem* item = NULL;
+            int rowIdx = -1;
             if (sequenceIdx < seqsInModel) { 
-                item = &al.alignedSeqs[sequenceIdx];
+				rowIdx = sequenceIdx;
             } else if (sequenceIdx == seqsInModel) {
                 assert(lastBlockLine);
-                item = &consensus;
+                // consensus line
             } else {
                 ti.setError( ClustalWAlnFormat::tr("incorrect_num_seqs_in_block"));
                 break;
             } 
-            if (item->name!=name) {
-                ti.setError( ClustalWAlnFormat::tr("seq_name_not_matched"));
-                break;
-            }
-            item->sequence.append(value);
+			if (rowIdx != -1) {
+				const MAlignmentRow& row = al.getRow(rowIdx);
+	            if (row.getName() != name) {
+					ti.setError( ClustalWAlnFormat::tr("seq_name_not_matched"));
+					break;
+				}
+				al.appendChars(rowIdx, value.constData(), value.size());
+			}
         }
         if (lastBlockLine) {
             firstBlock = false;
-            if (!checkModel(al, ti)) {
+			if (!MSAUtils::checkPackedModelSymmetry(al, ti)) {
                 break;
             }
             sequenceIdx = 0;
@@ -183,12 +155,12 @@ void ClustalWAlnFormat::load(IOAdapter* io, QList<GObject*>& objects, TaskStateI
 
         ti.progress = io->getProgress();
     }
-    checkModel(al, ti);
+    MSAUtils::checkPackedModelSymmetry(al, ti);
     if (ti.hasErrors()) {
         return;
     }
     DocumentFormatUtils::assignAlphabet(al);
-    if (al.alphabet == NULL) {
+    if (al.getAlphabet() == NULL) {
         ti.setError( ClustalWAlnFormat::tr("alphabet_unknown"));
         return;
     }
@@ -197,39 +169,16 @@ void ClustalWAlnFormat::load(IOAdapter* io, QList<GObject*>& objects, TaskStateI
     objects.append(obj);
 }
 
-Document* ClustalWAlnFormat::loadExistingDocument(IOAdapterFactory* iof, const QString& url, TaskStateInfo& ti, const QVariantMap& fs) {
-    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-
-    if (!io->open(url, IOAdapterMode_Read)) {
-        ti.setError(Translations::errorOpeningFileRead(url));
-        return NULL;
-    }
+Document* ClustalWAlnFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode) {
     QList<GObject*> objects;
-    load(io.get(), objects, ti);
-    io->close();
-
+    load(io, objects, ti);
+    
     if (ti.hasErrors()) {
         qDeleteAll( objects );
         return NULL;
     }
     assert(objects.size() == 1);
-    return new Document(this, iof, url, objects, fs);
-}
-
-Document* ClustalWAlnFormat::loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs ) {
-    if( NULL == io || !io->isOpen() ) {
-        ti.setError( Translations::badArgument("IO adapter"));
-        return NULL;
-    }
-    QList< GObject* > objs;
-    load( io, objs, ti ); // should load only one msa
-    
-    if( ti.hasErrors() ) {
-        qDeleteAll( objs );
-        return NULL;
-    }
-    assert( 1 == objs.size() );
-    return new Document( this, io->getFactory(), io->getUrl(), objs, fs );
+    return new Document(this, io->getFactory(), io->getURL(), objects, fs);
 }
 
 #define MAX_LINE_LEN    80
@@ -244,27 +193,29 @@ void ClustalWAlnFormat::save(IOAdapter* io, Document* d, TaskStateInfo& ti) {
             return;
     }
     const MAlignment& ma = obj->getMAlignment();
-    assert(ma.isNormalized());
-
+    
     //write header
     QByteArray header("CLUSTAL W 2.0 multiple sequence alignment\n\n");
     int len = io->writeBlock(header);
     if (len != header.length()) {
-        ti.setError(Translations::errorWritingFile(d->getURL()));
+        ti.setError(L10N::errorWritingFile(d->getURL()));
         return;
     }
 
     //precalculate seq writing params
     int maxNameLength = 0;
-    foreach(const MAlignmentItem& item, ma.alignedSeqs) {
-        maxNameLength = qMax(maxNameLength, item.name.length());
+    foreach(const MAlignmentRow& row, ma.getRows()) {
+        maxNameLength = qMax(maxNameLength, row.getName().length());
     }
     maxNameLength = qMin(maxNameLength, MAX_NAME_LEN);
 
     int aliLen = ma.getLength();
     QByteArray consensus(aliLen, MAlignment_GapChar);
-    MSAUtils::updateConsensus(ma, consensus, MSAConsensusType_ClustalW);
-
+	
+    MSAConsensusAlgorithmFactory* algoFactory = AppContext::getMSAConsensusAlgorithmRegistry()->getAlgorithmFactory(BuiltInConsensusAlgorithms::CLUSTAL_ALGO);
+    std::auto_ptr<MSAConsensusAlgorithm> algo(algoFactory->createAlgorithm(ma));
+    MSAConsensusUtils::updateConsensus(ma, consensus, algo.get());
+    
     int maxNumLength  = 1 + (aliLen < 10 ? 1 : (int)log10((double)aliLen));
 
     int seqStart = maxNameLength + 2; //+1 for space separator
@@ -283,14 +234,14 @@ void ClustalWAlnFormat::save(IOAdapter* io, Document* d, TaskStateInfo& ti) {
     //write sequence
     for(int i = 0; i < aliLen; i+=seqPerPage) {
         int partLen = i + seqPerPage > aliLen ? aliLen - i : seqPerPage;
-        foreach(const MAlignmentItem& item, ma.alignedSeqs) {
-            QByteArray line = item.name.toAscii();
+        foreach(const MAlignmentRow& row, ma.getRows()) {
+            QByteArray line = row.getName().toAscii();
             if (line.length() > MAX_NAME_LEN) {
                 line = line.left(MAX_NAME_LEN);
             }
             TextUtils::replace(line.data(), line.length(), TextUtils::WHITES, '_');
             line.append(QByteArray::fromRawData(spaces, seqStart - line.length()));
-            line.append(item.sequence.mid(i, partLen));
+            line.append(row.mid(i, partLen).toByteArray(partLen));
             line.append(' ');
             line.append(QString::number(qMin(i+seqPerPage, aliLen)));
             assert(line.length() <= MAX_LINE_LEN);
@@ -298,7 +249,7 @@ void ClustalWAlnFormat::save(IOAdapter* io, Document* d, TaskStateInfo& ti) {
 
             len = io->writeBlock(line);
             if (len != line.length()) {
-                ti.setError(Translations::errorWritingFile(d->getURL()));
+                ti.setError(L10N::errorWritingFile(d->getURL()));
                 return;
             }
         }
@@ -308,81 +259,37 @@ void ClustalWAlnFormat::save(IOAdapter* io, Document* d, TaskStateInfo& ti) {
         line.append("\n\n");
         len = io->writeBlock(line);
         if (len != line.length()) {
-            ti.setError(Translations::errorWritingFile(d->getURL()));
+            ti.setError(L10N::errorWritingFile(d->getURL()));
             return;
         }
     }
 }
 
-void ClustalWAlnFormat::storeDocument(Document* doc, TaskStateInfo& ti, IOAdapterFactory* iof, const QString& newDocURL) {
-    if (iof == NULL) {
-        iof = doc->getIOAdapterFactory();
-    }
-    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-    QString url = newDocURL.isEmpty() ? doc->getURL() : newDocURL;
-    if (!io->open(url, IOAdapterMode_Write)) {
-        ti.setError(Translations::errorOpeningFileWrite(url));
-        return;
-    }
-    save(io.get(), doc, ti);
-    io->close();
-}
-
-
 void ClustalWAlnFormat::storeDocument( Document* d, TaskStateInfo& ti, IOAdapter* io ) {
     if( NULL == d ) {
-        ti.setError(Translations::badArgument("doc"));
+        ti.setError(L10N::badArgument("doc"));
         return;
     }
     if( NULL == io || !io->isOpen() ) {
-        ti.setError(Translations::badArgument("IO adapter"));
+        ti.setError(L10N::badArgument("IO adapter"));
         return;
     }
     save(io, d, ti);
 }
 
-bool ClustalWAlnFormat::isDataFormatSupported(const char* data, int size) const {
-    if (TextUtils::contains(TextUtils::BINARY, data, size)) {
+bool ClustalWAlnFormat::checkRawData(const QByteArray& data) const {
+    if (TextUtils::contains(TextUtils::BINARY, data.constData(), data.size())) {
         return false;
     }
-    QByteArray str(data, size);
-    if (!str.startsWith(CLUSTAL_HEADER)) {
+    if (!data.startsWith(CLUSTAL_HEADER)) {
         return false;
     }
-    QTextStream s(str);
+    QTextStream s(data);
     QString line = s.readLine();
-    if (!line.endsWith("multiple sequence alignment")) {
-        return false;
+    if ( (line == CLUSTAL_HEADER) || (line.endsWith("multiple sequence alignment")) ) {
+        return true;
     }
-    return true;
+    return false;
 }
 
-bool ClustalWAlnFormat::isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const{
-    if (t != GObjectTypes::MULTIPLE_ALIGNMENT ) {
-        return false;
-    }
-    bool res = false;
-    if (op == DocumentFormat::DocObjectOp_Add) {
-        res = d->getObjects().isEmpty();
-    } 
-    return res;
-}
-
-bool ClustalWAlnFormat::checkConstraints(const DocumentFormatConstraints& c) const {
-    foreach (GObjectType t, c.supportedObjectTypes) {
-        if (t!=GObjectTypes::MULTIPLE_ALIGNMENT) {
-            return false;
-        }
-    }
-    if (c.checkRawData) {
-        return isDataFormatSupported(c.rawData.constData(), c.rawData.size());
-    }
-    bool ret = true;
-    if( c.supportsStreamingRead ) {
-        ret = ret && true;
-    }
-    return ret;
-}
-
-
 }//namespace
