@@ -12,12 +12,13 @@
 #define _GB2_DNA_TRANSLATION_IMPL_H_
 
 #include <core_api/DNATranslation.h>
+#include <QtCore/QVarLengthArray>
 
 namespace GB2 {
 
 class DNATranslation1to1Impl : public DNATranslation {
 public:
-	DNATranslation1to1Impl(const QString& _name, DNAAlphabet* src, DNAAlphabet* dst, QByteArray mapper121);
+	DNATranslation1to1Impl(const QString& id, const QString& _name, DNAAlphabet* src, DNAAlphabet* dst, QByteArray mapper121);
 	
 	virtual int translate(const char* src, int src_len, char* dst, int dst_capacity) const;
     virtual int translate(char* src_and_dst, int len) const;
@@ -40,6 +41,22 @@ public:
     char c[3];
 };
 
+//Triplet extended with probability value, used for back translation
+struct GB2_COREAPI_EXPORT TripletP {
+public:
+    TripletP() { c[0] = c[1] = c[2] = '\0'; p = 0; }
+    TripletP(const char* s) { c[0] = s[0]; c[1] = s[1]; c[2] = s[2]; p = 0;}
+    TripletP(char c0, char c1, char c2) {c[0] = c0; c[1] = c1; c[2] = c2; p = 0;}
+
+    TripletP(const char* s, int p0) { c[0] = s[0]; c[1] = s[1]; c[2] = s[2]; p = p0;}
+    TripletP(char c0, char c1, char c2, int p0) {c[0] = c0; c[1] = c1; c[2] = c2; p = p0;}
+
+    bool operator <(const TripletP &other) const { return (p > other.p); }
+
+    char c[3];
+    int p; //probability value, values in [0..100]
+};
+
 class GB2_COREAPI_EXPORT Index3To1 {
 public:
     Index3To1();
@@ -81,12 +98,8 @@ class Mapping3To1 {
 public:
     Mapping3To1(const Triplet& _t, const T& _res) : t(_t), res(_res){}
 
-    const Triplet   t;
-    const T         res;
-
-    inline Mapping3To1<T> &operator=(const Mapping3To1<T>& other) {
-        return *(Mapping3To1<T>*)&other;
-    }
+    Triplet   t;
+    T       res;
 };
 
 
@@ -105,7 +118,7 @@ public:
         int size = index.getIndexSize();
         assert(size > 0);
         resultByIndex = new T[size];
-        std::fill(resultByIndex, resultByIndex+size, defaultVal);
+        qFill(resultByIndex, resultByIndex+size, defaultVal);
         
         //assign indexed values
         foreach(const Mapping3To1<T>& m, rawMapping) {
@@ -122,7 +135,7 @@ public:
         int size = index.getIndexSize();
         assert(size > 0);
         resultByIndex = new T[size];
-        std::fill(resultByIndex, resultByIndex+size, defaultVal);
+        qFill(resultByIndex, resultByIndex+size, defaultVal);
     }
 
     ~IndexedMapping3To1() {
@@ -236,6 +249,35 @@ inline bool DNATranslation3to1Impl::isCodon(DNATranslationRole role, const char*
     return isCodon(role, s[0], s[1], s[2]);
 }
 
+////////////////////////////////////// 1->3
+struct BackTranslationRules {
+public:
+    int index[256];
+    QVarLengthArray<TripletP, 66> map;
+};
+
+enum BackTranslationMode {
+    USE_MOST_PROBABLE_CODONS,
+    USE_FREQUENCE_DISTRIBUTION
+};
+
+class DNATranslation1to3Impl : public DNATranslation {
+public:    
+
+    DNATranslation1to3Impl(const QString& _id, const QString& _name, DNAAlphabet* src, DNAAlphabet* dst,
+        const BackTranslationRules& rules);
+    virtual ~DNATranslation1to3Impl();
+
+    virtual int translate(const char* src, int src_len, char* dst, int dst_capacity, BackTranslationMode mode) const;
+    virtual int translate(const char* src, int src_len, char* dst, int dst_capacity) const;
+    virtual int translate(char* src_and_dst, int len) const;
+
+    virtual bool isOne2Three() const {return true;}
+
+private:
+    BackTranslationRules index;
+};
+
 } //namespace
 
 #endif
