@@ -15,6 +15,7 @@
 #include <core_api/IOAdapter.h>
 #include <core_api/DocumentModel.h>
 #include <core_api/DocumentFormats.h>
+#include <core_api/GUrlUtils.h>
 
 #include <util_gui/DialogUtils.h>
 #include <util_text/TextUtils.h>
@@ -65,7 +66,7 @@ DNASequenceObject* DocumentFormatUtils::addSequenceObject(QList<GObject*>& objec
 }
 
 
-DNASequenceObject* DocumentFormatUtils::addMergedSequenceObject(QList<GObject*>& objects, const QString& docUrl, const QStringList& contigs, QByteArray& mergedSequence, const QList<LRegion>& mergedMapping) {
+DNASequenceObject* DocumentFormatUtils::addMergedSequenceObject(QList<GObject*>& objects, const GUrl& docUrl, const QStringList& contigs, QByteArray& mergedSequence, const QList<LRegion>& mergedMapping) {
     if (contigs.size() == 1) {
         DNAAlphabet* al = findAlphabet(mergedSequence);
         const QString& name = contigs.first();
@@ -94,7 +95,7 @@ DNASequenceObject* DocumentFormatUtils::addMergedSequenceObject(QList<GObject*>&
 
     //save relation if docUrl is not empty
     if (!docUrl.isEmpty()) {
-        GObjectReference r(docUrl, so->getGObjectName(), GObjectTypes::DNA_SEQUENCE);
+        GObjectReference r(docUrl.getURLString(), so->getGObjectName(), GObjectTypes::SEQUENCE);
         ao->addObjectRelation(GObjectRelation(r, GObjectRelationRole::SEQUENCE));
     }
 
@@ -135,7 +136,7 @@ void DocumentFormatUtils::updateFormatSettings(QList<GObject*>& objects, QVarian
     //2. add new sizes
     QList<GObject*> sequences;
     foreach(GObject* obj, objects) {
-        if (obj->getGObjectType() == GObjectTypes::DNA_SEQUENCE) {
+        if (obj->getGObjectType() == GObjectTypes::SEQUENCE) {
             sequences.append(obj);
         }
     }
@@ -157,56 +158,77 @@ void DocumentFormatUtils::addOffset(QList<LRegion>& location, int offset) {
     }
 }
 
-static QList< DocumentFormat* > detectFormats( const QByteArray& rawData, const QString& ext ) {
-    QList<DocumentFormat*> result;
-    DocumentFormatConstraints constr;
 
-    constr.rawData = rawData;
-    constr.checkRawData = true;
+
+class ExtComparator {
+public:
+    ExtComparator(const QString& _ext) : ext(_ext) {}
+
+    bool operator()(const DocumentFormat* f1, const DocumentFormat* f2) const { 
+        int v1 = f1->getSupportedDocumentFileExtensions().contains(ext) ? 1 : 0;
+        int v2 = f2->getSupportedDocumentFileExtensions().contains(ext) ? 1 : 0;
+        return  v2 < v1; // reverse sort -> make higher vals on the top
+    }
+    QString ext;
+};
+
+
+static QList< DocumentFormat* > detectFormats( const QByteArray& rawData, const QString& ext ) {
+    DocumentFormatConstraints c;
+    c.rawData = rawData;
+    c.checkRawData = true;
+
+    QList<DocumentFormat*> matchedFormats;
+
     DocumentFormatRegistry* fr = AppContext::getDocumentFormatRegistry();
-    QList< DocumentFormatId > formatIds = fr->selectFormats( constr );
+    QList< DocumentFormatId > formatIds = fr->selectFormats(c);
     foreach( DocumentFormatId id, formatIds ) {
         DocumentFormat* f = fr->getFormatById( id );
-        assert( f );
-        if ( f->checkConstraints( constr ) ) {
-            if ( f->getSupportedDocumentFileExtensions().contains( ext ) ) {
-                result.prepend( f );
-            } else {
-                result.append( f );
-            }
-        }
+        assert(f!=NULL);
+        matchedFormats.append(f);
     }
-    result = AppContext::getDocumentFormatRegistry()->sortByDetectPriority(result);
-    return result;
+    QList<DocumentFormat*> formatsSortedByPriority = AppContext::getDocumentFormatRegistry()->sortByDetectPriority(matchedFormats);
+    if (ext.isEmpty()) {
+        return formatsSortedByPriority;
+    }
+
+    ExtComparator extComp(ext.toLower());
+    QList<DocumentFormat*> formatsSortedByExt= formatsSortedByPriority;
+    qStableSort(formatsSortedByExt.begin(), formatsSortedByExt.end(), extComp);
+    return formatsSortedByExt;
 }
 
-QList<DocumentFormat*> DocumentFormatUtils::detectFormat(const QString& url) {
+QList<DocumentFormat*> DocumentFormatUtils::detectFormat(const GUrl& url) {
     QList< DocumentFormat* > res;
     if( url.isEmpty() ) {
         return res;
     }
-    QByteArray rawData = BaseIOAdapters::readFileHeader( url );
-    QString ext = DialogUtils::getDocumentExtension( url );
+    QByteArray rawData = BaseIOAdapters::readFileHeader(url);
+    if (rawData.isEmpty()) {
+        return res;
+    }
+    QString ext = GUrlUtils::getUncompressedExtension(url);
     res = detectFormats( rawData, ext );
     return res;
 }
 
+
 QList< DocumentFormat* > DocumentFormatUtils::detectFormat( IOAdapter *io ) {
     QList< DocumentFormat* > res;
     if( NULL == io || !io->isOpen() ) {
         return res;
     }
     QByteArray rawData = BaseIOAdapters::readFileHeader( io );
-    QString ext = DialogUtils::getDocumentExtension( io->getUrl() );
+    QString ext = GUrlUtils::getUncompressedExtension(io->getURL());
     res = detectFormats( rawData, ext );
     return res;
 }
 
 void DocumentFormatUtils::assignAlphabet(MAlignment& ma) {
     QList<DNAAlphabet*> matchedAlphabets;
-    for (int i=0, n = ma.getNumSequences();i<n; i++) {
-        MAlignmentItem& item = ma.alignedSeqs[i];
-        QList<DNAAlphabet*> als = DocumentFormatUtils::findAlphabets(item.sequence);
+    for (int i=0, n = ma.getNumRows();i<n; i++) {
+        const MAlignmentRow& item = ma.getRow(i);
+        QList<DNAAlphabet*> als = DocumentFormatUtils::findAlphabets(item.getCore());
         if (i == 0) {
             matchedAlphabets = als;
         } else {
@@ -226,13 +248,10 @@ void DocumentFormatUtils::assignAlphabet(MAlignment& ma) {
         return; //nothing matched
     }
 
-    ma.alphabet = matchedAlphabets.first();
+    ma.setAlphabet(matchedAlphabets.first());
 
-    if (!ma.alphabet->isCaseSensitive()) {
-        for (int i=0, n = ma.getNumSequences();i<n; i++) {
-            MAlignmentItem& item = ma.alignedSeqs[i];
-            TextUtils::translate(TextUtils::UPPER_CASE_MAP, item.sequence.data(), item.sequence.length());
-        }
+    if (!ma.getAlphabet()->isCaseSensitive()) {
+		ma.toUpperCase();
     }
 }
 
