@@ -36,7 +36,7 @@ public:
     static DNASequenceObject* addSequenceObject(QList<GObject*>& objects, const QString& name, DNASequence& seq);
 
     /** if no docURL provided -> relations are not set*/
-    static DNASequenceObject* addMergedSequenceObject(QList<GObject*>& objects, const QString& docUrl, const QStringList& contigs, 
+    static DNASequenceObject* addMergedSequenceObject(QList<GObject*>& objects, const GUrl& docUrl, const QStringList& contigs, 
                             QByteArray& mergedSequence, const QList<LRegion>& mergedMapping);
 
     static DNAAlphabet* findAlphabet(const QByteArray& arr);
@@ -54,7 +54,7 @@ public:
     static void addOffset(QList<LRegion>& location, int offset);
 
     // the best match goes first in the returned list
-    static QList<DocumentFormat*> detectFormat(const QString& url);
+    static QList<DocumentFormat*> detectFormat(const GUrl& url);
     
     // io - opened io adapter
     static QList<DocumentFormat*> detectFormat( IOAdapter* io );
