@@ -8,6 +8,7 @@
 *     for details.
 *****************************************************************/
 
+
 #include "EMBLGenbankAbstractDocument.h"
 
 #include "GenbankLocationParser.h"
@@ -21,96 +22,50 @@
 #include <core_api/IOAdapter.h>
 #include <core_api/Task.h>
 #include <core_api/DNAAlphabet.h>
+#include <core_api/L10n.h>
+
 #include <datatype/DNAInfo.h>
 #include <util_text/TextUtils.h>
-#include <util_gui/GUIUtils.h>
-#include <memory>
 
 namespace GB2 {
 
 /* TRANSLATOR GB2::EMBLGenbankAbstractDocument */    
 //TODO: local8bit or ascii??
 
-EMBLGenbankAbstractDocument::EMBLGenbankAbstractDocument(const DocumentFormatId& _id, const QString& _formatName, int mls, QObject* p) 
-: DocumentFormat(p), id(_id), formatName(_formatName), maxAnnotationLineLen(mls)
+EMBLGenbankAbstractDocument::EMBLGenbankAbstractDocument(const DocumentFormatId& _id, const QString& _formatName, int mls, 
+                                                         DocumentFormatFlags flags, QObject* p) 
+: DocumentFormat(p, flags), id(_id), formatName(_formatName), maxAnnotationLineLen(mls)
 {
-}
-
-bool EMBLGenbankAbstractDocument::isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const {
-    Q_UNUSED(d); Q_UNUSED(op);
-	return (t == GObjectTypes::ANNOTATION_TABLE || t == GObjectTypes::DNA_SEQUENCE);
-}
-
-
-
-bool EMBLGenbankAbstractDocument::checkConstraints(const DocumentFormatConstraints& c) const {
-	foreach (GObjectType t, c.supportedObjectTypes) { 
-		if (t!=GObjectTypes::ANNOTATION_TABLE && t!=GObjectTypes::DNA_SEQUENCE) {
-			return false;
-		}
-	}
-	if (c.checkRawData) {
-		return isDataFormatSupported(c.rawData.constData(), c.rawData.size());
-	}
-    
-    bool ret = true;
-    if( c.supportsStreamingRead ) {
-        ret = ret && true;
-    }
-    return ret;
+    supportedObjectTypes+=GObjectTypes::ANNOTATION_TABLE;
+    supportedObjectTypes+=GObjectTypes::SEQUENCE;
 }
 
 
 //////////////////////////////////////////////////////////////////////////
 // loading
 
-Document* EMBLGenbankAbstractDocument::loadExistingDocument(IOAdapterFactory* iof, const QString& url, TaskStateInfo& ti, const QVariantMap& _fs) {
-	std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-	if (!io->open(url, IOAdapterMode_Read)) {
-        ti.setError(Translations::errorOpeningFileRead(url));
-		return NULL;
-	}
-
+Document* EMBLGenbankAbstractDocument::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& _fs, DocumentLoadMode mode) {
     QVariantMap fs = _fs;
     QList<GObject*> objects;
     QString writeLockReason;
-    load(url, io.get(), objects, fs, ti, writeLockReason, false );
-	io->close();
+    load(io, objects, fs, ti, writeLockReason, mode);
 
     if (ti.hasErrors() || ti.cancelFlag) {
-		return NULL;
-	}
+        return NULL;
+    }
 
     DocumentFormatUtils::updateFormatSettings(objects, fs);
-    Document* doc = new Document(this, iof, url, objects, fs, writeLockReason);
-	return doc;
-}
-
-Document* EMBLGenbankAbstractDocument::loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fSettings ) {
-    if( NULL == io || !io->isOpen() ) {
-        ti.setError(Translations::badArgument("IO adapter"));
-        return NULL;
-    }
-    QVariantMap fs = fSettings;
-    QList<GObject*> objects;
-    QString writeLockReason;
-    QString url = io->getUrl();
-    
-    load( url, io, objects, fs, ti, writeLockReason, true );
-    if (ti.hasErrors() || ti.cancelFlag) {
-        return NULL;
-    }
-    
-    DocumentFormatUtils::updateFormatSettings( objects, fs );
-    Document* doc = new Document( this, io->getFactory(), url, objects, fs, writeLockReason );
+    Document* doc = new Document(this, io->getFactory(), io->getURL(), objects, fs, writeLockReason);
     return doc;
 }
 
+
+
 const QString EMBLGenbankAbstractDocument::UGENE_MARK("UNIMARK");
 const QString EMBLGenbankAbstractDocument::DEFAULT_OBJ_NAME("unnamed");
 
 
-void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QList<GObject*>& objects, QVariantMap& fs, TaskStateInfo& si, QString& writeLockReason, bool onlyOne ) {
+void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects, QVariantMap& fs, TaskStateInfo& si, QString& writeLockReason, DocumentLoadMode mode) {
     writeLockReason.clear();
 
     //get settings
@@ -128,16 +83,16 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
 
     sequence.reserve(predictedSize + (merge ? gapSize : 0));
     
-	QSet<QString> usedNames;
-	bool toolMark = false;
+    QSet<QString> usedNames;
+    bool toolMark = false;
     int sequenceStart = 0;
-    GObjectReference sequenceRef(GObjectReference(docUrl, "", GObjectTypes::DNA_SEQUENCE));
+    GObjectReference sequenceRef(GObjectReference(io->getURL().getURLString(), "", GObjectTypes::SEQUENCE));
 
     QByteArray readBuffer(ParserState::READ_BUFF_SIZE, '\0');
     ParserState st(getFormatId() == BaseDocumentFormats::PLAIN_GENBANK ? 12 : 5, io, NULL, si);
     st.buff = readBuffer.data();
 
-	for (int i=0; !si.hasErrors() && !si.cancelFlag; i++) {
+    for (int i=0; !si.hasErrors() && !si.cancelFlag; i++) {
         if (!merge) {
             sequence.clear();
         } else if (sequence.size() > 0) {
@@ -148,9 +103,9 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
         EMBLGenbankDataEntry data;
         st.entry = &data;
         si.setStateDesc(tr("Reading entry header"));
-		if (!readEntry(sequence, &st)) {
-			break;
-		}
+        if (!readEntry(sequence, &st)) {
+            break;
+        }
         // tolerate blank lines between records
         char ch;
         bool b;
@@ -159,10 +114,10 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
             st.io->skip(-1);
         }
 
-		toolMark = data.tags.contains(UGENE_MARK);
+        toolMark = data.tags.contains(UGENE_MARK);
         AnnotationTableObject* annotationsObject  = NULL;
 
-		if (data.hasAnnotationObjectFlag) {
+        if (data.hasAnnotationObjectFlag) {
             QString annotationName = genObjectName(usedNames, data.name, data.tags, i+1, GObjectTypes::ANNOTATION_TABLE);
             if (merge && mergedAnnotations == NULL) {
                 mergedAnnotations = new AnnotationTableObject(annotationName);
@@ -181,7 +136,7 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
                         annotationsObject->getRootGroup()->getSubgroup(gName, true)->addAnnotation(a);
                     }
                 }
-			}
+            }
 
             if (!merge) {
                 objects.append(annotationsObject);
@@ -190,9 +145,9 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
             assert(data.features.isEmpty());
         }
         
-		if (!si.hasErrors() && !si.cancelFlag) {
+        if (!si.hasErrors() && !si.cancelFlag) {
             int sequenceLen = sequence.size() - sequenceStart;
-            QString sequenceName = genObjectName(usedNames, data.name, data.tags, i+1, GObjectTypes::DNA_SEQUENCE);
+            QString sequenceName = genObjectName(usedNames, data.name, data.tags, i+1, GObjectTypes::SEQUENCE);
             if (merge && sequenceLen == 0 && annotationsObject!=NULL) {
                 si.setError(tr("Merge error: found annotations without sequence"));
                 break;
@@ -209,7 +164,7 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
                 }
             }
         }
-        if( onlyOne ) {
+        if( mode == DocumentLoadMode_SingleObject ) {
             break;
         }
     }
@@ -218,7 +173,7 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
         assert(sequence.size() > gapSize);
         assert(qEqual(sequence.constEnd() - gapSize, sequence.constEnd(), gapSequence.constBegin()));
         sequence.resize(sequence.size() - gapSize);//remove last gap
-        DNASequenceObject* so = DocumentFormatUtils::addMergedSequenceObject(objects, docUrl, contigs, sequence, mergedMapping);
+        DNASequenceObject* so = DocumentFormatUtils::addMergedSequenceObject(objects, io->getURL(), contigs, sequence, mergedMapping);
         if (mergedAnnotations!=NULL) {
             sequenceRef.objName = so->getGObjectName();
             mergedAnnotations->addObjectRelation(GObjectRelation(sequenceRef, GObjectRelationRole::SEQUENCE));
@@ -231,7 +186,7 @@ void EMBLGenbankAbstractDocument::load(const QString& docUrl, IOAdapter* io, QLi
     }
 
     if (!toolMark) {
-		writeLockReason = DocumentFormat::CREATED_NOT_BY_UGENE;
+        writeLockReason = DocumentFormat::CREATED_NOT_BY_UGENE;
     } else if (merge && contigs.size() > 1) {
         writeLockReason = DocumentFormat::MERGED_SEQ_LOCK;
     }
@@ -264,8 +219,8 @@ static bool isNewQStart(const char* s, int l) {
 
 //TODO: make it IO active -> read util the end. Otherwise qualifier is limited in size by maxSize
 int EMBLGenbankAbstractDocument::readMultilineQualifier(IOAdapter* io, char* cbuff, int maxSize, bool _prevLineHasMaxSize) {
-	int len = 0;
-	bool lineOk = true;
+    int len = 0;
+    bool lineOk = true;
     static const int MAX_LINE = 256;
     int sizeToSkip = maxSize - MAX_LINE;
     const QBitArray& LINE_BREAKS = TextUtils::LINE_BREAKS;
@@ -298,16 +253,16 @@ int EMBLGenbankAbstractDocument::readMultilineQualifier(IOAdapter* io, char* cbu
         {
             io->skip(-readLen);
             break;
-		}
+        }
         if (breakWords && lineLen-A_COL > 0 && lineBuf[A_COL]!=' ') { //add space to separate words
             cbuff[len] = ' ';
             len++;
         }
-		qMemCopy(cbuff + len, lineBuf + A_COL, lineLen - A_COL);
-		len+=lineLen-A_COL;
+        qMemCopy(cbuff + len, lineBuf + A_COL, lineLen - A_COL);
+        len+=lineLen-A_COL;
         breakWords = breakWords || lineLen < maxAnnotationLineLen;
-	} while (true);
-	return len;
+    } while (true);
+    return len;
 }
 
 
@@ -335,7 +290,7 @@ QString EMBLGenbankAbstractDocument::genObjectName(QSet<QString>& usedNames, con
         }
         if(t == GObjectTypes::ANNOTATION_TABLE) {
             name+=" features";
-        } else if (t == GObjectTypes::DNA_SEQUENCE) {
+        } else if (t == GObjectTypes::SEQUENCE) {
             name+=" sequence";
         }
     }
@@ -460,7 +415,7 @@ bool EMBLGenbankAbstractDocument::readSequence(QByteArray& res, ParserState* st)
     QByteArray readBuffer(READ_BUFF_SIZE, '\0');
     char* buff  = readBuffer.data();
 
-    //reading sequence		
+    //reading sequence      
     QBuffer writer(&res);
     writer.open( QIODevice::WriteOnly | QIODevice::Append );
     bool ok = true;
@@ -520,7 +475,7 @@ bool EMBLGenbankAbstractDocument::readSequence(QByteArray& res, ParserState* st)
             break;
         }
 
-		si.progress = io->getProgress();
+        si.progress = io->getProgress();
     }
     if (!si.hasErrors() && !si.cancelFlag && buff[0] != '/') {
         si.setError(tr("Sequence is truncated"));
@@ -568,7 +523,6 @@ bool ParserState::hasKey( const char* key, int slen ) const {
 }
 
 QString ParserState::value() const {
-    assert (len >= valOffset);
     return len > valOffset ? QString::fromLocal8Bit(buff + valOffset, len - valOffset) : QString();
 }
 
