@@ -28,24 +28,15 @@ class EMBLGenbankDataEntry;
 class GB2_COREAPI_EXPORT EMBLGenbankAbstractDocument : public DocumentFormat {
     Q_OBJECT
 public:
-    EMBLGenbankAbstractDocument(const DocumentFormatId& id, const QString& formatName, int maxLineSize, QObject* p);
+    EMBLGenbankAbstractDocument(const DocumentFormatId& id, const QString& formatName, 
+                                int maxLineSize, DocumentFormatFlags flags, QObject* p);
 
     virtual DocumentFormatId getFormatId() const {return id;}
 
     virtual const QString& getFormatName() const {return formatName;}
 
-    virtual QStringList getSupportedDocumentFileExtensions() {return extensions;}
-
-    virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
+    virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
     
-    virtual Document* loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs );
-    
-    virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-
-    virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
-
-    virtual bool isDataFormatSupported(const char* data, int size) const = 0;
-
     static const QString UGENE_MARK;
     static const QString DEFAULT_OBJ_NAME;
 
@@ -54,7 +45,7 @@ public:
     
 protected:
 
-    virtual void load(const QString& docUrl, IOAdapter* io, QList<GObject*>& objects, QVariantMap& fs, TaskStateInfo& si, QString& writeLockReason, bool onlyOne );
+    virtual void load(IOAdapter* io, QList<GObject*>& objects, QVariantMap& fs, TaskStateInfo& si, QString& writeLockReason, DocumentLoadMode mode);
     
     virtual int     readMultilineQualifier(IOAdapter* io, char* cbuff, int maxSize, bool prevLineHasMaxSize);
     virtual SharedAnnotationData readAnnotation(IOAdapter* io, char* cbuff, int contentLen, int bufSize, TaskStateInfo& si, int offset);
@@ -66,7 +57,6 @@ protected:
     
     DocumentFormatId id;
     QString     formatName;
-    QStringList extensions;
     QByteArray  fPrefix;
     QByteArray  sequenceStartPrefix;
     int         maxAnnotationLineLen;
@@ -95,7 +85,7 @@ public:
 class ParserState {
 public:
     ParserState(int off, IOAdapter* io, EMBLGenbankDataEntry* e, TaskStateInfo& si)
-        : valOffset(off), entry(e), io(io), si(si) {}
+        : valOffset(off), entry(e), io(io), buff(NULL), len(0), si(si) {}
     const int valOffset;
     EMBLGenbankDataEntry* entry;
     IOAdapter* io;
