@@ -29,9 +29,9 @@ namespace GB2 {
 /* TRANSLATOR GB2::EMBLGenbankAbstractDocument */ 
 
 EMBLPlainTextFormat::EMBLPlainTextFormat(QObject* p) 
-: EMBLGenbankAbstractDocument(BaseDocumentFormats::PLAIN_EMBL, tr("EMBL"), 80, p) 
+: EMBLGenbankAbstractDocument(BaseDocumentFormats::PLAIN_EMBL, tr("EMBL"), 80, DocumentFormatFlag_SupportStreaming, p) 
 {
-	extensions << "em" << "emb" << "embl";
+	fileExtensions << "em" << "emb" << "embl";
     sequenceStartPrefix = "SQ";
     fPrefix = "FT";
 
@@ -43,24 +43,19 @@ EMBLPlainTextFormat::EMBLPlainTextFormat(QObject* p)
     tagMap["CO"] = DNAInfo::CONTIG;
 }
 
-bool EMBLPlainTextFormat::isDataFormatSupported(const char* data, int size) const {
-	//todo: improve handling
+bool EMBLPlainTextFormat::checkRawData(const QByteArray& rawData) const {
+    //TODO: improve format checking
+
+    const char* data = rawData.constData();
+    int size = rawData.size();
+
 	bool textOnly = !TextUtils::contains(TextUtils::BINARY, data, size);
 	if (!textOnly || size < 100) {
 		return false;
 	}
-    //todo: improve format checking
 	return TextUtils::equals("ID   ", data, 5);
 }
 
-bool EMBLPlainTextFormat::checkConstraints(const DocumentFormatConstraints& c) const {
-    if (c.mustSupportWrite) {
-        return false;
-    }
-    bool ok = EMBLGenbankAbstractDocument::checkConstraints(c);
-    return ok;
-}
-
 //////////////////////////////////////////////////////////////////////////
 // loading
 
