@@ -20,8 +20,7 @@ class GB2_COREAPI_EXPORT EMBLPlainTextFormat : public EMBLGenbankAbstractDocumen
 public:
     EMBLPlainTextFormat(QObject* p);
 
-    virtual bool isDataFormatSupported(const char* data, int size) const;
-    virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
+    virtual bool checkRawData(const QByteArray& rawData) const;
 
 protected:
 
