@@ -15,13 +15,12 @@
 #include <core_api/Task.h>
 #include <core_api/IOAdapter.h>
 #include <core_api/DNAAlphabet.h>
+#include <core_api/L10n.h>
 
 #include <gobjects/DNASequenceObject.h>
 #include <gobjects/AnnotationTableObject.h>
 #include <gobjects/GObjectTypes.h>
 #include <util_text/TextUtils.h>
-#include <util_gui/GUIUtils.h>
-#include <memory>
 
 namespace GB2 {
 
@@ -29,59 +28,35 @@ namespace GB2 {
 /* TRANSLATOR GB2::IOAdapter */
 /* TRANSLATOR GB2::Document */
 
-FastaFormat::FastaFormat(QObject* p) : DocumentFormat(p)
+FastaFormat::FastaFormat(QObject* p) : DocumentFormat(p, DocumentFormatFlags_SW, QStringList()<<"fa"<<"mpfa"<<"fna"<<"fsa"<<"fas"<<"fasta"<<"sef"<<"seq"<<"seqs")
 {
-	formatName = tr("FASTA");
+    formatName = tr("FASTA");
+    supportedObjectTypes+=GObjectTypes::SEQUENCE;
 }
 
-QStringList FastaFormat::getSupportedDocumentFileExtensions() {
-	QStringList l;
-	l<<"fa"<<"mpfa"<<"fna"<<"fsa"<<"fas"<<"fasta"<<"sef"<<"seq"<<"seqs";
-	return l;
-}
+bool FastaFormat::checkRawData(const QByteArray& rawData) const {
+    const char* data = rawData.constData();
+    int size = rawData.size();
 
-bool FastaFormat::isDataFormatSupported(const char* data, int size) const {
     int n = TextUtils::skip(TextUtils::WHITES, data, size);
     int newSize = size - n;
     const char* newData = data + n;
     if (newSize <= 0 || newData[0] != '>' ) {
-		return false;
-	}
-	return !TextUtils::contains(TextUtils::BINARY, data, size);
-}
-
-bool FastaFormat::isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const {
-    Q_UNUSED(d); Q_UNUSED(op);
-    return t == GObjectTypes::DNA_SEQUENCE;
-}
-
-
-bool FastaFormat::checkConstraints(const DocumentFormatConstraints& c) const {
-	bool ret = true;
-    foreach (GObjectType t, c.supportedObjectTypes) {
-        ret = ret && ( GObjectTypes::DNA_SEQUENCE == t );
-	}
-    if( !ret ) {
-        return ret;
+        return false;
     }
-    if (c.checkRawData) {
-		ret = ret && isDataFormatSupported(c.rawData.constData(), c.rawData.size());
-	}
-    if( c.supportsStreamingRead ) {
-        ret = ret && true;
-    }
-    return ret;
+    bool hasBinaryBlocks = TextUtils::contains(TextUtils::BINARY, data, size);
+    return hasBinaryBlocks ? false : true;
 }
 
 #define READ_BUFF_SIZE  4096
-static void load(IOAdapter* io, const QString& docUrl, QList<GObject*>& objects, TaskStateInfo& ti,
-                 int gapSize, int predictedSize, QString& writeLockReason, bool onlyOne ) {
+static void load(IOAdapter* io, const GUrl& docUrl, QList<GObject*>& objects, TaskStateInfo& ti,
+                 int gapSize, int predictedSize, QString& writeLockReason, DocumentLoadMode mode) {
     writeLockReason.clear();
-	QByteArray readBuff(READ_BUFF_SIZE+1, 0);
-	char* buff = readBuff.data();
-	qint64 len = 0;
+    QByteArray readBuff(READ_BUFF_SIZE+1, 0);
+    char* buff = readBuff.data();
+    qint64 len = 0;
     char fastaHeaderStartChar = '>';
-	QBitArray fastaHeaderStart = TextUtils::createBitMap(fastaHeaderStartChar);
+    QBitArray fastaHeaderStart = TextUtils::createBitMap(fastaHeaderStartChar);
 
     bool merge = gapSize!=-1;
     QByteArray sequence;
@@ -101,12 +76,12 @@ static void load(IOAdapter* io, const QString& docUrl, QList<GObject*>& objects,
     while (!ti.cancelFlag) {
         //read header
         len = io->readUntil(buff, READ_BUFF_SIZE, TextUtils::LINE_BREAKS, IOAdapter::Term_Include, &lineOk);
-		if (len == 0) { //end if stream
-			break;
-		}
-		if (!lineOk) {
-			ti.setError(FastaFormat::tr("line_is_too_long"));
-		}
+        if (len == 0) { //end if stream
+            break;
+        }
+        if (!lineOk) {
+            ti.setError(FastaFormat::tr("line_is_too_long"));
+        }
         QString headerLine = QString(QByteArray::fromRawData(buff+1, len-1)).trimmed();
         if (buff[0]!= fastaHeaderStartChar) {
             ti.setError(FastaFormat::tr("first_line_is_not_a_fasta_header"));
@@ -119,16 +94,16 @@ static void load(IOAdapter* io, const QString& docUrl, QList<GObject*>& objects,
             sequence.append(gapSequence);
             sequenceStart = sequence.size();
         }
-		do {
-			len = io->readUntil(buff, READ_BUFF_SIZE, fastaHeaderStart, IOAdapter::Term_Exclude);
-			if (len <= 0) {
-				break;
-			}
+        do {
+            len = io->readUntil(buff, READ_BUFF_SIZE, fastaHeaderStart, IOAdapter::Term_Exclude);
+            if (len <= 0) {
+                break;
+            }
             len = TextUtils::remove(buff, len, TextUtils::WHITES);
             buff[len] = 0;
-        	sequence.append(buff);
-			ti.progress = io->getProgress();
-		} while (!ti.cancelFlag);
+            sequence.append(buff);
+            ti.progress = io->getProgress();
+        } while (!ti.cancelFlag);
 
         if (merge) {
             headers.append(headerLine);
@@ -143,7 +118,7 @@ static void load(IOAdapter* io, const QString& docUrl, QList<GObject*>& objects,
             DocumentFormatUtils::addSequenceObject(objects, objName, seq);
         }
 
-        if( onlyOne ) {
+        if( mode == DocumentLoadMode_SingleObject ) {
             break;
         }
     }
@@ -162,39 +137,10 @@ static void load(IOAdapter* io, const QString& docUrl, QList<GObject*>& objects,
     }
 }
 
-Document* FastaFormat::loadExistingDocument(IOAdapterFactory* iof, const QString& url, TaskStateInfo& ti, const QVariantMap& _fs) {
-    //read file
-	std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-	if (!io->open(url, IOAdapterMode_Read)) {
-        ti.setError(Translations::errorOpeningFileRead(url));
-		return NULL;
-	}
 
-    QVariantMap fs = _fs;
-    QList<GObject*> objects;
-
-    //get settings
-    int gapSize = qBound(-1, DocumentFormatUtils::getIntSettings(fs, MERGE_MULTI_DOC_GAP_SIZE_SETTINGS, -1), 1000*1000);
-    int predictedSize = qMax(100*1000,
-        DocumentFormatUtils::getIntSettings(fs, MERGE_MULTI_DOC_SEQUENCE_SIZE_SETTINGS, gapSize==-1 ? 0 : io->left()));
-
-    QString lockReason;
-    load(io.get(), url, objects, ti, gapSize, predictedSize, lockReason, false );
-	io->close();
-
-	if (ti.hasErrors() || ti.cancelFlag) {
-		return NULL;
-	}
-
-    DocumentFormatUtils::updateFormatSettings(objects, fs);
-    Document* doc = new Document(this, iof, url, objects, fs, lockReason);
-	return doc;
-
-}
-
-Document* FastaFormat::loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& _fs ) {
+Document* FastaFormat::loadDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& _fs, DocumentLoadMode mode) {
     if( NULL == io || !io->isOpen() ) {
-        ti.setError(Translations::badArgument("IO adapter"));
+        ti.setError(L10N::badArgument("IO adapter"));
         return NULL;
     }
     QVariantMap fs = _fs;
@@ -205,14 +151,15 @@ Document* FastaFormat::loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, c
         DocumentFormatUtils::getIntSettings(fs, MERGE_MULTI_DOC_SEQUENCE_SIZE_SETTINGS, gapSize==-1 ? 0 : io->left()));
 
     QString lockReason;
-    load( io, io->getUrl(), objects, ti, gapSize, predictedSize, lockReason, true );
+    load(io, io->getURL(), objects, ti, gapSize, predictedSize, lockReason, mode);
 
     if (ti.hasErrors() || ti.cancelFlag) {
+        qDeleteAll(objects);
         return NULL;
     }
 
     DocumentFormatUtils::updateFormatSettings(objects, fs);
-    Document* doc = new Document( this, io->getFactory(), io->getUrl(), objects, fs, lockReason );
+    Document* doc = new Document(this, io->getFactory(), io->getURL(), objects, fs, lockReason);
     return doc;
 }
 
@@ -221,7 +168,7 @@ static void saveOneFasta( IOAdapter* io, GObject* fastaObj, TaskStateInfo& tsi )
     DNASequenceObject* seqObj = qobject_cast< DNASequenceObject* >( fastaObj );
 
     if ( NULL == seqObj ) {
-        tsi.setError(Translations::badArgument("NULL sequence" ));
+        tsi.setError(L10N::badArgument("NULL sequence" ));
         return;
     }
 
@@ -247,43 +194,15 @@ static void saveOneFasta( IOAdapter* io, GObject* fastaObj, TaskStateInfo& tsi )
             }
         }
     } catch (int) {
-        QString url = seqObj->getDocument() ? seqObj->getDocument()->getURL() : "";
-        tsi.setError(Translations::errorWritingFile(url));
+        GUrl url = seqObj->getDocument() ? seqObj->getDocument()->getURL() : GUrl();
+        tsi.setError(L10N::errorWritingFile(url));
     }
 }
 
-void FastaFormat::storeDocument(Document* doc, TaskStateInfo& ti, IOAdapterFactory* iof, const QString& newDocURL) {
-    assert(doc->getDocumentModLock(DocumentModLock_FORMAT_AS_INSTANCE) == NULL);
-    if (iof == NULL) {
-        iof = doc->getIOAdapterFactory();
-    }
-    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-    QString url = newDocURL.isEmpty() ? doc->getURL() : newDocURL;
-    if (!io->open(url, IOAdapterMode_Write)) {
-        ti.setError(Translations::errorOpeningFileWrite(url));
-        return;
-    }
-    save(io.get(), doc, ti);
-    io->close();
-}
-
-// stores only first fasta from document
 void FastaFormat::storeDocument( Document* doc, TaskStateInfo& ts, IOAdapter* io ) {
-    if( NULL == io || !io->isOpen() ) {
-        ts.setError(Translations::badArgument("IO adapter"));
-        return;
-    }
-    if( NULL == doc || doc->getObjects().isEmpty() ) {
-        ts.setError(Translations::badArgument("doc"));
-        return;
-    }
-    saveOneFasta( io, doc->getObjects().first(), ts );
-}
-
-void FastaFormat::save(IOAdapter* io, Document* d, TaskStateInfo& ti) {
     //TODO: check saved op states!!!
-    foreach( GObject* o, d->getObjects() ) {
-        saveOneFasta( io, o, ti );
+    foreach( GObject* o, doc->getObjects() ) {
+        saveOneFasta( io, o, ts );
     }
 }
 
