@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -27,21 +27,14 @@ public:
 
 	virtual const QString& getFormatName() const {return formatName;}
 
-	virtual QStringList getSupportedDocumentFileExtensions();
+	virtual Document* loadDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
+    
+    virtual void storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io );
 
-	virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
-
-	virtual void storeDocument(Document* d, TaskStateInfo& ti, IOAdapterFactory* io = NULL, const QString& newDocURL = QString::null);
-
-	virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-
-    virtual bool isDataFormatSupported(const char* data, int size) const;
-
-	virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
+    virtual bool checkRawData(const QByteArray& rawData) const;
 
 private:
-    void save(IOAdapter* io, Document* d, TaskStateInfo& ti);
-
+    
 	QString formatName;
 };
 
