@@ -22,18 +22,18 @@ class IOAdapter;
 class GB2_COREAPI_EXPORT FastqFormat : public DocumentFormat {
     Q_OBJECT
 public:
-    FastqFormat(QObject* p) : DocumentFormat(p), fn(tr("FASTQ")) {}
+    FastqFormat(QObject* p);
 
     virtual DocumentFormatId getFormatId() const {return BaseDocumentFormats::FASTQ;}
+
     virtual const QString& getFormatName() const {return fn;}
-    virtual QStringList getSupportedDocumentFileExtensions() {return QStringList("fastq");}
+    
+    virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
+    
+    virtual void storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io );
 
-    virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
-    virtual Document* loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& formatSettings );
+    virtual bool checkRawData(const QByteArray& rawData) const;
 
-    virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-    virtual bool isDataFormatSupported(const char* data, int size) const;
-    virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
 private:
     QString fn;
 };
