@@ -13,17 +13,19 @@
 #include "GenbankFeatures.h"
 #include "DocumentFormatUtils.h"
 
+#include <core_api/DNAAlphabet.h>
+#include <core_api/IOAdapter.h>
+#include <core_api/Task.h>
+#include <core_api/L10n.h>
+
+#include <datatype/DNAInfo.h>
+
 #include <gobjects/AnnotationTableObject.h>
 #include <gobjects/DNASequenceObject.h>
 #include <gobjects/GObjectUtils.h>
 #include <gobjects/GObjectRelationRoles.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/Task.h>
-#include <core_api/DNAAlphabet.h>
-#include <datatype/DNAInfo.h>
 
 #include <util_text/TextUtils.h>
-#include <util_gui/GUIUtils.h>
 #include <workflow_support/QVariantUtils.h>
 
 #include <memory>
@@ -35,20 +37,23 @@ namespace GB2 {
 /* TRANSLATOR GB2::IOAdapter */
 
 GenbankPlainTextFormat::GenbankPlainTextFormat(QObject* p)
-: EMBLGenbankAbstractDocument(BaseDocumentFormats::PLAIN_GENBANK, tr("Genbank"), 79, p)
+: EMBLGenbankAbstractDocument(BaseDocumentFormats::PLAIN_GENBANK, tr("Genbank"), 79, DocumentFormatFlags_SW, p)
 {
-    extensions << "gb" << "gbk" << "gen" << "genbank";
+    fileExtensions << "gb" << "gbk" << "gen" << "genbank";
     sequenceStartPrefix = "ORIGIN";
     fPrefix = "  ";
 }
 
-bool GenbankPlainTextFormat::isDataFormatSupported(const char* data, int size) const {
-    //todo: improve handling
+bool GenbankPlainTextFormat::checkRawData(const QByteArray& rawData) const {
+    //TODO: improve handling
+    const char* data = rawData.constData();
+    int size = rawData.size();
     bool textOnly = !TextUtils::contains(TextUtils::BINARY, data, size);
     if (!textOnly || size < 100) {
         return false;
     }
-    return TextUtils::equals("LOCUS ", data, 6);
+    bool startsWithLocus = TextUtils::equals("LOCUS ", data, 6);
+    return startsWithLocus ? true : false;
 }
 
 
@@ -183,34 +188,6 @@ bool GenbankPlainTextFormat::readEntry(QByteArray& sequence, ParserState* st) {
 //////////////////////////////////////////////////////////////////////////
 /// saving
 
-void GenbankPlainTextFormat::storeDocument(Document* doc, TaskStateInfo& ti, IOAdapterFactory* iof, const QString& newDocURL) {
-    //assert(doc->getDocumentModLock(DocumentModLock_FORMAT_AS_INSTANCE) == NULL);
-    if (iof == NULL) {
-        iof = doc->getIOAdapterFactory();
-    }
-    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-    QString url = newDocURL.isEmpty() ? doc->getURL() : newDocURL;
-    if (!io->open(url, IOAdapterMode_Write)) {
-        ti.setError(Translations::errorOpeningFileWrite(url));
-        return;
-    }
-    save(io.get(), doc, ti);
-    io->close();
-}
-
-void GenbankPlainTextFormat::storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io ) {
-    //assert( d->getDocumentModLock(DocumentModLock_FORMAT_AS_INSTANCE) == NULL );
-    if( NULL == d ) {
-        ts.setError(Translations::badArgument("doc"));
-        return;
-    }
-    if( NULL == io || !io->isOpen() ) {
-        ts.setError(Translations::badArgument("IO adapter"));
-        return;
-    }
-    save( io, d, ts );
-}
-
 static QString genLocusString(QList<GObject*> aos, DNASequenceObject* so);
 static void writeAnnotations(IOAdapter* io, QList<GObject*> aos, TaskStateInfo& si);
 static void writeSequence(IOAdapter* io, DNASequenceObject* ao, TaskStateInfo& si);
@@ -334,8 +311,8 @@ static QList<StrPair> formatKeywords(DNASequenceObject* so) {
     return res;
 }
 
-void GenbankPlainTextFormat::save(IOAdapter* io, Document* doc, TaskStateInfo& si) {
-    QList<GObject*> seqs = doc->findGObjectByType(GObjectTypes::DNA_SEQUENCE);
+void GenbankPlainTextFormat::storeDocument( Document* doc, TaskStateInfo& si, IOAdapter* io ) {
+    QList<GObject*> seqs = doc->findGObjectByType(GObjectTypes::SEQUENCE);
     QList<GObject*> anns = doc->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
 
     while (!seqs.isEmpty() || !anns.isEmpty()) {
@@ -403,7 +380,7 @@ void GenbankPlainTextFormat::save(IOAdapter* io, Document* doc, TaskStateInfo& s
         QByteArray lastLine("//\n");
         qint64 len = io->writeBlock(lastLine);
         if (len!=lastLine.size()) {
-            si.setError(Translations::errorWritingFile(doc->getURL()));
+            si.setError(L10N::errorWritingFile(doc->getURL()));
             return;
         }
     }
@@ -583,7 +560,7 @@ static void writeSequence(IOAdapter* io, DNASequenceObject* ao, TaskStateInfo& s
     bool ok = true;
     int blen = io->writeBlock(QByteArray("ORIGIN\n"));
     if (blen != 7) {
-        si.setError(Translations::errorWritingFile(ao->getDocument()->getURL()));
+        si.setError(L10N::errorWritingFile(ao->getDocument()->getURL()));
         return;
     }
     for (int pos = 0; pos < slen; pos+=charsInLine) {
@@ -631,7 +608,7 @@ static void writeSequence(IOAdapter* io, DNASequenceObject* ao, TaskStateInfo& s
         }
     }
     if (!ok) {
-        si.setError(Translations::errorWritingFile(ao->getDocument()->getURL()));
+        si.setError(L10N::errorWritingFile(ao->getDocument()->getURL()));
     }
 }
 
