@@ -20,13 +20,11 @@ class GB2_COREAPI_EXPORT GenbankPlainTextFormat : public EMBLGenbankAbstractDocu
 public:
 	GenbankPlainTextFormat(QObject* p);
 
-    virtual void storeDocument(Document* d, TaskStateInfo& ts, IOAdapterFactory* io = NULL, const QString& newDocURL = QString::null);
     virtual void storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io );
     
-    virtual bool isDataFormatSupported(const char* data, int size) const;
+    virtual bool checkRawData(const QByteArray& rawData) const;
 
 protected:
-    virtual void save(IOAdapter* io, Document* doc, TaskStateInfo& si);
 
     bool readIdLine(ParserState*);
     bool readEntry(QByteArray&, ParserState*);
