@@ -22,8 +22,8 @@ public:
     const char*    head;
     int             pos;
     int             size;
-    const uchar* ubuf() {return (const uchar*)(head + pos);}
-    const char* buf() {return (head + pos);}
+    const uchar* ubuf() const {return (const uchar*)(head + pos);}
+    const char* buf() const {return (head + pos);}
     uchar next() {return *(head + pos++);}
     int read(char* buf, int len) {
         if (pos + len <= size) {
@@ -85,6 +85,41 @@ inline int be_read_int_4(SeekableBuf* fp, uint *i4) {
     return 1;
 }
 
+
+/*
+* Write a big-endian int1
+*/
+inline int be_write_int_1(FILE *fp, uchar *i1)
+{
+    if (fwrite(i1, sizeof(uchar), 1, fp) != 1) return (0);
+    return (1);
+}
+
+
+/*
+* Write a big-endian int2
+*/
+inline int be_write_int_2(FILE *fp, ushort *i2)
+{
+    ushort i = be_int2( reinterpret_cast<const uchar*>(i2) );
+
+    if (fwrite(&i, 2, 1, fp) != 1) return (0);
+    return (1);
+}
+
+/*
+* Write a big-endian int4
+*/
+inline int be_write_int_4(FILE *fp, uint *i4)
+{
+    uint i = be_int4(reinterpret_cast<const uchar*> (i4));
+
+    if (fwrite(&i, 4, 1, fp) != 1) return (0);
+
+    return (1);
+}
+
+
 /*
 * Copyright (c) Medical Research Council 1994. All rights reserved.
 *
