@@ -25,22 +25,18 @@ public:
 
 	virtual const QString& getFormatName() const {return formatName;}
 
-	virtual QStringList getSupportedDocumentFileExtensions();
-
 	virtual Document* createNewDocument(IOAdapterFactory* io, const QString& url, const QVariantMap& fs = QVariantMap());
 	
-	virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
+	virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
 
-	virtual void storeDocument(Document* d, TaskStateInfo& ti, IOAdapterFactory* io = NULL, const QString& newDocURL = QString::null);
+	virtual void storeDocument(Document* d, TaskStateInfo& ts, IOAdapter* io);
 
-	virtual bool isDataFormatSupported(const char* data, int size) const;
-
-	virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-
-	virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
+	virtual bool checkRawData(const QByteArray& rawData) const;
 
     virtual int getFormatDetectionPriority() const {return -10;}
 
+	static void storeRawData(const QByteArray& data, TaskStateInfo& ts, IOAdapter* io);
+
 private:
 	QString formatName;
 };
