@@ -11,30 +11,28 @@
 #include "RawDNASequenceFormat.h"
 
 #include "DocumentFormatUtils.h"
+#include "PlainTextFormat.h"
 
 #include <core_api/Task.h>
 #include <core_api/IOAdapter.h>
-#include <gobjects/GObjectTypes.h>
-#include <util_text/TextUtils.h>
-#include <datatype/DNASequence.h>
 
-#include <memory>
+#include <gobjects/GObjectTypes.h>
+#include <gobjects/DNASequenceObject.h>
+
+#include <util_text/TextUtils.h>
 
 namespace GB2 {
 
 /* TRANSLATOR GB2::RawDNASequenceFormat */
 /* TRANSLATOR GB2::IOAdapter */
 
-RawDNASequenceFormat::RawDNASequenceFormat(QObject* p) : DocumentFormat(p)
+RawDNASequenceFormat::RawDNASequenceFormat(QObject* p) : DocumentFormat(p, DocumentFormatFlags_W1)
 {
-	formatName = tr("raw_dna_sequence_format");
+    formatName = tr("raw_dna_sequence_format");
+    fileExtensions << "seq" << "txt";
+    supportedObjectTypes+=GObjectTypes::SEQUENCE;
 }
 
-QStringList RawDNASequenceFormat::getSupportedDocumentFileExtensions() {
-	QStringList l;
-    l<<"seq" << "txt";
-	return l;
-}
 
 static void load(IOAdapter* io, QList<GObject*>& objects, TaskStateInfo& ti) {
     static int READ_BUFF_SIZE = 4096;
@@ -65,7 +63,7 @@ static void load(IOAdapter* io, QList<GObject*>& objects, TaskStateInfo& ti) {
                 ok = writer.putChar(c);
             }
         }
-		ti.progress = io->getProgress();
+        ti.progress = io->getProgress();
     }
     writer.close();
     if (ti.hasErrors()) {
@@ -79,50 +77,32 @@ static void load(IOAdapter* io, QList<GObject*>& objects, TaskStateInfo& ti) {
     DocumentFormatUtils::addSequenceObject(objects, "Sequence", dnaseq);
 }
 
-Document* RawDNASequenceFormat::loadExistingDocument(IOAdapterFactory* iof, const QString& url, TaskStateInfo& ti, const QVariantMap& fs) {
-	std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
-
-	if (!io->open(url, IOAdapterMode_Read)) {
-		ti.setError(IOAdapter::tr("error_opening_url_for_read '%1'").arg(url));
-		return NULL;
-	}
+Document* RawDNASequenceFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode) {
     QList<GObject*> objects;
-    load(io.get(), objects, ti);
-    io->close();
-
+    load(io, objects, ti);
+    
     if (ti.hasErrors()) {
         return NULL;
     }
 
-    Document* doc = new Document(this, iof, url, objects, fs);
+    Document* doc = new Document(this, io->getFactory(), io->getURL(), objects, fs);
     return doc;
 }
 
-bool RawDNASequenceFormat::isDataFormatSupported(const char* data, int size) const {
-	return !TextUtils::contains(TextUtils::BINARY, data, size);
+bool RawDNASequenceFormat::checkRawData(const QByteArray& rawData) const {
+    const char* data = rawData.constData();
+    int size = rawData.size();
+    bool hasBinaryData = TextUtils::contains(TextUtils::BINARY, data, size);
+    //returning 'looks like' here just because it's impossible to have 100% detection here
+    return hasBinaryData ? false : true; 
 }
 
-bool RawDNASequenceFormat::isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const{
-    Q_UNUSED(d); Q_UNUSED(op);
-	return (t == GObjectTypes::DNA_SEQUENCE);
-}
-
-bool RawDNASequenceFormat::checkConstraints(const DocumentFormatConstraints& c) const {
-	foreach (GObjectType t, c.supportedObjectTypes) {
-		if (t!=GObjectTypes::DNA_SEQUENCE) {
-			return false;
-		}
-	}
-	if (c.checkRawData) {
-		return isDataFormatSupported(c.rawData.constData(), c.rawData.size());
-	}
-    if (c.mustSupportWrite) {
-        return false;
-    }
-    if( c.supportsStreamingRead ) {
-        return false;
-    }
-    return true;
+void RawDNASequenceFormat::storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io) {
+	assert(d->getObjects().size() ==1);
+	GObject* obj = d->getObjects().first();
+	DNASequenceObject* so = qobject_cast<DNASequenceObject*>(obj);
+	assert(so!=NULL);
+	PlainTextFormat::storeRawData(so->getDNASequence().seq, ts, io);
 }
 
 
