@@ -25,15 +25,11 @@ public:
 
 	virtual const QString& getFormatName() const {return formatName;}
 
-	virtual QStringList getSupportedDocumentFileExtensions();
+	virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
 
-	virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
+	virtual void storeDocument(Document* d, TaskStateInfo& ts, IOAdapter* io);
 
-	virtual bool isDataFormatSupported(const char* data, int size) const;
-
-	virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-
-	virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
+	virtual bool checkRawData(const QByteArray& rawData) const;
 
     virtual int getFormatDetectionPriority() const {return -20;}
 
