@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -18,6 +18,8 @@ namespace GB2 {
 
 class IOAdapter;
 class SeekableBuf;
+class DNAChromatogram;
+class DNASequence;
 
 class GB2_COREAPI_EXPORT  SCFFormat : public DocumentFormat {
     Q_OBJECT
@@ -28,21 +30,16 @@ public:
 
 	virtual const QString& getFormatName() const {return formatName;}
 
-	virtual QStringList getSupportedDocumentFileExtensions();
+	virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
 
-	virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
+    virtual bool checkRawData(const QByteArray& rawData) const;
 
-	virtual void storeDocument(Document* d, TaskStateInfo& ti, IOAdapterFactory* io = NULL, const QString& newDocURL = QString::null);
-
-	virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-	    
-    virtual bool isDataFormatSupported(const char* data, int size) const;
-
-	virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
+    static void exportDocumentToSCF(const QString& fileName, const DNAChromatogram& cd, const DNASequence& dna, TaskStateInfo& ts);
 
 private:
-    Document* parseSCF(SeekableBuf*, IOAdapterFactory* io, const QString& url, const QVariantMap& fs);
-	QString formatName;
+    Document* parseSCF(SeekableBuf*, IOAdapterFactory* io, const GUrl& url, const QVariantMap& fs);
+
+    QString formatName;
 };
 
 }//namespace
