@@ -454,6 +454,37 @@ void AnnotationGroup::getSubgroupPaths(QStringList& res) const {
     }
 }
 
+QDataStream& operator>>(QDataStream& dataStream, AnnotationGroup* parentGroup) {
+    QString name;
+    dataStream >> name;
+    AnnotationGroup *group = parentGroup->getSubgroup(name, true);
+    int s;
+    dataStream >> s;
+    for (int i = 0; i < s; ++i) {
+        AnnotationData *adata = new AnnotationData;
+        dataStream >> *adata;
+        Annotation *a = new Annotation(QSharedDataPointer<AnnotationData>(adata));
+        group->addAnnotation(a);
+    }
+    dataStream >> s;
+    for (int i = 0; i < s; ++i)
+        dataStream >> group;
+    return dataStream;
+}
+
+QDataStream& operator<<(QDataStream& dataStream, const AnnotationGroup& group) {
+    dataStream << group.name;
+    int s = group.annotations.size();
+    dataStream << s;
+    for (int i = 0; i < s; ++i)
+        dataStream << *group.annotations[i]->data();
+    s = group.subgroups.size();
+    dataStream << s;
+    for (int i = 0; i < s; ++i)
+        dataStream << *group.subgroups[i];
+    return dataStream;
+}
+
 //////////////////////////////////////////////////////////////////////////
 /// Annotation table object
 
@@ -572,19 +603,20 @@ void AnnotationTableObject::addAnnotations(const QList<Annotation*>& list, const
 
 
 void AnnotationTableObject::removeAnnotations(const QList<Annotation*>& annotations) {
+    emit si_onAnnotationsRemoved(annotations);
     foreach(Annotation* a, annotations) {
         _removeAnnotation(a);
     }
     setModified(true);
-    emit si_onAnnotationsRemoved(annotations);
     qDeleteAll(annotations);
 }
 
 void AnnotationTableObject::removeAnnotation(Annotation* a) {
-    QList<Annotation*> v; v<<a;
+    QList<Annotation*> v; 
+    v<<a;
+    emit si_onAnnotationsRemoved(v);
     _removeAnnotation(a);
     setModified(true);
-    emit si_onAnnotationsRemoved(v);
     delete a;
 }
 
