@@ -176,6 +176,9 @@ public:
     bool isTopLevelGroup() const {return parentGroup!=NULL && parentGroup->isRootGroup();}
 
 private:
+    friend QDataStream& operator>>(QDataStream& dataStream, AnnotationGroup* parentGroup);
+    friend QDataStream& operator<<(QDataStream& dataStream, const AnnotationGroup& group);
+
     QString                 name;
     AnnotationTableObject*  obj;
     AnnotationGroup*        parentGroup;
@@ -183,6 +186,9 @@ private:
     QList<AnnotationGroup*> subgroups;
 };
 
+QDataStream& operator>>(QDataStream& dataStream, AnnotationGroup* parentGroup);
+QDataStream& operator<<(QDataStream& dataStream, const AnnotationGroup& group);
+
 class GB2_COREAPI_EXPORT AnnotationTableObject: public GObject {
     Q_OBJECT
     friend class Annotation;
