@@ -17,43 +17,43 @@
 namespace GB2 {
 
 DNASequenceObject::DNASequenceObject(const QString& name, const DNASequence& seq, const QVariantMap& hintsMap) 
-: GObject(GObjectTypes::DNA_SEQUENCE, name, hintsMap), dnaSeq(seq)
+: GObject(GObjectTypes::SEQUENCE, name, hintsMap), dnaSeq(seq)
 {
     assert(dnaSeq.alphabet!=NULL);
     seqRange = LRegion(0, dnaSeq.seq.length());
 }
 
 GObject* DNASequenceObject::clone() const {
-	DNASequenceObject* cln = new DNASequenceObject(getGObjectName(), dnaSeq, getGHintsMap());
+    DNASequenceObject* cln = new DNASequenceObject(getGObjectName(), dnaSeq, getGHintsMap());
     cln->setIndexInfo(getIndexInfo());
     return cln;
 }
 
 void DNASequenceObject::setBase(int pos, char base) {
-	assert(pos >=0 && pos < dnaSeq.length());
-	dnaSeq.seq[pos] = base;
-	setModified(true);
+    assert(pos >=0 && pos < dnaSeq.length());
+    dnaSeq.seq[pos] = base;
+    setModified(true);
 }
 
-bool DNASequenceObject::checkConstraints(const GObjectConstraints* c) const	{
-	const DNASequenceObjectConstraints* dnac = qobject_cast<const DNASequenceObjectConstraints*>(c);
-	bool resultDNAConstraints = true;
-	bool resultAlphabetType = true;
+bool DNASequenceObject::checkConstraints(const GObjectConstraints* c) const {
+    const DNASequenceObjectConstraints* dnac = qobject_cast<const DNASequenceObjectConstraints*>(c);
+    bool resultDNAConstraints = true;
+    bool resultAlphabetType = true;
 
-	if (dnac->exactSequenceSize != dnaSeq.length()) {
-		resultDNAConstraints = false;
-	}
-	if (dnac->exactSequenceSize <= 0)	{
-		resultDNAConstraints = true;
-	}
-	if (dnac->alphabetType != getAlphabet()->getType())	{
-		resultAlphabetType = false;
-	}
-	if (dnac->alphabetType == DNAAlphabet_RAW)	{
-		resultAlphabetType = true;
-	}
+    if (dnac->exactSequenceSize != dnaSeq.length()) {
+        resultDNAConstraints = false;
+    }
+    if (dnac->exactSequenceSize <= 0)   {
+        resultDNAConstraints = true;
+    }
+    if (dnac->alphabetType != getAlphabet()->getType()) {
+        resultAlphabetType = false;
+    }
+    if (dnac->alphabetType == DNAAlphabet_RAW)  {
+        resultAlphabetType = true;
+    }
 
-	return (resultDNAConstraints && resultAlphabetType);
+    return (resultDNAConstraints && resultAlphabetType);
 }
 
 void DNASequenceObject::setSequence( DNASequence seq ){
@@ -64,7 +64,13 @@ void DNASequenceObject::setSequence( DNASequence seq ){
     emit si_sequenceChanged();
 }
 
-DNASequenceObjectConstraints::DNASequenceObjectConstraints(QObject* p) : GObjectConstraints(GObjectTypes::DNA_SEQUENCE, p){}
+void DNASequenceObject::setQuality( const DNAQuality& quality )
+{
+    setModified(true);
+    dnaSeq.quality = quality;
+    emit si_sequenceChanged();
+}
+DNASequenceObjectConstraints::DNASequenceObjectConstraints(QObject* p) : GObjectConstraints(GObjectTypes::SEQUENCE, p){}
 
 
 
