@@ -23,11 +23,13 @@ class  GB2_COREAPI_EXPORT DNASequenceObject: public GObject {
 public:
     DNASequenceObject(const QString& name, const DNASequence& seq, const QVariantMap& hintsMap = QVariantMap());
 
-    const LRegion getSequenceRange() const {return seqRange;}
+    const LRegion& getSequenceRange() const {return seqRange;}
 
     const QByteArray& getSequence() const {return dnaSeq.seq;}
 
     DNAAlphabet* getAlphabet() const {return dnaSeq.alphabet;}
+    
+    const DNAQuality& getQuality() const { return dnaSeq.quality; }
 
     const DNASequence& getDNASequence() const {return dnaSeq;}
 
@@ -41,6 +43,8 @@ public:
 
     void setSequence(DNASequence seq);
 
+    void setQuality(const DNAQuality& quality);
+
 signals:
     void si_sequenceChanged();
 
