@@ -10,7 +10,9 @@
 
 #include "MAlignmentObject.h"
 
+#include <core_api/DNAAlphabet.h>
 #include <datatype/DNASequence.h>
+#include <util_algorithm/MSAUtils.h>
 
 namespace GB2 {
 
@@ -22,62 +24,24 @@ GObject* MAlignmentObject::clone() const {
 
 
 void MAlignmentObject::insertGap(int seqNum, int pos, int nGaps) {
-    int aliLen = msa.getLength();
-    int nSeqs = msa.getNumSequences();
-    assert(seqNum >=0 && seqNum <= nSeqs);
-    assert(pos >=0 && pos <= aliLen);
-    assert(nGaps > 0);
-    assert(msa.isNormalized());
-    assert(!isStateLocked());
-    
-    MAlignment maBefore = msa; //TODO: high mem use probabilty -> limit and use empty maBefore?
-
-    int nGapsAtEnd = 0;
-    MAlignmentItem& affItem = msa.alignedSeqs[seqNum];
-    for (; nGapsAtEnd < nGaps; nGapsAtEnd++) {
-        char c = affItem.sequence[aliLen - 1 - nGapsAtEnd];
-        if (c != MAlignment_GapChar) {
-            break;
-        }
-    }
-    //now trim nGapsAtEnd in affected item
-    if (nGapsAtEnd > 0) {
-        affItem.sequence.resize(aliLen - nGapsAtEnd);
-    }
-
-    //insert nGaps to the selected sequence
-    QByteArray gapAff(nGaps, MAlignment_GapChar);
-    affItem.sequence.insert(pos, gapAff);
-
-    //insert nGaps - nGapsAtEnd to other sequences
-    if (nGaps - nGapsAtEnd > 0) {
-        QByteArray gapOthers(nGaps - nGapsAtEnd , MAlignment_GapChar);
-        for (int i=0; i < nSeqs; i++) {
-            MAlignmentItem& item = msa.alignedSeqs[i];
-            if (i != seqNum) {
-                item.sequence.append(gapOthers);
-            }
-        }
-    }
-
-    setModified(true);
+	assert(!isStateLocked());
+	MAlignment maBefore = msa;
+	msa.insertChars(seqNum, pos, MAlignment_GapChar, nGaps);
 
+	setModified(true);
     MAlignmentModInfo mi;
     mi.sequenceListChanged = false;
     emit si_alignmentChanged(maBefore, mi);
 }
 
 void MAlignmentObject::insertGap(int pos, int nGaps) {
-    assert(pos >= 0 && pos <= msa.getLength());
     assert(nGaps > 0);
-    assert(msa.isNormalized());
     assert(!isStateLocked());
 
     MAlignment maBefore = msa;
     QByteArray gap(nGaps, MAlignment_GapChar);
-    for (int i=0, n = msa.getNumSequences(); i < n; i++) {
-        MAlignmentItem& item = msa.alignedSeqs[i];
-        item.sequence.insert(pos, gap);
+    for (int i=0, n = msa.getNumRows(); i < n; i++) {
+		msa.insertChars(i, pos, MAlignment_GapChar, nGaps);
     }
 
     setModified(true);
@@ -88,50 +52,43 @@ void MAlignmentObject::insertGap(int pos, int nGaps) {
 }
 
 int MAlignmentObject::deleteGap(int seqNum, int pos, int maxGaps) {
-    assert(seqNum >=0 && seqNum <= msa.getNumSequences());
-    assert(maxGaps > 0 && pos + maxGaps <= msa.getLength());
-    assert(pos >=0 && pos+maxGaps <= msa.getLength());
-    assert(msa.isNormalized());
     assert(!isStateLocked());
 
     MAlignment maBefore = msa;
 
-    int nDeleted = 0;
-    MAlignmentItem& delItem = msa.alignedSeqs[seqNum];
-    for(int i = pos, n = pos + maxGaps; i<n; i++) {
-        char c = delItem.sequence[i];
-        if (c != MAlignment_GapChar) {
-            break;
-        }
-        nDeleted++;
-    }
-    if (nDeleted == 0) {
-        return 0;
-    }
-    delItem.sequence.remove(pos, nDeleted);
-    delItem.sequence.append(QByteArray(nDeleted, MAlignment_GapChar));
-
-    setModified(true);
+	int n = 0, max = qBound(0, maxGaps, msa.getLength() - pos);
+	while (n < max) {
+		char c = msa.charAt(seqNum, pos + n);
+		if (c != MAlignment_GapChar) { //not a gap
+			break;
+		}
+		n++;
+	}
+	if (n == 0) {
+		return 0;
+	}
+	msa.removeChars(seqNum, pos, n);
+    
+	setModified(true);
 
     MAlignmentModInfo mi;
     mi.sequenceListChanged = false;
     emit si_alignmentChanged(maBefore, mi);
 
-    return nDeleted;
+    return n;
 }
 
 int MAlignmentObject::deleteGap(int pos, int maxGaps) {
-    assert(pos >=0 && pos <= msa.getLength());
-    assert(msa.isNormalized());
     assert(!isStateLocked());
 
     MAlignment maBefore = msa;
     //find min gaps in all sequences starting from pos
     int minGaps = maxGaps;
-    foreach(const MAlignmentItem& item, msa.alignedSeqs) {
+	int max = qBound(0, maxGaps, msa.getLength() - pos);
+    foreach(const MAlignmentRow& row, msa.getRows()) {
         int nGaps = 0;
-        for (int i=pos, n = pos+maxGaps; i < n; i++, nGaps++) {
-            if (item.sequence[i]!=MAlignment_GapChar) { 
+        for (int i = pos; i < pos + max; i++, nGaps++) {
+            if (row.chatAt(i) != MAlignment_GapChar) { 
                 break;
             }
         }
@@ -144,10 +101,10 @@ int MAlignmentObject::deleteGap(int pos, int maxGaps) {
         return  0;
     }
     int nDeleted = minGaps;
-    for (int i=0, n = msa.getNumSequences(); i < n; i++) {
-        MAlignmentItem& item = msa.alignedSeqs[i];
-        item.sequence.remove(pos, nDeleted);
+    for (int i = 0, n = msa.getNumRows(); i < n; i++) {
+		msa.removeChars(i, pos, nDeleted);
     }
+	msa.setLength(msa.getLength() - nDeleted);
 
     setModified(true);
 
@@ -158,37 +115,29 @@ int MAlignmentObject::deleteGap(int pos, int maxGaps) {
     return nDeleted;
 }
 
-void MAlignmentObject::addSequence(const DNASequence& seq, int seqIdx) {
+
+void MAlignmentObject::addRow(const DNASequence& seq, int seqIdx) {
     assert(!isStateLocked());
-    assert(msa.isNormalized());
-    assert(seq.alphabet == msa.alphabet);
-    assert(seq.length() == msa.getLength());
-    
     MAlignment maBefore = msa;
 
-    MAlignmentItem mai(seq.getName(), seq.seq);
-    if (seqIdx < 0 || seqIdx >= msa.getLength()) {
-        msa.alignedSeqs.append(mai);
-    } else {
-        msa.alignedSeqs.insert(seqIdx, mai);
-    }
-
+    DNAAlphabet* newAlphabet = DNAAlphabet::deriveCommonAlphabet(seq.alphabet, getAlphabet());
+    assert(newAlphabet != NULL);
+    msa.setAlphabet(newAlphabet);
+	
+	MAlignmentRow row(seq.getName(), seq.seq, 0);
+    msa.addRow(row, seqIdx);
+    
     setModified(true);
 
     MAlignmentModInfo mi;
-    mi.sequenceContentChanged = false;
     emit si_alignmentChanged(maBefore, mi);
 }
 
-void MAlignmentObject::removeSequence(int seqNum) {
-    assert(seqNum >= 0 && seqNum <= msa.getNumSequences());
-    assert(msa.isNormalized());
+void MAlignmentObject::removeRow(int seqNum) {
     assert(!isStateLocked());
 
     MAlignment maBefore = msa;
-
-    msa.alignedSeqs.removeAt(seqNum);
-
+    msa.removeRow(seqNum);
     setModified(true);
 
     MAlignmentModInfo mi;
@@ -200,7 +149,6 @@ void MAlignmentObject::removeSequence(int seqNum) {
 
 void MAlignmentObject::setMAlignment(const MAlignment& newMa) {
     assert(!isStateLocked());
-    assert(newMa.isNormalized());
 
     MAlignment maBefore = msa;
 
@@ -218,6 +166,51 @@ void MAlignmentObject::setGObjectName(const QString& newName) {
     GObject::setGObjectName(newName);
 }
 
+void MAlignmentObject::removeRegion(int startPos, int startRow, int nBases, int nRows, bool removeEmptyRows) {
+    assert(!isStateLocked());
+    MAlignment maBefore = msa;
+
+	msa.removeRegion(startPos, startRow, nBases, nRows, removeEmptyRows);
+    
+    setModified(true);
+    MAlignmentModInfo mi;
+    emit si_alignmentChanged(maBefore, mi);
+
+    
+}
+
+void MAlignmentObject::renameRow( int seqNum, const QString& newName ) {
+    assert(seqNum >= 0 && seqNum < msa.getNumRows());
+    assert(!isStateLocked());
+    assert(!newName.isEmpty());
+
+    const QString& curName = msa.getRow(seqNum).getName();
+    if (curName == newName) {
+        return;
+    }
+
+    MAlignment maBefore = msa;
+    msa.renameRow(seqNum, newName);
+    setModified(true);
+
+    MAlignmentModInfo mi;
+    emit si_alignmentChanged(maBefore, mi);
+}
+
+void MAlignmentObject::crop( LRegion window, const QSet<QString>& rowNames )
+{
+    assert(!isStateLocked());
+    MAlignment maBefore = msa;
+
+    msa.crop(window, rowNames);
+
+    setModified(true);
+    MAlignmentModInfo mi;
+    emit si_alignmentChanged(maBefore, mi);    
+}
+
+
+
 }//namespace
 
 
