@@ -22,8 +22,6 @@ namespace GB2 {
 class GHints;
 class DNASequence;
 
-#define MA_OBJECT_NAME QString("Multiple alignment")
-
 class MAlignmentModInfo {
 public:
     MAlignmentModInfo() : sequenceContentChanged(true), sequenceListChanged(true) {}
@@ -35,12 +33,12 @@ class GB2_COREAPI_EXPORT MAlignmentObject : public GObject {
     Q_OBJECT
 public:
 
-    MAlignmentObject(const MAlignment& a, const QVariantMap& hintsMap = QVariantMap())
+    explicit MAlignmentObject(const MAlignment& a, const QVariantMap& hintsMap = QVariantMap())
         : GObject(GObjectTypes::MULTIPLE_ALIGNMENT, a.getName(), hintsMap), msa(a){};
 
     const MAlignment& getMAlignment() const {return msa;}
-
-    char getBase(int seqNum, int pos) const {return msa.getBase(seqNum, pos);}
+	
+	char charAt(int seqNum, int pos) const {return msa.charAt(seqNum, pos);}
 
     virtual GObject* clone() const;
 
@@ -52,14 +50,24 @@ public:
     
     int deleteGap(int pos, int maxGaps);
 
-    void addSequence(const DNASequence& seq, int seqIdx);
+	void addRow(const DNASequence& seq, int seqIdx = -1);
 
-    void removeSequence(int seqNum);
+    void removeRow(int seqNum);
+
+    void renameRow(int seqNum, const QString& newName);
+
+    void removeRegion(int startPos, int startRow, int nBases, int nRows, bool removeEmptyRows);
+
+    void crop(LRegion window, const QSet<QString>& rowNames);
 
     void setMAlignment(const MAlignment& ma);
 
+    DNAAlphabet* getAlphabet() const { return msa.getAlphabet(); }
+
     virtual void setGObjectName(const QString& newName);
 
+	int getLength() const {return msa.getLength();}
+
 signals:
     void si_alignmentChanged(const MAlignment& maBefore, const MAlignmentModInfo& modInfo);
     
@@ -67,6 +75,7 @@ protected:
     MAlignment msa;
 };
 
+
 }//namespace
 
 
