@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -25,13 +25,24 @@ public:
         : GObject(GObjectTypes::PHYLOGENETIC_TREE, objectName, hintsMap), tree(_tree){};
 
     virtual const PhyTree& getTree() const {return tree;}
+    
+    // Warning!
+    // PhyBranches can be accessed and modified!
+    // TODO: move branches to private data, add getters and setters
+    const PhyNode* findPhyNodeByName(const QString& name);
 
     virtual GObject* clone() const;
+    
+    // Utility functions
+    
+    // Compares number of nodes and nodes with names (how many nodes etc.)
+    static bool treesAreAlike(const PhyTree& tree1, const PhyTree& tree2);
 
 protected:
     PhyTree tree;
 };
 
+
 }//namespace
 
 
