@@ -23,6 +23,8 @@
 
 namespace GB2 {
 
+#define MAX_GET_LENGTH 3000
+
 HttpFileAdapterFactory::HttpFileAdapterFactory(QObject* o) : IOAdapterFactory(o) {
 	name = tr("http_file");
 }		
@@ -48,15 +50,16 @@ QNetworkProxy HttpFileAdapterFactory::getProxyByUrl( const QUrl & url ) const {
 
 
 HttpFileAdapter::HttpFileAdapter(HttpFileAdapterFactory* factory, QObject* o) 
-: IOAdapter(factory, o), cached(false), begin_ptr(-1), end_ptr(0), http(0), badstate(false), is_downloaded(false), downloaded(0), total(0)
+: IOAdapter(factory, o), is_cached(false), begin_ptr(-1), end_ptr(0), 
+http(0), badstate(false), is_downloaded(false), downloaded(0), total(0)
 {
     chunk_list.push_back( QByteArray(CHUNKSIZE, char(0)) );
 }		
 
-bool HttpFileAdapter::open(const QString& url_, IOAdapterMode m) {
-    Q_UNUSED(m);
+bool HttpFileAdapter::open(const GUrl& url_, IOAdapterMode m) {
+	Q_UNUSED(m);
     assert(m==IOAdapterMode_Read);
-    QUrl url( url_.trimmed() );
+    QUrl url( url_.getURLString().trimmed() );
     if( !url.isValid() ) {
         return false;
     }
@@ -64,6 +67,7 @@ bool HttpFileAdapter::open(const QString& url_, IOAdapterMode m) {
     if( !url.scheme().isEmpty() && !https && url.scheme() != "http" ) {
         return false;
     }
+	gurl = url_;
     init();
 
     HttpFileAdapterFactory * f = qobject_cast<HttpFileAdapterFactory*> ( getFactory() ); 
@@ -90,7 +94,15 @@ bool HttpFileAdapter::open( const QString& host, const QString & what, const QNe
 //    connect( http, SIGNAL(stateChanged(int)), this, SLOT(state(int)), Qt::DirectConnection );
     connect( http, SIGNAL(done(bool)), this, SLOT(done(bool)), Qt::DirectConnection );
     connect( http, SIGNAL(readyRead(const QHttpResponseHeader&)), this, SLOT(add_data(const QHttpResponseHeader&)), Qt::DirectConnection );
-    http->get( what );
+    
+    if(what.length()>MAX_GET_LENGTH) {
+        QString path = what.split("?").first();
+        QByteArray params = what.split("?").last().toAscii();
+        http->post(path,params);
+    }
+    else {
+        http->get( what );
+    }
 
     return true;
 }
@@ -104,6 +116,7 @@ void HttpFileAdapter::close() {
 	http->abort();
 	delete http;
 	http = 0;
+	gurl = GUrl();
     init();
 }
 
@@ -159,7 +172,7 @@ bool HttpFileAdapter::skip(qint64 nBytes) {
                 rwmut.unlock();
                 return false;
             }
-            chunk_list.prepend( cached );
+            chunk_list.prepend( cache );
             begin_ptr = CHUNKSIZE - (-nBytes - begin_ptr);
             is_cached = false;
         }
@@ -175,11 +188,10 @@ qint64 HttpFileAdapter::left() const {
     return (is_downloaded ? stored() : -1);
 }
 
-void HttpFileAdapter::init()
-{
+void HttpFileAdapter::init() {
     badstate = false;
     is_downloaded = false;
-    cached = false;
+    is_cached= false;
     chunk_list.clear();
     chunk_list.append( QByteArray(CHUNKSIZE, 0) );
     loop.exit();
@@ -252,11 +264,11 @@ void HttpFileAdapter::skipFromChunk( qint64 nbytes )
 void HttpFileAdapter::popFront()
 {
     if( singleChunk() ) {
-        cached = chunk_list.first();
+        cache = chunk_list.first();
         Empty();
     } else {
         begin_ptr = 0;
-        cached = chunk_list.takeFirst();
+        cache = chunk_list.takeFirst();
         is_cached = true;
     }
 }
