@@ -39,6 +39,8 @@ public:
 
     QNetworkProxy getProxyByUrl( const QUrl & url ) const;
 
+	virtual TriState isResourceAvailable(const GUrl& ) const  {return TriState_Unknown;}
+
 protected:
     QString name;
 };
@@ -57,7 +59,7 @@ public:
     HttpFileAdapter(HttpFileAdapterFactory* f, QObject* o = NULL);
     ~HttpFileAdapter() {if (isOpen()) close();}
 	
-    virtual bool open(const QString& url, IOAdapterMode m);
+    virtual bool open(const GUrl& url, IOAdapterMode m);
 
     bool open(const QString& host, const QString & what, const QNetworkProxy & p, quint16 port=80, bool https=false);
 
@@ -74,6 +76,8 @@ public:
     virtual qint64 left() const;
 
     virtual int getProgress() const;
+	
+	virtual GUrl getURL() const {return gurl;}
 
 private:
     void        init();
@@ -91,7 +95,7 @@ private:
 
     static const int CHUNKSIZE = 32 * 1024;
     QLinkedList<QByteArray> chunk_list; 
-    QByteArray cached;
+    QByteArray cache;
     bool is_cached;
     int begin_ptr; //pointer to the first byte of data in first chunk
     int end_ptr; //pointer to the first free byte in last chunk 
@@ -106,6 +110,7 @@ private:
 //    QWaitCondition cond;
     QMutex rwmut;
     QEventLoop loop;
+	GUrl gurl;
 private slots:
     void add_data( const QHttpResponseHeader & resp );
     void done( bool error );
