@@ -13,6 +13,8 @@
 
 #include <core_api/IOAdapter.h>
 
+#include <QtCore/QFileInfo>
+
 namespace GB2 {
 
 class GB2_COREAPI_EXPORT LocalFileAdapterFactory: public IOAdapterFactory {
@@ -28,7 +30,7 @@ public:
 
 	virtual bool isIOModeSupported(IOAdapterMode m)  const {Q_UNUSED(m); return true;} //files can be read and be written
 
-    virtual TriState exists(const QString& url) const {return QFileInfo(url).exists() ? TriState_Yes : TriState_No;}
+    virtual TriState isResourceAvailable(const GUrl& url) const {return QFileInfo(url.getURLString()).exists() ? TriState_Yes : TriState_No;}
 
 protected:
 	QString name;
@@ -52,7 +54,7 @@ public:
 	LocalFileAdapter(LocalFileAdapterFactory* f, QObject* o = NULL);
 	~LocalFileAdapter() {if (isOpen()) close();}
 	
-	virtual bool open(const QString& url, IOAdapterMode m);
+	virtual bool open(const GUrl& url, IOAdapterMode m);
 
 	virtual bool isOpen() const {return f!=NULL;}
 
@@ -69,7 +71,7 @@ public:
     
     virtual qint64 bytesRead() const;
     
-    virtual QString getUrl() const;
+    virtual GUrl getURL() const;
     
 private:
 	QFile* f;
