@@ -24,6 +24,20 @@
 
 namespace GB2 {
 
+//Warn: works only for pointer type
+template<class T> static void removeDuplicatesPointersFromList(QList<T*>& list) {
+    QSet<const T*> tracked;
+    for(int i=0, n = list.size(); i < n ; i++) {
+        const T* val =  list.at(i);
+        if (tracked.contains(val)) {
+            list[i] = NULL;
+        } else {
+            tracked.insert(val);
+        }
+    }
+    list.removeAll(NULL);
+}
+
 QSet<GObject*> SelectionUtils::findObjects(GObjectType t, const MultiGSelection* ms, UnloadedObjectFilter f) {
 	QSet<GObject*> res;
 	foreach(const GSelection* s, ms->getSelections()) {
@@ -33,24 +47,42 @@ QSet<GObject*> SelectionUtils::findObjects(GObjectType t, const MultiGSelection*
 	return res;
 }
 
+QList<GObject*> SelectionUtils::findObjectsKeepOrder(GObjectType t, const MultiGSelection* ms, UnloadedObjectFilter f) {
+    QList<GObject*> res;
+    foreach(const GSelection* s, ms->getSelections()) {
+        QList<GObject*> tmp = findObjectsKeepOrder(t, s, f);
+        res+=tmp;
+    }
+    
+    //now remove duplicates from list
+    removeDuplicatesPointersFromList<GObject>(res);
+
+    return res;
+}
+
 QSet<GObject*> SelectionUtils::findObjects(GObjectType t, const GSelection* s, UnloadedObjectFilter f) {
-	QSet<GObject*> res;
-	GSelectionType stype = s->getSelectionType();
-	if (stype == GSelectionTypes::DOCUMENTS) {
-		const DocumentSelection* ds = qobject_cast<const DocumentSelection*>(s);
-		foreach(Document* d, ds->getSelectedDocuments()) {
-			const QList<GObject*>& objs= d->getObjects();
-            QSet<GObject*> tmp = GObjectUtils::select(objs, t, f).toSet();
-			res+=tmp;
-		}
-	} else  if (stype == GSelectionTypes::GOBJECTS) {
-		const GObjectSelection* os = qobject_cast<const GObjectSelection*>(s);
-		const QList<GObject*>& objs= os->getSelectedObjects();
-		res = GObjectUtils::select(objs, t, f).toSet();
-	}
+	QSet<GObject*> res = findObjectsKeepOrder(t, s, f).toSet();
 	return res;
 }
 
+QList<GObject*> SelectionUtils::findObjectsKeepOrder(GObjectType t, const GSelection* s, UnloadedObjectFilter f) {
+    QList<GObject*> res;
+    GSelectionType stype = s->getSelectionType();
+    if (stype == GSelectionTypes::DOCUMENTS) {
+        const DocumentSelection* ds = qobject_cast<const DocumentSelection*>(s);
+        foreach(Document* d, ds->getSelectedDocuments()) {
+            const QList<GObject*>& objs= d->getObjects();
+            QList<GObject*> tmp = GObjectUtils::select(objs, t, f);
+            res+=tmp;
+        }
+    } else  if (stype == GSelectionTypes::GOBJECTS) {
+        const GObjectSelection* os = qobject_cast<const GObjectSelection*>(s);
+        const QList<GObject*>& objs= os->getSelectedObjects();
+        res = GObjectUtils::select(objs, t, f);
+    }
+    return res;
+}
+
 
 QSet<Document*>	SelectionUtils::findDocumentsWithObjects(GObjectType t, const MultiGSelection* ms, UnloadedObjectFilter f, bool deriveDocsFromObjectSelection) {
 	QSet<Document*> res;
@@ -65,7 +97,7 @@ QSet<Document*>	SelectionUtils::findDocumentsWithObjects(GObjectType t, const GS
 	GSelectionType st = s->getSelectionType();
 	if (st == GSelectionTypes::DOCUMENTS) {
 		DocumentFormatConstraints c;
-		c.supportedObjectTypes.append(t);
+		c.supportedObjectTypes += t;
 		const DocumentSelection* ds = qobject_cast<const DocumentSelection*>(s);
 		const QList<Document*>& docs = ds->getSelectedDocuments();
 		foreach(Document* d, docs) {
