@@ -172,7 +172,7 @@ void TaskSchedulerImpl::processNewSubtasks() {
 
         int nParallel = ti->task->getNumParallelSubtasks();
         int nNew = ti->newSubtasks.size();
-        int nToRun = qMin(nParallel, nNew) - ti->numRunningSubtasks;
+        int nToRun = qMin(nParallel, nNew) - ti->numActiveSubtasks();
         int nRun = 0;
         for (int j=0; j < nToRun; j++) {
             Task* newSub = ti->newSubtasks[j];
@@ -553,6 +553,7 @@ void TaskSchedulerImpl::checkSerialPromotion(TaskInfo* pti, Task* subtask) {
     }
 #else
     Q_UNUSED(pti);
+    Q_UNUSED(subtask);
 #endif
 }
 
@@ -564,6 +565,7 @@ static void checkFinishedState(TaskInfo* ti) {
     assert(ti->newSubtasks.empty());
     assert(ti->task->getSubtasks().size() == ti->numFinishedSubtasks);
     assert(ti->numRunningSubtasks  == 0);
+    assert(ti->numPreparedSubtasks  == 0);
 #else
     Q_UNUSED(ti);
 #
@@ -591,13 +593,17 @@ void TaskSchedulerImpl::promoteTask(TaskInfo* ti, Task::State newState) {
     checkSerialPromotion(pti, ti->task);
     switch(newState) {
         case Task::State_Prepared:
-            if (ti->task->isTopLevelTask() && ti->task->isVerboseLogMode()) {
-                log.info(tr("Starting {%1} task").arg(ti->task->getTaskName()));
+            if (pti!=NULL) {
+                pti->numPreparedSubtasks++;
+                if (ti->task->isTopLevelTask() && ti->task->isVerboseLogMode()) {
+                    log.info(tr("Starting {%1} task").arg(ti->task->getTaskName()));
+                }
             }
             break;
         case Task::State_Running:
             tti.startTime = GTimer::currentTimeMicros();
             if (pti!=NULL) {
+                pti->numPreparedSubtasks--;
                 pti->numRunningSubtasks++;
                 if (pti->task->getState() < Task::State_Running) {
                     assert(pti->task->getState() == Task::State_Prepared);
@@ -627,6 +633,35 @@ void TaskSchedulerImpl::promoteTask(TaskInfo* ti, Task::State newState) {
             break;
         default: assert(0);
     }
+#ifdef _DEBUG
+    Task* parentTask = task->getParentTask();
+    if (parentTask!=NULL){
+        int localPreparedSubs, localRunningSubs, localFinishedSubs, localNewSubs, localTotalSubs;
+        localTotalSubs = localNewSubs = localPreparedSubs = localRunningSubs = localFinishedSubs = 0;
+        foreach (Task* sub, parentTask->getSubtasks()){
+            switch (sub->getState()){
+                case Task::State_New:
+                    localNewSubs++;
+                    break;
+                case Task::State_Prepared:
+                    localPreparedSubs++;
+                    break;
+                case Task::State_Running:
+                    localRunningSubs++;
+                    break;
+                case Task::State_Finished:
+                    localFinishedSubs++;
+                    break;
+            }
+            localTotalSubs++;
+        }
+        assert(localPreparedSubs == pti->numPreparedSubtasks);
+        assert(localRunningSubs == pti->numRunningSubtasks);
+        assert(localPreparedSubs+localRunningSubs == pti->numActiveSubtasks());
+        assert(localFinishedSubs == pti->numFinishedSubtasks);
+        assert(localTotalSubs == localNewSubs+localPreparedSubs+localRunningSubs+localFinishedSubs);
+    }
+#endif
     updateTaskProgressAndDesc(ti);
 }
 
@@ -652,8 +687,10 @@ void TaskSchedulerImpl::updateTaskProgressAndDesc(TaskInfo* ti) {
 
     //update progress
     int newProgress = tsi.progress;
+    bool updateProgress = false;
     if (task->isFinished()) {
         newProgress = 100;
+        updateProgress = tsi.progress != newProgress;
     } else if (task->getProgressManagementType() == Task::Progress_Manual) {
         int prevProgress = ti->prevProgress;
         if (tsi.progress != prevProgress) {
@@ -674,9 +711,10 @@ void TaskSchedulerImpl::updateTaskProgressAndDesc(TaskInfo* ti) {
             }
             newProgress = qRound(sum / maxSum);
         }
+        updateProgress = tsi.progress != newProgress;
     }
 
-    if (tsi.progress != newProgress) {
+    if (updateProgress) {
         tsi.progress = newProgress;
         emit_taskProgressChanged(task);
     }
@@ -704,9 +742,9 @@ static QThread::Priority getThreadPriority(Task* t) {
 
 static void updateThreadPriority(TaskInfo* ti) {
     assert(ti->thread!=NULL);
-    QThread::Priority tp = getThreadPriority(ti->task->getTopLevelParentTask());
-    if (ti->thread->priority() != tp) {
-        ti->thread->setPriority(tp);
+	QThread::Priority tp = getThreadPriority(ti->task->getTopLevelParentTask());
+    if (ti->thread->priority() != tp && ti->thread->isRunning()) {
+		ti->thread->setPriority(tp);	
     }
 }
 
@@ -731,6 +769,18 @@ void TaskSchedulerImpl::sl_threadFinished() {
     timer.setInterval(0);
 }
 
+Task * TaskSchedulerImpl::getTopLevelTaskById( qint64 id ) const {
+    Task * ret = NULL;
+    foreach( Task * task, topLevelTasks ) {
+        assert( NULL != task );
+        if( id == task->getTaskId() ) {
+            ret = task;
+            break;
+        }
+    }
+    return ret;
+}
+
 void TaskThread::run() {
     assert(!ti->selfRunFinished);
     assert(ti->task->getState()== Task::State_Running);
@@ -741,5 +791,15 @@ void TaskThread::run() {
     ti->selfRunFinished = true;
 }
 
+TaskInfo::~TaskInfo() {
+    if (thread!=NULL) {
+        if (!thread->isFinished()) {
+            log.trace("TaskScheduler: Waiting for the thread before delete");
+            thread->wait();
+            log.trace("TaskScheduler: Wait finished");
+        }
+        delete thread;
+    }
+}
 
 }//namespace
