@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -36,8 +36,20 @@ private:
 
 class GB2_COREAPI_EXPORT TestFramework {
 public:
+    static const int TEST_TIMEOUT_DEFAULT = 0;
+    static const QString TEST_TIMEOUT_CMD_OPTION;
+    
+private:
+    static bool helpRegistered;
+    static void setTRHelpSections();
+    
+public:
+    TestFramework();
     GTestFormatRegistry* getTestFormatRegistry() {return &formatRegistry;}
 
+private:
+    void setTestRunnerSettings();
+    
 private:
     GTestFormatRegistry formatRegistry;
 };
