@@ -28,6 +28,8 @@ namespace GB2 {
 #define START_ATTR  "seqstart"
 #define OBJ_ATTR    "obj"
 #define SEQNAME_ATTR  "seqname"
+#define QUALITY_ATTR "quality"
+#define POSITION_ATTR "pos"
 
 void GTest_DNASequenceSize::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
@@ -125,7 +127,7 @@ void GTest_DNASequencePart::init(XMLTestFormat *tf, const QDomElement& el) {
         return;
     } 
     
-	QString p = el.attribute(START_ATTR);
+    QString p = el.attribute(START_ATTR);
     if (p.isEmpty()) {
         failMissingValue(START_ATTR);
         return;
@@ -157,10 +159,10 @@ Task::ReportResult GTest_DNASequencePart::report() {
     if (!objSequence->getAlphabet()->isCaseSensitive()) {
         subseq = subseq.toUpper();
     }
-	if (objSubSeq != subseq){	
-	    stateInfo.setError(QString("region not matched: %1, expected %2").arg(objSubSeq.constData()).arg(subseq.constData()));
-	    return ReportResult_Finished;
-	}
+    if (objSubSeq != subseq){   
+        stateInfo.setError(QString("region not matched: %1, expected %2").arg(objSubSeq.constData()).arg(subseq.constData()));
+        return ReportResult_Finished;
+    }
     return ReportResult_Finished;
 }
 void GTest_DNASequenceAlphabetType::init(XMLTestFormat *tf, const QDomElement& el) {
@@ -172,26 +174,26 @@ void GTest_DNASequenceAlphabetType::init(XMLTestFormat *tf, const QDomElement& e
         return;
     }
 
-	QString v = el.attribute(VALUE_ATTR);
+    QString v = el.attribute(VALUE_ATTR);
     if (v.isEmpty()) {
         failMissingValue(VALUE_ATTR);
         return;
     } 
-	if (v == "DNAAlphabet_RAW"){
-		alphabetType = DNAAlphabet_RAW;
-		return;
-	}
-	if (v == "DNAAlphabet_NUCL"){
-		alphabetType = DNAAlphabet_NUCL;
-		return;
-	}
-	if (v == "DNAAlphabet_AMINO"){
-		alphabetType = DNAAlphabet_AMINO;
-		return;
-	}
-	stateInfo.setError(QString("alphabetType not set %1").arg(VALUE_ATTR));
+    if (v == "DNAAlphabet_RAW"){
+        alphabetType = DNAAlphabet_RAW;
+        return;
+    }
+    if (v == "DNAAlphabet_NUCL"){
+        alphabetType = DNAAlphabet_NUCL;
+        return;
+    }
+    if (v == "DNAAlphabet_AMINO"){
+        alphabetType = DNAAlphabet_AMINO;
+        return;
+    }
+    stateInfo.setError(QString("alphabetType not set %1").arg(VALUE_ATTR));
     return;
-	
+    
 }
 Task::ReportResult GTest_DNASequenceAlphabetType::report() {
     GObject *obj = getContext<GObject>(this,objContextName);
@@ -200,15 +202,15 @@ Task::ReportResult GTest_DNASequenceAlphabetType::report() {
         return ReportResult_Finished;  
     }
 
-	DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
-	if(mySequence==NULL){
+    DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
+    if(mySequence==NULL){
         stateInfo.setError(QString("can't cast to sequence from: %1").arg(obj->getGObjectName()));
         return ReportResult_Finished;
     }
-	DNAAlphabet *tempAlphabet = mySequence->getAlphabet();
-	if( tempAlphabet->getType() != alphabetType){	
-		stateInfo.setError(QString("Alphabet type not matched: %1, expected %2").arg(tempAlphabet->getType()).arg(alphabetType));
-	}
+    DNAAlphabet *tempAlphabet = mySequence->getAlphabet();
+    if( tempAlphabet->getType() != alphabetType){   
+        stateInfo.setError(QString("Alphabet type not matched: %1, expected %2").arg(tempAlphabet->getType()).arg(alphabetType));
+    }
     return ReportResult_Finished;
 }
 void GTest_DNASequenceAlphabetId::init(XMLTestFormat *tf, const QDomElement& el) {
@@ -220,13 +222,13 @@ void GTest_DNASequenceAlphabetId::init(XMLTestFormat *tf, const QDomElement& el)
         return;
     }
 
-	alpId = el.attribute(VALUE_ATTR);
+    alpId = el.attribute(VALUE_ATTR);
     if (alpId.isEmpty()) {
         failMissingValue(VALUE_ATTR);
         return;
     } 
     return;
-	
+    
 }
 Task::ReportResult GTest_DNASequenceAlphabetId::report() {
     GObject *obj = getContext<GObject>(this, objContextName);
@@ -235,15 +237,15 @@ Task::ReportResult GTest_DNASequenceAlphabetId::report() {
         return ReportResult_Finished;  
     }
 
-	DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
-	if(mySequence==NULL){
+    DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
+    if(mySequence==NULL){
         stateInfo.setError(QString("can't cast to sequence from: %1").arg(obj->getGObjectName()));
         return ReportResult_Finished;
     }
-	DNAAlphabet *tempAlphabet = mySequence->getAlphabet();
-	if( tempAlphabet->getId() != alpId){	
-		stateInfo.setError(QString("Alphabet id not matched: %1 expected %2").arg(tempAlphabet->getId()).arg(alpId));
-	}
+    DNAAlphabet *tempAlphabet = mySequence->getAlphabet();
+    if( tempAlphabet->getId() != alpId){    
+        stateInfo.setError(QString("Alphabet id not matched: %1 expected %2").arg(tempAlphabet->getId()).arg(alpId));
+    }
     return ReportResult_Finished;
 }
 
@@ -287,7 +289,7 @@ Task::ReportResult GTest_DNAcompareSequencesNamesInTwoObjects::report() {
         obj = objs.at(i);
         obj2 = objs2.at(i);
         
-        if((obj->getGObjectType()== GObjectTypes::DNA_SEQUENCE)&&(obj2->getGObjectType()== GObjectTypes::DNA_SEQUENCE)){
+        if((obj->getGObjectType()== GObjectTypes::SEQUENCE)&&(obj2->getGObjectType() == GObjectTypes::SEQUENCE)){
             mySequence = qobject_cast<DNASequenceObject*>(obj);
             if(mySequence==NULL){
                 stateInfo.setError(QString("can't cast to sequence from: %1 in position %2").arg(obj->getGObjectName()).arg(i));
@@ -360,7 +362,7 @@ Task::ReportResult GTest_DNAcompareSequencesInTwoObjects::report() {
         obj = objs.at(i);
         obj2 = objs2.at(i);
         
-        if((obj->getGObjectType()== GObjectTypes::DNA_SEQUENCE)&&(obj2->getGObjectType()== GObjectTypes::DNA_SEQUENCE)){
+        if((obj->getGObjectType()== GObjectTypes::SEQUENCE)&&(obj2->getGObjectType()== GObjectTypes::SEQUENCE)){
             mySequence = qobject_cast<DNASequenceObject*>(obj);
             if(mySequence==NULL){
                 stateInfo.setError(QString("can't cast to sequence from: %1 in position %2").arg(obj->getGObjectName()).arg(i));
@@ -432,7 +434,7 @@ Task::ReportResult GTest_DNAcompareSequencesAlphabetsInTwoObjects::report() {
         obj = objs.at(i);
         obj2 = objs2.at(i);
         
-        if((obj->getGObjectType()== GObjectTypes::DNA_SEQUENCE)&&(obj2->getGObjectType()== GObjectTypes::DNA_SEQUENCE)){
+        if((obj->getGObjectType()== GObjectTypes::SEQUENCE)&&(obj2->getGObjectType()== GObjectTypes::SEQUENCE)){
             mySequence = qobject_cast<DNASequenceObject*>(obj);
             if(mySequence==NULL){
                 stateInfo.setError(QString("can't cast to sequence from: %1 in position %2").arg(obj->getGObjectName()).arg(i));
@@ -475,13 +477,13 @@ void GTest_DNAMulSequenceAlphabetId::init(XMLTestFormat *tf, const QDomElement&
         return;
     }
 
-	alpId = el.attribute(VALUE_ATTR);
+    alpId = el.attribute(VALUE_ATTR);
     if (alpId.isEmpty()) {
         failMissingValue(VALUE_ATTR);
         return;
     } 
     return;
-	
+    
 }
 Task::ReportResult GTest_DNAMulSequenceAlphabetId::report() {
     GObject *obj = getContext<GObject>(this, objContextName);
@@ -490,18 +492,20 @@ Task::ReportResult GTest_DNAMulSequenceAlphabetId::report() {
         return ReportResult_Finished;  
     }
 
-	MAlignmentObject* myMSequence= qobject_cast<MAlignmentObject*>(obj);
-	if(myMSequence==NULL){
+    MAlignmentObject* myMSequence= qobject_cast<MAlignmentObject*>(obj);
+    if(myMSequence==NULL){
         stateInfo.setError(QString("can't cast to sequence from: %1").arg(obj->getGObjectName()));
         return ReportResult_Finished;
     }
-    DNAAlphabet *tempAlphabet = myMSequence->getMAlignment().alphabet;
-	if( tempAlphabet->getId() != alpId){	
-		stateInfo.setError(QString("Alphabet id not matched: %1 expected %2").arg(tempAlphabet->getId()).arg(alpId));
-	}
+    const DNAAlphabet *tempAlphabet = myMSequence->getAlphabet();
+    if( tempAlphabet->getId() != alpId){    
+        stateInfo.setError(QString("Alphabet id not matched: %1 expected %2").arg(tempAlphabet->getId()).arg(alpId));
+    }
     return ReportResult_Finished;
 }
 
+//-----------------------------------------------------------------------------
+
 void GTest_DNAMulSequenceSize::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
 
@@ -542,6 +546,9 @@ Task::ReportResult GTest_DNAMulSequenceSize::report() {
     }
     return ReportResult_Finished;
 }
+
+//-----------------------------------------------------------------------------
+
 void GTest_DNAMulSequencePart::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
 
@@ -557,7 +564,7 @@ void GTest_DNAMulSequencePart::init(XMLTestFormat *tf, const QDomElement& el) {
         return;
     } 
     
-	QString p = el.attribute(START_ATTR);
+    QString p = el.attribute(START_ATTR);
     if (p.isEmpty()) {
         failMissingValue(START_ATTR);
         return;
@@ -594,17 +601,17 @@ Task::ReportResult GTest_DNAMulSequencePart::report() {
         return ReportResult_Finished;
     }
     
-    if (!myMSequence->getMAlignment().alphabet->isCaseSensitive()) {
+    if (!myMSequence->getAlphabet()->isCaseSensitive()) {
         subseq = subseq.toUpper();
     }
     bool ok_flag=false;
-    foreach(MAlignmentItem myItem , myMSequence->getMAlignment().alignedSeqs){
-        if(myItem.name==seqName){
+    foreach(const MAlignmentRow& myItem , myMSequence->getMAlignment().getRows()){
+        if (myItem.getName() == seqName){
             ok_flag=true;
-            QByteArray objSubSeq = myItem.sequence.mid(startPos, subseq.length());
-	        if (objSubSeq != subseq){	
-	            stateInfo.setError(QString("region not matched: %1, expected %2").arg(objSubSeq.constData()).arg(subseq.constData()));
-	            return ReportResult_Finished;
+            QByteArray objSubSeq = myItem.mid(startPos, subseq.length()).toByteArray(subseq.length());
+            if (objSubSeq != subseq){   
+                stateInfo.setError(QString("region not matched: %1, expected %2").arg(objSubSeq.constData()).arg(subseq.constData()));
+                return ReportResult_Finished;
             }
         }   
     }
@@ -614,6 +621,68 @@ Task::ReportResult GTest_DNAMulSequencePart::report() {
     return ReportResult_Finished;
 
 }
+
+//-----------------------------------------------------------------------------
+
+void GTest_DNAMulSequenceQuality::init(XMLTestFormat *tf, const QDomElement& el) {
+    Q_UNUSED(tf);
+
+    objContextName = el.attribute(OBJ_ATTR);
+    if (objContextName.isEmpty()) {
+        failMissingValue(OBJ_ATTR);
+        return;
+    }
+    
+    seqName = el.attribute(SEQNAME_ATTR);
+    if (seqName.isEmpty()) {
+        failMissingValue(SEQNAME_ATTR);
+        return;
+    } 
+
+    expectedQuality = el.attribute(QUALITY_ATTR).toAscii();
+    if (expectedQuality.isEmpty()) {
+        failMissingValue(QUALITY_ATTR);
+        return;
+    } 
+    
+
+}
+
+Task::ReportResult GTest_DNAMulSequenceQuality::report() {
+    GObject *obj = getContext<GObject>(this,objContextName);
+    if (obj==NULL) {
+        stateInfo.setError(QString("wrong object name: %1").arg(objContextName));
+        return ReportResult_Finished;  
+    }
+
+    MAlignmentObject* myMSequence= qobject_cast<MAlignmentObject*>(obj);
+    if(myMSequence==NULL){
+        stateInfo.setError(QString("Can not cast to alignment from: %1").arg(obj->getGObjectName()));
+        return ReportResult_Finished;
+    }
+
+    bool ok_flag=false;
+    foreach(const MAlignmentRow& myItem , myMSequence->getMAlignment().getRows()){
+        if (myItem.getName() == seqName){
+            ok_flag = true;
+            QByteArray qualityCodes = myItem.getCoreQuality().qualCodes;
+            if (qualityCodes != expectedQuality){   
+                stateInfo.setError( 
+                    QString("Quality scores are not valid! The score is %1, expected %2").arg(qualityCodes.constData()).arg(expectedQuality.constData())
+                    );
+                return ReportResult_Finished;
+            }
+        }   
+    }
+    if(!ok_flag){
+        stateInfo.setError(QString("Sequence %1 is not found in the alignment").arg(seqName));
+    }
+    return ReportResult_Finished;
+
+}
+
+//-----------------------------------------------------------------------------
+
 void GTest_DNASequencInMulSequence::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
 
@@ -648,8 +717,8 @@ Task::ReportResult GTest_DNASequencInMulSequence::report() {
         stateInfo.setError(QString("can't cast to sequence from: %1").arg(obj->getGObjectName()));
         return ReportResult_Finished;
     }
-    int tempSize=myMSequence->getMAlignment().getNumSequences();
-    if(tempSize != seqInMSeq){
+    int tempSize=myMSequence->getMAlignment().getNumRows();
+    if (tempSize != seqInMSeq){
         stateInfo.setError(QString("numbers of Sequence not match: %1, expected %2 ").arg(tempSize).arg(seqInMSeq));
     }
     return ReportResult_Finished;
@@ -712,8 +781,8 @@ Task::ReportResult GTest_DNAcompareMulSequencesInTwoObjects::report() {
            stateInfo.setError(QString("sequences size not matched: size1=%1, size2=%").arg(myMSequence->getMAlignment().getLength(), myMSequence2->getMAlignment().getLength()));
            return ReportResult_Finished;
         }
-        QList <MAlignmentItem> alignedSeqs1 = myMSequence->getMAlignment().alignedSeqs;
-        QList <MAlignmentItem> alignedSeqs2 = myMSequence2->getMAlignment().alignedSeqs;
+        const QList <MAlignmentRow>& alignedSeqs1 = myMSequence->getMAlignment().getRows();
+        const QList <MAlignmentRow>& alignedSeqs2 = myMSequence2->getMAlignment().getRows();
         
         if( alignedSeqs1.size() != alignedSeqs2.size() ) {
             stateInfo.setError(QString( "different_sequences_number_in_msa_in_%1_object" ).arg( i ));
@@ -722,13 +791,13 @@ Task::ReportResult GTest_DNAcompareMulSequencesInTwoObjects::report() {
         
         int seqSz = alignedSeqs1.size();
         for(int n = 0; n < seqSz; n++ ) {
-            MAlignmentItem myItem1=alignedSeqs1.at(i);
-            MAlignmentItem myItem2=alignedSeqs2.at(i);
-            if(myItem1.name != myItem2.name){
-                stateInfo.setError(QString("names of regions in position %1 not matched: %2, expected %3").arg(n).arg(myItem2.name).arg(myItem1.name));
-	            return ReportResult_Finished;
+            const MAlignmentRow& myItem1=alignedSeqs1.at(i);
+            const MAlignmentRow& myItem2=alignedSeqs2.at(i);
+            if(myItem1.getName()!= myItem2.getName()){
+                stateInfo.setError(QString("names of regions in position %1 not matched: %2, expected %3").arg(n).arg(myItem2.getName()).arg(myItem1.getName()));
+                return ReportResult_Finished;
             }
-            if( myItem1.sequence != myItem2.sequence ) {
+            if( myItem1 != myItem2) {
                 stateInfo.setError(QString( "sequence_#%1_in_msa_in_object_#%2_not_matched" ).arg( n ).arg( i ));
             }
         }
@@ -797,15 +866,15 @@ Task::ReportResult GTest_DNAcompareMulSequencesNamesInTwoObjects::report() {
         stateInfo.setError(QString("sequences size not matched: size1=%1, size2=%").arg(myMSequence->getMAlignment().getLength(), myMSequence2->getMAlignment().getLength()));
         return ReportResult_Finished;
     }
-    QList <MAlignmentItem> myQList1 = myMSequence->getMAlignment().alignedSeqs;
-    QList <MAlignmentItem> myQList2 = myMSequence2->getMAlignment().alignedSeqs;
+    const QList <MAlignmentRow>& myQList1 = myMSequence->getMAlignment().getRows();
+    const QList <MAlignmentRow>& myQList2 = myMSequence2->getMAlignment().getRows();
 
     for(int n=0;(n!=myQList1.size())||(n!=myQList2.size());n++){
-        MAlignmentItem myItem1=myQList1.at(i);
-        MAlignmentItem myItem2=myQList2.at(i);
-        if(myItem1.name != myItem2.name){
-            stateInfo.setError(QString("names of regions in position %1 not matched: %2, expected %3").arg(n).arg(myItem2.name).arg(myItem1.name));
-	        return ReportResult_Finished;
+        const MAlignmentRow& myItem1 = myQList1.at(i);
+        const MAlignmentRow&  myItem2=myQList2.at(i);
+        if(myItem1.getName() != myItem2.getName()){
+            stateInfo.setError(QString("names of regions in position %1 not matched: %2, expected %3").arg(n).arg(myItem2.getName()).arg(myItem1.getName()));
+            return ReportResult_Finished;
         }
     }
  //////////////////////////////////////////////////////////      
@@ -822,7 +891,118 @@ Task::ReportResult GTest_DNAcompareMulSequencesNamesInTwoObjects::report() {
 
     return ReportResult_Finished;
 }
+//----------------------------------------------------------
+void GTest_DNASequenceQualityScores::init(XMLTestFormat* tf, const QDomElement& el) {
+    Q_UNUSED(tf);
 
+    objContextName = el.attribute(OBJ_ATTR);
+    if (objContextName.isEmpty()) {
+        failMissingValue(OBJ_ATTR);
+        return;
+    }
+    
+    qualityScores = el.attribute(QUALITY_ATTR).toAscii();
+    if (qualityScores.isEmpty()) {
+        failMissingValue(QUALITY_ATTR);
+
+    }
+}
+
+Task::ReportResult GTest_DNASequenceQualityScores::report() {
+
+    GObject *obj = getContext<GObject>(this, objContextName);
+    if(obj==NULL){
+        stateInfo.setError(QString("wrong value: %1").arg(OBJ_ATTR));
+        return ReportResult_Finished;  
+    }
+
+    DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
+    if(mySequence==NULL){
+        stateInfo.setError(QString("Can't cast to sequence from: %1").arg(obj->getGObjectName()));
+        return ReportResult_Finished;
+    } 
+    
+    const DNAQuality& quality = mySequence->getQuality();
+    if (quality.isEmpty()) {
+        stateInfo.setError("Sequence doesn't have quality scores");
+        return ReportResult_Finished;
+    }
+    
+    if (quality.qualCodes != qualityScores) {
+        stateInfo.setError( QString("Quality scores are not valid! The score is %1, expected %2").arg(quality.qualCodes.constData()).arg(qualityScores.constData()));
+        return ReportResult_Finished;
+    }
+
+    return ReportResult_Finished; 
+}
+
+//----------------------------------------------------------
+
+void GTest_DNASequenceQualityValue::init(XMLTestFormat* tf, const QDomElement& el) {
+    Q_UNUSED(tf);
+
+    objContextName = el.attribute(OBJ_ATTR);
+    if (objContextName.isEmpty()) {
+        failMissingValue(OBJ_ATTR);
+        return;
+    }
+
+    QString buf;
+    bool ok = false;    
+    buf = el.attribute(POSITION_ATTR).toAscii();
+    if (buf.isEmpty()) {
+        failMissingValue(POSITION_ATTR);
+    }
+    
+    pos = buf.toInt(&ok);
+    if (!ok) {
+        setError("Failed to parse sequence position");
+        return;
+    }
+
+    ok = false;
+    buf = el.attribute(VALUE_ATTR).toAscii();
+    if (buf.isEmpty()) {
+        failMissingValue(VALUE_ATTR);
+    }
+
+    expectedVal = buf.toInt(&ok);
+    if (!ok) {
+        setError("Failed to parse expected value");
+        return;
+    }
+
+}
+
+Task::ReportResult GTest_DNASequenceQualityValue::report() {
+
+    GObject *obj = getContext<GObject>(this, objContextName);
+    if(obj==NULL){
+        stateInfo.setError(QString("wrong value: %1").arg(OBJ_ATTR));
+        return ReportResult_Finished;  
+    }
+
+    DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
+    if(mySequence==NULL){
+        stateInfo.setError(QString("Can't cast to sequence from: %1").arg(obj->getGObjectName()));
+        return ReportResult_Finished;
+    } 
+
+    const DNAQuality& quality = mySequence->getQuality();
+    if ( (pos < 0) || (pos > quality.qualCodes.count() - 1 )  ) {
+        stateInfo.setError(QString("Quality scores doesn't have position %1").arg(pos));
+        return ReportResult_Finished;
+    }
+
+    int val = quality.getValue(pos);
+
+    if (val != expectedVal) {
+        stateInfo.setError( QString("Quality score values do not match! The score is %1, expected %2").arg(val).arg(expectedVal));
+        return ReportResult_Finished;
+    }
+
+    return ReportResult_Finished; 
+}
 //----------------------------------------------------------
 void GTest_DNAcompareMulSequencesAlphabetIdInTwoObjects::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
@@ -878,8 +1058,8 @@ Task::ReportResult GTest_DNAcompareMulSequencesAlphabetIdInTwoObjects::report()
             }
         }
 ////////////////////////////////////////
-        DNAAlphabet *tempAlphabet = myMSequence->getMAlignment().alphabet;
-        DNAAlphabet *tempAlphabet2 = myMSequence2->getMAlignment().alphabet;
+        const DNAAlphabet *tempAlphabet = myMSequence->getAlphabet();
+        const DNAAlphabet *tempAlphabet2 = myMSequence2->getAlphabet();
         if (tempAlphabet->getId() != tempAlphabet2->getId()) {
             stateInfo.setError(QString("sequences alphabets not matched: alphabet1=%1, alphabet2=%").arg(tempAlphabet->getId(),tempAlphabet2->getId()));
             return ReportResult_Finished;
@@ -906,8 +1086,10 @@ QList<XMLTestFactory*> DNASequenceObjectTests::createTestFactories() {
     res.append(GTest_DNASequenceSize::createFactory());
     res.append(GTest_DNASequenceAlphabet::createFactory());
     res.append(GTest_DNASequencePart::createFactory());
-	res.append(GTest_DNASequenceAlphabetType::createFactory());
+    res.append(GTest_DNASequenceAlphabetType::createFactory());
     res.append(GTest_DNASequenceAlphabetId::createFactory());
+    res.append(GTest_DNASequenceQualityScores::createFactory());
+    res.append(GTest_DNASequenceQualityValue::createFactory());
     res.append(GTest_DNAMulSequenceAlphabetId::createFactory());
     res.append(GTest_DNAMulSequenceSize::createFactory());
     res.append(GTest_DNAMulSequencePart::createFactory());
@@ -916,9 +1098,12 @@ QList<XMLTestFactory*> DNASequenceObjectTests::createTestFactories() {
     res.append(GTest_DNAcompareSequencesInTwoObjects::createFactory());
     res.append(GTest_DNAcompareSequencesAlphabetsInTwoObjects::createFactory());
     res.append(GTest_DNAcompareMulSequencesInTwoObjects::createFactory());
+    res.append(GTest_DNAMulSequenceQuality::createFactory());
     res.append(GTest_DNAcompareMulSequencesNamesInTwoObjects::createFactory());
     res.append(GTest_DNAcompareMulSequencesAlphabetIdInTwoObjects::createFactory());
     return res;
 }
 
+
+
 }//namespace
