@@ -79,6 +79,28 @@ class GTest_DNASequenceAlphabetId : public GTest {
 	QString alpId;
 };
 
+
+class GTest_DNASequenceQualityScores : public GTest {
+    Q_OBJECT
+        SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DNASequenceQualityScores, "check-sequence-quality-scores");
+
+    ReportResult report();
+
+    QString		objContextName;
+    QByteArray qualityScores;
+};
+
+class GTest_DNASequenceQualityValue : public GTest {
+    Q_OBJECT
+        SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DNASequenceQualityValue, "check-sequence-quality-value");
+
+    ReportResult report();
+
+    QString		objContextName;
+    int pos;
+    int expectedVal;
+};
+
 class GTest_DNAcompareSequencesNamesInTwoObjects : public GTest {
     Q_OBJECT
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DNAcompareSequencesNamesInTwoObjects, "compare-sequences-names-in-two-objects");
@@ -128,6 +150,7 @@ class GTest_DNAMulSequenceSize : public GTest {
     int seqSize;
 
 };
+
 class GTest_DNAMulSequencePart : public GTest {
     Q_OBJECT
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DNAMulSequencePart, "check-Msequence-part");
@@ -142,6 +165,21 @@ class GTest_DNAMulSequencePart : public GTest {
 
 };
 
+class GTest_DNAMulSequenceQuality : public GTest {
+    Q_OBJECT
+        SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DNAMulSequenceQuality, "check-Msequence-quality");
+
+    ReportResult report();
+
+    QString		objContextName;
+
+    QByteArray  expectedQuality;
+    int         startPos;
+    QString     seqName;
+
+};
+
+
 class GTest_DNASequencInMulSequence : public GTest {
     Q_OBJECT
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DNASequencInMulSequence, "check-numbers-of-sequence-in-Msequence");
@@ -180,6 +218,7 @@ class GTest_DNAcompareMulSequencesAlphabetIdInTwoObjects : public GTest {
     QString secondDocContextName;
 };
 
+
 class DNASequenceObjectTests {
 public:
     static QList<XMLTestFactory*> createTestFactories();
