@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -12,6 +12,7 @@
 
 #include <core_api/AppContext.h>
 #include <core_api/Task.h>
+
 namespace GB2 {
     
 #define VALUE_ATTR      "value"
@@ -31,22 +32,29 @@ namespace GB2 {
 #define CANCEL_FLAG_ATTR "cancel"
 #define RUN_AFTER_ALL_SUBS_FINISHED_FLAG_ATTR "run_after_all_subs"
 #define DELAY_ATTR       "ms"
+#define CONDITION_ATTR   "cond"
+
+class SThread : public QThread {
+public:
+    static void msleep(unsigned long msecs){ QThread::msleep(msecs);}
+};
 
 static TaskFlags flagsFromString(QString str, bool *ok = NULL) {
     TaskFlags taskFlags = TaskFlags(TaskFlag_None);
     if(ok!=NULL) *ok = false;
     if(!str.isEmpty()) {
-        QRegExp rx("(..)[(\\|)]");
+        QRegExp rx("([^\\|]+)");
         int pos = 0;
         QHash<QString, TaskFlag> hash;
         hash["TaskFlag_None"] = TaskFlag_None;
         hash["TaskFlag_NoRun"] = TaskFlag_NoRun;
-        hash["TaskFlag_DeleteWhenFinished"] = TaskFlag_DeleteWhenFinished;
-        hash["TaskFlag_RunAfterAllSubtasksFinished"] = TaskFlag_RunAfterAllSubtasksFinished;
-        hash["TaskFlag_SerialSubtasks"]	= TaskFlag_SerialSubtasks;
-        hash["TaskFlag_StopOnSubtaskError"] = TaskFlag_StopOnSubtaskError;    
+        hash["TaskFlag_NoAutoDelete"] = TaskFlag_NoAutoDelete;
+        hash["TaskFlag_RunBeforeSubtasksFinished"] = TaskFlag_RunBeforeSubtasksFinished;
+        hash["TaskFlag_FailOnSubtaskError"] = TaskFlag_FailOnSubtaskError;    
+        hash["TaskFlag_FailOnSubtaskCancel"] = TaskFlag_FailOnSubtaskCancel;    
         while ((pos = rx.indexIn(str, pos)) != -1) {
             pos += rx.matchedLength();
+            QString capText = rx.cap(1);
             TaskFlag flag = hash.value(rx.cap(1),(TaskFlag)-1);
             if(flag == -1) {
                 return taskFlags;
@@ -59,7 +67,7 @@ static TaskFlags flagsFromString(QString str, bool *ok = NULL) {
 }
 
 static Task::State stateFromString(QString str, bool *ok = NULL) {
-    Task::State taskState;
+    Task::State taskState = Task::State_New;
     if(ok!=NULL) *ok = false;
     if(!str.isEmpty()) {
         //int pos = 0;
@@ -78,26 +86,32 @@ static Task::State stateFromString(QString str, bool *ok = NULL) {
 }
 
 void InfiniteTestTask::run() {
-    QMutex mutex;
-    while(!stateInfo.cancelFlag) ;
+    while(!stateInfo.cancelFlag) {
+        SThread::msleep(100);
+    }
 }
+
 StateOrderTestTask::StateOrderTestTask(StateOrderTestTaskCallback *ptr, TaskFlags _f)
-: Task("calback_test_task",TaskFlags(TaskFlag_DeleteWhenFinished)|_f)
+: Task("calback_test_task",_f)
 {
     callback = ptr;
     step = 0;
 }
 void StateOrderTestTask::prepare() {
-    callback->func(this);
+    callback->func(this,StateOrder_Prepare);
 }
 void StateOrderTestTask ::run() {
-    callback->func(this);
+    callback->func(this,StateOrder_Run);
 }
 Task::ReportResult StateOrderTestTask::report() {
-    callback->func(this);
+    callback->func(this,StateOrder_Report);
     return ReportResult_Finished;
 }
 
+StateOrderTestTask::~StateOrderTestTask() {
+    callback->func(this,StateOrder_Done);
+}
+
 void GTest_TaskCreateTest::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
 
@@ -106,7 +120,7 @@ void GTest_TaskCreateTest::init(XMLTestFormat *tf, const QDomElement& el) {
     resultContextName = el.attribute(INDEX_ATTR);
     QString taskName_str = el.attribute(NAME_ATTR);
     if (taskName_str.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(NAME_ATTR);
+        failMissingValue(NAME_ATTR);
         return;
     }
 
@@ -116,14 +130,14 @@ void GTest_TaskCreateTest::init(XMLTestFormat *tf, const QDomElement& el) {
         bool ok = false;
         taskFlags = flagsFromString(taskFlags_str,&ok);
         if(!ok) {
-            stateInfo.error = GTest::tr("value not set %1").arg(FLAGS_ATTR);
+            failMissingValue(FLAGS_ATTR);
             return;
         }
     }
 
     QString taskType_str = el.attribute(TASK_TYPE_ATTR);
     if(taskType_str.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(TASK_TYPE_ATTR);
+        failMissingValue(TASK_TYPE_ATTR);
         return;
     }
 
@@ -132,20 +146,19 @@ void GTest_TaskCreateTest::init(XMLTestFormat *tf, const QDomElement& el) {
         bool ok = false;
         deleteTask = deleteTask_str.toInt(&ok);
         if(!ok) {
-            stateInfo.error = GTest::tr("value not set %1").arg(DELETE_ATTR);
+            failMissingValue(DELETE_ATTR);
             return;
         }
     }
 
-    if(taskType_str == "base_task") {
-        task = new Task(taskName_str,taskFlags);
+    if( taskType_str == "base_task") {
+        task = new Task(taskName_str, taskFlags|TaskFlags(TaskFlag_NoRun));
+    } else if(taskType_str == "infinite_task") {
+        task = new InfiniteTestTask(taskName_str, taskFlags);
+    } else {
+        failMissingValue(TASK_TYPE_ATTR);
+        return;
     }
-    else 
-        if(taskType_str == "infinite_task") {
-            task = new InfiniteTestTask(taskName_str,taskFlags);
-        }
-
-
 }
 
 Task::ReportResult GTest_TaskCreateTest::report() {
@@ -154,8 +167,12 @@ Task::ReportResult GTest_TaskCreateTest::report() {
     }
     return ReportResult_Finished;
 }
+
 void GTest_TaskCreateTest::cleanup() {
-    if (deleteTask) {
+    if(!resultContextName.isEmpty()) {
+        removeContext(resultContextName);
+    }
+    if (deleteTask /*|| task->hasFlags(TaskFlag_NoAutoDelete)*/) {
         delete task;
     }
 }
@@ -164,40 +181,35 @@ void GTest_TaskAddSubtaskTest::init(GB2::XMLTestFormat *tf, const QDomElement &e
     Q_UNUSED(tf);
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName .isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(OBJ_ATTR);
+        failMissingValue(OBJ_ATTR);
         return;
     }
     subtaskContextName = el.attribute(SUBTASK_ATTR);
     if (subtaskContextName.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(SUBTASK_ATTR);
+        failMissingValue(SUBTASK_ATTR);
         return;
     }
 }
 Task::ReportResult GTest_TaskAddSubtaskTest::report() {
-    QObject *obj1 = getContext(taskContextName );
-    if(obj1==NULL) {
-        stateInfo.error = GTest::tr("invalid object context");
+    Task *task= getContext<Task>(this, taskContextName);
+    if(task==NULL) {
+        stateInfo.setError(QString("invalid context: %1").arg(taskContextName));
         return ReportResult_Finished;
     }
-    assert(obj1!=NULL);
-    Task *task = qobject_cast<Task*>(obj1);
-
-    QObject  *obj2 = getContext(subtaskContextName );
-    if(obj2==NULL) {
-        stateInfo.error = GTest::tr("invalid object context");
+    
+    Task* subtask = getContext<Task>(this, subtaskContextName);
+    if(subtask==NULL) {
+        stateInfo.setError(QString("invalid context: %1").arg(subtaskContextName));
         return ReportResult_Finished;
     }
-    assert(obj2!=NULL);
-    Task *subtask = qobject_cast<Task*>(obj2);
-
     task->addSubTask(subtask);
 
     if(!task->getSubtasks().contains(subtask)) {
-        stateInfo.error = GTest::tr("subtask not add");
+        stateInfo.setError(QString("subtask not add"));
         return ReportResult_Finished;
     }
     if(subtask->getParentTask()!=task) {
-        stateInfo.error = GTest::tr("subtask parent not set");
+        stateInfo.setError(QString("subtask parent not set"));
         return ReportResult_Finished;
     }
 
@@ -210,7 +222,7 @@ void GTest_TaskCancelTest::init(XMLTestFormat *tf, const QDomElement& el) {
 
     objContextName = el.attribute(OBJ_ATTR);
     if (objContextName.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(OBJ_ATTR);
+        failMissingValue(OBJ_ATTR);
         return;
     }
 }
@@ -218,14 +230,14 @@ void GTest_TaskCancelTest::init(XMLTestFormat *tf, const QDomElement& el) {
 Task::ReportResult GTest_TaskCancelTest::report() {
     QObject *obj = getContext(objContextName);
     if(obj==NULL) {
-        stateInfo.error = GTest::tr("invalid object context");
+        stateInfo.setError(QString("invalid object context"));
         return ReportResult_Finished;
     }
     assert(obj!=NULL);
     Task *task = qobject_cast<Task*>(obj);
     task->cancel();
     if(!task->getStateInfo().cancelFlag) {
-        stateInfo.error = GTest::tr("task state flag not matched: %1, expected %2 ").arg(task->getStateInfo().cancelFlag).arg(true);
+        stateInfo.setError(QString("task state flag not matched: %1, expected %2 ").arg(task->getStateInfo().cancelFlag).arg(true));
         return ReportResult_Finished;
     }
     return ReportResult_Finished;
@@ -235,18 +247,18 @@ void GTest_TaskCheckFlag::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(OBJ_ATTR);
+        failMissingValue(OBJ_ATTR);
         return;
     }
     QString taskFlags_str = el.attribute(FLAGS_ATTR);
     if (taskFlags_str.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(FLAGS_ATTR);
+        failMissingValue(FLAGS_ATTR);
         return;
     }
     bool ok = false;
     TaskFlags taskFlags = flagsFromString(taskFlags_str,&ok);
     if(!ok) {
-        stateInfo.error = GTest::tr("value not set %1").arg(FLAGS_ATTR);
+        failMissingValue(FLAGS_ATTR);
         return;
     }
 }
@@ -254,13 +266,13 @@ void GTest_TaskCheckFlag::init(XMLTestFormat *tf, const QDomElement& el) {
 Task::ReportResult GTest_TaskCheckFlag::report() {
     QObject *obj = getContext(taskContextName);
     if(obj==NULL) {
-        stateInfo.error = GTest::tr("invalid object context");
+        stateInfo.setError(QString("invalid object context"));
         return ReportResult_Finished;
     }
     assert(obj!=NULL);
     Task *task = qobject_cast<Task*>(obj);
     if(task->getFlags().operator &(flag) == 0) {
-        stateInfo.error = GTest::tr("task flags not matched %1, expected %2").arg(task->getFlags()).arg(flag);
+        stateInfo.setError(QString("task flags not matched %1, expected %2").arg(task->getFlags()).arg(flag));
         return ReportResult_Finished;
     }
     return ReportResult_Finished;
@@ -277,15 +289,15 @@ void GTest_TaskCheckState::init(XMLTestFormat *tf, const QDomElement& el) {
 
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(OBJ_ATTR);
+        failMissingValue(OBJ_ATTR);
         return;
     }
     QString taskState_str = el.attribute(STATE_ATTR);
     if (!taskState_str.isEmpty()) {
         bool ok = false;
         taskState = stateFromString(taskState_str,&ok);
-        if(!ok) {
-            stateInfo.error = GTest::tr("value not set %1").arg(STATE_ATTR);
+        if (!ok) {
+            failMissingValue(STATE_ATTR);
             return;
         }
         checkState = true;
@@ -294,8 +306,8 @@ void GTest_TaskCheckState::init(XMLTestFormat *tf, const QDomElement& el) {
     if (!progress_str.isEmpty()) {
         bool ok = false;
         taskStateInfo.progress = progress_str.toInt(&ok);
-        if(!ok) {
-            stateInfo.error = GTest::tr("value not set %1").arg(STATEINFO_PROGRESS_ATTR);
+        if (!ok) {
+            failMissingValue(STATEINFO_PROGRESS_ATTR);
             return;
         }
         checkProgress = true;
@@ -306,7 +318,7 @@ void GTest_TaskCheckState::init(XMLTestFormat *tf, const QDomElement& el) {
         bool ok = false;
         taskStateInfo.cancelFlag = cancelFlag_str.toInt(&ok);
         if(!ok) {
-            stateInfo.error = GTest::tr("value not set %1").arg(STATEINFO_CANCEL_FLAG_ATTR);
+            failMissingValue(STATEINFO_CANCEL_FLAG_ATTR);
             return;
         }
         checkCancelFlag = true;
@@ -315,28 +327,26 @@ void GTest_TaskCheckState::init(XMLTestFormat *tf, const QDomElement& el) {
 }
 
 Task::ReportResult GTest_TaskCheckState::report() {
-    QObject *obj = getContext(taskContextName);
-    if(obj==NULL) {
-        stateInfo.error = GTest::tr("invalid object context");
+    Task *task = getContext<Task>(this, taskContextName);
+    if(task == NULL) {
+        stateInfo.setError(QString("invalid context %1").arg(taskContextName));
         return ReportResult_Finished;
     }
-    assert(obj!=NULL);
-    Task *task = qobject_cast<Task*>(obj);
     if(checkState) {
         if(task->getState() != taskState) {
-            stateInfo.error = GTest::tr("task state not matched %1, expected %2").arg(task->getState()).arg(taskState);
+            stateInfo.setError(QString("task state not matched %1, expected %2").arg(task->getState()).arg(taskState));
             return ReportResult_Finished;
         }
     }
     if(checkProgress) {
         if(taskStateInfo.progress != task->getStateInfo().progress) {
-            stateInfo.error = GTest::tr("task stateInfo.progress not matched %1, expected %2").arg(task->getStateInfo().progress).arg(taskStateInfo.progress);
+            stateInfo.setError(QString("task stateInfo.progress not matched %1, expected %2").arg(task->getStateInfo().progress).arg(taskStateInfo.progress));
             return ReportResult_Finished;
         }
     }
     if(checkCancelFlag) {
         if(taskStateInfo.cancelFlag!= task->getStateInfo().cancelFlag) {
-            stateInfo.error = GTest::tr("task stateInfo.cancelFlag not matched %1, expected %2").arg(task->getStateInfo().cancelFlag).arg(taskStateInfo.cancelFlag);
+            stateInfo.setError(QString("task stateInfo.cancelFlag not matched %1, expected %2").arg(task->getStateInfo().cancelFlag).arg(taskStateInfo.cancelFlag));
             return ReportResult_Finished;
         }
     }
@@ -347,21 +357,20 @@ void GTest_TaskExec::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
     taskContextName = el.attribute(OBJ_ATTR);
     if (taskContextName.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(OBJ_ATTR);
+        failMissingValue(OBJ_ATTR);
         return;
     }
 }
 
 void GTest_TaskExec::prepare() {
-    QObject *obj = getContext(taskContextName);
-    if(obj==NULL) {
-        stateInfo.error = GTest::tr("invalid object context");
+    Task *task = getContext<Task>(this, taskContextName);
+    if (task==NULL) {
+        stateInfo.setError(QString("invalid context %1").arg(taskContextName));
         return;
     }
-    assert(obj!=NULL);
-    Task *task = qobject_cast<Task*>(obj);
     AppContext::getTaskScheduler()->registerTopLevelTask(task);
 }
+
 Task::ReportResult GTest_TaskExec::report() {
     return ReportResult_Finished;
 }
@@ -373,25 +382,26 @@ void GTest_TaskStateOrder::init(XMLTestFormat *tf, const QDomElement& el) {
     subtask_num = 0;
     cancel_flag = false;
     run_after_all_subs_flag = false;
+    done_flag = false;
 
     QString subtask_num_str = el.attribute(SUBTASK_NUM_ATTR);
     if (!subtask_num_str.isEmpty()) {
         bool ok = false;
         subtask_num = subtask_num_str.toInt(&ok);
         if(!ok && subtask_num >= 0) {
-            stateInfo.error = GTest::tr("value not set %1").arg(SUBTASK_NUM_ATTR);
+            failMissingValue(SUBTASK_NUM_ATTR);
             return;
         }
     }
     QString serial_flag_str = el.attribute(SERIAL_FLAG_ATTR);
     if (serial_flag_str.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(SERIAL_FLAG_ATTR);
+        failMissingValue(SERIAL_FLAG_ATTR);
         return;
     }
     bool ok = false;
     serial_flag = serial_flag_str.toInt(&ok);
     if(!ok) {
-        stateInfo.error = GTest::tr("value not set %1").arg(SERIAL_FLAG_ATTR);
+        failMissingValue(SERIAL_FLAG_ATTR);
         return;
     }
 
@@ -400,7 +410,7 @@ void GTest_TaskStateOrder::init(XMLTestFormat *tf, const QDomElement& el) {
         ok = false;
         cancel_flag = cancel_flag_str.toInt(&ok);
         if(!ok) {
-            stateInfo.error = GTest::tr("value not set %1").arg(CANCEL_FLAG_ATTR);
+            failMissingValue(CANCEL_FLAG_ATTR);
             return;
         }
     }
@@ -409,30 +419,45 @@ void GTest_TaskStateOrder::init(XMLTestFormat *tf, const QDomElement& el) {
         ok = false;
         run_after_all_subs_flag = run_after_all_subs_flag_str.toInt(&ok);
         if(!ok) {
-            stateInfo.error = GTest::tr("value not set %1").arg(RUN_AFTER_ALL_SUBS_FINISHED_FLAG_ATTR );
+            stateInfo.setError(QString("Mandatory attribute not set: %1").arg(RUN_AFTER_ALL_SUBS_FINISHED_FLAG_ATTR ));
             return;
         }
     }
-    task = new StateOrderTestTask(this, TaskFlags((serial_flag?TaskFlag_SerialSubtasks:TaskFlag_None)|
-        (run_after_all_subs_flag?TaskFlag_RunAfterAllSubtasksFinished:TaskFlag_None)));
-    addSubTask(task);
+    task = new StateOrderTestTask(this, (run_after_all_subs_flag ? TaskFlag_None : TaskFlag_RunBeforeSubtasksFinished));
+    
     for (int i=0; i<subtask_num; i++) {
         StateOrderTestTask *sub = new StateOrderTestTask(this, TaskFlag_None);
         subs.append(sub);
         task->addSubTask(sub);
     }
+    AppContext::getTaskScheduler()->registerTopLevelTask(task);
 }
 
-void GTest_TaskStateOrder::func(StateOrderTestTask *_task) {
+
+void GTest_TaskStateOrder::run() {
+    while (!done_flag || (!subs.isEmpty() && !isCanceled())) {
+        SThread::msleep(100);
+    }
+}
+
+void GTest_TaskStateOrder::func(StateOrderTestTask *_task, StateOrderType st) {
 
     int ind = -1;
     if(task == _task) {
+        if(st == StateOrder_Done) {
+            done_flag = true;
+            return;
+        }
     } else {
-        ind = subs.indexOf((StateOrderTestTask *)_task);
+        ind = subs.indexOf(_task);
         if(ind < 0) {
-            stateInfo.error = GTest::tr("task test internal error: can't find subtask in list").arg(1);
+            stateInfo.setError(QString("task test internal error: can't find subtask in list").arg(1));
             return; 
         }
+        if(st == StateOrder_Done) {
+            subs.removeAt(ind);
+            return;
+        }
     }
     int &step = _task->step;
     State newState = _task->getState();
@@ -444,14 +469,14 @@ void GTest_TaskStateOrder::func(StateOrderTestTask *_task) {
         if(serial_flag) {
             for(int i=0; i<ind; i++) {
                 if(!subs[i]->isFinished()) {
-                    stateInfo.error = GTest::tr("task serial subtask promoting error");
+                    stateInfo.setError(QString("task serial subtask promoting error"));
                     return;
                 }
             }
         }
         step++;
         if(newState != State_New) {
-            stateInfo.error = GTest::tr("task promoting error: state value not matched %1, expected %2").arg(newState).arg(State_New);
+            stateInfo.setError(QString("task promoting error: state value not matched %1, expected %2").arg(newState).arg(State_New));
             return;
         }
         return;
@@ -462,23 +487,29 @@ void GTest_TaskStateOrder::func(StateOrderTestTask *_task) {
                 if(run_after_all_subs_flag) {
                     for(int i=0; i<subs.count(); i++) {
                         if(!subs[i]->isFinished()) {
-                            stateInfo.error = GTest::tr("task promoting error: run after all subtasks finished");
+                            stateInfo.setError(QString("task promoting error: run after all subtasks finished"));
                             return;
                         }
                     }
                 }
             }
             if(task->getStateInfo().cancelFlag) {
-                if(newState == State_Running) {
-                    stateInfo.error = GTest::tr("task promoting error: run canceled task");
+                if(newState == State_Running && st == StateOrder_Run) {
+                    stateInfo.setError(QString("task promoting error: run canceled task"));
                     return;
                 }
             } else
                 if(newState != State_Running) {
-                    stateInfo.error = GTest::tr("task promoting error: state value not matched %1, expected %2").arg(newState).arg(State_Running);
+                    stateInfo.setError(QString("task promoting error: state value not matched %1, expected %2").arg(newState).arg(State_Running));
                     return;
                 }
-        }
+        } else
+            if(step == 2) {
+                if (st != StateOrder_Report) {
+                    stateInfo.setError(QString("task promoting error"));
+                    return;
+                }
+            }
 }
 
 Task::ReportResult GTest_TaskStateOrder::report() {
@@ -488,23 +519,97 @@ Task::ReportResult GTest_TaskStateOrder::report() {
 
 void GTest_Wait::init(GB2::XMLTestFormat *tf, const QDomElement &el) {
     Q_UNUSED(tf);
+    waitOk = false;
+    condition = WaitCond_None;
     QString ms_str = el.attribute(DELAY_ATTR);
     if (ms_str.isEmpty()) {
-        stateInfo.error = GTest::tr("value not set %1").arg(DELAY_ATTR);
+        failMissingValue(DELAY_ATTR);
         return;
     }
     bool ok = false;
     ms = ms_str.toInt(&ok);
     if(!ok) {
-        stateInfo.error = GTest::tr("value not set %1").arg(DELAY_ATTR);
+        failMissingValue(DELAY_ATTR);
         return;
     }
+    objContextName = el.attribute(OBJ_ATTR);
+    if (!objContextName.isEmpty()) {
+        waitCondString = el.attribute(CONDITION_ATTR);
+        if(waitCondString.isEmpty()) {
+            failMissingValue(CONDITION_ATTR);
+            return;
+        }
+        if (waitCondString == "WaitCond_StateChanged") {
+            condition = WaitCond_StateChanged;
+            waitStateString = el.attribute(STATE_ATTR);
+            if(waitStateString.isEmpty()) {
+                failMissingValue(STATE_ATTR);
+                return;
+            }
+            ok = false;
+            waitForState = stateFromString(waitStateString, &ok);
+            if (!ok) {
+                failMissingValue(STATE_ATTR);
+                return;
+            }
+        }
+        else {
+            //do nothing;
+        }
+    }
+}
+
+void GTest_Wait::prepare() {
+    if(!objContextName.isEmpty()) {
+        Task *task = getContext<Task>(this, objContextName);
+        if (task==NULL) {
+            stateInfo.setError(QString("invalid context %1").arg(objContextName));
+            return;
+        }
+        this->connect(task,SIGNAL(si_stateChanged()),SLOT(sl_WaitCond_StateChanged()));
+    }
+}
+
+void GTest_Wait::sl_WaitCond_StateChanged() {
+    Task *task = getContext<Task>(this, objContextName);
+    if (task==NULL) {
+        stateInfo.setError(QString("invalid context %1").arg(objContextName));
+        return;
+    }
+    if(task->getState() == waitForState) {
+        waitOk = true;
+        ms = 0;
+    }
+}
+
+void GTest_Wait::run() {
+    if(!objContextName.isEmpty()) {
+        Task *task = getContext<Task>(this, objContextName);
+        if (task==NULL) {
+            stateInfo.setError(QString("invalid context %1").arg(objContextName));
+            return;
+        }
+        QTime timer;
+        timer.start();
+        while(timer.elapsed() < ms && !isCanceled()) {
+            if(task->getState() == waitForState) {
+                break;
+            }
+            SThread::msleep(100);
+        }
+    } else {
+        QTime timer;
+        timer.start();
+        while(timer.elapsed() < ms && !isCanceled()) {
+            SThread::msleep(100);
+        }
+    }
 }
 
 Task::ReportResult GTest_Wait::report() {
-    QTime timer;
-    timer.start();
-    while(timer.elapsed() < ms) ;
+    if (!hasErrors() && (condition!=WaitCond_None && !waitOk)) {
+        setError(QString("Wait condition was not met: cond: %1, state: %2").arg(waitCondString).arg(waitStateString));
+    }
     return ReportResult_Finished;
 }
 
