@@ -30,7 +30,14 @@
 #include <test_framework/xmltest/FilesIndexingTests.h>
 #include <test_framework/xmltest/AsnParserTests.h>
 #include <test_framework/xmltest/SequenceWalkerTests.h>
+#include <test_framework/xmltest/PhyTreeObjectTests.h>
+#include <test_framework/xmltest/PWMatrixTests.h>
 #include <util_sec_struct_predict/SecStructPredictTests.h>
+#include <util_dna_assembly/DnaAssemblyTests.h>
+
+#include <util_ov_msaedit/EditAlignmentTests.h>
+
+#include <util_tasks/LoadRemoteDocumentTask.h>
 
 
 namespace GB2 {
@@ -124,7 +131,6 @@ void XMLTestFormat::registerBuiltInFactories() {
             assert(res); Q_UNUSED(res);
         }
     }
-   
    { //DNASequenceObject Tests
         QList<XMLTestFactory*> fs = DNASequenceObjectTests::createTestFactories();
         foreach(XMLTestFactory* f, fs) { 
@@ -139,14 +145,14 @@ void XMLTestFormat::registerBuiltInFactories() {
             assert(res); Q_UNUSED(res);
         }
     }
-   	{ //Annotation Table Object Test
+    { //Annotation Table Object Test
         QList<XMLTestFactory*> fs = AnnotationTableObjectTest::createTestFactories();
         foreach(XMLTestFactory* f, fs) { 
             bool res = registerTestFactory(f);
             assert(res); Q_UNUSED(res);
         }
     }
-	{ //Sequence Walker Test
+    { //Sequence Walker Test
         QList<XMLTestFactory*> fs = SequenceWalkerTests::createTestFactories();
         foreach(XMLTestFactory* f, fs) { 
             bool res = registerTestFactory(f);
@@ -154,13 +160,22 @@ void XMLTestFormat::registerBuiltInFactories() {
         }
     }
 
-	{ //BioStruct3D Object Tests
+    { //BioStruct3D Object Tests
             QList<XMLTestFactory*> fs = BioStruct3DObjectTests::createTestFactories();
             foreach(XMLTestFactory* f, fs) {
                 bool res = registerTestFactory(f);
                 assert(res); Q_UNUSED(res);
             }
-	}
+    }
+
+    { //PhyTree Object Tests
+        QList<XMLTestFactory*> fs = PhyTreeObjectTests::createTestFactories();
+        foreach(XMLTestFactory* f, fs) {
+            bool res = registerTestFactory(f);
+            assert(res); Q_UNUSED(res);
+        }
+    }
+
     { //Task Tests
         QList<XMLTestFactory*> fs = TaskTests::createTestFactories();
         foreach(XMLTestFactory* f, fs) { 
@@ -208,9 +223,37 @@ void XMLTestFormat::registerBuiltInFactories() {
         }
     }
 
+    { // DnaAssembly tests
+        QList<XMLTestFactory*> fs = DnaAssemblyTests::createTestFactories();
+        foreach(XMLTestFactory* f, fs) { 
+            bool res = registerTestFactory(f);
+            assert(res); Q_UNUSED(res);
+        }
+    }
 
+    {
+        QList<XMLTestFactory*> fs = CreateSubalignimentTests::createTestFactories();
+        foreach(XMLTestFactory* f, fs) { 
+            bool res = registerTestFactory(f);
+            assert(res); Q_UNUSED(res);
+        }
+    }
 
-    
+    {
+        QList<XMLTestFactory*> fs = LoadRemoteDocumentTests::createTestFactories();
+        foreach(XMLTestFactory* f, fs) { 
+            bool res = registerTestFactory(f);
+            assert(res); Q_UNUSED(res);
+        }
+    }
+
+     { // PWMatrix tests
+        QList<XMLTestFactory*> fs = PWMatrixTests::createTestFactories();
+        foreach(XMLTestFactory* f, fs) { 
+            bool res = registerTestFactory(f);
+            assert(res); Q_UNUSED(res);
+        }
+    }
 }
 
 }//namespace
