@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -27,18 +27,16 @@ public:
     StrandContext(int width, int height, bool insDel, const char* p) 
         : dynTable(width, height, insDel), pattern(p)
     {
-
     }
+
     StrandContext( const char * data, int arr_size, const char * p ) //using rolling array only in subst mode
         : rollArr( data, arr_size ), pattern(p)
     {
     }
-    StrandContext()
-    {
-    }
+    
+    StrandContext() : pattern(NULL) {}
 
     DynTable dynTable;
-	//
     RollingArray<char> rollArr;
     const char* pattern;
     FindAlgorithmResult res;
@@ -66,7 +64,7 @@ static void findInAmino(
                      int patternLen, 
                      bool singleShot, 
                      int maxErr, 
-                     bool& stopFlag, 
+                     int& stopFlag, 
                      int& percentsCompleted, 
                      int& currentPos)
 {
@@ -181,7 +179,7 @@ static void findInAmino_subst(
                               int patternLen, 
                               bool singleShot, 
                               int maxErr,
-                              bool& stopFlag, 
+                              int& stopFlag, 
                               int& percentsCompleted, 
                               int& currentPos) 
 {
@@ -304,7 +302,7 @@ static void find_subst(
     int patternLen, 
     bool singleShot, 
     int maxErr,
-    bool& stopFlag, 
+    int& stopFlag, 
     int& percentsCompleted, 
     int& currentPos) 
 {
@@ -396,7 +394,7 @@ void FindAlgorithm::find(
                          int patternLen, 
                          bool singleShot, 
                          int maxErr, 
-                         bool& stopFlag, 
+                         int& stopFlag, 
                          int& percentsCompleted, 
                          int& currentPos) 
 {
