@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -12,13 +12,16 @@
 
 #include <util_text/TextUtils.h>
 #include <core_api/DNATranslation.h>
+#include <core_api/Counter.h>
 
 namespace GB2 {
 
 ORFFindTask::ORFFindTask(const ORFAlgorithmSettings& s, const QByteArray& seq) 
-: Task (tr("ORF find"), TaskFlag_DeleteWhenFinished), config(s), sequence(seq)
+: Task (tr("ORF find"), TaskFlag_None), config(s), sequence(seq)
 {
+    GCOUNTER( cvar, tvar, "ORFFindTask" );
     tpm = Progress_Manual;
+    assert(config.proteinTT && config.proteinTT->isThree2One());
 }
 
 void ORFFindTask::run() {
