@@ -53,7 +53,7 @@ public:
 
 static FRListItem* findItem(const FindAlgorithmResult& r, QListWidget* lv) {
     for (int i=0, n = lv->count(); i<n ; i++) {
-        FRListItem* item = (FRListItem*)lv->item(i);
+        FRListItem* item = static_cast<FRListItem*>(lv->item(i));
         if (r == item->res) {
             return item;
         }
@@ -198,7 +198,7 @@ bool FindDialog::eventFilter(QObject *obj, QEvent *ev) {
     if (obj == lbResult && ev->type() == QEvent::KeyPress) {
         QKeyEvent* ke = (QKeyEvent*)ev;
         if (ke->key() == Qt::Key_Space) {
-            FRListItem* item = (FRListItem*)lbResult->currentItem();
+            FRListItem* item = static_cast<FRListItem*>(lbResult->currentItem());
             if (item != NULL) {
                 sl_onResultActivated(item);
             }
@@ -225,7 +225,7 @@ void FindDialog::sl_onSaveAnnotations() {
     const QString& name = m.data->name;
     QList<SharedAnnotationData> list;
     for (int i=0, n = lbResult->count(); i<n; ++i) {
-        FRListItem* item = (FRListItem* )lbResult->item(i);
+        FRListItem* item = static_cast<FRListItem*>(lbResult->item(i));
         list.append(item->res.toAnnotation(name));
     }
 
@@ -472,7 +472,7 @@ void FindDialog::runTask(bool singleShot) {
     s.searchRegion = getCompleteSearchRegion();
 
     if (singleShot) { //TODO: loosing complementary strand here!
-        int newStartPos = sbCurrentPos->value(); //visual val is +1 to the last used current
+        int newStartPos = sbCurrentPos->value() - 1; //visual val is +1 to the last used current
         s.searchRegion.len-=(newStartPos - s.searchRegion.startPos);
         s.searchRegion.startPos = newStartPos;
     }
@@ -505,8 +505,8 @@ void FindDialog::importResults() {
     }
     
     int currentPos = task->getCurrentPos();
-    sbCurrentPos->setValue(currentPos+1);
-
+    sbCurrentPos->setValue(currentPos + 1);
+    
     QList<FindAlgorithmResult> newResults = task->popResults();
     if (!newResults.empty()) {
         FRListItem* item = NULL;
@@ -521,20 +521,22 @@ void FindDialog::importResults() {
         if (task->getSettings().singleShot) {
             item->setSelected(true);
             lbResult->scrollToItem(item);
-            sl_onResultActivated(item);
+            sl_onResultActivated(item,false);
         }
         lbResult->setFocus();
     }
     updateStatus();
 }
 
-void FindDialog::sl_onResultActivated(QListWidgetItem* i) {
+void FindDialog::sl_onResultActivated(QListWidgetItem* i, bool setCurPos) {
     assert(i);
-    FRListItem* item = (FRListItem*)i;
+    FRListItem* item = static_cast<FRListItem*>(i);
     DNASequenceSelection* sel = ctx->getSequenceSelection();
     sel->clear();
     sel->addRegion(item->res.region);
-    sbCurrentPos->setValue(item->res.region.startPos+1);
+    if (setCurPos) {
+        sbCurrentPos->setValue(item->res.region.startPos + 1);
+    }
     ADVSingleSequenceWidget* sw = qobject_cast<ADVSingleSequenceWidget*>(ctx->getAnnotatedDNAView()->getSequenceWidgetInFocus());
     if (sw!=NULL && sw->getSequenceContext() == ctx)  {
         if (item->res.complement) {
@@ -547,12 +549,12 @@ void FindDialog::sl_onResultActivated(QListWidgetItem* i) {
 }
 
 void FindDialog::sl_currentResultChanged(QListWidgetItem* current, QListWidgetItem* prev) {
-    Q_UNUSED(prev);
-    if (current==NULL) {
+    if (current==NULL || prev==NULL) {
         return;
     }
-    FRListItem* item = (FRListItem*)current;
-    sbCurrentPos->setValue(item->res.region.startPos+1);
+    FRListItem* item = static_cast<FRListItem*>(current);
+    sbCurrentPos->setValue(item->res.region.startPos + 1);
+
 }
 
 void FindDialog::sl_onRangeToSelection() {
@@ -574,9 +576,9 @@ void FindDialog::sl_onRangeToSequence() {
 void FindDialog::sl_onRemoveOverlaps() {
     int nBefore = lbResult->count();
     for (int i = 0, n = lbResult->count(); i < n; i++) {
-        FRListItem* ri = (FRListItem*)lbResult->item(i);
+        FRListItem* ri = static_cast<FRListItem*>(lbResult->item(i));
         for (int j=i+1; j < n; j++) {
-            FRListItem* rj = (FRListItem*)lbResult->item(j);
+            FRListItem* rj = static_cast<FRListItem*>(lbResult->item(j));
             assert(rj->res.region.startPos >= ri->res.region.startPos);
 
             if (rj->res.complement != ri->res.complement) {
