@@ -74,7 +74,7 @@ private slots:
     void sl_onCurrentPosChanged(int);
     void sl_onRangeEndChanged(int);
 
-    void sl_onResultActivated(QListWidgetItem* i);
+    void sl_onResultActivated(QListWidgetItem* i, bool setPos = true);
     void sl_currentResultChanged(QListWidgetItem*, QListWidgetItem*);
 
     void sl_onRangeToSelection();
