@@ -101,7 +101,7 @@ void AnnotationSettingsDialogController::storeModel() {
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
     QList<AnnotationSettings*> mods;
     for (int i=0; i<tree->topLevelItemCount(); i++) {
-        ASTreeItem *item = (ASTreeItem*)tree->topLevelItem(i);
+        ASTreeItem *item = static_cast<ASTreeItem*>(tree->topLevelItem(i));
         item->fillModel();
         const AnnotationSettings& s = item->as;
         AnnotationSettings* orig = asr->getAnnotationSettings(s.name);
@@ -128,7 +128,7 @@ void AnnotationSettingsDialogController::sl_itemClicked(QTreeWidgetItem * i, int
     if (column != 1) {
         return;
     }
-    ASTreeItem* item = (ASTreeItem*)i;
+    ASTreeItem* item = static_cast<ASTreeItem*>(i);
     QColor c = QColorDialog::getColor(item->as.color, this);
     item->as.color = c;
     item->drawColorCell();
@@ -138,7 +138,7 @@ void AnnotationSettingsDialogController::sl_itemDoubleClicked(QTreeWidgetItem* i
     if (col!=QUALIFIER_COLUMN) {
         return;
     }
-    ASTreeItem* ai = (ASTreeItem*)item;
+    ASTreeItem* ai = static_cast<ASTreeItem*>(item);
 
     TextEditorDialog d(this, tr("Visual qualifiers for %1").arg(ai->as.name), 
         tr("Please enter a comma-separated list of qualifier names."
