@@ -17,32 +17,23 @@
 #include <core_api/DocumentModel.h>
 #include <core_services/DocumentFormatRegistryImpl.h>
 
-namespace GB2{
+namespace GB2 {
+
+class SaveDocumentGroupController;
 
 class GB2_COREAPI_EXPORT CopyDocumentDialogController : public QDialog, public Ui_CopyDocumentDialog {
     Q_OBJECT
 public:
-    CopyDocumentDialogController(const QString &_filter, Document* d, QWidget* p = NULL);
+    CopyDocumentDialogController(Document* d, QWidget* p);
 
-    virtual void accept();
-    virtual void reject();
-    const QString getFilename(){return fileName;}
-    DocumentFormatId getDocumentFormatId(){return selectedId;};
-    bool getAddToProjectFlag(){return addToProjCheck->isChecked();};
+    QString getDocumentURL() const;
+    
+    bool getAddToProjectFlag() const {return addToProjCheck->isChecked();}
 
-private slots:
-    void sl_browseButtonClicked();
-    void sl_textChanged(const QString&);
-    void sl_currentIndexChanged(const QString & text);
+    DocumentFormatId getDocumentFormatId() const;
 
 private:
-
-    void detectWritableFormats();
-
-    QList<DocumentFormatId> ids;
-    QString filter;
-    QString fileName;
-    DocumentFormatId selectedId;
+    SaveDocumentGroupController* saveController;
 };
 
 }//ns
