@@ -49,7 +49,8 @@ void CreateObjectRelationDialogController::accept() {
         c.sequenceSizeToFit = dnaObj->getSequenceLen();
         bool res = ao->checkConstraints(&c);
         if (!res) {
-            int rc = QMessageBox::question(this, tr("warning"), tr("annotations_out_of_range"));
+            int rc = QMessageBox::question(this, tr("Warning"), 
+                tr("Found annotations that are out of the sequence range, continue?"), QMessageBox::Yes, QMessageBox::No);
             if (rc == QMessageBox::No) {
                 return;
             }
