@@ -166,7 +166,7 @@ void GObjectComboBoxController::sl_onObjectRemoved(GObject* obj) {
     if (t == GObjectTypes::UNLOADED && settings.uof == UOF_LoadedAndUnloaded) {
         t = qobject_cast<UnloadedObject*>(obj)->getLoadedObjectType();
     }
-    removeObject(GObjectReference(doc->getURL(), obj->getGObjectName(), t));
+    removeObject(GObjectReference(doc->getURLString(), obj->getGObjectName(), t));
     obj->disconnect(this);
 }
 
