@@ -18,6 +18,8 @@
 
 namespace GB2 {
 
+#define PI 3.1415926535897932384626433832795
+
 class GB2_COREAPI_EXPORT GraphUtils {
 public:
 	
@@ -63,6 +65,7 @@ public:
     };
 
 	static void drawRuler(QPainter& p, const QPoint& pos, qint64 len, qint64 start, qint64 end, const QFont& f, const RulerConfig& config);
+    static void drawCircularRuler(QPainter& p, const QPoint& pos, qint64 diam, qreal rotationDegree, qint64 start, qint64 end, int notchSize, const QFont& f);
 	
 	//static void drawDensityPlot(QPainter& p, QRect& drawRect, QRect& calcRect, quint32 n, quint32* x, quint32 *y, quint32* len);
 
