@@ -126,7 +126,7 @@ void ObjectViewTreeController::addState(GObjectViewState* s) {
 void ObjectViewTreeController::removeState(GObjectViewState* s) {
 	OVTStateItem* si = findStateItem(s);
 	assert(si != NULL);
-	OVTViewItem* vi = (OVTViewItem*)si->parent();
+	OVTViewItem* vi = static_cast<OVTViewItem*>(si->parent());
 	delete si;
     if (vi->childCount() == 0) {
         if (vi->view==NULL) {
@@ -140,17 +140,17 @@ void ObjectViewTreeController::removeState(GObjectViewState* s) {
 
 OVTItem* ObjectViewTreeController::currentItem() const {
 	QTreeWidgetItem* i = tree->currentItem();
-	return (OVTItem*)i;
+	return static_cast<OVTItem*>(i);
 }
 
 
 OVTViewItem* ObjectViewTreeController::currentViewItem(bool deriveFromState) const {
 	OVTItem* i = currentItem();
-	OVTViewItem* vi = i!=NULL && i->isViewItem() ? (OVTViewItem*)i : NULL;
+	OVTViewItem* vi = (i != NULL && i->isViewItem()) ? static_cast<OVTViewItem*>(i) : NULL;
 	if (vi == NULL && deriveFromState) {
 		OVTStateItem* si = currentStateItem();
 		if (si!=NULL) {
-			vi = (OVTViewItem*)si->parent();
+			vi = static_cast<OVTViewItem*>(si->parent());
 		}
 	}
 	return vi;
@@ -158,7 +158,7 @@ OVTViewItem* ObjectViewTreeController::currentViewItem(bool deriveFromState) con
 
 OVTStateItem* ObjectViewTreeController::currentStateItem() const {
 	OVTItem* i = currentItem();
-	return i!=NULL && i->isStateItem() ? (OVTStateItem*)i : NULL;
+	return (i != NULL && i->isStateItem()) ? static_cast<OVTStateItem*>(i) : NULL;
 }
 
 GObjectViewState* ObjectViewTreeController::findStateToOpen() const {
@@ -238,7 +238,7 @@ void ObjectViewTreeController::sl_onViewPersistentStateChanged(GObjectViewWindow
 
 OVTViewItem* ObjectViewTreeController::findViewItem(const QString& name) {
 	for(int i =0; i< tree->topLevelItemCount(); i++) {
-		OVTViewItem* vi = (OVTViewItem*)tree->topLevelItem(i);
+		OVTViewItem* vi = static_cast<OVTViewItem*>(tree->topLevelItem(i));
 		if (vi->viewName == name) {
 			return vi;
 		}
@@ -252,7 +252,7 @@ OVTStateItem* ObjectViewTreeController::findStateItem(GObjectViewState* s) {
 		return NULL;
 	}
 	for(int i =0; i< vi->childCount(); i++) {
-		OVTStateItem* si = (OVTStateItem*)vi->child(i);
+		OVTStateItem* si = static_cast<OVTStateItem*>(vi->child(i));
 		if (si->state == s) {
 			return si;
 		}
@@ -357,7 +357,7 @@ void ObjectViewTreeController::sl_removeState() {
         int childs = vi->childCount();
         assert(childs > 0);
         for (int i=0; i< childs; i++) {
-            OVTStateItem* si2 = (OVTStateItem*)vi->child(0);
+            OVTStateItem* si2 = static_cast<OVTStateItem*>(vi->child(0));
             p->removeGObjectViewState(si2->state);
         } 
     }
@@ -375,14 +375,14 @@ void ObjectViewTreeController::sl_renameState() {
 
 void ObjectViewTreeController::sl_onItemChanged(QTreeWidgetItem* i, int c) {
 	assert(c == 0);
-	OVTItem* oi = (OVTItem*)i;
+	OVTItem* oi = static_cast<OVTItem*>(i);
 	if (oi->isViewItem()) {
-		OVTViewItem* vi = (OVTViewItem*)oi;
+		OVTViewItem* vi = static_cast<OVTViewItem*>(oi);
 		assert(vi->text(0).endsWith(vi->viewName));
 		return;
 	}
 	assert(oi->isStateItem());
-	OVTStateItem* si = (OVTStateItem*)oi;
+	OVTStateItem* si = static_cast<OVTStateItem*>(oi);
 	QString newName = si->text(0);
 	GObjectViewState* state = GObjectViewUtils::findStateByName(si->state->getViewName(), newName);
 	if (state == si->state) {
