@@ -45,11 +45,11 @@ void ProjectDocumentComboBoxController::sl_onDocumentRemoved(Document* d) {
 
 
 void ProjectDocumentComboBoxController::addDocument(Document* d) {
-	cb->addItem(d->getURL());
+	cb->addItem(d->getURLString());
 }
 
 void ProjectDocumentComboBoxController::removeDocument(Document* d) {
-	int i =cb->findText(d->getURL());
+	int i =cb->findText(d->getURLString());
 	if (i >=0 ) {
 		cb->removeItem(i);
 	}
@@ -64,7 +64,7 @@ void ProjectDocumentComboBoxController::selectDocument(const QString& url) {
 
 void ProjectDocumentComboBoxController::selectDocument(Document* d) {
 	assert(filter->matches(d));
-    selectDocument(d->getURL());
+    selectDocument(d->getURLString());
 }
 
 Document* ProjectDocumentComboBoxController::getDocument() const {
