@@ -237,10 +237,11 @@ void ProjectTreeController::buildDocumentTree(Document* d) {
                     itemsToUpdate.insert(topItem);
                 }
             }
-        }
+        } 
 	}
 
-    if (topItem!=NULL) {
+    
+    if (topItem!=NULL && topItem->childCount() > 0) {
         insertTreeItemSorted(NULL, topItem);
         if (docIsShown && d->isLoaded() && topItem->childCount() < MAX_OBJECTS_TO_AUTOEXPAND) { 
             //avoid system slowdown without user interaction -> do not auto expant docs with huge num of objects
@@ -253,11 +254,11 @@ ProjViewTypeItem* ProjectTreeController::findTypeItem(const GObjectType& t) cons
     assert(t!=GObjectTypes::UNLOADED);
 
     for (int i=0;i<tree->topLevelItemCount(); i++) {
-        ProjViewItem* item = (ProjViewItem*)tree->topLevelItem(i);
+        ProjViewItem* item =  static_cast<ProjViewItem*>(tree->topLevelItem(i));
         if (!item->isTypeItem()) {
             continue;
         }
-        ProjViewTypeItem* typeItem = (ProjViewTypeItem*)item;
+        ProjViewTypeItem* typeItem = static_cast<ProjViewTypeItem*>(item);
         if (typeItem->otype == t) {
             return typeItem;
         }
@@ -276,11 +277,11 @@ ProjViewTypeItem* ProjectTreeController::findTypeItem(const GObjectType& t, bool
 
 ProjViewDocumentItem* ProjectTreeController::findDocumentItem(Document* doc) const {
     for (int i=0;i<tree->topLevelItemCount(); i++) {
-        ProjViewItem* item = (ProjViewItem*)tree->topLevelItem(i);
+        ProjViewItem* item = static_cast<ProjViewItem*>(tree->topLevelItem(i));
         if (!item->isDocumentItem()) {
             continue;
         }
-        ProjViewDocumentItem* docItem = (ProjViewDocumentItem*)item;
+        ProjViewDocumentItem* docItem = static_cast<ProjViewDocumentItem*>(item);
         if (docItem->doc == doc) {
             return docItem;
         }
@@ -312,18 +313,18 @@ ProjViewObjectItem* ProjectTreeController::findGObjectItem(Document* doc, GObjec
 ProjViewObjectItem* ProjectTreeController::findGObjectItem(ProjViewItem* topItem, GObject* obj) const {
     if (topItem!=NULL) {
         for (int i = 0 ; i < topItem->childCount(); i++) {
-            ProjViewObjectItem* item = (ProjViewObjectItem*)topItem->child(i);
+            ProjViewObjectItem* item = static_cast<ProjViewObjectItem*>(topItem->child(i));
             if (item->obj == obj) {
                 return item;
             }
         }
     } else {
         for (int i=0; i < tree->topLevelItemCount(); i++) {
-            ProjViewItem* item = (ProjViewItem*)tree->topLevelItem(i);
+            ProjViewItem* item = static_cast<ProjViewItem*>(tree->topLevelItem(i));
             if (!item->isObjectItem()) {
                 continue;
             }
-            ProjViewObjectItem* objItem = (ProjViewObjectItem*)item;
+            ProjViewObjectItem* objItem = static_cast<ProjViewObjectItem*>(item);
             if (objItem->obj == obj) {
                 return objItem;
             }
@@ -347,12 +348,12 @@ void ProjectTreeController::updateSelection() {
 	QList<Document*> selectedDocs;
 	QList<GObject*> selectedObjs;
 	foreach(QTreeWidgetItem* item , items) {
-		ProjViewItem* pvi = (ProjViewItem*)item;
+		ProjViewItem* pvi = static_cast<ProjViewItem*>(item);
 		if (pvi->isDocumentItem()) {
-			ProjViewDocumentItem* di = (ProjViewDocumentItem*)pvi;
+			ProjViewDocumentItem* di = static_cast<ProjViewDocumentItem*>(pvi);
 			selectedDocs.push_back(di->doc);
         } else if (pvi->isObjectItem()) {
-			ProjViewObjectItem* oi = (ProjViewObjectItem*)pvi;
+			ProjViewObjectItem* oi = static_cast<ProjViewObjectItem*>(pvi);
 			selectedObjs.push_back(oi->obj);
 		}
 	}
@@ -363,11 +364,11 @@ void ProjectTreeController::updateSelection() {
 
 void ProjectTreeController::sl_onItemDoubleClicked(QTreeWidgetItem * item, int column) {
     Q_UNUSED(column);
-	ProjViewItem* pvi = (ProjViewItem*)item;
+	ProjViewItem* pvi = static_cast<ProjViewItem*>(item);
 	if (pvi->isObjectItem()) {
-		emit si_doubleClicked(((ProjViewObjectItem*)pvi)->obj);
+		emit si_doubleClicked((static_cast<ProjViewObjectItem*>(pvi))->obj);
 	} else if (pvi->isDocumentItem()) {
-        Document* d = ((ProjViewDocumentItem*)pvi)->doc;
+        Document* d = (static_cast<ProjViewDocumentItem*>(pvi))->doc;
         if (!d->isLoaded() && pvi->childCount() == 0) { //children > 0 -> expand action
             assert(loadSelectedDocumentsAction->isEnabled());
             loadSelectedDocumentsAction->trigger();
@@ -465,7 +466,7 @@ void ProjectTreeController::updateActions() {
 void ProjectTreeController::sl_onRemoveSelectedDocuments() {
 	Project* p = AppContext::getProject();
     QSet<Document*> docsInSelection = getDocsInSelection(mode.groupMode != ProjectTreeGroupMode_ByDocument);
-	if (!docsInSelection.isEmpty())
+    if (!docsInSelection.isEmpty())
         AppContext::getTaskScheduler()->registerTopLevelTask(new RemoveMultipleDocumentsTask(p, docsInSelection.toList(), true, true));
 }
 
@@ -511,15 +512,32 @@ void ProjectTreeController::sl_onDocumentAddedToProject(Document* d) {
 void ProjectTreeController::sl_onDocumentRemovedFromProject(Document* d) {
     disconnectDocument(d);
 
-    ProjViewDocumentItem* di = findDocumentItem(d);
-    delete di;
-
+    if (mode.groupMode == ProjectTreeGroupMode_ByDocument) {
+        ProjViewDocumentItem* di = findDocumentItem(d);
+        delete di;
+    } else {
+        foreach (GObject* obj, d->getObjects()) {
+             ProjViewObjectItem* oi = findGObjectItem(d,obj);
+             if (mode.groupMode == ProjectTreeGroupMode_ByType) {
+                ProjViewTypeItem* topItem = findTypeItem(getLoadedObjectType(obj), true);
+                topItem->removeChild(oi);
+                if (topItem->childCount() == 0) {
+                    delete topItem;
+                } else {
+                    topItem->updateVisual();
+                }
+             } 
+             delete oi;
+        }
+    }
+  
     updateSelection();
-	updateActions();
+    updateActions();
+    
 }
 
 void ProjectTreeController::sl_onToggleReadonly() {
-    QSet<Document*> docsInSelection = getDocsInSelection(mode.groupMode != ProjectTreeGroupMode_ByDocument);
+    QSet<Document*> docsInSelection = getDocsInSelection(true);
     if (docsInSelection.size()!=1) {
         return;
     }
@@ -550,6 +568,7 @@ void ProjectTreeController::sl_lockedStateChanged() {
                     ProjViewObjectItem* oi = findGObjectItem(di, obj);
                     if (oi!=NULL) {
                         delete oi;
+                        oi = NULL;
                     }
                 }
             }
@@ -570,9 +589,9 @@ void ProjectTreeController::flattenDocumentItem(ProjViewDocumentItem* docItem) {
     assert(mode.groupMode == ProjectTreeGroupMode_Flat);
 
     while (docItem->childCount()!=0) {
-        ProjViewItem* item = (ProjViewItem*)docItem->takeChild(0);
+        ProjViewItem* item = static_cast<ProjViewItem*>(docItem->takeChild(0));
         assert(item->isObjectItem());
-        ProjViewObjectItem* objItem = (ProjViewObjectItem*)item;
+        ProjViewObjectItem* objItem = static_cast<ProjViewObjectItem*>(item);
         if (mode.isObjectShown(objItem->obj)) {
             tree->addTopLevelItem(objItem);
             objItem->updateVisual();
@@ -585,9 +604,12 @@ void ProjectTreeController::flattenDocumentItem(ProjViewDocumentItem* docItem) {
 void ProjectTreeController::sl_onDocumentLoadedStateChanged() {
     Document* d = qobject_cast<Document*>(sender());
     ProjViewDocumentItem* docItem = findDocumentItem(d);
-    if (!mode.isDocumentShown(d)) { //document item can be automatically removed from the view after its loaded
-        if (docItem!=NULL) {
-            flattenDocumentItem(docItem);
+    if (!mode.isDocumentShown(d)) { 
+        // document item can be automatically removed from the view after its loaded due to filters
+        if (docItem != NULL) {
+            if (mode.groupMode == ProjectTreeGroupMode_Flat) {
+                flattenDocumentItem(docItem);
+            }
             delete docItem;
             docItem = NULL;
         }
@@ -629,15 +651,20 @@ void ProjectTreeController::sl_onObjectAdded(GObject* obj) {
     if (!mode.isObjectShown(obj)) {
         return;
     }
-	Document* doc = obj->getDocument();
+    Document* doc = obj->getDocument();
 	assert(doc!=NULL);
 	ProjViewItem* topItem = NULL;
     if (mode.groupMode == ProjectTreeGroupMode_ByType) {
         topItem = findTypeItem(getLoadedObjectType(obj), true);
     } else if (mode.isDocumentShown(doc)) {
         topItem = findDocumentItem(doc);
-        assert(topItem!=NULL);
+        if (topItem == NULL) { //doc is not really shown yet -> add it using general routine
+            buildDocumentTree(doc);
+            connectDocument(doc);
+            return;
+        }
     }
+    connectGObject(obj);
 	ProjViewObjectItem* objItem = new ProjViewObjectItem(obj, this);
 
     if (mode.groupMode != ProjectTreeGroupMode_ByDocument || topItem == NULL) {
@@ -659,7 +686,7 @@ void ProjectTreeController::sl_onObjectRemoved(GObject* obj) {
         assert(!objectSelection.contains(obj));
         return;
     }
-    ProjViewItem* pi = (ProjViewItem*)objItem->parent();
+    ProjViewItem* pi = static_cast<ProjViewItem*>(objItem->parent());
 	delete objItem;
     if (pi!=NULL && pi->isTypeItem()) {
         pi->updateVisual();
@@ -705,7 +732,9 @@ void ProjectTreeController::sl_onResourceUserUnregistered(const QString& res, Ta
     lut->disconnect(this);
 
     Document* doc = lut->getDocument();
-    updateLoadingState(doc);
+    if (doc!=NULL) {
+        updateLoadingState(doc);
+    }
 }
 
 void ProjectTreeController::sl_onLoadingDocumentProgressChanged() {
@@ -747,9 +776,9 @@ void ProjectTreeController::filterItemsRecursive(ProjViewItem* pi) {
     TreeUpdateHelper h(itemsToUpdate);
     if (pi == NULL) {
         for(int i=0; i < tree->topLevelItemCount(); i++) {
-            ProjViewItem* ci = (ProjViewItem*)tree->topLevelItem(i);
+            ProjViewItem* ci = static_cast<ProjViewItem*>(tree->topLevelItem(i));
             if (ci->isDocumentItem()) {
-                ProjViewDocumentItem*  di = (ProjViewDocumentItem*)ci;
+                ProjViewDocumentItem*  di = static_cast<ProjViewDocumentItem*>(ci);
                 if (!mode.isDocumentShown(di->doc)) {
                     delete di;
                     i--;
@@ -765,7 +794,7 @@ void ProjectTreeController::filterItemsRecursive(ProjViewItem* pi) {
                 }
             } else {            
                 assert(ci->isObjectItem());
-                ProjViewObjectItem* oi = (ProjViewObjectItem*)ci;
+                ProjViewObjectItem* oi = static_cast<ProjViewObjectItem*>(ci);
                 bool filterObject = !mode.isObjectShown(oi->obj) 
                     || (mode.isDocumentShown(oi->obj->getDocument()) && oi->parent() == NULL);
                 if (filterObject) {
@@ -776,9 +805,9 @@ void ProjectTreeController::filterItemsRecursive(ProjViewItem* pi) {
         }
     } else {
         for(int i=0; i<pi->childCount(); i++) {
-            ProjViewItem* ci = (ProjViewItem*)pi->child(i);
+            ProjViewItem* ci = static_cast<ProjViewItem*>(pi->child(i));
             assert(ci->isObjectItem());
-            ProjViewObjectItem* oi = (ProjViewObjectItem*)ci;
+            ProjViewObjectItem* oi = static_cast<ProjViewObjectItem*>(ci);
             if (!mode.isObjectShown(oi->obj)) {
                 delete oi;
                 i--;
@@ -818,7 +847,7 @@ void ProjectTreeController::sl_onGroupFlat() {
 void ProjectTreeController::insertTreeItemSorted(ProjViewItem* p, ProjViewItem* item) {
     if (p == NULL) { //top level
         for (int i=0, n = tree->topLevelItemCount(); i < n; i++) {
-            ProjViewItem* otherItem = (ProjViewItem*)tree->topLevelItem(i);
+            ProjViewItem* otherItem = static_cast<ProjViewItem*>(tree->topLevelItem(i));
             if (*item < *otherItem) {
                 tree->insertTopLevelItem(i, item);
                 return;
@@ -827,7 +856,7 @@ void ProjectTreeController::insertTreeItemSorted(ProjViewItem* p, ProjViewItem*
         tree->addTopLevelItem(item);
     } else {
         for (int i = 0, n = p->childCount(); i < n; i++) {
-            ProjViewItem* otherItem = (ProjViewItem*)p->child(i);
+            ProjViewItem* otherItem = static_cast<ProjViewItem*>(p->child(i));
             if (*item < *otherItem) {
                 p->insertChild(i, item);
                 return;
@@ -883,7 +912,7 @@ bool ProjViewDocumentItem::operator< ( const QTreeWidgetItem & other ) const {
 void ProjViewDocumentItem::updateVisual(bool recursive) {
 	if (recursive) {
 		for (int i = 0, n = childCount(); i < n ; i++ ) {
-			ProjViewObjectItem* oi = (ProjViewObjectItem*)child(i);
+			ProjViewObjectItem* oi = static_cast<ProjViewObjectItem*>(child(i));
 			oi->updateVisual(recursive);
 		}
 	}
@@ -912,7 +941,7 @@ void ProjViewDocumentItem::updateVisual(bool recursive) {
     setIcon(0, showLockedIcon ? controller->roDocumentIcon : controller->documentIcon);
 
     //update tooltip
-    QString tooltip = doc->getURL();
+    QString tooltip = doc->getURLString();
     if  (doc->isStateLocked()) {
         tooltip.append("<br><br>").append(ProjectTreeController::tr("locks:"));
         if (doc->getParentStateLockItem()->isStateLocked()) {
@@ -982,10 +1011,10 @@ void ProjViewObjectItem::updateVisual(bool recursive) {
 
 
     QString tooltip;
-    //todo: make tooltop for object items
+    //todo: make tooltip for object items
    
     if (groupMode == ProjectTreeGroupMode_Flat) {
-        tooltip.append(obj->getDocument()->getURL());
+        tooltip.append(obj->getDocument()->getURLString());
     }
     setToolTip(0, tooltip);
 }
@@ -1037,22 +1066,25 @@ bool ProjectTreeControllerModeSettings::isDocumentShown(Document* doc) const {
     //filter by object types
     if (!objectTypesToShow.isEmpty()) { 
         const QList<GObject*>& docObjs = doc->getObjects();
-        if (!docObjs.isEmpty()) {
+        if (!docObjs.isEmpty()) { //ok we have mapping about document objects -> apply filter to the objects
             bool found = false;
             foreach(GObject* o, docObjs) {
-                GObjectType t = o->getGObjectType();
-                if (t ==  GObjectTypes::UNLOADED) {
-                    t = qobject_cast<UnloadedObject*>(o)->getLoadedObjectType();
-                }
-                if (objectTypesToShow.contains(t)) {
-                    found = true;
+                found = isObjectShown(o);
+                if (found) {
                     break;
                 }
             }
+            if (!found) {
+                return false;
+            }
         } else {
-            DocumentFormatConstraints c;
-            c.supportedObjectTypes << objectTypesToShow;
-            res = doc->getDocumentFormat()->checkConstraints(c);
+            if (!doc->isLoaded()) {
+                DocumentFormatConstraints c;
+                c.supportedObjectTypes += objectTypesToShow.toSet();
+                res = doc->getDocumentFormat()->checkConstraints(c);
+            } else {
+                res = false;
+            }
             if (!res) {
                 return false;
             }
@@ -1061,7 +1093,7 @@ bool ProjectTreeControllerModeSettings::isDocumentShown(Document* doc) const {
 
     //filter by name
     foreach(const QString& token, tokensToShow) {
-        if (!doc->getURL().contains(token)) {
+        if (!doc->getURLString().contains(token)) {
             return false;
         }
     }
@@ -1080,7 +1112,7 @@ bool ProjectTreeControllerModeSettings::isDocumentShown(Document* doc) const {
 bool ProjectTreeControllerModeSettings::isObjectShown(GObject* o) const  {
     //filter by type
     GObjectType t = o->isUnloaded() ? qobject_cast<UnloadedObject*>(o)->getLoadedObjectType() : o->getGObjectType();
-    bool res = isObjectShown(t);
+    bool res = isTypeShown(t);
     if (!res) {
         return false;
     }
@@ -1132,7 +1164,7 @@ bool ProjectTreeControllerModeSettings::isObjectShown(GObject* o) const  {
     return true;
 }
 
-bool ProjectTreeControllerModeSettings::isObjectShown(GObjectType t) const {
+bool ProjectTreeControllerModeSettings::isTypeShown(GObjectType t) const {
     if (objectTypesToShow.isEmpty()) {
         return true;
     }
