@@ -92,7 +92,7 @@ public:
     PTCDocumentFilter*          documentFilter;
     
     bool isDocumentShown(Document* doc) const;
-    bool isObjectShown(GObjectType t) const;
+    bool isTypeShown(GObjectType t) const;
     bool isObjectShown(GObject* o) const ;
 };
 
@@ -109,7 +109,7 @@ public:
     QAction* getGroupByDocumentAction() const {return groupByDocumentAction;}
     QAction* getGroupByTypeAction() const {return groupByTypeAction;}
     QAction* getGroupFlatAction() const {return groupFlatAction;}
-
+    QAction* getLoadSeletectedDocumentsAction() { return loadSelectedDocumentsAction; }
     const ProjectTreeControllerModeSettings& getModeSettings() const {return mode;}
 
     void highlightItem(Document*);
