@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -42,7 +42,8 @@ private:
 class GB2_COREAPI_EXPORT  ADVCreateAnnotationsTask : public Task {
     Q_OBJECT
 public:
-    ADVCreateAnnotationsTask(AnnotatedDNAView* _ctx, AnnotationTableObject* o, const QString& group, const QList<SharedAnnotationData>& data);
+    ADVCreateAnnotationsTask(AnnotatedDNAView* _ctx, const GObjectReference& aobjRef, 
+                            const QString& group, const QList<SharedAnnotationData>& data);
         
     ReportResult report();
 
