@@ -25,9 +25,7 @@ GSequenceGraphData::GSequenceGraphData(const QString& _graphName) : graphName(_g
 }
 
 GSequenceGraphData::~GSequenceGraphData() {
-	if (ga!=NULL) {
-		delete ga;
-	}
+	delete ga;
 }
 
 void GSequenceGraphUtils::calculateMinMax(const QVector<float>& data, float& min, float& max)  {
@@ -466,7 +464,9 @@ void GSequenceGraphDrawer::calculateWithFit(GSequenceGraphData* d, PairVector& p
 	int step  = wdata.step;
 
 	int nSteps = (alignedLast - alignedFirst)/step;
-	int lastBase = alignedLast + win;
+#ifdef DEBUG
+    int lastBase = alignedLast + win;
+#endif // DEBUG
     
 	int stepsPerPoint = nSteps / points.firstPoints.size();
 	assert(stepsPerPoint >= 1);
@@ -477,7 +477,9 @@ void GSequenceGraphDrawer::calculateWithFit(GSequenceGraphData* d, PairVector& p
 	for (int i=0; i < points.firstPoints.size(); i++) {
 		pointData.clear();
         LRegion r(int(alignedFirst + i*basesPerPoint), len);
+#ifdef DEBUG
 		assert(r.endPos() <= lastBase);
+#endif
 		d->ga->calculate(pointData, o, r, &wdata);
 		float min, max;
 		GSequenceGraphUtils::calculateMinMax(pointData, min, max);
