@@ -12,6 +12,14 @@
 #include "ADVSequenceObjectContext.h"
 #include "AnnotatedDNAView.h"
 
+#include "ADVConstants.h"
+#include "DetView.h"
+#include "PanView.h"
+#include "Overview.h"
+#include "CreateRulerDialogController.h"
+
+#include <core_api/L10n.h>
+
 #include <gobjects/DNASequenceObject.h>
 #include <gobjects/AnnotationTableObject.h>
 
@@ -23,16 +31,12 @@
 #include <util_gui/GUIUtils.h>
 #include <util_gui/DialogUtils.h>
 
-#include "ADVConstants.h"
-#include "DetView.h"
-#include "PanView.h"
-#include "CreateRulerDialogController.h"
-
 #include <QtGui/QApplication>
 #include <QtGui/QToolButton>
 #include <QtGui/QWidgetAction>
 #include <QtGui/QDialog>
 #include <QtGui/QFileDialog>
+#include <QtGui/QMessageBox>
 
 namespace GB2 {
 #define ADV_HEADER_HEIGHT 24
@@ -50,6 +54,9 @@ ADVSingleSequenceWidget::ADVSingleSequenceWidget(ADVSequenceObjectContext* seqCt
     toggleDetViewAction = new QAction(this);
     connect(toggleDetViewAction, SIGNAL(triggered()), SLOT(sl_toggleDetView()));
 
+    toggleOverviewAction = new QAction(this);
+    connect(toggleOverviewAction, SIGNAL(triggered()), SLOT(sl_toggleOverview()));
+
     connect(seqCtx->getAnnotatedDNAView()->getAnnotationsSelection(), 
         SIGNAL(si_selectionChanged(AnnotationSelection* , const QList<Annotation*>&, const QList<Annotation*>&)),
         SLOT(sl_onAnnotationSelectionChanged(AnnotationSelection* , const QList<Annotation*>&, const QList<Annotation*>&)));
@@ -97,9 +104,13 @@ void ADVSingleSequenceWidget::init() {
     panView->setObjectName("pan_view");
     connect(panView, SIGNAL(si_centerPosition(int)), SLOT(sl_onLocalCenteringRequest(int)));
 
-    addSequenceView(panView);
+    addSequenceView(panView, headerWidget);
 
     panView->setFrameView(detView);
+
+    overview = new Overview(this, seqCtx);
+    overview->setObjectName("overview");
+    addSequenceView(overview, headerWidget);
     
     setFixedHeight(linesLayout->minimumSize().height());
 
@@ -138,6 +149,13 @@ void ADVSingleSequenceWidget::init() {
     hBar->addAction(panView->getZoomToSequenceAction());
 
     updateSelectionActions();
+
+#define MIN_SEQUENCE_LEN_TO_USE_FULL_MODE 100
+	if (seqCtx->getSequenceLen() < MIN_SEQUENCE_LEN_TO_USE_FULL_MODE) {
+		//sequence is rather small -> show panview only by default
+		setOverviewCollapsed(true);
+		setDetViewCollapsed(true);
+	}
 }
 
 
@@ -149,6 +167,7 @@ ADVSingleSequenceWidget::~ADVSingleSequenceWidget() {
 
 bool ADVSingleSequenceWidget::isPanViewCollapsed() const {return panView->isHidden();}
 bool ADVSingleSequenceWidget::isDetViewCollapsed() const {return detView->isHidden();}
+bool ADVSingleSequenceWidget::isOverviewCollapsed() const {return overview->isHidden();}
 
 bool ADVSingleSequenceWidget::isViewCollapsed() const {
     bool collapsed = true;
@@ -171,6 +190,7 @@ void ADVSingleSequenceWidget::setViewCollapsed(bool v) {
 void ADVSingleSequenceWidget::setPanViewCollapsed(bool v) {
     panView->setHidden(v);
     updateMinMaxHeight();
+	zoomToRangeAction->setDisabled(isPanViewCollapsed());
 }
 
 void ADVSingleSequenceWidget::setDetViewCollapsed(bool v) {
@@ -178,10 +198,27 @@ void ADVSingleSequenceWidget::setDetViewCollapsed(bool v) {
     updateMinMaxHeight();
 }
 
-void ADVSingleSequenceWidget::addSequenceView(GSequenceLineView* v) {
+void ADVSingleSequenceWidget::setOverviewCollapsed(bool v) {
+    overview->setHidden(v);
+    updateMinMaxHeight();
+}
+
+void ADVSingleSequenceWidget::addSequenceView(GSequenceLineView* v, QWidget* after) {
     assert(!lineViews.contains(v));
     lineViews.append(v);
-    linesLayout->insertWidget(1, v);
+    if (after==NULL) {
+        if(lineViews.size()>1) {
+            linesLayout->insertWidget(2, v);
+        }
+        else {
+            linesLayout->insertWidget(1, v);
+        }
+    }
+    else {
+        int after_ = linesLayout->indexOf(after);
+        assert(after_!=-1);
+        linesLayout->insertWidget(after_+1, v);
+    }
     v->setVisible(true);
     v->installEventFilter(this);
     updateMinMaxHeight();
@@ -219,7 +256,7 @@ void ADVSingleSequenceWidget::setNumBasesVisible(int n) {
 
 
 void ADVSingleSequenceWidget::sl_onViewDestroyed(QObject* o) {
-    GSequenceLineView* v = (GSequenceLineView*)o;
+    GSequenceLineView* v = static_cast<GSequenceLineView*>(o);
     bool r = lineViews.removeOne(v);
     linesLayout->removeWidget(v);//need here for updateMinMaxHeight
     assert(r);
@@ -418,7 +455,7 @@ void ADVSingleSequenceWidget::addADVSequenceWidgetAction(ADVSequenceWidgetAction
 }
 
 void ADVSingleSequenceWidget::sl_onSelectRange() {
-    QDialog dlg;
+    QDialog dlg(this);
     dlg.setModal(true);
     dlg.setWindowTitle(tr("selection_range_title"));
     ADVSequenceObjectContext* ctx = getSequenceContext();
@@ -478,10 +515,18 @@ void ADVSingleSequenceWidget::sl_onSelectOutRange() {
 }
 
 void ADVSingleSequenceWidget::sl_zoomToRange() {
-    QDialog dlg;
+    QDialog dlg(this);
     dlg.setModal(true);
     dlg.setWindowTitle(tr("visible_range_title"));
-    RangeSelector* rs = new RangeSelector(&dlg, 1, getSequenceLen(), true);
+    DNASequenceSelection* sel = getSequenceSelection();
+    int start=getVisibleRange().startPos + 1, end=getVisibleRange().endPos();
+    if (!sel->isEmpty()) {
+        const QList<LRegion>& regions = sel->getSelectedRegions();
+        start=regions.first().startPos+1;
+        end=regions.first().endPos();
+    }
+    
+    RangeSelector* rs = new RangeSelector(&dlg, start, end, true);
 
     int rc = dlg.exec();
     if (rc == QDialog::Accepted) {
@@ -495,6 +540,7 @@ void ADVSingleSequenceWidget::sl_zoomToRange() {
 #define SPLITTER_STATE_MAP_NAME "ADVSI_MAP"
 #define PAN_REG_NAME            "PAN_REG"
 #define DET_POS_NAME            "DET_POS"
+#define OVERVIEW_VISIBLE        "OVERVIEW_VISIBLE"
 #define PAN_VISIBLE             "PAN_VISIBLE"
 #define DET_VISIBLE             "DET_VISIBLE"
 #define MAIN_RULER_VISIBLE      "MAINR_VISIBLE"
@@ -517,6 +563,9 @@ void ADVSingleSequenceWidget::updateState(const QVariantMap& m) {
         panView->setVisibleRange(panReg);
     }
     
+	bool overIsVisible = myData.value(OVERVIEW_VISIBLE, true).toBool();
+	setOverviewCollapsed(!overIsVisible);
+	
     bool panIsVisible = myData.value(PAN_VISIBLE, true).toBool();
     setPanViewCollapsed(!panIsVisible);
 
@@ -549,6 +598,7 @@ void ADVSingleSequenceWidget::saveState(QVariantMap& m) {
     QVariantMap myData;
     myData[PAN_REG_NAME] = QVariant::fromValue<LRegion>(panView->getVisibleRange());
     myData[DET_POS_NAME] = QVariant::fromValue<int>(detView->getVisibleRange().startPos);
+	myData[OVERVIEW_VISIBLE] = !isOverviewCollapsed();
     myData[PAN_VISIBLE] = !isPanViewCollapsed();
     myData[DET_VISIBLE] = !isDetViewCollapsed();
     myData[MAIN_RULER_VISIBLE] = panView->getToggleMainRulerAction()->isChecked();
@@ -583,21 +633,46 @@ void ADVSingleSequenceWidget::sl_saveScreenshot()
                                   this->geometry().bottomRight().x(),
                                   this->geometry().bottomRight().y());
     QPixmap curPixMap = QPixmap::grabWidget(this, *screenRect);
-    QStringList formats = (QStringList() << "png" << "jpg" << "tiff");
-    QString initialPath = lod.dir + "/untitled";//QDir::currentPath() + tr("/untitled");
+    QMap<QString, QString> filters;
+    filters[ "PNG - Portable Network Graphics (*.png)" ] = "png";
+    filters[ "JPG/JPEG format (*.jpg)" ] = "jpg";
+    filters[ "TIF - Tagged Image File format (*.tiff)" ] = "tiff";
+
+    QString initialPath = lod.dir + "/untitled";
+    QString selectedFormat;
     QString fileName = QFileDialog::getSaveFileName(this, tr("Save As"),
-        initialPath,
-        QString("%1 Files (*.%2);;%3 Files (*.%4);;%5 Files (*.%6);;All Files (*)")
-        .arg(formats.at(0).toUpper())
-        .arg(formats.at(0))
-        .arg(formats.at(1).toUpper())
-        .arg(formats.at(1))
-        .arg(formats.at(2).toUpper())
-        .arg(formats.at(2)));
+        initialPath, QStringList(filters.keys()).join(";;"), &selectedFormat);
     lod.url = fileName;
+    
     if (!fileName.isEmpty()) {
-        curPixMap.save(fileName);
-    };
+        bool formatAppend = true;
+        foreach( const QString & format, filters.values() ) {
+            if( fileName.endsWith("." + format) ){
+                formatAppend = false;
+                break;
+            }
+        }
+        if( formatAppend ) {
+            assert( filters.contains(selectedFormat) );
+            fileName.append( "." + filters[selectedFormat] );
+            
+            if( QFile::exists(fileName) ) {
+                QMessageBox::StandardButtons b = 
+                        QMessageBox::warning( 
+                                0, tr("Replace file"), 
+                                tr("%1 already exists.\nDo you want to replace it?").arg(fileName),
+                                QMessageBox::Yes|QMessageBox::No);
+                if( QMessageBox::Yes != b ) {
+                    return;
+                }
+            }
+        }
+        bool result = curPixMap.save(fileName);
+        if (!result) {
+            QMessageBox::critical(this, L10N::errorTitle(), L10N::errorImageSave(fileName, selectedFormat));
+            return;
+        }
+    }
 }
 
 void ADVSingleSequenceWidget::closeView() {
@@ -639,27 +714,29 @@ void ADVSingleSequenceWidget::updateSelectionActions() {
 
 void ADVSingleSequenceWidget::addStateActions( QMenu& m )
 {
-    toggleViewAction->setText(isViewCollapsed() ? tr("Show all") : tr("Hide all"));
-    togglePanViewAction->setText(isPanViewCollapsed() ? tr("Show overview") : tr("Hide overview"));
-    toggleDetViewAction->setText(isDetViewCollapsed() ? tr("Show details") : tr("Hide details"));
+    toggleViewAction->setText(isViewCollapsed() ? tr("Show all views") : tr("Hide all views"));
+    togglePanViewAction->setText(isPanViewCollapsed() ? tr("Show zoom view") : tr("Hide zoom view"));
+    toggleDetViewAction->setText(isDetViewCollapsed() ? tr("Show details view") : tr("Hide details view"));
+    toggleOverviewAction->setText(isOverviewCollapsed() ? tr("Show overview") : tr("Hide overview"));
     m.addAction(toggleViewAction);
     m.addAction(toggleDetViewAction);
     m.addAction(togglePanViewAction);
+    m.addAction(toggleOverviewAction);
 }
 
+void ADVSingleSequenceWidget::sl_toggleView(){
+	bool newStateCollapsed = !isViewCollapsed();
+	setViewCollapsed(newStateCollapsed);
+}
+
+void ADVSingleSequenceWidget::sl_togglePanView(){
+    setPanViewCollapsed(!isPanViewCollapsed());
+}
+
+
 //////////////////////////////////////////////////////////////////////////
 // header
 
-class HBar : public QToolBar {
-public:
-    HBar(QWidget* w) : QToolBar(w){}
-protected:
-    void paintEvent(QPaintEvent* pe) {
-        Q_UNUSED(pe);
-        //do not draw any special toolbar control -> make is merged with parent widget
-    }
-};
-
 ADVSingleSequenceHeaderWidget::ADVSingleSequenceHeaderWidget(ADVSingleSequenceWidget* p) : QWidget(p), ctx(p) {
     setFixedHeight(ADV_HEADER_HEIGHT);
     setBackgroundRole(QPalette::Window);
@@ -729,6 +806,7 @@ void ADVSingleSequenceHeaderWidget::populateToolBars() {
     widgetStateMenuButton = new QToolButton(this);
     widgetStateMenuButton->setIcon(QIcon(":core/images/adv_widget_menu.png"));
     widgetStateMenuButton->setFixedWidth(20);
+    widgetStateMenuButton->setToolTip(tr("Toggle view"));
     connect(widgetStateMenuButton, SIGNAL(pressed()), SLOT(sl_showStateMenu()));
 
 
