@@ -34,6 +34,7 @@ class DNASequenceObject;
 class GSequenceLineView;
 class DetView;
 class PanView;
+class Overview;
 class GSingleSeqBlockState;
 class DNATranslation;
 class ADVSequenceObjectContext;
@@ -71,7 +72,7 @@ public:
     
     int getSequenceLen() const;
 
-    virtual void addSequenceView(GSequenceLineView* v);
+    virtual void addSequenceView(GSequenceLineView* v, QWidget* after = NULL);
 
     virtual void removeSequenceView(GSequenceLineView* v, bool deleteView = true);
 
@@ -92,6 +93,9 @@ public:
     void setDetViewCollapsed(bool v);
     bool isDetViewCollapsed() const;
 
+    void setOverviewCollapsed(bool v);
+    bool isOverviewCollapsed() const;
+
     virtual void updateState(const QVariantMap& m);
     virtual void updateSelectionActions();
     QList<LRegion> getSelectedAnnotationRegions(int max);
@@ -111,9 +115,10 @@ public:
 protected slots:
     void sl_onViewDestroyed(QObject*);
 
-    void sl_toggleView() {setViewCollapsed(!isViewCollapsed());}
-    void sl_togglePanView() {setPanViewCollapsed(!isPanViewCollapsed());}
+    void sl_toggleView();
+    void sl_togglePanView();
     void sl_toggleDetView() {setDetViewCollapsed(!isDetViewCollapsed());}
+    void sl_toggleOverview() {setOverviewCollapsed(!isOverviewCollapsed());}
     void sl_onSelectRange();
     void sl_onSelectInRange();
     void sl_onSelectOutRange();
@@ -139,7 +144,7 @@ protected:
 private:
     virtual void updateMinMaxHeight();
 
-    void addStateActions(QMenu& m);
+	void addStateActions(QMenu& m);
 
     void addRulersMenu(QMenu& m);
     void addSelectMenu(QMenu& m);
@@ -150,6 +155,7 @@ private:
     
     DetView*                        detView;
     PanView*                        panView;
+    Overview*                       overview;
     QList<GSequenceLineView*>       lineViews;
     QVBoxLayout*                    linesLayout;
     ADVSingleSequenceHeaderWidget   *headerWidget;
@@ -157,6 +163,7 @@ private:
     QAction*        toggleViewAction;
     QAction*        togglePanViewAction;
     QAction*        toggleDetViewAction;
+    QAction*        toggleOverviewAction;
     QAction*        selectRangeAction1;
     QAction*        selectRangeAction2;
     QAction*        selectInAnnotationRageAction;
@@ -171,6 +178,16 @@ private:
     friend class ADVSingleSequenceHeaderWidget;
 };
 
+class HBar : public QToolBar {
+public:
+    HBar(QWidget* w) : QToolBar(w){}
+protected:
+    void paintEvent(QPaintEvent* pe) {
+        Q_UNUSED(pe);
+        //do not draw any special toolbar control -> make is merged with parent widget
+    }
+};
+
 class GB2_COREAPI_EXPORT ADVSingleSequenceHeaderWidget : public QWidget {
     Q_OBJECT
 public:
@@ -193,7 +210,7 @@ protected slots:
 private:
     void populateToolBars();
     void updateActiveState();
-
+	
     ADVSingleSequenceWidget*        ctx;
     QToolBar*                       toolBar;
     QToolBar*                       closeBar;
