@@ -18,7 +18,6 @@
 #include "ADVAnnotationCreation.h"
 #include "ADVClipboard.h"
 #include "ADVConstants.h"
-#include "ADVAlignmentSupport.h"
 #include "ADVSequenceObjectContext.h"
 #include "ADVSingleSequenceWidget.h"
 #include "ADVSplitWidget.h"
@@ -79,7 +78,6 @@ AnnotatedDNAView::AnnotatedDNAView(const QString& viewName, const QList<DNASeque
     annotationGroupSelection = new AnnotationGroupSelection(this);
     
     clipb = NULL;
-    aliSupport = NULL;
     
     mainSplitter = NULL;
     scrollArea = NULL;
@@ -168,7 +166,6 @@ QWidget* AnnotatedDNAView::createWidget() {
     scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     
     clipb = new ADVClipboard(this);
-    aliSupport = new ADVAlignmentSupport(this);
     
     mainSplitter->installEventFilter(this);
     mainSplitter->setAcceptDrops(true);
@@ -281,7 +278,7 @@ bool AnnotatedDNAView::onObjectRemoved(GObject* o) {
         }
         annotations.removeOne(ao);
         emit si_annotationObjectRemoved(ao);
-    } else if (o->getGObjectType() == GObjectTypes::DNA_SEQUENCE) {
+    } else if (o->getGObjectType() == GObjectTypes::SEQUENCE) {
         DNASequenceObject* seqObj = qobject_cast<DNASequenceObject*>(o);
         ADVSequenceObjectContext* seqCtx = getSequenceContext(seqObj);
         if (seqCtx!=NULL) {
@@ -413,7 +410,7 @@ void AnnotatedDNAView::addEditMenu(QMenu* m) {
     Document *curDoc = seqObj->getDocument();
     QMenu* rm = m->addMenu(tr("edit_menu"));
     
-    if(curDoc->findGObjectByType(GObjectTypes::DNA_SEQUENCE).isEmpty() || curDoc->isStateLocked()){
+    if(curDoc->findGObjectByType(GObjectTypes::SEQUENCE).isEmpty() || curDoc->isStateLocked()){
         rm->setDisabled(true);
     }else{
         rm->setEnabled(true);
@@ -454,7 +451,7 @@ bool AnnotatedDNAView::canAddObject(GObject* obj) {
     if (isChildWidgetObject(obj)) {
             return true;
     }
-    if (obj->getGObjectType() == GObjectTypes::DNA_SEQUENCE) {
+    if (obj->getGObjectType() == GObjectTypes::SEQUENCE) {
         return true;
     }
     if (obj->getGObjectType()!=GObjectTypes::ANNOTATION_TABLE) {
@@ -639,7 +636,7 @@ QString AnnotatedDNAView::addObject(GObject* o) {
         return "";
     }
    
-    if (o->getGObjectType() == GObjectTypes::DNA_SEQUENCE) {
+    if (o->getGObjectType() == GObjectTypes::SEQUENCE) {
         DNASequenceObject* dnaObj = qobject_cast<DNASequenceObject*>(o);
         ADVSequenceObjectContext* sc = new ADVSequenceObjectContext(this, dnaObj);
         seqContexts.append(sc);
@@ -664,7 +661,7 @@ QString AnnotatedDNAView::addObject(GObject* o) {
 }
 
 QList<ADVSequenceObjectContext*> AnnotatedDNAView::findRelatedSequenceContexts(GObject* obj) const {
-    QSet<GObject*> relatedObjects = GObjectUtils::selectRelations(obj, GObjectTypes::DNA_SEQUENCE, GObjectRelationRole::SEQUENCE, objects, UOF_LoadedOnly);
+    QSet<GObject*> relatedObjects = GObjectUtils::selectRelations(obj, GObjectTypes::SEQUENCE, GObjectRelationRole::SEQUENCE, objects, UOF_LoadedOnly);
     QList<ADVSequenceObjectContext*> res;
     foreach(GObject* seqObj, relatedObjects) {
         DNASequenceObject* dnaObj = qobject_cast<DNASequenceObject*>(seqObj);
@@ -684,7 +681,7 @@ void AnnotatedDNAView::sl_onPosChangeRequest(int pos) {
 void AnnotatedDNAView::sl_onShowPosSelectorRequest() {
     ADVSequenceObjectContext* seqCtx = getSequenceInFocus();
     assert(seqCtx!=NULL);
-    QDialog dlg;
+    QDialog dlg(getWidget());
     dlg.setModal(true);
     dlg.setWindowTitle(tr("Go To"));
     std::auto_ptr<PositionSelector> ps(new PositionSelector(&dlg, 1, seqCtx->getSequenceLen(), true));
