@@ -33,7 +33,6 @@ class AnnotationGroupSelection;
 class DNASequenceSelection;
 class Task;
 class ADVClipboard;
-class ADVAlignmentSupport;
 class ADVSequenceWidget;
 class ADVSplitWidget;
 class ADVSequenceObjectContext;
@@ -196,7 +195,6 @@ private:
     AnnotationGroupSelection *  annotationGroupSelection;
     
     ADVClipboard*               clipb;
-    ADVAlignmentSupport*        aliSupport;
     ADVSyncViewManager*         syncViewManager;
 
     ADVSequenceWidget*          focusedWidget;
