@@ -48,13 +48,13 @@ bool AnnotatedDNAViewFactory::canCreateView(const MultiGSelection& multiSelectio
     
     //1.
     QList<GObject*> selectedObjects = SelectionUtils::findObjects("", &multiSelection, UOF_LoadedAndUnloaded).toList();
-    QList<GObject*> selectedSequences = GObjectUtils::select(selectedObjects, GObjectTypes::DNA_SEQUENCE, UOF_LoadedAndUnloaded);
+    QList<GObject*> selectedSequences = GObjectUtils::select(selectedObjects, GObjectTypes::SEQUENCE, UOF_LoadedAndUnloaded);
     if (!selectedSequences.isEmpty()) {
         return true;
     }
     
     //2.
-    QList<GObject*> objectsWithSeqRelation = GObjectUtils::selectObjectsWithRelation(selectedObjects, GObjectTypes::DNA_SEQUENCE, 
+    QList<GObject*> objectsWithSeqRelation = GObjectUtils::selectObjectsWithRelation(selectedObjects, GObjectTypes::SEQUENCE, 
                                                             GObjectRelationRole::SEQUENCE, UOF_LoadedAndUnloaded, true);
     if (!objectsWithSeqRelation.isEmpty()) {
         return true;
@@ -66,11 +66,11 @@ bool AnnotatedDNAViewFactory::canCreateView(const MultiGSelection& multiSelectio
         return false;
     }
     foreach(Document* doc, ds->getSelectedDocuments()) {
-        if (!doc->findGObjectByType(GObjectTypes::DNA_SEQUENCE, UOF_LoadedAndUnloaded).isEmpty()) {
+        if (!doc->findGObjectByType(GObjectTypes::SEQUENCE, UOF_LoadedAndUnloaded).isEmpty()) {
             return true;
         }    
         objectsWithSeqRelation = GObjectUtils::selectObjectsWithRelation(doc->getObjects(), 
-            GObjectTypes::DNA_SEQUENCE, GObjectRelationRole::SEQUENCE, UOF_LoadedAndUnloaded, true);
+            GObjectTypes::SEQUENCE, GObjectRelationRole::SEQUENCE, UOF_LoadedAndUnloaded, true);
         
         if (!objectsWithSeqRelation.isEmpty()) {
             return true;
@@ -83,19 +83,19 @@ bool AnnotatedDNAViewFactory::canCreateView(const MultiGSelection& multiSelectio
 
 Task* AnnotatedDNAViewFactory::createViewTask(const MultiGSelection& multiSelection, bool single /*=false*/) {
     Q_UNUSED(single);
-    QSet<GObject*> objectsToOpen = SelectionUtils::findObjects(GObjectTypes::DNA_SEQUENCE, &multiSelection, UOF_LoadedAndUnloaded);
+    QSet<GObject*> objectsToOpen = SelectionUtils::findObjects(GObjectTypes::SEQUENCE, &multiSelection, UOF_LoadedAndUnloaded);
 
     QSet<GObject*> selectedObjects = SelectionUtils::findObjects("", &multiSelection, UOF_LoadedAndUnloaded);
     QList<GObject*> objectsWithSequenceRelation = GObjectUtils::selectObjectsWithRelation(selectedObjects.toList(), 
-                                                    GObjectTypes::DNA_SEQUENCE, GObjectRelationRole::SEQUENCE, UOF_LoadedAndUnloaded, true);
+                                                    GObjectTypes::SEQUENCE, GObjectRelationRole::SEQUENCE, UOF_LoadedAndUnloaded, true);
 
     objectsToOpen.unite(objectsWithSequenceRelation.toSet());
 
     const DocumentSelection* ds = qobject_cast<const DocumentSelection*>(multiSelection.findSelectionByType(GSelectionTypes::DOCUMENTS));
     if (ds != NULL) {
         foreach(Document* doc, ds->getSelectedDocuments()) {
-            objectsToOpen.unite(doc->findGObjectByType(GObjectTypes::DNA_SEQUENCE, UOF_LoadedAndUnloaded).toSet());
-            objectsToOpen.unite(GObjectUtils::selectObjectsWithRelation(doc->getObjects(), GObjectTypes::DNA_SEQUENCE, 
+            objectsToOpen.unite(doc->findGObjectByType(GObjectTypes::SEQUENCE, UOF_LoadedAndUnloaded).toSet());
+            objectsToOpen.unite(GObjectUtils::selectObjectsWithRelation(doc->getObjects(), GObjectTypes::SEQUENCE, 
                 GObjectRelationRole::SEQUENCE, UOF_LoadedAndUnloaded, true).toSet());
         }
     }
@@ -105,24 +105,24 @@ Task* AnnotatedDNAViewFactory::createViewTask(const MultiGSelection& multiSelect
 }
 
 bool AnnotatedDNAViewFactory::isStateInSelection(const MultiGSelection& multiSelection, const QVariantMap& stateData) {
-	AnnotatedDNAViewState state(stateData);
-	if (!state.isValid()) {
-		return false;
-	}
-	QList<GObjectReference> refs = state.getSequenceObjects();
+    AnnotatedDNAViewState state(stateData);
+    if (!state.isValid()) {
+        return false;
+    }
+    QList<GObjectReference> refs = state.getSequenceObjects();
     assert(!refs.isEmpty());
     foreach (const GObjectReference& ref, refs) {
-	    Document* doc = AppContext::getProject()->findDocumentByURL(ref.docUrl);
-	    if (doc == NULL) { //todo: accept to use invalid state removal routines of ObjectViewTask ???
-    		return false;
-    	}
+        Document* doc = AppContext::getProject()->findDocumentByURL(ref.docUrl);
+        if (doc == NULL) { //todo: accept to use invalid state removal routines of ObjectViewTask ???
+            return false;
+        }
         //check that document is in selection
-	    QList<Document*> selectedDocs = SelectionUtils::getSelectedDocs(multiSelection);
-	    bool docIsSelected = selectedDocs.contains(doc);
+        QList<Document*> selectedDocs = SelectionUtils::getSelectedDocs(multiSelection);
+        bool docIsSelected = selectedDocs.contains(doc);
 
         //check that object is in selection
-	    QList<GObject*> selectedObjects = SelectionUtils::getSelectedObjects(multiSelection);
-	    GObject* obj = doc->findGObjectByName(ref.objName);
+        QList<GObject*> selectedObjects = SelectionUtils::getSelectedObjects(multiSelection);
+        GObject* obj = doc->findGObjectByName(ref.objName);
         bool objIsSelected = obj!=NULL && selectedObjects.contains(obj);
 
         //check that object associated with sequence object is in selection
@@ -139,11 +139,11 @@ bool AnnotatedDNAViewFactory::isStateInSelection(const MultiGSelection& multiSel
         }
     }
 
-	return true;
+    return true;
 }
 
 Task* AnnotatedDNAViewFactory::createViewTask(const QString& viewName, const QVariantMap& stateData) {
-	return new OpenSavedAnnotatedDNAViewTask(viewName, stateData);
+    return new OpenSavedAnnotatedDNAViewTask(viewName, stateData);
 }
 
 
