@@ -45,9 +45,9 @@ typedef QFlags<ATVAnnUpdateFlag> ATVAnnUpdateFlags;
 
 
 class GB2_COREAPI_EXPORT AnnotationsTreeView : public QWidget {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	AnnotationsTreeView(AnnotatedDNAView* ctx);
+    AnnotationsTreeView(AnnotatedDNAView* ctx);
 
     void saveWidgetState();
     void restoreWidgetState();
@@ -65,15 +65,15 @@ public:
 
     void setSortingEnabled(bool v);
 
-    AVItem* currentItem() {return (AVItem*)tree->currentItem();}
+    AVItem* currentItem();
 
 private slots:
 
-	void sl_onAnnotationObjectAdded(AnnotationTableObject* obj);
-	void sl_onAnnotationObjectRemoved(AnnotationTableObject* obj);
+    void sl_onAnnotationObjectAdded(AnnotationTableObject* obj);
+    void sl_onAnnotationObjectRemoved(AnnotationTableObject* obj);
 
-	void sl_onAnnotationsAdded(const QList<Annotation*>&);
-	void sl_onAnnotationsRemoved(const QList<Annotation*>&);
+    void sl_onAnnotationsAdded(const QList<Annotation*>&);
+    void sl_onAnnotationsRemoved(const QList<Annotation*>&);
     void sl_onAnnotationModified(const AnnotationModification& md);
     void sl_annotationObjectModifiedStateChanged();
 
@@ -83,9 +83,9 @@ private slots:
 
     void sl_onAnnotationSettingsChanged(const QStringList& changedSettings);
 
-	void sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>&);
+    void sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>&);
     void sl_onAnnotationGroupSelectionChanged(AnnotationGroupSelection*, const QList<AnnotationGroup*>&, const QList<AnnotationGroup*>&);
-	void sl_onItemSelectionChanged();
+    void sl_onItemSelectionChanged();
     void sl_onAddAnnotationObjectToView();
     void sl_removeObjectFromView();
     void sl_removeAnnsAndQs();
@@ -100,8 +100,11 @@ private slots:
     void sl_rename();
     void sl_edit();
     void sl_addQualifier();
+//    void sl_cutAnnotations();
+//    void sl_copyAnnotations();
+//    void sl_pasteAnnotations();
 
-	void sl_itemEntered(QTreeWidgetItem * i, int column);
+    void sl_itemEntered(QTreeWidgetItem * i, int column);
     void sl_itemClicked( QTreeWidgetItem * item, int column);
     void sl_itemDoubleClicked (QTreeWidgetItem * item, int column);
     void sl_itemExpanded(QTreeWidgetItem*);
@@ -122,25 +125,25 @@ private:
     void moveDialogToItem(QTreeWidgetItem* item, QDialog& d);
     
     void adjustMenu(QMenu* m_) const;
-	AVGroupItem* buildGroupTree(AVGroupItem* parentGroup, AnnotationGroup* g);
-	AVAnnotationItem* buildAnnotationTree(AVGroupItem* parentGroup, Annotation* a);
+    AVGroupItem* buildGroupTree(AVGroupItem* parentGroup, AnnotationGroup* g);
+    AVAnnotationItem* buildAnnotationTree(AVGroupItem* parentGroup, Annotation* a);
     void populateAnnotationQualifiers(AVAnnotationItem* ai);
     void updateAllAnnotations(ATVAnnUpdateFlags flags);
 
-	AVGroupItem* findGroupItem(const AnnotationGroup* g) const;
-	AVAnnotationItem* findAnnotationItem(const AnnotationGroup* g, const Annotation* a) const;
-	AVAnnotationItem* findAnnotationItem(const AVGroupItem* gi, const Annotation* a) const;
+    AVGroupItem* findGroupItem(const AnnotationGroup* g) const;
+    AVAnnotationItem* findAnnotationItem(const AnnotationGroup* g, const Annotation* a) const;
+    AVAnnotationItem* findAnnotationItem(const AVGroupItem* gi, const Annotation* a) const;
     QList<AVAnnotationItem*> findAnnotationItems(const Annotation* a) const;
 
-	void connectAnnotationSelection();
+    void connectAnnotationSelection();
     void connectAnnotationGroupSelection();
     
     void updateState();
     void updateColumnContextActions(AVItem* item, int col);
 
-	QTreeWidget* tree;
+    QTreeWidget* tree;
 
-	AnnotatedDNAView*   ctx;
+    AnnotatedDNAView*   ctx;
     QAction*            addAnnotationObjectAction;
     QAction*            removeObjectsFromViewAction;
     QAction*            removeAnnsAndQsAction;
@@ -150,6 +153,9 @@ private:
     QAction*            removeColumnByHeaderClickAction;
     QAction*            copyColumnTextAction;
     QAction*            copyColumnURLAction;
+//    QAction*            cutAnnotationsAction;
+//    QAction*            copyAnnotationsAction;
+//    QAction*            pasteAnnotationsAction;
     
     QAction*            renameAction;       // action to rename active group/qualifier/annotation only
     QAction*            editAction;         // action to edit active item -> only for non-readonly
@@ -163,6 +169,10 @@ private:
     QIcon               addColumnIcon;
     QIcon               removeColumnIcon;
     QTimer              sortTimer;
+    QPoint              dragStartPos;
+    bool                isDragging;
+
+    static const QString annotationMimeType;
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -171,24 +181,24 @@ private:
 //TODO: create qualifiers subtrees only when qualifier node is opened (usually qualifiers get ~ 90% of memory)
 
 enum AVItemType {
-	AVItemType_Group,
-	AVItemType_Annotation,
-	AVItemType_Qualifier
+    AVItemType_Group,
+    AVItemType_Annotation,
+    AVItemType_Qualifier
 };
 
 class AVItem : public QTreeWidgetItem {
 public:
-	AVItem(QTreeWidgetItem* parent, AVItemType _type) : QTreeWidgetItem(parent), type(_type) {}
-	const AVItemType type;
+    AVItem(QTreeWidgetItem* parent, AVItemType _type) : QTreeWidgetItem(parent), type(_type) {}
+    const AVItemType type;
     bool processLinks(const QString& qname, const QString& qval, int col);
     bool isColumnLinked(int col) const;
     QString buildLinkURL(int col) const;
     QString getFileUrl(int col) const;
-    virtual bool isReadonly() const  {assert(parent()!=NULL); return ((AVItem*)parent())->isReadonly();}
+    virtual bool isReadonly() const  {assert(parent()!=NULL); return (static_cast<AVItem*>(parent())->isReadonly());}
 
-    virtual AnnotationsTreeView* getAnnotationTreeView() const {assert(parent()!=NULL); return ((AVItem*)parent())->getAnnotationTreeView();}
-    virtual AnnotationTableObject* getAnnotationTableObject() const {assert(parent()!=NULL); return ((AVItem*)parent())->getAnnotationTableObject();}
-    virtual AnnotationGroup* getAnnotationGroup() const {assert(parent()!=NULL); return ((AVItem*)parent())->getAnnotationGroup();}
+    virtual AnnotationsTreeView* getAnnotationTreeView() const {assert(parent()!=NULL); return (static_cast<AVItem*>(parent())->getAnnotationTreeView());}
+    virtual AnnotationTableObject* getAnnotationTableObject() const {assert(parent()!=NULL); return (static_cast<AVItem*>(parent())->getAnnotationTableObject());}
+    virtual AnnotationGroup* getAnnotationGroup() const {assert(parent()!=NULL); return (static_cast<AVItem*>(parent())->getAnnotationGroup());}
 
 };
 
@@ -214,10 +224,10 @@ public:
 
 class AVAnnotationItem : public AVItem {
 public:
-	AVAnnotationItem(AVGroupItem* parent, Annotation* a);
+    AVAnnotationItem(AVGroupItem* parent, Annotation* a);
     ~AVAnnotationItem();
-	Annotation* annotation;
-	mutable QString locationString;
+    Annotation* annotation;
+    mutable QString locationString;
 
     virtual QVariant data ( int column, int role ) const;
     void updateVisual(ATVAnnUpdateFlags flags);
@@ -235,10 +245,10 @@ public:
 
 class AVQualifierItem: public AVItem {
 public:
-	AVQualifierItem(AVAnnotationItem* parent, const Qualifier& q);
+    AVQualifierItem(AVAnnotationItem* parent, const Qualifier& q);
 
     const QString qName;
-	const QString qValue;
+    const QString qValue;
 };
 
 
