@@ -69,7 +69,7 @@ DetView::DetView(QWidget* p, ADVSequenceObjectContext* ctx)
 }
 
 void DetView::updateSize() {
-    ((DetViewRenderArea*)renderArea)->updateSize();
+    (static_cast<DetViewRenderArea*>(renderArea))->updateSize();
     setFixedHeight(renderArea->height() + scrollBar->height());
 }
 
@@ -152,7 +152,7 @@ void DetView::mouseReleaseEvent(QMouseEvent* me) {
     bool singleBaseSelectionMode = km.testFlag(Qt::AltModifier);
     if (me->button() == Qt::LeftButton && singleBaseSelectionMode) {
         QPoint areaPoint = toRenderAreaPoint(me->pos());
-        if (((DetViewRenderArea*)renderArea)->isOnTranslationsLine(areaPoint.y())) {
+        if ((static_cast<DetViewRenderArea*>(renderArea))->isOnTranslationsLine(areaPoint.y())) {
             int pos = renderArea->coordToPos(areaPoint.x());
             if (pos == lastPressPos) {
                 LRegion rgn(pos-1, 3);
