@@ -71,7 +71,7 @@ public:
 	virtual float posToCoordF(int x, bool useVirtualSpace = false) const;
 	virtual float getCurrentScale() const; 
 
-	DetView*		getDetView() const {return (DetView*)view;}
+	DetView*		getDetView() const {return static_cast<DetView*>(view);}
 
 	virtual LRegion getAnnotationYRange(Annotation* a, const LRegion& r, const AnnotationSettings* as) const;
     
