@@ -21,7 +21,7 @@ namespace GB2{
 class GB2_COREAPI_EXPORT EditAnnotationDialogController : public QDialog, public Ui_EditAnnotationDialog {
     Q_OBJECT
 public:
-    EditAnnotationDialogController(Annotation* a, QWidget* p = NULL);
+    EditAnnotationDialogController(Annotation* a, LRegion _seqRange, QWidget* p = NULL);
 
     virtual void accept ();
 
@@ -37,6 +37,7 @@ private slots:
 private:
     QMenu* createAnnotationNamesMenu(QWidget* p, QObject* receiver);
 
+	LRegion seqRange;
     QList<LRegion> currentRegionList;
     QString currentName;
     bool compliment;
