@@ -61,7 +61,7 @@ class GB2_COREAPI_EXPORT GSequenceGraphViewRA : public GSequenceLineViewRenderAr
 public:
 	GSequenceGraphViewRA(GSequenceGraphView* g);
 	~GSequenceGraphViewRA();
-	virtual GSequenceGraphView* getGraphView() const {return (GSequenceGraphView*)view;}
+	virtual GSequenceGraphView* getGraphView() const {return static_cast<GSequenceGraphView*>(view);}
     
     float getCurrentScale() const;
 
