@@ -160,7 +160,7 @@ public:
     int getCharWidth() const {return charWidth;}
 
 protected:
-	void paintEvent(QPaintEvent *e);
+	virtual void paintEvent(QPaintEvent *e);
     
 	virtual void drawAll(QPaintDevice* pd) = 0;
     void drawFrame(QPainter& p);
