@@ -236,6 +236,24 @@ void GSequenceLineViewAnnotated::mousePressEvent(QMouseEvent * me) {
 	GSequenceLineView::mousePressEvent(me);
 }
 
+QString GSequenceLineViewAnnotated::prepareAnnotationText(const Annotation* a, const AnnotationSettings* as) {
+    if (as->nameQuals.isEmpty()) {
+        return a->getAnnotationName();
+    }
+
+    static QVector<Qualifier> qs; //warn: main thread model only
+
+    foreach(const QString& qn, as->nameQuals) {
+        qs.clear();
+        a->findQualifiers(qn, qs);
+        if (!qs.isEmpty()) {
+            QString res = qs[0].getQualifierValue();
+            return res;
+        }
+    }
+    return a->getAnnotationName();
+}
+
 //////////////////////////////////////////////////////////////////////////
 /// Renderer
 
@@ -284,25 +302,6 @@ void GSequenceLineViewAnnotatedRenderArea::drawAnnotations(QPainter& p) {
     }
 }
 
-
-static QString prepareAnnotationText(const Annotation* a, const AnnotationSettings* as) {
-    if (as->nameQuals.isEmpty()) {
-        return a->getAnnotationName();
-    }
-    
-    static QVector<Qualifier> qs; //warn: main thread model only
-
-    foreach(const QString& qn, as->nameQuals) {
-        qs.clear();
-        a->findQualifiers(qn, qs);
-        if (!qs.isEmpty()) {
-            QString res = qs[0].getQualifierValue();
-            return res;
-        }
-    }
-    return a->getAnnotationName();
-}
-
 #define FEATURE_ARROW_HLEN 3
 #define FEATURE_ARROW_VLEN 3
 void static addArrowPath(QPainterPath& path, const QRect& rect, bool leftArrow) {
@@ -327,7 +326,7 @@ void static addArrowPath(QPainterPath& path, const QRect& rect, bool leftArrow)
     path = path.united(arrowPath);
 }
 
-#define FEATURE_TRIM_HLEN 5
+/*#define FEATURE_TRIM_HLEN 5
 void static addTrimPath(QPainterPath& path, const QRect& rect, bool leftTrim) {
     //TODO: normalize line line by 4
     if (rect.width() <= FEATURE_TRIM_HLEN || rect.height() <= 0) {
@@ -350,7 +349,7 @@ void static addTrimPath(QPainterPath& path, const QRect& rect, bool leftTrim) {
     trimPath.addPolygon(arr);
 
     path = path.subtracted(trimPath);
-}
+}*/
 
 
 void GSequenceLineViewAnnotatedRenderArea::drawAnnotation(QPainter& p, DrawAnnotationPass pass, Annotation* a, const QPen& borderPen, bool selected, 
@@ -408,7 +407,7 @@ void GSequenceLineViewAnnotatedRenderArea::drawAnnotation(QPainter& p, DrawAnnot
             if (rw > MIN_ANNOTATION_WIDTH) {
                 p.drawPath(rectPath);
                 if (drawSettings.drawAnnotationNames &&  annotationRect.width() >= MIN_ANNOTATION_TEXT_WIDTH) {
-                    QString aText = prepareAnnotationText(a, as);
+                    QString aText = GSequenceLineViewAnnotated::prepareAnnotationText(a, as);
                     drawBoundedText(p, annotationRect, aText);
                 }
                 if (simple && annotationRect.width() > MIN_WIDTH_TO_DRAW_EXTRA_FEATURES) {
