@@ -36,7 +36,9 @@ public:
 	bool isAnnotationVisible(Annotation* a) const;
 	const DrawSettings& getDrawSettings() const {return drawSettings;}
 
-	QList<AnnotationSelectionData> selectAnnotationByCoord(const QPoint& coord) const;
+	virtual QList<AnnotationSelectionData> selectAnnotationByCoord(const QPoint& coord) const;
+
+    static QString prepareAnnotationText(const Annotation* a, const AnnotationSettings* as);
 
 protected:
 	void mousePressEvent(QMouseEvent * e);
@@ -55,8 +57,8 @@ protected slots:
 	void sl_onAnnotationObjectRemoved(AnnotationTableObject*);
 	void sl_onAnnotationsAdded(const QList<Annotation*>&);
 	void sl_onAnnotationsRemoved(const QList<Annotation*>&);
-    void sl_onAnnotationsModified(const AnnotationModification& md);
-	void sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>& added, const QList<Annotation*>& removed);
+    virtual void sl_onAnnotationsModified(const AnnotationModification& md);
+	virtual void sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>& added, const QList<Annotation*>& removed);
     
 private:
 	void connectAnnotationObject(AnnotationTableObject* ao);
