@@ -180,6 +180,14 @@ void PanView::sl_onRowBarMoved(int v) {
     update();
 }
 
+void PanView::sl_onAnnotationsModified(const AnnotationModification& md) {
+    QList<Annotation*> modified;
+    modified << md.annotation;
+    unregisterAnnotations(modified);
+    registerAnnotations(modified);
+    GSequenceLineViewAnnotated::sl_onAnnotationsModified(md);
+}
+
 void PanView::sl_onAnnotationSettingsChanged(const QStringList& changedSettings) {
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
     foreach (const QString& name, changedSettings) {
@@ -341,7 +349,7 @@ void PanView::setNumBasesVisible(int n) {
 }
 
 PanViewRenderArea* PanView::getRenderArea() const {
-    return (PanViewRenderArea*)renderArea;
+    return static_cast<PanViewRenderArea*>(renderArea);
 }
 
 QList<RulerInfo> PanView::getCustomRulers() const {
@@ -428,6 +436,20 @@ void PanView::sl_sequenceChanged(){
     }
     GSequenceLineView::sl_sequenceChanged();
 }
+
+void PanView::hideEvent( QHideEvent *ev ){
+    zoomInAction->setDisabled(true);
+    zoomOutAction->setDisabled(true);
+    zoomToSelectionAction->setDisabled(true);
+    zoomToSequenceAction->setDisabled(true);
+    QWidget::hideEvent(ev);
+}
+
+void PanView::showEvent( QShowEvent *ev ){
+    QWidget::showEvent(ev);
+	updateActions();
+}
+
 //////////////////////////////////////////////////////////////////////////
 /// render
 PanViewRenderArea::PanViewRenderArea(PanView* d) : GSequenceLineViewAnnotatedRenderArea(d, false), panView(d) {
@@ -583,7 +605,7 @@ void PanViewRenderArea::drawAnnotations(QPainter& p) {
         } else {
             text = rData->key + " (" + QString::number(rData->annotations.size()) + ")";
         }
-        int y = lineY + lineHeight;
+
         QRect textRect(LINE_TEXT_OFFSET, lineY + 1, w, lineHeight - 2);
         p.drawText(textRect, text);
 
@@ -665,7 +687,16 @@ void PanViewRenderArea::drawSequenceSelection(QPainter& p) {
     }
     int halfNum = rfm.boundingRect('1').height() / 2;
     int rty = ly + halfNum;
-    QString rangePattern = " "+tr("[%1 bp]")+" ";
+    
+    DNAAlphabet* alphabet = panView->getSequenceObject()->getAlphabet();
+    QString unitType;
+    if (alphabet->isAmino()) {
+        unitType = "aa";
+    } else {
+        unitType = "bp";
+    }
+
+    QString rangePattern = " "+tr("[%1 %2]")+" ";
     foreach(const LRegion& r, selection) {
         if (!visibleRange.intersects(r)) {
             continue;
@@ -699,7 +730,7 @@ void PanViewRenderArea::drawSequenceSelection(QPainter& p) {
             QRect t2Rect = rfm.boundingRect(t2).translated(x2 + tOffs, rty);
 
             // define range text coords
-            QString rangeText = rangePattern.arg(r.len);
+            QString rangeText = rangePattern.arg(r.len).arg(unitType);
             QRect rtRect = rfm.boundingRect(rangeText);
             int rulerWidth = x2 - x1;
             bool rangeTextInTheMiddle = rulerWidth - dArrow > rtRect.width();
@@ -780,14 +811,15 @@ void PanViewRenderArea::setRowLinesOffset(int r) {
 }
 
 bool PanViewRenderArea::updateNumVisibleRows() {
-    int actualRows = getPanView()->getRowsManager()->getNumRows();
-    int expectedRows = actualRows + EXTRA_EMPTY_ROWS;
-    int actualRowsToShow = qBound(MIN_VISIBLE_ROWS, expectedRows, MAX_VISIBLE_ROWS);
+    int annotationRows = getPanView()->getRowsManager()->getNumRows();
+    int expectedRowsToShow = annotationRows + EXTRA_EMPTY_ROWS;
+    int actualAnnotationsRowsToShow = qBound(MIN_VISIBLE_ROWS, expectedRowsToShow, MAX_VISIBLE_ROWS);
     int currentRowsShown = getNumVisibleRows();
-    if (actualRowsToShow == currentRowsShown) {
-        return false;
-    }
-    numLines = 2 + actualRowsToShow; //2 == ruler + selection
+    int newNumLines = actualAnnotationsRowsToShow + 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+	if (newNumLines == numLines) {
+		return false; //height was not changed
+	}
+	numLines = newNumLines;
     setFixedHeight(numLines * lineHeight);
     view->addUpdateFlags(GSLV_UF_ViewResized);
     view->update();
