@@ -28,7 +28,7 @@ class Annotation;
 
 class RulerInfo {
 public:
-    RulerInfo(){}
+    RulerInfo(): offset(0){}
     RulerInfo(const QString& _name, int _offset, const QColor& _color) : name(_name), offset(_offset), color(_color) {}
     
     QString name;
@@ -78,6 +78,10 @@ public:
     
     QAction* getToggleCustomRulersAction() const {return toggleCustomRulersAction;}
 
+    void hideEvent(QHideEvent *ev);
+
+    void showEvent(QShowEvent *ev);
+
 protected:
     virtual int getSingleStep() const {return qMax(1, visibleRange.len / 10);}
 	virtual int getPageStep() const {return qMax(1, visibleRange.len / 5);}
@@ -89,6 +93,7 @@ protected:
 	virtual void ensureVisible(Annotation* a, int locationIdx);
 protected slots:
     virtual void sl_sequenceChanged();
+    void sl_onAnnotationsModified(const AnnotationModification& md);
 
 private slots:
 	void sl_zoomInAction();
