@@ -13,7 +13,7 @@
 
 #include <gobjects/MAlignmentObject.h>
 #include <util_gui/GUIUtils.h>
-#include <util_algorithm/MSAUtils.h>
+#include <util_msa_consensus//MSAConsensusUtils.h>
 
 namespace GB2 {
 
@@ -101,7 +101,7 @@ QColor MSAColorSchemePercIdent::getColor(int seq, int pos) {
         return QColor();
     }
     quint32 packedVal = indentCache[pos];
-    MSAUtils::unpackConsensusCharsFromInt(packedVal, tmpChars, tmpRanges);
+    MSAConsensusUtils::unpackConsensusCharsFromInt(packedVal, tmpChars, tmpRanges);
     for (int i=0; i < 4; i++) {
         if (c == tmpChars[i]) {
             int range = tmpRanges[i];
@@ -119,7 +119,7 @@ void MSAColorSchemePercIdent::updateCache() {
     int aliLen = ma.getLength();
     indentCache.resize(aliLen);
     for (int i=0; i < aliLen; i++) {
-        indentCache[i] = MSAUtils::packConsensusCharsToInt(ma, i, mask4, true);
+        indentCache[i] = MSAConsensusUtils::packConsensusCharsToInt(ma, i, mask4, true);
     }
     cacheVersion = objVersion;
 }
@@ -192,7 +192,7 @@ void MSAColorSchemeClustalX::updateCache() {
     // compute colors for whole ali
     // use 4 bits per color
     const MAlignment& ma = maObj->getMAlignment();
-    int nSeq = ma.getNumSequences();
+    int nSeq = ma.getNumRows();
     aliLen = maObj->getMAlignment().getLength();
     cacheVersion = objVersion;
 
@@ -234,7 +234,7 @@ void MSAColorSchemeClustalX::updateCache() {
     
     for (int pos = 0; pos < aliLen; pos++) {
         int nonGapChars = 0;
-        MSAUtils::getColumnFreqs(ma, pos, freqsByChar, nonGapChars);
+        MSAConsensusUtils::getColumnFreqs(ma, pos, freqsByChar, nonGapChars);
         int content50 = int(nonGapChars * 50.0 / 100);
         int content60 = int(nonGapChars * 60.0 / 100);
         int content80 = int(nonGapChars * 80.0 / 100);
