@@ -20,6 +20,7 @@
 #include <QtGui/QClipboard>
 #include <QtGui/QPainter>
 #include <QtGui/QMouseEvent>
+#include <QtGui/QInputDialog>
 
 namespace GB2 {
 
@@ -27,9 +28,14 @@ MSAEditorNameList::MSAEditorNameList(MSAEditorUI* _ui, QScrollBar* _nhBar) : edi
     setFocusPolicy(Qt::WheelFocus);
     cachedView = new QPixmap();
     completeRedraw = true;
+    scribbling = false;
+    curSeq = -1;
     
     connect(editor, SIGNAL(si_buildStaticMenu(GObjectView*, QMenu*)), SLOT(sl_buildStaticMenu(GObjectView*, QMenu*)));
     
+    editSequenceNameAction = new QAction(tr("Edit sequence name"), this);
+    connect(editSequenceNameAction, SIGNAL(triggered()), SLOT(sl_editSequenceName()));
+    
     copyCurrentSequenceAction = new QAction(tr("copy_current_sequence"), this);
     connect(copyCurrentSequenceAction, SIGNAL(triggered()), SLOT(sl_copyCurrentSequence()));
 
@@ -37,14 +43,18 @@ MSAEditorNameList::MSAEditorNameList(MSAEditorUI* _ui, QScrollBar* _nhBar) : edi
     connect(removeCurrentSequenceAction, SIGNAL(triggered()), SLOT(sl_removeCurrentSequence()));
         
     connect(editor, SIGNAL(si_buildPopupMenu(GObjectView* , QMenu*)), SLOT(sl_buildContextMenu(GObjectView*, QMenu*)));
-    connect(editor->getMSAObject(), SIGNAL(si_alignmentChanged(const MAlignment&, const MAlignmentModInfo&)), 
-        SLOT(sl_alignmentChanged(const MAlignment&, const MAlignmentModInfo&)));
+    if (editor->getMSAObject()) {
+        connect(editor->getMSAObject(), SIGNAL(si_alignmentChanged(const MAlignment&, const MAlignmentModInfo&)), 
+            SLOT(sl_alignmentChanged(const MAlignment&, const MAlignmentModInfo&)));
+        connect(editor->getMSAObject(), SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
+    }
 
-    connect(editor->getMSAObject(), SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
-
-    connect(ui->seqArea, SIGNAL(si_startChanged(const QPoint& , const QPoint& )), SLOT(sl_startChanged(const QPoint& , const QPoint&)));
-    connect(ui->seqArea, SIGNAL(si_cursorMoved(const QPoint& , const QPoint& )), SLOT(sl_cursorMoved(const QPoint& , const QPoint& )));
-    connect(ui->seqArea, SIGNAL(si_scaleChanged()), SLOT(sl_scaleChanged()));
+    if (ui->seqArea) {
+        connect(ui->seqArea, SIGNAL(si_startChanged(const QPoint& , const QPoint& )), SLOT(sl_startChanged(const QPoint& , const QPoint&)));
+        connect(ui->seqArea, SIGNAL(si_selectionChanged(const MSAEditorSelection&, const MSAEditorSelection&)), SLOT(sl_selectionChanged(const MSAEditorSelection& , const MSAEditorSelection& )));
+        connect(ui->editor, SIGNAL(si_fontChanged(const QFont&)), SLOT(sl_fontChanged()));
+        connect(ui->seqArea->getVBar(), SIGNAL(actionTriggered(int)), SLOT(sl_onScrollBarActionTriggered(int)));
+    }
     
     nhBar->setEnabled(false);
     updateActions();
@@ -58,7 +68,10 @@ void MSAEditorNameList::updateActions() {
     copyCurrentSequenceAction->setEnabled(true);
     
     MAlignmentObject* maObj = editor->getMSAObject();
-    removeCurrentSequenceAction->setEnabled(!maObj->isStateLocked() && maObj->getMAlignment().getNumSequences() > 1);
+    if (maObj){
+        removeCurrentSequenceAction->setEnabled(!maObj->isStateLocked() && maObj->getMAlignment().getNumRows() > 1);
+        editSequenceNameAction->setEnabled(!maObj->isStateLocked());
+    }
 }
 
 #define MARGIN_TEXT_LEFT 5
@@ -68,13 +81,15 @@ void MSAEditorNameList::updateActions() {
 void MSAEditorNameList::updateScrollBar() {
     nhBar->disconnect(this);
 
-    QFont f = ui->seqArea->getFont();
+    QFont f = ui->editor->getFont();
     f.setItalic(true);
     QFontMetrics fm(f);
     int maxNameWidth = 0;
-    foreach(const MAlignmentItem& mai, editor->getMSAObject()->getMAlignment().alignedSeqs) {
-        maxNameWidth = qMax(fm.width(mai.name), maxNameWidth);
-    }
+
+    MAlignmentObject* maObj = editor->getMSAObject();
+    foreach(const MAlignmentRow& row, maObj->getMAlignment().getRows()) {
+		maxNameWidth = qMax(fm.width(row.getName()), maxNameWidth);
+	}
 
     int availableWidth = width() - MARGIN_TEXT_LEFT;
     int nSteps = 1;
@@ -103,6 +118,11 @@ void MSAEditorNameList::sl_buildContextMenu(GObjectView* v, QMenu* m) {
 }
 
 void MSAEditorNameList::buildMenu(QMenu* m) {    
+    
+    if ( !rect().contains( mapFromGlobal(QCursor::pos()) ) )  {
+        return;
+    } 
+    
     QMenu* copyMenu = GUIUtils::findSubMenu(m, MSAE_MENU_COPY);
     assert(copyMenu!=NULL);
     copyMenu->addAction(copyCurrentSequenceAction);
@@ -110,13 +130,23 @@ void MSAEditorNameList::buildMenu(QMenu* m) {
     QMenu* editMenu = GUIUtils::findSubMenu(m, MSAE_MENU_EDIT);
     assert(editMenu!=NULL);
     editMenu->addAction(removeCurrentSequenceAction);
+    editMenu->insertAction(editMenu->actions().first(), editSequenceNameAction);
+   
 }
 
 
 void MSAEditorNameList::sl_copyCurrentSequence() {
-    int n = ui->seqArea->getCursorPos().y();
-    const MAlignmentItem& item = editor->getMSAObject()->getMAlignment().alignedSeqs[n];
-    QApplication::clipboard()->setText(QString(item.sequence));
+    const MSAEditorSelection& selection = ui->seqArea->getSelection();
+    if (selection.height() == 0) {
+        return;
+    }
+    int n = selection.y();
+    MAlignmentObject* maObj = editor->getMSAObject();
+	if (maObj) {
+		const MAlignmentRow& row = maObj->getMAlignment().getRow(n);
+		//TODO: trim large sequence?
+        QApplication::clipboard()->setText(row.toByteArray(maObj->getLength()));
+	}
 }
 
 void MSAEditorNameList::sl_alignmentChanged(const MAlignment&, const MAlignmentModInfo& mi) {
@@ -133,13 +163,20 @@ void MSAEditorNameList::sl_nameBarMoved(int) {
 }
 
 void MSAEditorNameList::sl_removeCurrentSequence() {
-    int n = ui->seqArea->getCursorPos().y();
+    const MSAEditorSelection& selection = ui->seqArea->getSelection();
+    if (selection.height() == 0) {
+        return;
+    }
+    int n = selection.y();
     MAlignmentObject* maObj = editor->getMSAObject();
-    assert(!maObj->isStateLocked());
-    MAlignment ma = maObj->getMAlignment();
-    assert(ma.getNumSequences() > 1);
-    ma.alignedSeqs.removeAt(n);
-    maObj->setMAlignment(ma);
+    if (maObj) {
+        assert(!maObj->isStateLocked());
+        maObj->removeRow(n);
+        //MAlignment ma = maObj->getMAlignment();
+        //assert(ma.getNumSequences() > 1);
+        //ma.alignedSeqs.removeAt(n);
+        //maObj->setMAlignment(ma);
+    }
 }
 
 void MSAEditorNameList::sl_lockedStateChanged() {
@@ -147,6 +184,7 @@ void MSAEditorNameList::sl_lockedStateChanged() {
 }
 
 void MSAEditorNameList::resizeEvent(QResizeEvent* e) {
+
     completeRedraw = true;
     updateScrollBar();
     QWidget::resizeEvent(e);
@@ -159,11 +197,14 @@ void MSAEditorNameList::paintEvent(QPaintEvent*) {
 void MSAEditorNameList::keyPressEvent (QKeyEvent *e) {
     int key = e->key();
     switch(key) {
+         case Qt::Key_Delete:
+             ui->seqArea->deleteCurrentSelection();    
+             break;
         case Qt::Key_Up:
-            ui->seqArea->moveCursor(0, -1);    
+            ui->seqArea->moveSelection(0, -1);    
             break;
         case Qt::Key_Down:
-            ui->seqArea->moveCursor(0,  1);    
+            ui->seqArea->moveSelection(0,  1);    
             break;
         case Qt::Key_Left:
             nhBar->triggerAction(QAbstractSlider::SliderSingleStepSub);
@@ -173,49 +214,93 @@ void MSAEditorNameList::keyPressEvent (QKeyEvent *e) {
             break;
         case Qt::Key_Home:
             ui->seqArea->setFirstVisibleSequence(0);
-            ui->seqArea->setCursorPos(ui->seqArea->getCursorPos().x(), 0);
+            ui->seqArea->cancelSelection();
+            //TODO: select first sequence?
             break;
-        case Qt::Key_End:
+        case Qt::Key_End: 
             {
                 int s = editor->getNumSequences() - 1;
                 ui->seqArea->setFirstVisibleSequence(s);
-                ui->seqArea->setCursorPos(ui->seqArea->getCursorPos().x(), s);
-            }
+                ui->seqArea->cancelSelection();
+                //TODO: select last sequence?
+            }            
             break;
         case Qt::Key_PageUp:
-            { 
+            {
                 int nVis = ui->seqArea->getNumVisibleSequences(false);
                 int fp = qMax(0, ui->seqArea->getFirstVisibleSequence() - nVis);
-                int cp = qMax(0, ui->seqArea->getCursorPos().y() - nVis);
+                //int cp = qMax(0, ui->seqArea->getCursorPos().y() - nVis);
                 ui->seqArea->setFirstVisibleSequence(fp);
-                ui->seqArea->setCursorPos(ui->seqArea->getCursorPos().x(), cp);
+                ui->seqArea->cancelSelection();
             }
             break;
         case Qt::Key_PageDown:
-            { 
+            {
                 int nVis = ui->seqArea->getNumVisibleSequences(false);
                 int nSeq = editor->getNumSequences();
                 int fp = qMin(nSeq-1, ui->seqArea->getFirstVisibleSequence() + nVis);
-                int cp = qMin(nSeq-1, ui->seqArea->getCursorPos().y() + nVis);
+                //int cp = qMin(nSeq-1, ui->seqArea->getCursorPos().y() + nVis);
                 ui->seqArea->setFirstVisibleSequence(fp);
-                ui->seqArea->setCursorPos(ui->seqArea->getCursorPos().x(), cp);
-            } 
+                ui->seqArea->cancelSelection();
+            }
             break;
-    }
+  }
     QWidget::keyPressEvent(e);
 }
 
 void MSAEditorNameList::mousePressEvent(QMouseEvent *e) {
     int y = e->y();
-    int s = ui->seqArea->getSequenceNumByY(y);
-    if (s !=-1 ) {
-        QPoint pos = ui->seqArea->getCursorPos();
-        pos.setY(s);
-        ui->seqArea->setCursorPos(pos);
+    curSeq = ui->seqArea->getSequenceNumByY(y);
+    if ( ui->seqArea->isSeqInRange(curSeq) ) {
+        int width = editor->getAlignmentLen(); 
+        // select current sequence
+        MSAEditorSelection selection(0, curSeq, width, 1);
+        ui->seqArea->setSelection(selection);
+        scribbling = true;
     }
     QWidget::mousePressEvent(e);
 }
 
+void MSAEditorNameList::mouseMoveEvent( QMouseEvent* e )
+{
+    if ((e->buttons() & Qt::LeftButton) && scribbling) {
+        int newSeqNum = ui->seqArea->getSequenceNumByY(e->pos().y());
+        if (ui->seqArea->isSeqInRange(newSeqNum)) {
+            ui->seqArea->updateVBarPosition(newSeqNum);
+        }
+        updateSelection(newSeqNum);
+    }
+    QWidget::mouseMoveEvent(e);
+
+}
+
+void MSAEditorNameList::mouseReleaseEvent( QMouseEvent *e )
+{
+    if (e->button() == Qt::LeftButton) {
+        curSeq = ui->seqArea->getSequenceNumByY(e->y());
+        updateSelection(curSeq);
+        scribbling = false;
+    }
+    ui->seqArea->getVBar()->setupRepeatAction(QAbstractSlider::SliderNoAction);
+    QWidget::mouseReleaseEvent(e);
+}
+
+void MSAEditorNameList::updateSelection( int newSeq )
+{
+    if (newSeq == curSeq) {
+        return;
+    } 
+
+    if (newSeq != -1) {
+        int startSeq = qMin(curSeq,newSeq);
+        int width = editor->getAlignmentLen();
+        int height = qAbs(newSeq - curSeq) + 1;
+        MSAEditorSelection selection(0, startSeq, width, height );
+        ui->seqArea->setSelection(selection);
+    }
+
+}
+
 void MSAEditorNameList::wheelEvent (QWheelEvent * we) {
     bool toMin = we->delta() > 0;
     ui->seqArea->getVBar()->triggerAction(toMin ? QAbstractSlider::SliderSingleStepSub : QAbstractSlider::SliderSingleStepAdd);
@@ -231,11 +316,20 @@ void MSAEditorNameList::sl_startChanged(const QPoint& p, const QPoint& prev) {
     update();
 }
 
-void MSAEditorNameList::sl_cursorMoved(const QPoint& p, const QPoint& prev) {
-    if (p.y() == prev.y()) {
-        return;
-    }
+void MSAEditorNameList::sl_selectionChanged( const MSAEditorSelection& current, const MSAEditorSelection& prev )
+{
+    Q_UNUSED(current);
+    Q_UNUSED(prev);
+    // TODO: consider optimization -> check for height changes
+
+    //MSAEditorSelection intersected = current.intersected(prev);
+    //if (intersected.height() == current.height()) {
+    //    return;
+    //}
+    //printf("selection changed!\n");
+ 
     update();
+
 }
 
 void MSAEditorNameList::focusInEvent(QFocusEvent* fe) {
@@ -248,7 +342,7 @@ void MSAEditorNameList::focusOutEvent(QFocusEvent* fe) {
     update();
 }
 
-void MSAEditorNameList::sl_scaleChanged() {
+void MSAEditorNameList::sl_fontChanged() {
     completeRedraw = true; 
     updateScrollBar(); 
     update();
@@ -284,7 +378,7 @@ void MSAEditorNameList::drawContent(QPainter& p) {
 }
 
 void MSAEditorNameList::drawSequenceItem(QPainter& p, int s, bool selected) {
-    QFont f = ui->seqArea->getFont();
+    QFont f = ui->editor->getFont();
     f.setItalic(true);
     QFontMetrics fm(f);
     p.setFont(f);
@@ -297,8 +391,12 @@ void MSAEditorNameList::drawSequenceItem(QPainter& p, int s, bool selected) {
     int textY = yRange.startPos + MARGIN_TEXT_TOP;
     int textH = yRange.len - MARGIN_TEXT_TOP - MARGIN_TEXT_BOTTOM;
 
-    const MAlignment& ma = editor->getMSAObject()->getMAlignment();
-    const MAlignmentItem& mai = ma.alignedSeqs[s];
+    MAlignmentObject* maObj = editor->getMSAObject();
+    if (maObj == NULL)
+        return;
+
+    const MAlignment& ma = maObj->getMAlignment();
+    const MAlignmentRow& row = ma.getRow(s);
     QRect textRect(textX, textY, textW, textH);
     if (nhBar->isEnabled()) {
         int stepSize = fm.width('W');
@@ -311,12 +409,25 @@ void MSAEditorNameList::drawSequenceItem(QPainter& p, int s, bool selected) {
         p.drawRect(itemRect);
     }
     p.setPen(Qt::black);
-    p.drawText(textRect, Qt::AlignVCenter | Qt::AlignLeft, mai.name);
+    p.drawText(textRect, Qt::AlignVCenter | Qt::AlignLeft, row.getName());
 }
 
 void MSAEditorNameList::drawSelection(QPainter& p) {
-    int s = ui->seqArea->getCursorPos().y();
-    drawSequenceItem(p, s, true);
+    MSAEditorSelection sel = ui->seqArea->getSelection();
+    
+    if ((sel.height() == editor->getNumSequences()) || (sel.height() == 0)) {
+        return;
+    }
+
+    int startPos = sel.y();
+    int w = width();
+    
+    LRegion yRange = ui->seqArea->getSequenceYRange(startPos, true);
+    QRect itemsRect(0, yRange.startPos, w - 1, sel.height()*yRange.len -1 );       
+    
+    p.setPen(QPen(Qt::gray, 1, Qt::DashLine));
+    p.drawRect(itemsRect);
+
 }
 
 void MSAEditorNameList::drawFocus(QPainter& p) {
@@ -326,4 +437,42 @@ void MSAEditorNameList::drawFocus(QPainter& p) {
     }
 }
 
+void MSAEditorNameList::sl_onScrollBarActionTriggered( int scrollAction )
+{
+    if (scrollAction ==  QAbstractSlider::SliderSingleStepAdd || scrollAction == QAbstractSlider::SliderSingleStepSub) {
+        if (scribbling) {
+            QPoint coord = mapFromGlobal(QCursor::pos());
+            int seqNum = ui->seqArea->getSequenceNumByY(coord.y());
+            updateSelection(seqNum);
+        }
+    }
+}
+
+void MSAEditorNameList::sl_editSequenceName()
+{
+    const MSAEditorSelection& selection = ui->seqArea->getSelection();
+    if (selection.height() == 0) {
+        return;
+    }
+    MAlignmentObject* maObj = editor->getMSAObject();
+    if (maObj->isStateLocked()) {
+        return;
+    }
+    int seqIdx = selection.y();
+    
+	bool ok = false;
+	const MAlignmentRow& row = maObj->getMAlignment().getRow(curSeq);
+	QString curName = row.getName();
+	QString newName = QInputDialog::getText(this, tr("Rename"),
+			tr("New sequence name:"), QLineEdit::Normal, curName, &ok);
+	if (ok && !newName.isEmpty()) {
+		maObj->renameRow(seqIdx,newName);
+	}
+}
+
+void MSAEditorNameList::mouseDoubleClickEvent( QMouseEvent *e )
+{
+    Q_UNUSED(e);
+    sl_editSequenceName();
+}
 }//namespace
