@@ -24,6 +24,7 @@ class MSAEditorUI;
 class GObjectView;
 class MAlignment;
 class MAlignmentModInfo;
+class MSAEditorSelection;
 
 class MSAEditorNameList: public QWidget {
     Q_OBJECT
@@ -35,21 +36,26 @@ private slots:
     void sl_buildStaticMenu(GObjectView* v, QMenu* m);
     void sl_buildContextMenu(GObjectView* v, QMenu* m);
     void sl_copyCurrentSequence();
+    void sl_editSequenceName();
     void sl_lockedStateChanged();
     void sl_removeCurrentSequence();
     void sl_alignmentChanged(const MAlignment&, const MAlignmentModInfo&);
+    void sl_onScrollBarActionTriggered( int scrollAction );
     
     void sl_startChanged(const QPoint& p, const QPoint& prev);
-    void sl_cursorMoved(const QPoint& p, const QPoint& prev);
+    void sl_selectionChanged(const MSAEditorSelection& current, const MSAEditorSelection& prev);
 
     void sl_nameBarMoved(int n);
-    void sl_scaleChanged();
+    void sl_fontChanged();
 
 protected:
     void resizeEvent(QResizeEvent* e);
     void paintEvent(QPaintEvent* e);
     void keyPressEvent (QKeyEvent *e);
     void mousePressEvent(QMouseEvent *e);
+    void mouseMoveEvent(QMouseEvent* e);
+    void mouseReleaseEvent(QMouseEvent *e);
+    void mouseDoubleClickEvent(QMouseEvent *e);
     void focusOutEvent(QFocusEvent* fe);
     void focusInEvent(QFocusEvent* fe);
     void wheelEvent (QWheelEvent * we);
@@ -59,6 +65,7 @@ private:
     void updateActions();
     void buildMenu(QMenu* m);
     void updateScrollBar();
+    void updateSelection(int newSeqNum);
     
     void drawAll();
     void drawContent(QPainter& p);
@@ -69,7 +76,10 @@ private:
     MSAEditor*          editor;
     MSAEditorUI*        ui;
     QScrollBar*         nhBar;
+    int                 curSeq;
+    bool                scribbling;
 
+    QAction*            editSequenceNameAction;
     QAction*            copyCurrentSequenceAction;
     QAction*            removeCurrentSequenceAction;
     QPixmap*            cachedView;
