@@ -11,16 +11,26 @@
 #include "MSAEditorSequenceArea.h"
 #include "MSAEditor.h"
 #include "MSAColorScheme.h"
+#include "CreateSubalignimentDialogController.h"
+#include "CreateSubalignimentTask.h"
+#include "AddSequencesToAlignmentTask.h"
 
 #include <core_api/Log.h>
 #include <core_api/DNAAlphabet.h>
 #include <core_api/AppContext.h>
 #include <core_api/Settings.h>
+#include <core_api/Task.h>
+#include <core_api/DocumentModel.h>
+#include <util_tasks/LoadDocumentTask.h>
 #include <datatype/MAlignment.h>
 #include <gobjects/MAlignmentObject.h>
+#include <gobjects/DNASequenceObject.h>
 #include <util_gui/GUIUtils.h>
 #include <util_gui/PositionSelector.h>
+#include <util_gui/ProjectTreeController.h>
+#include <util_gui/ProjectTreeItemSelectorDialog.h>
 #include <util_text/TextUtils.h>
+#include <util_gui/DialogUtils.h>
 
 
 #include <QtGui/QPainter>
@@ -28,7 +38,10 @@
 #include <QtGui/QClipboard>
 #include <QtGui/QApplication>
 #include <QtGui/QDialog>
-#include <QtGui/QFontDialog>
+#include <QtGui/QFileDialog>
+#include <QtGui/QMessageBox>
+
+#include <memory>
 
 namespace GB2 {
 
@@ -36,22 +49,11 @@ namespace GB2 {
 
 static LogCategory log(ULOG_CAT_MSA);
 
-#define MIN_FONT_SIZE 6
-#define MAX_FONT_SIZE 24
-
 #define SETTINGS_ROOT QString("msaeditor/")
-
-#define SETTINGS_FONT_FAMILY    "font_family"
-#define SETTINGS_FONT_SIZE      "font_size"
-#define SETTINGS_FONT_ITALIC    "font_italic"
-#define SETTINGS_FONT_BOLD      "font_bold"
 #define SETTINGS_COLOR_NUCL     "color_nucl"
 #define SETTINGS_COLOR_AMINO    "color_amino"
 
-#define DEFAULT_FONT_FAMILY "Verdana" 
-#define DEFAULT_FONT_SIZE 10
-
-MSAEditorSequenceArea::MSAEditorSequenceArea(MSAEditorUI* _ui, QScrollBar* hb, QScrollBar* vb) 
+MSAEditorSequenceArea::MSAEditorSequenceArea(MSAEditorUI* _ui, GScrollBar* hb, GScrollBar* vb) 
 : editor(_ui->editor), ui(_ui), shBar(hb), svBar(vb) 
 {
     setFocusPolicy(Qt::WheelFocus);
@@ -64,20 +66,20 @@ MSAEditorSequenceArea::MSAEditorSequenceArea(MSAEditorUI* _ui, QScrollBar* hb, Q
     startPos = 0;
     startSeq = 0;
     highlightSelection = false;
+    scribbling = false;
+   
+    delSelectionAction = new QAction(tr("Delete selection"), this);
+    delSelectionAction->setShortcut(QKeySequence(Qt::Key_Delete));
+    delSelectionAction->setShortcutContext(Qt::WidgetShortcut);
+    connect(delSelectionAction, SIGNAL(triggered()), SLOT(sl_delCurrentSelection()));
 
-    Settings* s = AppContext::getSettings();
-    seqFont.setFamily(s->getValue(SETTINGS_ROOT + SETTINGS_FONT_FAMILY, DEFAULT_FONT_FAMILY).toString());
-    seqFont.setPointSize(s->getValue(SETTINGS_ROOT + SETTINGS_FONT_SIZE, DEFAULT_FONT_SIZE).toInt());
-    seqFont.setItalic(s->getValue(SETTINGS_ROOT + SETTINGS_FONT_ITALIC, false).toBool());
-    seqFont.setBold(s->getValue(SETTINGS_ROOT + SETTINGS_FONT_BOLD, false).toBool());
-    updateSeqFontMetrics();
-    
-    delSymAction = new QAction(tr("del_sym"), this);
-    delSymAction->setShortcut(QKeySequence(Qt::Key_Delete));
-    delSymAction->setShortcutContext(Qt::WidgetShortcut);
-    connect(delSymAction, SIGNAL(triggered()), SLOT(sl_delSym()));
-    
-    delColAction = new QAction(tr("del_col"), this);
+    copySelectionAction = new QAction(tr("Copy selection"), this);
+    copySelectionAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_C));
+    copySelectionAction->setShortcutContext(Qt::WidgetShortcut);
+    connect(copySelectionAction, SIGNAL(triggered()), SLOT(sl_copyCurrentSelection()));
+    addAction(copySelectionAction);
+
+    delColAction = new QAction(QIcon(":core/images/msaed_remove_columns_with_gaps.png"), tr("del_col"), this);
     delColAction->setShortcut(QKeySequence(Qt::SHIFT| Qt::Key_Delete));
     delColAction->setShortcutContext(Qt::WidgetShortcut);
     connect(delColAction, SIGNAL(triggered()), SLOT(sl_delCol()));
@@ -86,8 +88,12 @@ MSAEditorSequenceArea::MSAEditorSequenceArea(MSAEditorUI* _ui, QScrollBar* hb, Q
     insSymAction->setShortcut(QKeySequence(Qt::Key_Space));
     insSymAction->setShortcutContext(Qt::WidgetShortcut);
     connect(insSymAction, SIGNAL(triggered()), SLOT(sl_insSym()));
-    
-    insColAction = new QAction(tr("ins_col"), this);
+
+	createSubaligniment = new QAction(tr("Create subaligniment"), this);
+	createSubaligniment->setShortcutContext(Qt::WidgetShortcut);
+	connect(createSubaligniment, SIGNAL(triggered()), SLOT(sl_createSubaligniment()));
+
+	insColAction = new QAction(tr("ins_col"), this);
     insColAction->setShortcut(QKeySequence(Qt::SHIFT| Qt::Key_Space));
     insColAction->setShortcutContext(Qt::WidgetShortcut);
     connect(insColAction, SIGNAL(triggered()), SLOT(sl_insCol()));
@@ -97,34 +103,30 @@ MSAEditorSequenceArea::MSAEditorSequenceArea(MSAEditorUI* _ui, QScrollBar* hb, Q
     insColAction->setShortcutContext(Qt::WindowShortcut);
     connect(gotoAction, SIGNAL(triggered()), SLOT(sl_goto()));
 
-    takeScreenshotAction = new QAction(QIcon(":core/images/cam2.png"), tr("Capture scren"), this);
-    connect(takeScreenshotAction, SIGNAL(triggered()), ui, SLOT(sl_saveScreenshot()));
-
-    increaseFontAction = new QAction(QIcon(":core/images/zoom_in.png"), tr("Increase Font"), this);
-    connect(increaseFontAction, SIGNAL(triggered()), SLOT(sl_zoomIn()));
-    
-    decreseFontAction = new QAction(QIcon(":core/images/zoom_out.png"), tr("Decrease Font"), this);
-    connect(decreseFontAction, SIGNAL(triggered()), SLOT(sl_zoomOut()));
-    
-    changeFontAction = new QAction(QIcon(":core/images/font.png"), tr("Change Font"), this);
-    connect(changeFontAction, SIGNAL(triggered()), SLOT(sl_changeFont()));
-
-    resetFontAction = new QAction(QIcon(":core/images/font_default.png"), tr("Reset Font"), this);
-    connect(resetFontAction, SIGNAL(triggered()), SLOT(sl_resetFont()));
-
-    removeGapColumnsAction = new QAction(QIcon(":core/images/msaed_remove_columns_with_gaps.png"), tr("Remove columns with gaps"), this);
-    connect(removeGapColumnsAction, SIGNAL(triggered()), SLOT(sl_removeColumnsWithGaps()));
+    //removeGapColumnsAction = new QAction(QIcon(":core/images/msaed_remove_columns_with_gaps.png"), tr("Remove columns with gaps"), this);
+    //connect(removeGapColumnsAction, SIGNAL(triggered()), SLOT(sl_removeColumnsWithGaps()));
     
     removeAllGapsAction = new QAction(QIcon(":core/images/msaed_remove_all_gaps.png"), tr("Remove all gaps"), this);
     connect(removeAllGapsAction, SIGNAL(triggered()), SLOT(sl_removeAllGaps()));
+
+    addSeqFromFileAction = new QAction(tr("Sequence from file..."), this);
+    connect(addSeqFromFileAction, SIGNAL(triggered()), SLOT(sl_addSeqFromFile()));
+
+    addSeqFromProjectAction = new QAction(tr("Sequence from current project..."), this);
+    connect(addSeqFromProjectAction, SIGNAL(triggered()), SLOT(sl_addSeqFromProject()));
+
+    sortByNameAction = new QAction(tr("Sort sequences by name"), this);
+    connect(sortByNameAction, SIGNAL(triggered()), SLOT(sl_sortByName()));
+
     
     connect(editor->getMSAObject(), SIGNAL(si_alignmentChanged(const MAlignment&, const MAlignmentModInfo&)), 
         SLOT(sl_alignmentChanged(const MAlignment&, const MAlignmentModInfo&)));
+    connect(editor->getMSAObject(), SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
 
     connect(editor, SIGNAL(si_buildStaticMenu(GObjectView*, QMenu*)), SLOT(sl_buildStaticMenu(GObjectView*, QMenu*)));
     connect(editor, SIGNAL(si_buildStaticToolbar(GObjectView*, QToolBar*)), SLOT(sl_buildStaticToolbar(GObjectView*, QToolBar*)));
     connect(editor, SIGNAL(si_buildPopupMenu(GObjectView* , QMenu*)), SLOT(sl_buildContextMenu(GObjectView*, QMenu*)));
-    connect(editor->getMSAObject(), SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
+    connect(editor, SIGNAL(si_zoomOperationPerformed(bool)), SLOT(sl_zoomOperationPerformed(bool)));
 
     prepareColorSchemeMenuActions();
     updateActions();
@@ -137,7 +139,10 @@ MSAEditorSequenceArea::~MSAEditorSequenceArea() {
 void MSAEditorSequenceArea::prepareColorSchemeMenuActions() {
     Settings* s = AppContext::getSettings();
     MAlignmentObject* maObj = editor->getMSAObject();
-    DNAAlphabetType atype = maObj->getMAlignment().alphabet->getType();
+    if (maObj == NULL)
+        return;
+
+    DNAAlphabetType atype = maObj->getMAlignment().getAlphabet()->getType();
     MSAColorSchemeRegistry* csr = AppContext::getMSAColorSchemeRegistry();
     QString csid = atype == DNAAlphabet_AMINO ? 
             s->getValue(SETTINGS_ROOT + SETTINGS_COLOR_AMINO, MSAColorScheme::UGENE_AMINO).toString()
@@ -166,6 +171,9 @@ void MSAEditorSequenceArea::sl_changeColorScheme() {
     QString id = a->data().toString();
     MSAColorSchemeFactory* f = AppContext::getMSAColorSchemeRegistry()->getMSAColorSchemeFactoryById(id);
     delete colorScheme;
+    if (ui->editor->getMSAObject() == NULL)
+        return;
+
     colorScheme = f->create(this, ui->editor->getMSAObject());
     foreach(QAction* action, colorSchemeMenuActions) {
         action->setChecked(action == a);
@@ -180,30 +188,29 @@ void MSAEditorSequenceArea::sl_changeColorScheme() {
     update();
 }
 
-void MSAEditorSequenceArea::updateSeqFontMetrics() {
-    QFontMetrics seqFM(seqFont);
-    seqCharWidth = seqFM.width('W') * 5 / 4;
-    seqCharHeight = seqFM.height() * 5 / 4;
-}
-
 void MSAEditorSequenceArea::updateActions() {
-    bool readOnly = editor->getMSAObject()->isStateLocked();
+    MAlignmentObject* maObj = editor->getMSAObject();
+    if (maObj == NULL)
+        return;
+    bool readOnly = maObj->isStateLocked();
     
+    delSelectionAction->setEnabled(!readOnly);
     delColAction->setEnabled(!readOnly);
-    delSymAction->setEnabled(!readOnly);
     insColAction->setEnabled(!readOnly);
     insSymAction->setEnabled(!readOnly);
-    removeGapColumnsAction->setEnabled(!readOnly);
+	createSubaligniment->setEnabled(!readOnly);
     removeAllGapsAction->setEnabled(!readOnly);
+    addSeqFromProjectAction->setEnabled(!readOnly);
+    addSeqFromFileAction->setEnabled(!readOnly);
+    sortByNameAction->setEnabled(!readOnly);
 
-    increaseFontAction->setEnabled(seqFont.pointSize() < MAX_FONT_SIZE);
-    decreseFontAction->setEnabled(seqFont.pointSize() > MIN_FONT_SIZE);
     assert(checkState());
 }
 
 
 
 void MSAEditorSequenceArea::paintEvent(QPaintEvent *e) {
+
     drawAll();
     QWidget::paintEvent(e);
 }
@@ -222,13 +229,17 @@ void MSAEditorSequenceArea::drawAll() {
     }
     QPainter p(this);
     p.drawPixmap(0, 0, *cachedView);
-    drawCursor(p);
+    //drawCursor(p);
+    drawSelection(p);
     drawFocus(p);
 }
 
 void MSAEditorSequenceArea::drawContent(QPainter& p) {
+    MAlignmentObject* maObj = editor->getMSAObject();
+    if (maObj == NULL)
+        return;
     p.fillRect(cachedView->rect(), Qt::white);
-    p.setFont(seqFont);
+    p.setFont(editor->getFont());
     
     //for every sequence in msa starting from first visible
     //draw it starting from startPos
@@ -237,9 +248,8 @@ void MSAEditorSequenceArea::drawContent(QPainter& p) {
     int lastPos = getLastVisibleBase(true);
     int w = width();
     int h = height();
-    const MAlignment& msa = editor->getMSAObject()->getMAlignment();
+    const MAlignment& msa = maObj->getMAlignment();
     for (int seq = firstVisibleSeq; seq <= lastVisibleSeq; seq++) {
-        const MAlignmentItem& item = msa.alignedSeqs[seq];
         LRegion baseYRange = getSequenceYRange(seq, true);
 
         //draw horizontal grid
@@ -251,14 +261,35 @@ void MSAEditorSequenceArea::drawContent(QPainter& p) {
             assert(cr.left() < w && cr.top() < h); Q_UNUSED(w); Q_UNUSED(h);
             char c = msa.charAt(seq, pos);
             QColor color = colorScheme->getColor(seq, pos);
+            
             if (color.isValid()) {
                 p.fillRect(cr, color);
             }
-            p.drawText(cr, Qt::AlignCenter, QString(c));
+            
+            if (editor->getResizeMode() == MSAEditor::ResizeMode_FontAndContent) {
+                p.drawText(cr, Qt::AlignCenter, QString(c));
+            }
         }
     }
 }
 
+void MSAEditorSequenceArea::drawSelection( QPainter &p )
+{
+
+    int x = selection.x();
+    int y = selection.y();
+    
+    LRegion xRange = getBaseXRange(x, true);
+    LRegion yRange = getSequenceYRange(y, true);
+ 
+    QPen pen(highlightSelection || hasFocus()? Qt::black : Qt::gray);
+    pen.setStyle(Qt::DashLine);
+    pen.setWidth(highlightSelection ? 2 : 1);
+    p.setPen(pen);
+    p.drawRect(xRange.startPos, yRange.startPos, xRange.len*selection.width(), yRange.len*selection.height());
+
+}
+
 void MSAEditorSequenceArea::drawCursor(QPainter& p) {
     if (!isVisible(cursorPos, true)) {
         return;
@@ -405,6 +436,7 @@ void MSAEditorSequenceArea::updateHScrollBar() {
     shBar->setDisabled(numVisibleBases == alignmentLen);
 
     connect(shBar, SIGNAL(valueChanged(int)), SLOT(sl_onHScrollMoved(int)));
+    connect(shBar, SIGNAL(actionTriggered(int)), SLOT(sl_onScrollBarActionTriggered(int)));
 }
 
 void MSAEditorSequenceArea::updateVScrollBar() {
@@ -424,18 +456,19 @@ void MSAEditorSequenceArea::updateVScrollBar() {
     svBar->setDisabled(numVisibleSequences == nSeqs);
 
     connect(svBar, SIGNAL(valueChanged(int)), SLOT(sl_onVScrollMoved(int)));
+    connect(svBar, SIGNAL(actionTriggered(int)), SLOT(sl_onScrollBarActionTriggered(int)));
 }
 
 
 int MSAEditorSequenceArea::countWidthForBases(bool countClipped) const {
     int seqAreaWidth = width();
-    int nVisible = seqAreaWidth / seqCharWidth + (countClipped && (seqAreaWidth % seqCharWidth != 0) ? 1 : 0);
+    int nVisible = seqAreaWidth / editor->getColumnWidth() + (countClipped && (seqAreaWidth % editor->getColumnWidth() != 0) ? 1 : 0);
     return nVisible;
 }
 
 int MSAEditorSequenceArea::countHeightForSequences(bool countClipped) const {
     int seqAreaHeight = height();
-    int nVisible = seqAreaHeight / seqCharHeight + (countClipped && (seqAreaHeight % seqCharHeight != 0) ? 1 : 0);
+    int nVisible = seqAreaHeight / editor->getRowHeight() + (countClipped && (seqAreaHeight % editor->getRowHeight() != 0) ? 1 : 0);
     return nVisible;
 }
 
@@ -469,17 +502,27 @@ int MSAEditorSequenceArea::getNumVisibleSequences(bool countClipped) const {
     return res;
 }
 
-int MSAEditorSequenceArea::getSequenceNumByY(int y) {
-    int seqOffs = y / seqCharHeight;
+int MSAEditorSequenceArea::getColumnNumByX(int x) const {
+    int colOffs = x / editor->getColumnWidth();
+    int pos = startPos + colOffs;
+    if ((pos >= editor->getAlignmentLen()) || (pos < 0)) {
+        return -1; 
+    }
+    return pos;
+
+}
+
+int MSAEditorSequenceArea::getSequenceNumByY(int y) const {
+    int seqOffs = y / editor->getRowHeight();
     int seq = startSeq + seqOffs;
-    if (seq >= editor->getNumSequences()) {
+    if ((seq >= editor->getNumSequences()) || (seq < 0)) {
         return -1; 
     }
     return seq;
 }
 
 LRegion MSAEditorSequenceArea::getBaseXRange(int pos, bool useVirtualCoords) const {
-    LRegion res(seqCharWidth * (pos - startPos), seqCharWidth);
+    LRegion res(editor->getColumnWidth() * (pos - startPos), editor->getColumnWidth());
     if (!useVirtualCoords) {
         int w = width();
         res = res.intersect(LRegion(0, w));
@@ -488,7 +531,7 @@ LRegion MSAEditorSequenceArea::getBaseXRange(int pos, bool useVirtualCoords) con
 }
 
 LRegion MSAEditorSequenceArea::getSequenceYRange(int seq, bool useVirtualCoords) const {
-    LRegion res(seqCharHeight* (seq - startSeq), seqCharHeight);
+    LRegion res(editor->getRowHeight()* (seq - startSeq), editor->getRowHeight());
     if (!useVirtualCoords) {
         int h = height();
         res = res.intersect(LRegion(0, h));
@@ -496,6 +539,58 @@ LRegion MSAEditorSequenceArea::getSequenceYRange(int seq, bool useVirtualCoords)
     return res;
 }
 
+#define SCROLL_STEP 1
+
+void MSAEditorSequenceArea::updateSelection( const QPoint& newPos)
+{
+    if (!isInRange(newPos)) {
+        return;
+    }
+    
+    int width = qAbs(newPos.x() - cursorPos.x()) + 1;
+    int height = qAbs(newPos.y() - cursorPos.y()) + 1;
+    // find top left 
+    int left = qMin(newPos.x(), cursorPos.x());
+    int top = qMin(newPos.y(), cursorPos.y());
+    
+    MSAEditorSelection s(left, top, width, height);
+    if (newPos.x()!=-1 && newPos.y()!=-1) {
+        setSelection(s);
+    }
+
+}
+
+
+void MSAEditorSequenceArea::mouseMoveEvent( QMouseEvent* e )
+{
+    if ((e->buttons() & Qt::LeftButton) && scribbling) {
+        QPoint absPos = coordToAbsolutePos(e->pos());
+        if ( isInRange(absPos) ) {
+            updateHBarPosition(absPos.x());
+            updateVBarPosition(absPos.y());
+        }
+        updateSelection(absPos);
+    }
+    
+    QWidget::mouseMoveEvent(e);
+
+}
+
+
+
+void MSAEditorSequenceArea::mouseReleaseEvent(QMouseEvent *e)
+{
+    
+    if (e->button() == Qt::LeftButton) {
+        QPoint pos = coordToAbsolutePos(e->pos());
+        updateSelection(pos);
+        scribbling = false;
+    }
+    shBar->setupRepeatAction(QAbstractSlider::SliderNoAction);
+    svBar->setupRepeatAction(QAbstractSlider::SliderNoAction);
+
+    QWidget::mouseReleaseEvent(e);
+}
 
 
 void MSAEditorSequenceArea::mousePressEvent(QMouseEvent *e) {
@@ -503,14 +598,16 @@ void MSAEditorSequenceArea::mousePressEvent(QMouseEvent *e) {
         setFocus();
     }
 
-    if (e->button() != Qt::LeftButton) {
-        QWidget::mousePressEvent(e);
-        return;
-    }
-    QPoint p = coordToPos(e->pos());
-    if (p.x()!=-1 && p.y()!=-1) {
-        setCursorPos(p);
+    if (e->button() == Qt::LeftButton) {
+        QPoint p = coordToPos(e->pos());
+        if (p.x()!=-1 && p.y()!=-1) {
+            setCursorPos(p);
+            setSelection(MSAEditorSelection(p,1,1));
+        }
+        scribbling = true;
     }
+    mousePos = e->pos();
+
     QWidget::mousePressEvent(e);
 }
 
@@ -528,28 +625,38 @@ void MSAEditorSequenceArea::keyPressEvent(QKeyEvent *e) {
     }
     //part of these keys are assigned to actions -> so them never passed to keyPressEvent (action handling has higher priority)
     switch(key) {
+        case Qt::Key_Escape:
+             cancelSelection();
+             break;
         case Qt::Key_Left:
-            moveCursor(-1, 0);    
+            //moveCursor(-1, 0);    
+            moveSelection(-1,0);
             break;
         case Qt::Key_Right:
-            moveCursor(1, 0);    
+            //moveCursor(1, 0);    
+            moveSelection(1,0);
             break;
         case Qt::Key_Up:
-            moveCursor(0, -1);    
+            //moveCursor(0, -1);    
+            moveSelection(0,-1);
             break;
         case Qt::Key_Down:
-            moveCursor(0, 1);    
+            //moveCursor(0, 1);    
+            moveSelection(0,1);
             break;
         case Qt::Key_Home:
+            cancelSelection();
             if (shift) { //scroll namelist
                 setFirstVisibleSequence(0);
                 setCursorPos(QPoint(cursorPos.x(), 0));
             } else { //scroll sequence
+                cancelSelection();
                 setFirstVisibleBase(0);
                 setCursorPos(QPoint(0, cursorPos.y()));
             }
             break;
         case Qt::Key_End:
+            cancelSelection();
             if (shift) { //scroll namelist
                 int n = editor->getNumSequences() - 1;
                 setFirstVisibleSequence(n);
@@ -561,6 +668,7 @@ void MSAEditorSequenceArea::keyPressEvent(QKeyEvent *e) {
             }
             break;
         case Qt::Key_PageUp:
+            cancelSelection();
             if (shift) { //scroll namelist
                 int nVis = getNumVisibleSequences(false);
                 int fp = qMax(0, getFirstVisibleSequence() - nVis);
@@ -576,6 +684,7 @@ void MSAEditorSequenceArea::keyPressEvent(QKeyEvent *e) {
             }
             break;
         case Qt::Key_PageDown:
+            cancelSelection();
             if (shift) { //scroll namelist
                 int nVis = getNumVisibleSequences(false);
                 int nSeq = editor->getNumSequences();
@@ -593,17 +702,23 @@ void MSAEditorSequenceArea::keyPressEvent(QKeyEvent *e) {
             }
             break;
         case Qt::Key_Delete:
-            del(cursorPos, shift);
+            deleteCurrentSelection();
             break;
         case Qt::Key_Backspace:
-            if (cursorPos.x() > 0) {
-                del(QPoint(cursorPos.x()-1, cursorPos.y()), shift);
+            // Cursor mode emulation: selection is of size one
+            if ( (selection.width() == 1) && (selection.height() == 1) ) {
+                QPoint pos = selection.topLeft();
+                if (pos.x() > 0) {
+                    del(QPoint(pos.x()-1, pos.y()), shift);
+                }
             }
             break;
         case Qt::Key_Insert:
         case Qt::Key_Space:
-            //printf("key!\n");
-            ins(cursorPos, shift);
+            // Cursor mode emulation: selection is of size one
+            if ( (selection.width() == 1) && (selection.height() == 1) ) {
+                ins(selection.topLeft(), shift);
+            }
             break;
     }
     QWidget::keyPressEvent(e);
@@ -620,11 +735,60 @@ void MSAEditorSequenceArea::focusOutEvent(QFocusEvent* fe) {
 }
 
 
+void MSAEditorSequenceArea::moveSelection( int dx, int dy )
+{   
+    int leftX = selection.x();
+    int topY = selection.y();
+    int bottomY = selection.y() + selection.height() - 1;
+    int rightX = selection.x() + selection.width() - 1;
+    QPoint baseTopLeft(leftX, topY);
+    QPoint baseBottomRight(rightX,bottomY);
+
+    QPoint newTopLeft = baseTopLeft  + QPoint(dx,dy);
+    QPoint newBottomRight = baseBottomRight + QPoint(dx,dy);
+
+    if ((!isInRange(newTopLeft)) || (!isInRange(newBottomRight)) ) {
+        return;
+    }
+
+     if (!isVisible(newTopLeft, false)) {
+         if (isVisible(newTopLeft, true)) {
+             if (dx != 0) { 
+                 setFirstVisibleBase(startPos + dx);
+             } 
+             if (dy!=0) {
+                 setFirstVisibleSequence(getFirstVisibleSequence()+dy);
+             }
+         } else {
+             if (dx != 0) {
+                setFirstVisibleBase(newTopLeft.x());
+             }
+             if (dy !=0 ) {
+                setFirstVisibleSequence(newTopLeft.y());
+             }
+         }
+     }
+
+   MSAEditorSelection newSelection(newTopLeft, selection.width(), selection.height());
+   setSelection(newSelection);
+
+}
+
+
+
 void MSAEditorSequenceArea::moveCursor(int dx, int dy) {
     QPoint p = cursorPos + QPoint(dx, dy);
     if (!isInRange(p)) {
         return;
     }   
+    
+    // Move only one cell selection?
+    // TODO: consider selection movement
+    int sz = selection.width()*selection.height();
+    if (sz != 1) {
+        return;
+    }
+    
     if (!isVisible(p, false)) {
         if (isVisible(cursorPos, true)) {
             if (dx != 0) { 
@@ -639,6 +803,7 @@ void MSAEditorSequenceArea::moveCursor(int dx, int dy) {
         }
     }
     setCursorPos(p);
+    //setSelection(MSAEditorSelection(p, 1,1));
 }
 
 
@@ -647,6 +812,15 @@ int MSAEditorSequenceArea::coordToPos(int x) const {
     return coordToPos(QPoint(x, y)).x();
 }
 
+
+QPoint MSAEditorSequenceArea::coordToAbsolutePos(const QPoint& coord) const {
+    int column = getColumnNumByX(coord.x());
+    int row = getSequenceNumByY(coord.y());
+
+    return QPoint(column, row);
+}
+
+
 QPoint MSAEditorSequenceArea::coordToPos(const QPoint& coord) const {
     QPoint res(-1, -1);
     //Y: row
@@ -669,21 +843,38 @@ QPoint MSAEditorSequenceArea::coordToPos(const QPoint& coord) const {
     return res;
 }
 
+
+void MSAEditorSequenceArea::setSelection(const MSAEditorSelection& s) {
+    
+    // TODO: assert(isInRange(s));
+    if (s == selection) {
+        return;
+    }
+
+    MSAEditorSelection prevSelection = selection;
+    selection = s;
+    
+    emit si_selectionChanged(selection, prevSelection);
+    QPoint current = prevSelection.topLeft(), prev = prevSelection.topLeft();
+    emit si_cursorMoved(current, prev);
+    update();
+
+}
+
 void MSAEditorSequenceArea::setCursorPos(const QPoint& p) {
     assert(isInRange(p));
     if (p == cursorPos) {
         return;
     }
     
-    bool up = isVisible(cursorPos, true) || isVisible(p, true);
     QPoint prev = cursorPos;
     cursorPos = p;
     
     emit si_cursorMoved(cursorPos, prev);
     
-    if (up) {
-        update();
-    }
+    //if (up) {
+    //    update();
+    //}
     highlightSelection = false;
     updateActions();
 }
@@ -691,7 +882,7 @@ void MSAEditorSequenceArea::setCursorPos(const QPoint& p) {
 void MSAEditorSequenceArea::ins(const QPoint& p, bool columnMode) {
     assert(isInRange(p));
     MAlignmentObject* maObj = editor->getMSAObject();
-    if (maObj->isStateLocked()) {
+    if (maObj == NULL || maObj->isStateLocked()) {
         return;
     }
     if (columnMode) {
@@ -704,7 +895,7 @@ void MSAEditorSequenceArea::ins(const QPoint& p, bool columnMode) {
 void MSAEditorSequenceArea::del(const QPoint& p, bool columnMode) {
     assert(isInRange(p));
     MAlignmentObject* maObj = editor->getMSAObject();
-    if (maObj->isStateLocked()) {
+    if (maObj == NULL || maObj->isStateLocked()) {
         return;
     }
     if (columnMode) {
@@ -723,6 +914,14 @@ void MSAEditorSequenceArea::sl_alignmentChanged(const MAlignment&, const MAlignm
     setFirstVisibleSequence(qBound(0, startSeq, nSeq - countHeightForSequences(false)));
 
     setCursorPos(qMin(cursorPos.x(), aliLen-1), qMin(cursorPos.y(), nSeq-1));
+    
+    QPoint selTopLeft( qMin(selection.x(), aliLen - 1),  qMin(selection.y(), nSeq - 1) );
+    QPoint selBottomRight( qMin(selection.x() + selection.width() - 1, aliLen - 1), qMin(selection.y() + selection.height() - 1, nSeq -1 ) );
+
+    MSAEditorSelection newSelection(selTopLeft, selBottomRight);
+    
+    // we don't emit "selection changed" signal to avoid redrawing
+    selection = newSelection;  
 
     updateHScrollBar();
     updateVScrollBar();
@@ -733,13 +932,7 @@ void MSAEditorSequenceArea::sl_alignmentChanged(const MAlignment&, const MAlignm
 
 void MSAEditorSequenceArea::sl_buildStaticToolbar(GObjectView*, QToolBar* t) {
     t->addAction(gotoAction);
-    t->addAction(removeGapColumnsAction);
     t->addAction(removeAllGapsAction);
-    t->addAction(takeScreenshotAction);
-    t->addAction(increaseFontAction);
-    t->addAction(decreseFontAction);
-    t->addAction(changeFontAction);
-    t->addAction(resetFontAction);
     t->addAction(ui->getUndoAction());
     t->addAction(ui->getRedoAction());
 }
@@ -752,21 +945,46 @@ void MSAEditorSequenceArea::sl_buildStaticMenu(GObjectView* v, QMenu* m) {
 void MSAEditorSequenceArea::sl_buildContextMenu(GObjectView* v, QMenu* m) {
     Q_UNUSED(v);
     buildMenu(m);
+    
+    QMenu* editMenu = GUIUtils::findSubMenu(m, MSAE_MENU_EDIT);
+    assert(editMenu!=NULL);
+
+    QList<QAction*> actions; actions << delSelectionAction << 
+        delColAction << insSymAction;
+    
+    QMenu* copyMenu = GUIUtils::findSubMenu(m, MSAE_MENU_COPY);
+    assert(copyMenu != NULL);
+    
+
+    if (rect().contains( mapFromGlobal(QCursor::pos()) ) ) {
+        editMenu->addActions(actions);
+        copyMenu->addAction(copySelectionAction);
+    }
+
 }
 
 void MSAEditorSequenceArea::buildMenu(QMenu* m) {
-    QAction* copyMenuAction = GUIUtils::findAction(m->actions(), MSAE_MENU_COPY);
+    QAction* copyMenuAction = GUIUtils::findAction(m->actions(), MSAE_MENU_LOAD);
     m->insertAction(copyMenuAction, gotoAction);
+    
+    QMenu* loadSeqMenu = GUIUtils::findSubMenu(m, MSAE_MENU_LOAD);
+    assert(loadSeqMenu!=NULL);
+    loadSeqMenu->addAction(addSeqFromProjectAction);
+    loadSeqMenu->addAction(addSeqFromFileAction);
 
     QMenu* editMenu = GUIUtils::findSubMenu(m, MSAE_MENU_EDIT);
     assert(editMenu!=NULL);
-    
-    QList<QAction*> actions; actions << insSymAction << insColAction 
-        << delSymAction << delColAction 
-        << removeGapColumnsAction << removeAllGapsAction;
-
+    QList<QAction*> actions; 
+    actions << createSubaligniment << removeAllGapsAction;
     editMenu->insertActions(editMenu->isEmpty() ? NULL : editMenu->actions().first(), actions);
 
+    QMenu* copyMenu = GUIUtils::findSubMenu(m, MSAE_MENU_COPY);
+    copyMenu->addAction(copySelectionAction);
+
+    QMenu* viewMenu = GUIUtils::findSubMenu(m, MSAE_MENU_VIEW);
+    assert(viewMenu!=NULL);
+    viewMenu->addAction(sortByNameAction);
+
     QMenu* colorsSchemeMenu = new QMenu(tr("Colors"), m);
     colorsSchemeMenu->setIcon(QIcon(":core/images/color_wheel.png"));
     foreach(QAction* a, colorSchemeMenuActions) {
@@ -805,7 +1023,7 @@ void MSAEditorSequenceArea::sl_goto() {
 
 void MSAEditorSequenceArea::sl_onPosChangeRequest(int pos) {
     centerPos(pos-1);
-    setCursorPos(pos-1);
+    setSelection(MSAEditorSelection(pos-1,selection.y(),1,1));
 }
 
 void MSAEditorSequenceArea::sl_lockedStateChanged() {
@@ -837,62 +1055,14 @@ void MSAEditorSequenceArea::wheelEvent (QWheelEvent * we) {
     QWidget::wheelEvent(we);
 }
 
-void MSAEditorSequenceArea::sl_removeColumnsWithGaps() {
-    MAlignmentObject* msa = editor->getMSAObject();
-    assert(!msa->isStateLocked());
-    MAlignment ma = msa->getMAlignment();
-    QList<int> columnsWithGaps;
-    for (int c = 0, nc = ma.getLength(); c < nc; c++) {
-        bool onlyGaps = true;
-        foreach(const MAlignmentItem& item, ma.alignedSeqs) {
-            if (item.sequence[c] != MAlignment_GapChar) {
-                onlyGaps = false;
-                break;
-            }
-        }
-        if (onlyGaps) {
-            columnsWithGaps.append(c);
-        }
-    }
-    if (columnsWithGaps.isEmpty()) {
-        return;
-    }
-    foreach(int c, columnsWithGaps) {
-        for (int i = 0, n = ma.getNumSequences(); i < n; i++) {
-            MAlignmentItem& item = ma.alignedSeqs[i];
-            item.sequence[c] = 0;
-        }
-    }
-
-    QBitArray gapMap(256);
-    gapMap[0] = true;
-    for (int i = 0, n = ma.getNumSequences(); i < n; i++) {
-        MAlignmentItem& item = ma.alignedSeqs[i];
-        int newLen = TextUtils::remove(item.sequence.data(), item.sequence.length(), gapMap);
-        assert(newLen == item.sequence.length() - columnsWithGaps.size());
-        item.sequence.resize(newLen);
-    }
-
-    ma.normalizeModel();
-    msa->setMAlignment(ma);
-}
-
 void MSAEditorSequenceArea::sl_removeAllGaps() {
     QBitArray gapMap(256);
     gapMap[MAlignment_GapChar] = true;
-    
     MAlignmentObject* msa = editor->getMSAObject();
     assert(!msa->isStateLocked());
     MAlignment ma = msa->getMAlignment();
-    bool changed = false;
-    for (int i = 0, n = ma.getNumSequences(); i < n; i++) {
-        MAlignmentItem& item = ma.alignedSeqs[i];
-        int newLen = TextUtils::remove(item.sequence.data(), item.sequence.length(), gapMap);
-        changed = changed || newLen != item.sequence.length();
-        item.sequence.resize(newLen);
-    }
+	bool changed = ma.simplify();
     if (changed) {
-        ma.normalizeModel();
         msa->setMAlignment(ma);
         setFirstVisibleBase(0);
         setFirstVisibleSequence(0);
@@ -901,8 +1071,9 @@ void MSAEditorSequenceArea::sl_removeAllGaps() {
 
 bool MSAEditorSequenceArea::checkState() const {
 #ifdef _DEBUG
-    int aliLen = editor->getMSAObject()->getMAlignment().getLength();
-    int nSeqs = editor->getMSAObject()->getMAlignment().getNumSequences();
+    MAlignmentObject* maObj = editor->getMSAObject();
+    int aliLen = maObj->getMAlignment().getLength();
+    int nSeqs = maObj->getMAlignment().getNumRows();
     
     assert(startPos >=0 && startSeq >=0);
     int lastPos = getLastVisibleBase(true);
@@ -917,53 +1088,197 @@ bool MSAEditorSequenceArea::checkState() const {
     return true;
 }
 
-static void saveFont(const QFont& f) {
-    Settings* s = AppContext::getSettings();
-    s->setValue(SETTINGS_ROOT + SETTINGS_FONT_FAMILY, f.family());
-    s->setValue(SETTINGS_ROOT + SETTINGS_FONT_SIZE, f.pointSize());
-    s->setValue(SETTINGS_ROOT + SETTINGS_FONT_ITALIC, f.italic());
-    s->setValue(SETTINGS_ROOT + SETTINGS_FONT_BOLD, f.bold());
-}
-
-void MSAEditorSequenceArea::setFont(const QFont& f) {
-    seqFont = f;
-    seqFont.setPointSize(qBound(MIN_FONT_SIZE, f.pointSize(), MAX_FONT_SIZE));
+void MSAEditorSequenceArea::sl_zoomOperationPerformed( bool resizeModeChanged )
+{
+    Q_UNUSED(resizeModeChanged);
     completeRedraw = true;
-    updateSeqFontMetrics();
     validateRanges();
     updateActions();
-    emit si_scaleChanged();
     update();
-    saveFont(seqFont);
 }
 
-void MSAEditorSequenceArea::sl_changeFont() {
-    bool ok = false;
-    QFont f = QFontDialog::getFont(&ok, seqFont, this, tr("Select font for alignment"));
-    if (!ok) {
+
+void MSAEditorSequenceArea::sl_createSubaligniment(){
+    CreateSubalignimentDialogController dialog(editor->getMSAObject(), selection.getRect(), this);
+	dialog.exec();
+	if(dialog.result() == QDialog::Accepted){
+		LRegion window = dialog.getRegion();
+		bool isAdd = dialog.getAddToProjFlag();
+		QString path = dialog.getSavePath();
+		QStringList seqNames = dialog.getSelectedSeqNames();
+		AppContext::getTaskScheduler()->registerTopLevelTask(new CreateSubalignimentTask(editor->getMSAObject(), window, seqNames, path, isAdd, true));
+	}
+}
+
+void MSAEditorSequenceArea::cancelSelection()
+{
+    MSAEditorSelection emptySelection;
+    setSelection(emptySelection);
+}
+
+void MSAEditorSequenceArea::sl_onScrollBarActionTriggered( int scrollAction )
+{
+    QScrollBar* sbar = qobject_cast<QScrollBar*>( QObject::sender() );
+    if (sbar == NULL) {
         return;
     }
-    setFont(f);
-}
 
-void MSAEditorSequenceArea::sl_zoomIn() {
-    int pSize = seqFont.pointSize();
-    if (pSize < MAX_FONT_SIZE) {
-        seqFont.setPointSize(pSize+1);
-        setFont(seqFont);
+    if (scrollAction ==  QAbstractSlider::SliderSingleStepAdd || scrollAction == QAbstractSlider::SliderSingleStepSub) {
+        if (scribbling) {
+            QPoint coord = mapFromGlobal(QCursor::pos());
+            QPoint pos = coordToAbsolutePos(coord);
+            if ( (scrollAction == QAbstractSlider::SliderSingleStepSub) && (sbar == shBar) ) {
+                pos.setX(pos.x() - 1);
+            } else if ( (scrollAction == QAbstractSlider::SliderSingleStepSub) && (sbar == svBar) )  {
+                pos.setY(pos.y() - 1);
+            }
+            updateSelection(pos);
+        }
     }
 }
 
-void MSAEditorSequenceArea::sl_zoomOut() {
-    int pSize = seqFont.pointSize();
-    if (pSize > MIN_FONT_SIZE) {
-        seqFont.setPointSize(pSize-1);
-        setFont(seqFont);
+void MSAEditorSequenceArea::updateHBarPosition( int base )
+{
+    if (base <= getFirstVisibleBase() ) {
+        shBar->setupRepeatAction(QAbstractSlider::SliderSingleStepSub, 50, 10);
+    } else  if (base >= getLastVisibleBase(true)) {
+        shBar->setupRepeatAction(QAbstractSlider::SliderSingleStepAdd, 50, 10);
+    } else {
+        shBar->setupRepeatAction(QAbstractSlider::SliderNoAction);
     }
 }
 
-void MSAEditorSequenceArea::sl_resetFont() {
-    QFont f(DEFAULT_FONT_FAMILY, DEFAULT_FONT_SIZE);
-    setFont(f);
+
+
+void MSAEditorSequenceArea::updateVBarPosition( int seq )
+{
+    if (seq <= getFirstVisibleSequence()) {
+        svBar->setupRepeatAction(QAbstractSlider::SliderSingleStepSub, 50, 10);
+    } else if (seq >= getLastVisibleSequence(true)) {
+        svBar->setupRepeatAction(QAbstractSlider::SliderSingleStepAdd, 50, 10);
+    } else {
+        svBar->setupRepeatAction(QAbstractSlider::SliderNoAction);
+    }
+
+    
 }
+
+void MSAEditorSequenceArea::sl_delCurrentSelection()
+{
+    deleteCurrentSelection();
+}
+
+void MSAEditorSequenceArea::sl_copyCurrentSelection()
+{
+    // TODO: probably better solution would be to export selection???
+
+    assert(isInRange(selection.topLeft()));
+    assert(isInRange( QPoint(selection.x() + selection.width() - 1, selection.y() + selection.height() - 1) ) );
+    
+    MAlignmentObject* maObj = editor->getMSAObject();
+    if ( selection.isNull() ) {
+        return;
+    }
+    const MAlignment& msa = maObj->getMAlignment(); 
+    int startSeq = selection.y();
+    int endSeq = startSeq + selection.height();
+    QString selText;
+    for (int i = startSeq; i < endSeq; ++i) {
+		const MAlignmentRow& row = msa.getRow(i);
+		int len = selection.width();
+        QByteArray seqPart = row.mid(selection.x(), len).toByteArray(len);
+        selText.append(seqPart);
+        selText.append("\n");
+    }    
+    QApplication::clipboard()->setText(selText);
+        
+    
+}
+
+void MSAEditorSequenceArea::deleteCurrentSelection()
+{
+    if (selection.isNull()) {
+        return;
+    }
+    assert(isInRange(selection.topLeft()));
+    assert(isInRange( QPoint(selection.x() + selection.width() - 1, selection.y() + selection.height() - 1) ) );
+    MAlignmentObject* maObj = editor->getMSAObject();
+    if (maObj == NULL || maObj->isStateLocked()) {
+        return;
+    }
+
+    if ( !selection.isNull() ) {
+        const MAlignment& msa = maObj->getMAlignment();
+        if (selection.width() == msa.getLength() && selection.height() == msa.getNumRows()) {
+            return;
+        }
+
+        maObj->removeRegion(selection.x(), selection.y(), selection.width(), selection.height(), true);
+    }
+    cancelSelection();
+    
+}
+
+void MSAEditorSequenceArea::sl_addSeqFromFile()
+{
+    MAlignmentObject* msaObject = editor->getMSAObject();
+    if (msaObject->isStateLocked()) {
+        return;
+    }
+    
+    QString filter = DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::SEQUENCE, true);
+    
+    LastOpenDirHelper lod;
+    lod.url = QFileDialog::getOpenFileName(this, tr("Open file with sequences"), lod.dir, filter);
+    
+    if (!lod.url.isEmpty()) {
+        cancelSelection();
+        AddSequencesToAlignmentTask * task = new AddSequencesToAlignmentTask(msaObject, lod.url);    
+        AppContext::getTaskScheduler()->registerTopLevelTask(task);
+    }
+    
+}
+
+void MSAEditorSequenceArea::sl_addSeqFromProject()
+{
+    MAlignmentObject* msaObject = editor->getMSAObject();
+    if (msaObject->isStateLocked()) {
+        return;
+    }
+
+    ProjectTreeControllerModeSettings settings;
+    settings.objectTypesToShow.append(GObjectTypes::SEQUENCE);
+    std::auto_ptr<DNASequenceObjectConstraints> seqConstraints(new DNASequenceObjectConstraints());
+    seqConstraints->alphabetType = msaObject->getAlphabet()->getType();
+    settings.objectConstraints.append(seqConstraints.get());
+
+    QList<GObject*> objects = ProjectTreeItemSelectorDialog::selectObjects(settings,this);
+
+    if (!objects.isEmpty()) {
+        foreach(GObject* obj, objects) {
+            if (obj->isUnloaded()) {
+                continue;
+            }
+            DNASequenceObject* seqObj = qobject_cast<DNASequenceObject*>(obj);
+            if (seqObj) {
+				msaObject->addRow(seqObj->getDNASequence(), 0);
+                cancelSelection();
+            }
+        }
+    }    
+}
+
+void MSAEditorSequenceArea::sl_sortByName() {
+    MAlignmentObject* msaObject = editor->getMSAObject();
+    if (msaObject->isStateLocked()) {
+        return;
+    }
+    MAlignment ma = msaObject->getMAlignment();
+    ma.sortRowsByName();
+    QStringList rowNames = ma.getRowNames();
+    if (rowNames != msaObject->getMAlignment().getRowNames()) {
+        msaObject->setMAlignment(ma);
+    }
+}
+
 }//namespace
