@@ -30,7 +30,7 @@ bool MSAEditorState::isValid() const {
 }
 
 GObjectReference MSAEditorState::getMSAObject() const {
-	return stateData[MSA_OBJ].value<GObjectReference>();
+	return stateData.contains(MSA_OBJ) ? stateData[MSA_OBJ].value<GObjectReference>() : GObjectReference();
 }
 
 void MSAEditorState::setMSAObject(const GObjectReference& ref) {
@@ -69,7 +69,8 @@ QVariantMap MSAEditorState::saveState(MSAEditor* v) {
     ss.stateData[VIEW_ID]=MSAEditorFactory::ID;
 
 	MAlignmentObject* msaObj = v->getMSAObject();
-	ss.setMSAObject(GObjectReference(msaObj));
+    if (msaObj)
+    	ss.setMSAObject(GObjectReference(msaObj));
 	ss.setX(0);
 	ss.setY(0);
 	
