@@ -173,7 +173,7 @@ QVariantMap SimpleTextObjectView::saveState() {
 	QVariantMap data;
 	//Content:
 	//file url
-	data[URL_KEY] = textObject->getDocument()->getURL();
+	data[URL_KEY] = textObject->getDocument()->getURLString();
     data[OBJ_KEY] = textObject->getGObjectName();
 	//GUI:
 	//start vis pos
