@@ -18,7 +18,7 @@ namespace GB2 {
 
 class ADVSequenceObjectContext;
 class SecStructPredictTask;  
-class SecStructPredcitAlgRegistry;
+class SecStructPredictAlgRegistry;
 class Task;
 
 class GB2_COREAPI_EXPORT SecStructDialog : public QDialog, private Ui::SecStructDialog    {
@@ -40,7 +40,7 @@ private:
     QList<SharedAnnotationData> results;
     ADVSequenceObjectContext* ctx;
     SecStructPredictTask* task;
-    SecStructPredcitAlgRegistry* sspr;
+    SecStructPredictAlgRegistry* sspr;
     void connectGUI();
     void updateState();
     void showResults();
