@@ -8,21 +8,22 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_SMITH_WATERMAN_ALG_H_
-#define _GB2_SMITH_WATERMAN_ALG_H_
+#ifndef _GB2_SMITH_WATERMAN_TASK_FACTORY_H_
+#define _GB2_SMITH_WATERMAN_TASK_FACTORY_H_
 
 #include "SmithWatermanSettings.h"
 #include <core_api/Task.h>
 
+
 namespace GB2 {
 
 class SmithWatermanTaskFactory {
 public:
-	virtual Task* getTaskInstance(const SmithWatermanSettings& config,
+    virtual Task* getTaskInstance(const SmithWatermanSettings& config,
                                   const QString& taskName) const = 0;
-    virtual bool hasAbvancedSettings() const = 0;
-	virtual void execAbvancedDialog() = 0;
-	virtual ~SmithWatermanTaskFactory() {}
+    virtual bool hasAdvancedSettings() const { return false; }
+    virtual void execAdvancedDialog() {}
+    virtual ~SmithWatermanTaskFactory() {}
 };
 
 } // namespace
