@@ -17,18 +17,22 @@ namespace GB2
 {
 
 AddDocumentTask::AddDocumentTask( Document * _d ) :
-Task( tr("add_document_task"), TaskFlag_NoRun), d(_d)
+Task( tr("Add document to the project: %1").arg(_d->getURLString()), TaskFlag_NoRun), d(_d)
 {
 
 }
 
-Task::ReportResult AddDocumentTask::report()
-{
+Task::ReportResult AddDocumentTask::report() {
     Project * p = AppContext::getProject();
     if( p->isStateLocked() ) {
         return ReportResult_CallMeAgain;
-    } else if(d) {
-        p->addDocument( d );
+    } else if (d!= NULL) {
+		Document* sameURLDoc = p->findDocumentByURL(d->getURL());
+		if (sameURLDoc!=NULL) {
+			stateInfo.setError(tr("Document is already added to the project %1").arg(d->getURL().getURLString()));
+		} else {
+			p->addDocument( d );
+		}
     } else {
         stateInfo.setError(stateInfo.getError() + tr("document_removed"));
     }
