@@ -14,12 +14,11 @@
 #include <qpointer.h>
 #include <core_api/Task.h>
 
-namespace GB2
-{
+namespace GB2 {
 class Document;
 
-class GB2_COREAPI_EXPORT AddDocumentTask : public Task
-{
+// Adds document to the project. Waits for locks if any
+class GB2_COREAPI_EXPORT AddDocumentTask : public Task {
     Q_OBJECT
 public:
     AddDocumentTask( Document * d );
@@ -31,5 +30,4 @@ private:
 
 }//namespace
 
-
 #endif
