@@ -8,34 +8,41 @@
 *     for details.
 *****************************************************************/
 
-#include <QtCore/QString>
-#include <QtCore/QByteArray>
-#include <memory>
-#include <core_api/IOAdapter.h>
 #include "CopyDataTask.h"
 
-namespace GB2
-{
+#include <core_api/IOAdapter.h>
+#include <core_api/L10n.h>
 
-CopyDataTask::CopyDataTask( IOAdapterFactory * io_f_, QString url_f_, IOAdapterFactory * io_w_, QString url_w_ ) :
-Task(tr("copy_data_task_name"), TaskFlag_None), io_f(io_f_), io_w(io_w_),
-url_f(url_f_), url_w(url_w_)
+#include <QtCore/QString>
+#include <QtCore/QByteArray>
+
+#include <memory>
+
+namespace GB2 {
+
+CopyDataTask::CopyDataTask( IOAdapterFactory * _ioFrom, const GUrl& _urlFrom, 
+						   IOAdapterFactory * _ioTo, const GUrl& _urlTo ) :
+Task(tr("copy_data_task_name"), TaskFlag_None), ioFrom(_ioFrom), ioTo(_ioTo),
+urlFrom(_urlFrom), urlTo(_urlTo)
 {
-    tpm = Progress_Manual;
+	assert(ioFrom != NULL && ioTo != NULL);
+	tpm = Progress_Manual;
 }
 
-void CopyDataTask::run()
-{
-    assert( io_f && io_w );
-    std::auto_ptr<IOAdapter> from( io_f->createIOAdapter() );
-    std::auto_ptr<IOAdapter> wheree( io_w->createIOAdapter() );
-    from->open( url_f, IOAdapterMode_Read );
-    wheree->open( url_w, IOAdapterMode_Write );
-    if( !from->isOpen() || !wheree->isOpen() ) {
-        stateInfo.setError(stateInfo.getError()+tr("cannot_open_io_adapter"));
+void CopyDataTask::run() {
+    std::auto_ptr<IOAdapter> from( ioFrom->createIOAdapter() );
+    std::auto_ptr<IOAdapter> wheree( ioTo->createIOAdapter() );
+    from->open( urlFrom, IOAdapterMode_Read );
+    if (!from->isOpen()) {
+        stateInfo.setError(L10N::errorOpeningFileRead(urlFrom));
         return;
     }
-
+    wheree->open( urlTo, IOAdapterMode_Write );
+    if (!from->isOpen()) {
+        stateInfo.setError(L10N::errorOpeningFileWrite(urlTo));
+        return;
+    }
+    
     qint64 count = 0;
     qint64 count_w = 0;
     QByteArray buff( BUFFSIZE, 0 );
@@ -55,7 +62,9 @@ void CopyDataTask::run()
         count = from->readBlock( buff.data(), BUFFSIZE );
     }
     if( count < 0 || count_w < 0 ) {
-        stateInfo.setError(stateInfo.getError() + tr("io_adapter_error"));
+        if (!stateInfo.hasErrors()) {
+            stateInfo.setError(tr("IO adapter error"));
+        }
     }
 }
 
