@@ -12,8 +12,8 @@
 #define _GB2_COPY_DATA_TASK_H_
 
 #include <core_api/Task.h>
+#include <core_api/GUrl.h>
 
-class QString;
 namespace GB2 {
 
 class IOAdapterFactory;
@@ -21,15 +21,17 @@ class IOAdapterFactory;
 class GB2_COREAPI_EXPORT CopyDataTask : public Task {
     Q_OBJECT
 public:
-    CopyDataTask( IOAdapterFactory * io_f, QString url_f, IOAdapterFactory * io_w, QString url_w );
+    CopyDataTask( IOAdapterFactory * ioFrom, const GUrl& urlFrom, 
+				IOAdapterFactory * ioTo, const GUrl& urlTo );
+
     virtual void run();
 
 private:
     static const int BUFFSIZE = 32 * 1024;    
-    IOAdapterFactory * io_f;
-    IOAdapterFactory * io_w;
-    QString url_f;
-    QString url_w;
+    IOAdapterFactory * ioFrom;
+    IOAdapterFactory * ioTo;
+    GUrl urlFrom;
+    GUrl urlTo;
 
 };
 
