@@ -66,8 +66,8 @@ void LoadUnloadedDocumentTask::prepare() {
     DocumentFormatId format = unloadedDoc->getDocumentFormatId();
     QString formatName = AppContext::getDocumentFormatRegistry()->getFormatById(format)->getFormatName();
 	IOAdapterFactory* iof = unloadedDoc->getIOAdapterFactory();
-	const QString& url = unloadedDoc->getURL();
-    log.details(tr("Starting load document from %1, document format %2").arg(url).arg(formatName));
+	const GUrl& url = unloadedDoc->getURL();
+    log.details(tr("Starting load document from %1, document format %2").arg(url.getURLString()).arg(formatName));
 	subtask = new LoadDocumentTask(format, url, iof, unloadedDoc->getGHintsMap(), config);
 	addSubTask(subtask);
 
@@ -141,7 +141,7 @@ Document* LoadUnloadedDocumentTask::getDocument() const {
 
 
 QString LoadUnloadedDocumentTask::getResourceName(Document* d) {
-    return QString(LoadUnloadedDocumentTask::tr("project_doc_resource") + ":" + d->getURL());
+    return QString(LoadUnloadedDocumentTask::tr("project_doc_resource") + ":" + d->getURLString());
 }
 
 LoadUnloadedDocumentTask* LoadUnloadedDocumentTask::findActiveLoadingTask(Document* d) {
@@ -173,17 +173,17 @@ bool LoadUnloadedDocumentTask::addLoadingSubtask(Task* t, const LoadDocumentTask
 // Load Document
 
 
-LoadDocumentTask::LoadDocumentTask(DocumentFormatId f, const QString& u, 
+LoadDocumentTask::LoadDocumentTask(DocumentFormatId f, const GUrl& u, 
                                    IOAdapterFactory* i, const QVariantMap& map, const LoadDocumentTaskConfig& _config)
 : Task("", TaskFlag_None), format(f), url(u), iof(i), hints(map), result(NULL), config(_config)
 {
-    setTaskName(tr("Read document: '%1'").arg(QFileInfo(u).fileName()));
+    setTaskName(tr("Read document: '%1'").arg(u.fileName()));
  
     tpm = Progress_Manual;
 	assert(iof!=NULL);
 }
 
-LoadDocumentTask * LoadDocumentTask::getDefaultLoadDocTask( const QString & url ) {
+LoadDocumentTask * LoadDocumentTask::getDefaultLoadDocTask(const GUrl& url) {
     if( url.isEmpty() ) {
         return NULL;
     }
@@ -191,7 +191,7 @@ LoadDocumentTask * LoadDocumentTask::getDefaultLoadDocTask( const QString & url
     if( NULL == iof ) {
         return NULL;
     }
-    QList< DocumentFormat* > dfs = DocumentFormatUtils::detectFormat( url );
+    QList< DocumentFormat* > dfs = DocumentFormatUtils::detectFormat(url);
     if( dfs.isEmpty() ) {
         return NULL;
     }
@@ -215,14 +215,14 @@ void LoadDocumentTask::run() {
 		setError(tr("invalid_format_%1").arg(format));
 		return;
 	}
-    if (config.createDoc && iof->exists(url) == TriState_No) {
+    if (config.createDoc && iof->isResourceAvailable(url) == TriState_No) {
         if (iof->isIOModeSupported(IOAdapterMode_Write)) {
             result = f->createNewDocument(iof, url, hints);
         } else {
-            setError(tr("Document not found %1").arg(url));
+            setError(tr("Document not found %1").arg(url.getURLString()));
         }
     } else {
-        result = f->loadExistingDocument(iof, url, stateInfo, hints);
+        result = f->loadDocument(iof, url, stateInfo, hints);
     }
     if (config.checkObjRef.isValid() && !hasErrors()) {
         processObjRef();
@@ -353,7 +353,7 @@ QList<Task*> LoadUnloadedDocumentAndOpenViewTask::onSubTaskFinished(Task* subTas
             if (seqDoc!=NULL) {
                 if (seqDoc->isLoaded()) { //try open sequence view 
                     GObject* seqObj = seqDoc->findGObjectByName(rel.ref.objName);
-                    if (seqObj!=NULL && seqObj->getGObjectType() == GObjectTypes::DNA_SEQUENCE) {
+                    if (seqObj!=NULL && seqObj->getGObjectType() == GObjectTypes::SEQUENCE) {
                         GObjectSelection os2; os2.addToSelection(seqObj);
                         MultiGSelection ms2; ms2.addSelection(&os2);
                         Task* openViewTask = createOpenViewTask(ms2);
