@@ -12,6 +12,7 @@
 #define _GB2_LOAD_DOCUMENT_TASK_H_
 
 #include <core_api/Task.h>
+#include <core_api/GUrl.h>
 #include <core_api/GObjectReference.h>
 
 #include <QtCore/QPointer>
@@ -71,10 +72,10 @@ private:
 class GB2_COREAPI_EXPORT LoadDocumentTask : public Task {
     Q_OBJECT
 public:
-    static LoadDocumentTask * getDefaultLoadDocTask( const QString & url );
+    static LoadDocumentTask * getDefaultLoadDocTask( const GUrl & url );
     
 public:
-	LoadDocumentTask(DocumentFormatId format, const QString& url, 
+	LoadDocumentTask(DocumentFormatId format, const GUrl& url, 
                 IOAdapterFactory* iof, const QVariantMap& hints = QVariantMap(), 
                 const LoadDocumentTaskConfig& config = LoadDocumentTaskConfig());
 
@@ -86,13 +87,13 @@ public:
 
 	Document* getDocument() const {return result;}
 	Document* takeDocument() {Document* d = result; result = NULL; return d;}
-    const QString& getUrl() const {return url;}
+    const GUrl& getURL() const {return url;}
 
 private:
     void processObjRef();
 
 	DocumentFormatId    format;
-	const QString       url;
+	const GUrl			url;
 	IOAdapterFactory*   iof;
     QVariantMap         hints;
 	Document*           result;
