@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -14,8 +14,9 @@ namespace GB2
 {
 
 MultiTask::MultiTask( const QString & name, const QList<Task *>& taskz ) : 
-Task(name, TaskFlags_NR_DWF_SSSOR )
+Task(name, TaskFlags_NR_FOSCOE)
 {
+    setMaxParallelSubtasks(1);
     if( taskz.empty() ) {
         assert( false ); 
         return;
