@@ -25,7 +25,7 @@ public:
         AnnotationStrategyForRemove_Remove
     };
     RemovePartFromSequenceTask(DocumentFormatId _dfId, DNASequenceObject *_seqObj, LRegion _regionToDelete, 
-        AnnotationStrategyForRemove _str = AnnotationStrategyForRemove_Resize, QString _url = QString(), bool _mergeAnnotations = false);
+        AnnotationStrategyForRemove _str = AnnotationStrategyForRemove_Resize, const GUrl& _url = GUrl(), bool _mergeAnnotations = false);
     virtual Task::ReportResult report();
 
 private:
@@ -37,7 +37,7 @@ private:
     Document *curDoc;
     Document *newDoc;
     bool save;
-    QString url;
+    GUrl url;
     AnnotationStrategyForRemove strat;
     QList<Document*> docs;
     DNASequenceObject *seqObj;
