@@ -16,9 +16,11 @@
 #include <core_api/ObjectViewModel.h>
 #include <core_api/AppContext.h>
 #include <core_api/ProjectModel.h>
+#include <core_api/L10n.h>
+#include <core_api/GUrlUtils.h>
+#include <core_api/DocumentUtils.h>
+
 #include <gobjects/GObjectUtils.h>
-#include <util_gui/DialogUtils.h>
-#include <util_gui/GUIUtils.h>
 
 #include <QtGui/QMessageBox>
 
@@ -28,7 +30,7 @@ namespace GB2 {
 
 static LogCategory log(ULOG_CAT_CORE_SERVICES);
 
-SaveDocumentTask::SaveDocumentTask(Document* _doc, IOAdapterFactory* _io, const QString& _url, bool ensureExt)
+SaveDocumentTask::SaveDocumentTask(Document* _doc, IOAdapterFactory* _io, const GUrl& _url)
 : Task(tr("save_document_task_name"), TaskFlag_None), doc(_doc), iof(_io), url(_url), flags(SaveDoc_Overwrite)
 {
 	assert(doc!=NULL);
@@ -36,16 +38,14 @@ SaveDocumentTask::SaveDocumentTask(Document* _doc, IOAdapterFactory* _io, const
 		iof = doc->getIOAdapterFactory();
 	}
 	if (url.isEmpty()) {
-		url = doc->getURL();
+		url = doc->getURLString();
 	}
-    if (ensureExt) {
-        url = DialogUtils::ensureFileExt(url, doc->getDocumentFormat()->getSupportedDocumentFileExtensions());
-    }
 	lock = NULL;
 }
 
-SaveDocumentTask::SaveDocumentTask(Document* _doc, uint f)
-: Task(tr("save_document_task_name"), TaskFlag_None), doc(_doc), iof(doc->getIOAdapterFactory()), url(doc->getURL()), flags(f)
+SaveDocumentTask::SaveDocumentTask(Document* _doc, SaveDocFlags f, const QSet<QString>& _excludeFileNames)
+: Task(tr("save_document_task_name"), TaskFlag_None), 
+doc(_doc), iof(doc->getIOAdapterFactory()), url(doc->getURL()), flags(f), excludeFileNames(_excludeFileNames)
 {
     assert(doc!=NULL);
     lock = new StateLock(getTaskName());
@@ -62,17 +62,17 @@ void SaveDocumentTask::prepare() {
 }
 
 void SaveDocumentTask::run() {
-    if (flags & SaveDoc_Roll && !DialogUtils::rollFile(url, stateInfo, &log)) {
+    if (flags.testFlag(SaveDoc_Roll) && !GUrlUtils::renameFileWithNameRoll(url.getURLString(), stateInfo, excludeFileNames, &log)) {
         return;
     }
 
-    log.info(tr("Saving document %1\n").arg(url));
+    log.info(tr("Saving document %1\n").arg(url.getURLString()));
     DocumentFormat* df = doc->getDocumentFormat();
 
-    if (flags & SaveDoc_Append) {
+    if (flags.testFlag(SaveDoc_Append)) {
         std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
         if (!io->open(url, IOAdapterMode_Append)) {
-            setError(Translations::errorOpeningFileWrite(url));
+            setError(L10N::errorOpeningFileWrite(url));
             return;
         }
         df->storeDocument(doc, stateInfo, io.get());
@@ -94,7 +94,7 @@ Task::ReportResult SaveDocumentTask::report() {
     if (url == doc->getURL() && iof == doc->getIOAdapterFactory()) {
 		doc->makeClean();
 	}
-    if (flags & SaveDoc_DestroyAfter) {
+    if (flags.testFlag(SaveDoc_DestroyAfter)) {
         doc->unload();
         delete doc;
     }
@@ -118,7 +118,7 @@ SaveMiltipleDocuments::SaveMiltipleDocuments(const QList<Document*>& docs, bool
             }
 
             QMessageBox::StandardButton res = saveAll ? QMessageBox::YesToAll : QMessageBox::question(NULL,
-                tr("save_doc_title"), tr("save_doc_text: %1").arg(doc->getURL()),
+                tr("save_doc_title"), tr("save_doc_text: %1").arg(doc->getURLString()),
                 buttons, QMessageBox::Yes);
 
             if (res == QMessageBox::NoToAll) {
@@ -151,7 +151,7 @@ QList<Document*> SaveMiltipleDocuments::findModifiedDocuments(const QList<Docume
 //////////////////////////////////////////////////////////////////////////
 // unload document
 UnloadDocumentTask::UnloadDocumentTask(Document* _doc, bool save)
-: Task(tr("unload_document_%1").arg(_doc->getURL()), TaskFlag_NoRun), doc(_doc), saveTask(NULL)
+: Task(tr("unload_document_%1").arg(_doc->getURLString()), TaskFlag_NoRun), doc(_doc), saveTask(NULL)
 {
     if (save) {
         saveTask = new SaveDocumentTask(doc);
@@ -206,7 +206,7 @@ void UnloadDocumentTask::runUnloadTaskHelper(const QList<Document*>& docs, Unloa
             }
 
             QMessageBox::StandardButton res = saveAll ? QMessageBox::YesToAll : QMessageBox::question(NULL,
-                tr("save_doc_title"), tr("save_doc_text: %1").arg(doc->getURL()),
+                tr("save_doc_title"), tr("save_doc_text: %1").arg(doc->getURLString()),
                 buttons, QMessageBox::Yes);
 
             if (res == QMessageBox::NoToAll) {
@@ -249,13 +249,15 @@ QString UnloadDocumentTask::checkSafeUnload(Document* doc) {
 
 //////////////////////////////////////////////////////////////////////////
 // save a copy and add to project
-SaveCopyAndAddToProjectTask::SaveCopyAndAddToProjectTask(Document* doc, IOAdapterFactory* iof, const QString& url, bool ensureExt)
-: Task (tr("Save a copy %1").arg(url), TaskFlags_NR_FOSCOE), url(url)
+SaveCopyAndAddToProjectTask::SaveCopyAndAddToProjectTask(Document* doc, IOAdapterFactory* iof, const GUrl& _url)
+: Task (tr("Save a copy %1").arg(url.getURLString()), TaskFlags_NR_FOSCOE), url(_url)
 {
     origURL = doc->getURL();
     df = doc->getDocumentFormat();
     hints = doc->getGHintsMap();
-    saveTask = new SaveDocumentTask(doc, iof, url, ensureExt);
+    
+    saveTask = new SaveDocumentTask(doc, iof, url);
+    saveTask->setExcludeFileNames(DocumentUtils::getNewDocFileNameExcludesHint());
     addSubTask(saveTask);
 
     foreach(GObject* obj, doc->getObjects()) {
@@ -276,9 +278,9 @@ Task::ReportResult SaveCopyAndAddToProjectTask::report() {
         setError(tr("Project is locked"));
         return ReportResult_Finished;
     }
-    const QString& url = saveTask->getURL();
+    const GUrl& url = saveTask->getURL();
     if (p->findDocumentByURL(url)) {
-        setError(tr("Document is already added to the project %1").arg(url));
+        setError(tr("Document is already added to the project %1").arg(url.getURLString()));
         return ReportResult_Finished;
     }
     Document* doc = new Document(df, saveTask->getIOAdapterFactory(), url, info, hints);
@@ -293,8 +295,8 @@ Task::ReportResult SaveCopyAndAddToProjectTask::report() {
 ///////////////////////////////////////////////////////////////////////////
 // relocate task
 
-RelocateDocumentTask::RelocateDocumentTask(const QString& fu, const QString& tu)
-: Task (tr("Relocate document %1 -> %2").arg(fu).arg(tu), TaskFlag_NoRun), fromURL(fu), toURL(tu)
+RelocateDocumentTask::RelocateDocumentTask(const GUrl& fu, const GUrl& tu)
+: Task (tr("Relocate document %1 -> %2").arg(fu.getURLString()).arg(tu.getURLString()), TaskFlag_NoRun), fromURL(fu), toURL(tu)
 {
 }
 
@@ -310,7 +312,7 @@ Task::ReportResult RelocateDocumentTask::report() {
     }
     Document* d = p->findDocumentByURL(fromURL);
     if (d == NULL) {
-        setError(tr("Document not found: %1").arg(fromURL));
+        setError(tr("Document not found: %1").arg(fromURL.getURLString()));
         return ReportResult_Finished;
     }
     if (d->isLoaded()) {
@@ -319,9 +321,9 @@ Task::ReportResult RelocateDocumentTask::report() {
     }
 
     d->setURL(toURL);
-    if (fromURL.endsWith(d->getName())) { // if document name is default -> update it too
-        d->setName(QFileInfo(toURL).fileName());
-    }
+    if (fromURL.baseFileName() == d->getName() || fromURL.fileName() == d->getName()) { // if document name is default -> update it too
+        d->setName(toURL.baseFileName());
+	}
 
     //update relations to new url
     foreach(Document* d, p->getDocuments()) {
