@@ -11,6 +11,7 @@
 #ifndef _GB2_SAVE_DOCUMENT_TASK_H_
 #define _GB2_SAVE_DOCUMENT_TASK_H_
 
+#include <core_api/GUrl.h>
 #include <core_api/Task.h>
 #include <gobjects/UnloadedObject.h>
 
@@ -23,11 +24,20 @@ class StateLock;
 class IOAdapterFactory;
 class DocumentFormat;
 
+enum SaveDocFlag {
+    SaveDoc_Overwrite = 0x0,
+    SaveDoc_Append = 0x1, 
+    SaveDoc_Roll = 0x2, 
+    SaveDoc_DestroyAfter = 0x4
+};
+
+typedef QFlags<SaveDocFlag>  SaveDocFlags;
+
 class GB2_COREAPI_EXPORT SaveDocumentTask : public Task {
     Q_OBJECT
 public:
-	SaveDocumentTask(Document* doc, IOAdapterFactory* iof = NULL, const QString& url = QString::null, bool ensureExt = true);
-    SaveDocumentTask(Document* doc, uint flags);
+	SaveDocumentTask(Document* doc, IOAdapterFactory* iof = NULL, const GUrl& url = GUrl());
+    SaveDocumentTask(Document* doc, SaveDocFlags flags, const QSet<QString>& excludeFileNames = QSet<QString>());
 
 	virtual void prepare();
 
@@ -35,17 +45,22 @@ public:
 
 	ReportResult report();
 
-    const QString& getURL() const {return url;}
+    const GUrl& getURL() const {return url;}
 
     IOAdapterFactory* getIOAdapterFactory() const {return iof;}
 
     const QPointer<Document>& getDocument() const {return doc;}
+
+    //used in file-name rolling mode
+    void setExcludeFileNames(const QSet<QString>& _excludeFileNames) {excludeFileNames = _excludeFileNames;}
+
 private:
 	StateLock*          lock;
     QPointer<Document>  doc;
 	IOAdapterFactory*   iof;
-	QString             url;
-    uint                flags;
+	GUrl				url;
+    SaveDocFlags        flags;
+    QSet<QString>       excludeFileNames;
 };
 
 
@@ -82,13 +97,13 @@ private:
 class GB2_COREAPI_EXPORT SaveCopyAndAddToProjectTask : public Task {
     Q_OBJECT
 public:
-    SaveCopyAndAddToProjectTask(Document* doc, IOAdapterFactory* iof, const QString& url, bool ensureExt = true);
+    SaveCopyAndAddToProjectTask(Document* doc, IOAdapterFactory* iof, const GUrl& url);
     ReportResult report();
 private:
     SaveDocumentTask*           saveTask;
     QList<UnloadedObjectInfo>   info;
-    QString                     url;
-    QString                     origURL;
+    GUrl						url;
+    GUrl						origURL;
     DocumentFormat*             df;
     QVariantMap                 hints;
 };
@@ -97,12 +112,12 @@ private:
 class GB2_COREAPI_EXPORT RelocateDocumentTask : public Task {
     Q_OBJECT
 public:
-    RelocateDocumentTask(const QString& fromURL, const QString& toURL);
+    RelocateDocumentTask(const GUrl& fromURL, const GUrl& toURL);
     ReportResult report();
 
 public:
-    QString fromURL;
-    QString toURL;
+    GUrl fromURL;
+    GUrl toURL;
 };
 
 }//namespace
