@@ -15,11 +15,20 @@
 
 namespace GB2 {
 
+SequenceWalkerConfig::SequenceWalkerConfig() 
+: seq(NULL), seqSize(0), complTrans(NULL), aminoTrans(NULL), 
+        chunkSize(0), lastChunkExtraLen(0), overlapSize(0), nThreads(MAX_PARALLEL_SUBTASKS_SERIAL) 
+{
+    strandToWalk = (complTrans!=NULL) ? StrandOption_Both : StrandOption_DirectOnly;
+}
+
+
 SequenceWalkerTask::SequenceWalkerTask(const SequenceWalkerConfig& c, SequenceWalkerCallback* cb, const QString& name, TaskFlags tf) 
 : Task(name, tf), config(c), callback(cb)
 {
-    assert(config.chunkSize > config.overlapSize);
+    assert(config.chunkSize >= config.overlapSize);
     assert(cb != NULL);
+    assert(config.strandToWalk == StrandOption_DirectOnly || config.complTrans!=NULL);
 
     maxParallelSubtasks = config.nThreads;
     QList<SequenceWalkerSubtask*> subs = prepareSubtasks();
@@ -40,23 +49,30 @@ QList<SequenceWalkerSubtask*> SequenceWalkerTask::prepareSubtasks() {
         config.range = wholeSeqReg.intersect(config.range);
     }
     if (config.aminoTrans == NULL ) {
-        //try walk direct in complement strands
+        //try walk direct and complement strands
         QList<LRegion> chunks = splitRange(config.range, config.chunkSize, config.overlapSize, config.lastChunkExtraLen, false);
-        QList<SequenceWalkerSubtask*> directTasks  = createSubs(chunks, false, false);
-        res+=directTasks;
-        if (config.complTrans!=NULL) {
+
+        if (config.strandToWalk == StrandOption_Both || config.strandToWalk == StrandOption_DirectOnly) {
+            QList<SequenceWalkerSubtask*> directTasks  = createSubs(chunks, false, false);
+            res+=directTasks;
+        }
+        if (config.strandToWalk == StrandOption_Both || config.strandToWalk == StrandOption_ComplementOnly) {
+            assert(config.complTrans!=NULL);
             QList<SequenceWalkerSubtask*> complTasks = createSubs(chunks, true, false);
             res+=complTasks;
         }
     } else {
         // try walk 3 direct and 3 complement translations
-        for (int i=0; i<3; i++) {
-            LRegion strandRange(config.range.startPos + i, config.range.len - i);
-            QList<LRegion> chunks = splitRange(strandRange, config.chunkSize, config.overlapSize, config.lastChunkExtraLen, false);
-            QList<SequenceWalkerSubtask*> directTasks = createSubs(chunks, false, true);
-            res+=directTasks;
+        if (config.strandToWalk == StrandOption_Both || config.strandToWalk == StrandOption_DirectOnly) {
+            for (int i=0; i<3; i++) {
+                LRegion strandRange(config.range.startPos + i, config.range.len - i);
+                QList<LRegion> chunks = splitRange(strandRange, config.chunkSize, config.overlapSize, config.lastChunkExtraLen, false);
+                QList<SequenceWalkerSubtask*> directTasks = createSubs(chunks, false, true);
+                res+=directTasks;
+            }
         }
-        if (config.complTrans!=NULL) {
+        if (config.strandToWalk == StrandOption_Both || config.strandToWalk == StrandOption_ComplementOnly) {
+            assert(config.complTrans!=NULL);
             for (int i=0; i<3; i++) {
                 LRegion strandRange(config.range.startPos, config.range.len - i);
                 QList<LRegion> chunks = splitRange(strandRange, config.chunkSize, config.overlapSize, config.lastChunkExtraLen, true);
@@ -83,7 +99,7 @@ QList<SequenceWalkerSubtask*> SequenceWalkerTask::createSubs(const QList<LRegion
 QList<LRegion> SequenceWalkerTask::splitRange(const LRegion& range, int chunkSize, int overlapSize, 
                                               int lastChunkExtraLen, bool reverseMode) 
 {
-    assert(chunkSize > overlapSize);
+    assert(chunkSize >= overlapSize);
     int stepSize = chunkSize - overlapSize;
     
     QList<LRegion> res;
@@ -116,6 +132,12 @@ localLen(_len), originalLocalLen(_len), doCompl(_doCompl), doAmino(_doAmino),
 leftOverlap(lo), rightOverlap(ro)
 {
     tpm = Task::Progress_Manual;
+    
+    // get resources
+    QList< TaskResourceUsage > resources = t->getCallback()->getResources( this );
+    foreach( const TaskResourceUsage & resource, resources ) {
+        taskResources.append( resource );
+    }
 }
 
 const char* SequenceWalkerSubtask::getRegionSequence() {
