@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -13,9 +13,6 @@
 
 #include <core_api/Task.h>
 
-#include <QtCore/QList>
-#include <QtCore/QString>
-
 namespace GB2
 {
 
@@ -29,11 +26,11 @@ public:
 public slots:
     void sl_taskStateChanged();
 signals:
-    void si_taskPrepared();
-    void si_taskRunning();
-    void si_taskFinished();
-    void si_taskSucceeded();
-    void si_taskFailed();
+    void si_taskPrepared(Task*);
+    void si_taskRunning(Task*);
+    void si_taskFinished(Task*);
+    void si_taskSucceeded(Task*);
+    void si_taskFailed(Task*);
 };
 
 } //namespace
