@@ -29,6 +29,8 @@ public:
 	static const QBitArray WHITES;
 	static const QBitArray LINE_BREAKS;
 	static const QBitArray BINARY;
+    static const QBitArray LESS_THAN;
+    static const QBitArray GREATER_THAN;
 	
 	static const QByteArray UPPER_CASE_MAP;
 	static const QByteArray LOWER_CASE_MAP;
@@ -73,10 +75,20 @@ public:
 
     inline static bool isQuoted(const char* str, int len, int qChar);
 
+    static QString variate(const QString& prefix, const QString& sep, const QSet<QString>& filter, bool mustHaveSuffix = false, int startSeed = 0);
+
+    inline static void charBounds(const char* data, int dataSize, char& minChar, char& maxChar);
+
+    //todo: move this method to another class
     inline static QByteArray selectIdx256(const QBitArray& map, bool sign);
 
-    static QString variate(const QString& prefix, const QString& sep, const QSet<QString>& filter, bool mustHaveSuffix = false, int startSeed = 0);
-	
+	// Returns first index of the character not equal to 'c'. Returns -1 if not found
+	inline static int firstIndexOfNotEqualChar(const char* seq, int size, char c);
+
+	// Returns last index of the character not equal to 'c'. Returns -1 if not found
+	inline static int lastIndexOfNotEqualChar(const char* seq, int size, char c);
+
+
 };
 
 template <typename T>
@@ -242,6 +254,39 @@ inline QByteArray TextUtils::selectIdx256(const QBitArray& map, bool sign) {
     return res;
 }
 
+
+inline void TextUtils::charBounds(const char* data, int dataSize, char& minChar, char& maxChar) {
+    assert(dataSize > 0);
+    maxChar = minChar = data[0];
+    for (int i=1; i < dataSize; i++) {
+        char c = data[i];
+        minChar = qMin(minChar, c);
+        maxChar = qMax(maxChar, c);
+    }
+}
+
+// returns first index of the character not equal to 'c'
+inline int TextUtils::firstIndexOfNotEqualChar(const char* seq, int size, char c) {
+	for (int i = 0; i < size; i++) {
+		char ci = seq[i];
+		if (ci != c) {
+			return i;
+		}
+	}
+	return -1;
+}
+
+// returns last index of the character not equal to 'c'
+inline int TextUtils::lastIndexOfNotEqualChar(const char* seq, int size, char c) {
+	for (int i = size - 1; i >= 0; i--) {
+		char ci = seq[i];
+		if (ci != c) {
+			return i;
+		}
+	}
+	return -1;
+}
+
 } //namespace
 
 #endif
