@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -29,8 +29,10 @@ public:
         ItemListValueRole
     };
 
-    virtual QWidget* getWidget() {return NULL;}
-    virtual PropertyDelegate* getDelegate(const QString&) {return NULL;}
+    virtual QWidget* getWidget() { return NULL; }
+    virtual PropertyDelegate* getDelegate(const QString&) { return NULL; }
+    virtual PropertyDelegate* removeDelegate( const QString&) { return NULL; }
+    virtual void addDelegate( PropertyDelegate * , const QString & ) {}
     virtual void commit() {}
     virtual ~ConfigurationEditor() {}
 };
