@@ -28,8 +28,8 @@ static QMap<QString, QStringList> getListMappings(const QStrStrMap& bm, const Po
             res.insert(p->getId(), bm.value(p->getId()).split(";"));
         }
     } else if (dt->isMap()) {
-        foreach(Descriptor d, dt->getElements()) {
-            if (dt->getElement(d)->isList() && bm.contains(d.getId())) {
+        foreach(Descriptor d, dt->getAllDescriptors()) {
+            if (dt->getDatatypeByDescriptor(d)->isList() && bm.contains(d.getId())) {
                 res.insert(d.getId(), bm.value(d.getId()).split(";"));
             }
         }
@@ -38,27 +38,29 @@ static QMap<QString, QStringList> getListMappings(const QStrStrMap& bm, const Po
 }
 
 
-IntegralBus::IntegralBus(Port* p) : busType(p->getType()), complement(NULL) {
+IntegralBus::IntegralBus(Port* p) : busType(p->getType()), complement(NULL), portId(p->getId()) {
     QString name = p->owner()->getLabel() + "[" + p->owner()->getId()+"]";
     if (p->isInput()) {
         Attribute* a = p->getParameter(BusPort::BUS_MAP);
-        assert(a);
-        if (a) {
-            busMap = a->value.value<QStrStrMap>();
-            assert(!busMap.isEmpty());
-            QMapIterator<QString, QString> it(busMap);
-            while (it.hasNext()) {
-                it.next();
-                log.trace(QString("%1 - input bus map key=%2 val=%3").arg(name).arg(it.key()).arg(it.value()));
-            }
-            listMap = getListMappings(busMap, p);
+        if(a == NULL) {
+            assert(false);
+            return;
         }
+        
+        busMap = a->getAttributeValue<QStrStrMap>();
+        assert(!busMap.isEmpty());
+        QMapIterator<QString, QString> it(busMap);
+        while (it.hasNext()) {
+            it.next();
+            log.trace(QString("%1 - input bus map key=%2 val=%3").arg(name).arg(it.key()).arg(it.value()));
+        }
+        listMap = getListMappings(busMap, p);
 
-    } else {
+    } else { // ps is output
         BusPort* bp = qobject_cast<BusPort*>(p);
         DataTypePtr t = bp ? bp->getOwnType() : p->getType();
         if (t->isMap()) {
-            foreach(Descriptor d, t->getElements()) {
+            foreach(Descriptor d, t->getAllDescriptors()) {
                 QString key = d.getId();
                 QString val = IntegralBusType::assignSlotDesc(d, p).getId();
                 busMap.insert(key, val);
@@ -73,7 +75,16 @@ IntegralBus::IntegralBus(Port* p) : busType(p->getType()), complement(NULL) {
         }
     }
 }
-    
+
+bool IntegralBus::addCommunication(const QString& id, CommunicationChannel* ch) {
+    outerChannels.insertMulti(id, ch); 
+    return true;
+}
+
+CommunicationChannel * IntegralBus::getCommunication(const QString& id) {
+    return outerChannels.value(id);
+}
+
 Message IntegralBus::get() {
     QVariantMap result;
     context.clear();
@@ -96,7 +107,7 @@ Message IntegralBus::get() {
                 assert(!lit.value().isEmpty());
                 if (lit.value().contains(ikey)) {
                     QVariantList vl = result[rkey].toList();
-                    if (m.getType()->getElement(ikey)->isList()) {
+                    if (m.getType()->getDatatypeByDescriptor(ikey)->isList()) {
                         vl += ival.toList();
                         log.trace("reducing bus key="+ikey+" to list of "+rkey);
                     } else {
@@ -121,6 +132,17 @@ Message IntegralBus::get() {
     return Message(busType, data);
 }
 
+Message IntegralBus::look() const {
+    QVariantMap result;
+    foreach(CommunicationChannel* channel, outerChannels) {
+        assert(channel != NULL);
+        Message message = channel->look();
+        assert(message.getData().type() == QVariant::Map);
+        result.unite(message.getData().toMap());
+    }
+    return Message(busType, result);
+}
+
 Message IntegralBus::composeMessage(const Message& m) {
     QVariantMap data(getContext());
     if (m.getData().type() == QVariant::Map) {
@@ -129,7 +151,6 @@ Message IntegralBus::composeMessage(const Message& m) {
             it.next();
             QString key = busMap.value(it.key());
             log.trace("putting key="+key+" remapped from="+it.key());
-
             data.insert(key, it.value());
         }
     } else {
@@ -140,9 +161,9 @@ Message IntegralBus::composeMessage(const Message& m) {
 }
 
 void IntegralBus::put(const Message& m) {
-    Message busM = composeMessage(m);
+    Message busMessage = composeMessage(m);
     foreach(CommunicationChannel* ch, outerChannels) {
-        ch->put(busM);
+        ch->put(busMessage);
     }
 }
 
