@@ -23,10 +23,11 @@ class WCOREAPI_EXPORT IntegralBus : public QObject, public CommunicationSubject,
     Q_OBJECT
 public:
     IntegralBus(Port* peer);
-    virtual bool addCommunication(const QString& id, CommunicationChannel* ch) {outerChannels.insertMulti(id, ch); return true;}
-    virtual CommunicationChannel* getCommunication(const QString& id) {return outerChannels.value(id);}
+    virtual bool addCommunication(const QString& id, CommunicationChannel* ch);
+    virtual CommunicationChannel* getCommunication(const QString& id);
 
     virtual Message get();
+    virtual Message look() const;
     virtual void put(const Message& m);
     virtual int hasMessage() const;
     virtual int hasRoom(const DataType* t = NULL) const;
@@ -40,7 +41,9 @@ public:
     virtual void setContext(const QVariantMap& m) {context = m;}
 
     virtual void addComplement(IntegralBus* b) {assert(!complement);complement = b;}
-
+    
+    QString getPortId() const {return portId;}
+    
 protected:
     virtual Message composeMessage(const Message&);
 
@@ -51,7 +54,9 @@ protected:
     QMap<QString, QStringList> listMap;
     QVariantMap context;
     IntegralBus* complement;
-};
+    QString portId;
+    
+}; // IntegralBus
 
 }//Workflow namespace
 }//GB2 namespace
