@@ -24,9 +24,11 @@ public:
     BusPort(const PortDescriptor& d, Actor* p);
     virtual DataTypePtr getType() const;
     DataTypePtr getOwnType() const {return type;}
+    
     Actor* getProducer(const QString& slot);
     QList<Actor*> getProducers(const QString& slot);
-
+    Actor* getLinkedActorById(ActorId id) const;
+    
     void setupBusMap();
 
     virtual bool validate(QStringList&) const;
@@ -56,6 +58,15 @@ protected:
     QStringList screenedSlots;
 };
 
+class WCOREAPI_EXPORT ScreenedParamValidator : public ConfigurationValidator {
+public:
+    ScreenedParamValidator(const QString& id, const QString& port, const QString& slot);
+    virtual ~ScreenedParamValidator() {}
+    virtual bool validate(const Configuration*, QStringList& output) const;
+protected:
+    QString id, port, slot;
+};
+
 }//namespace Workflow
 }//namespace GB2
 
