@@ -11,15 +11,15 @@
 #ifndef _GB2_PLAINBUS_TYPE_H_
 #define _GB2_PLAINBUS_TYPE_H_
 
-#include <workflow/TypeSet.h>
+#include <workflow/Datatype.h>
 #include <workflow/IntegralBusModel.h>
 
 namespace GB2 {
 namespace Workflow {
 
-class WCOREAPI_EXPORT IntegralBusType : public DataTypeSet {
+class WCOREAPI_EXPORT IntegralBusType : public MapDataType {
 public:
-    IntegralBusType(const Descriptor& d, const QMap<Descriptor, DataTypePtr>& m) : DataTypeSet(d, m) {}
+    IntegralBusType(const Descriptor& d, const QMap<Descriptor, DataTypePtr>& m);
 
     void addInputs(const Port* p);
     void addOutput(DataTypePtr, const Port* producer);
@@ -27,7 +27,8 @@ public:
     static Descriptor assignSlotDesc(const Descriptor& elementDesc, const Port* producer);
     static void remap(QStrStrMap& busMap, const QMap<ActorId, ActorId>&);
     static ActorId parseSlotDesc(const QString& id);
-
+    static QString parseAttributeIdFromSlotDesc(const QString & str);
+    
     //QMap<Descriptor, DataTypePtr> findMatches(const Descriptor& d, DataTypePtr t);
     
 protected:
