@@ -43,6 +43,20 @@ Schema::~Schema() {
     reset();
 }
 
+Schema::Schema( const Schema & other ) {
+    *this = other;
+}
+
+Schema & Schema::operator =( const Schema & other ) {
+    procs = other.procs;
+    flows = other.flows;
+    iterations = other.iterations;
+    // aliasMap = other.aliasMap;
+    domain = other.domain;
+    deepCopy = false;
+    return *this;
+}
+
 void Schema::reset()
 {
     if (deepCopy) {
@@ -50,6 +64,7 @@ void Schema::reset()
         flows.clear();
         qDeleteAll(procs);
         procs.clear();
+//        aliasMap.clear();
     }
 }
 
