@@ -12,6 +12,7 @@
 #define _GB2_WORKFLOW_ENV_H_
 
 #include <assert.h>
+#include <workflow/Datatype.h>
 #include "Descriptor.h"
 
 namespace GB2 {
@@ -30,6 +31,7 @@ public:
     static DataTypeRegistry* getDataTypeRegistry() {return getInstance()->data;}
     static WProtoRegistry* getProtoRegistry() {return getInstance()->proto;}
     static DomainRegistry* getDomainRegistry() {return getInstance()->domain;}
+    static DataTypeValueFactoryRegistry* getDataTypeValueFactoryRegistry() { return getInstance()->dvfReg; }
     virtual ~WorkflowEnv() {}
 
 protected:
@@ -39,12 +41,12 @@ protected:
     virtual DataTypeRegistry* initDataRegistry() = 0;
     virtual WProtoRegistry* initProtoRegistry() = 0;
     virtual DomainRegistry* initDomainRegistry() = 0;
-
+    virtual DataTypeValueFactoryRegistry* initDataTypeValueFactoryRegistry() = 0;
 
     DataTypeRegistry* data;
     WProtoRegistry* proto;
     DomainRegistry* domain;
-
+    DataTypeValueFactoryRegistry* dvfReg;
 };
 
 } //namespace Workflow
