@@ -24,12 +24,10 @@ public:
     ActorPrototype* unregisterProto(const QString& id);
     const QMap<Descriptor, QList<ActorPrototype*> >& getProtos() const {return groups;}
     ActorPrototype* getProto(const QString& id) const;
-    void addAliases(const QMap<QString,QString>& m) {aliases.unite(m);}
 signals:
     void si_registryModified();
 private:
      QMap<Descriptor, QList<ActorPrototype*> > groups;
-     QMap<QString,QString> aliases;
 };
 
 }//namespace Workflow
