@@ -38,6 +38,11 @@ private:
 class WCOREAPI_EXPORT CommunicationChannel {
 public:
     virtual Message get() = 0;
+    // look at message without getting it out of channel
+    // Message is united of data that was putted to outer channels
+    // Message is differs from what get() will return
+    // used in scripting
+    virtual Message look() const = 0;
     virtual void put(const Message& m) = 0;
     virtual int hasMessage() const = 0;
     virtual int hasRoom(const DataType* t = NULL) const = 0;
