@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -25,6 +25,10 @@ namespace Workflow {
     const Descriptor BioActorLibrary::MA_SLOT() {return Descriptor(MA_SLOT_ID, tr("Multiple alignment"), tr("A multiple sequence alignment"));}
     const Descriptor BioActorLibrary::FEATURE_TABLE_SLOT() {return Descriptor(FEATURE_TABLE_SLOT_ID, tr("Set of annotations"), tr("A set of annotated regions"));}
 
+    const QString BioActorLibrary::FILE_MODE_ATTR_ID("zz-file-mode");
+    const Descriptor BioActorLibrary::FILE_MODE_ATTR() {return Descriptor(FILE_MODE_ATTR_ID, tr("Existing file"), 
+        tr("If a target file already exists, you can specify how it should be handled: either overwritten, renamed or appended (if supported by file format)."));}
+
 void BioActorLibrary::init() {
 
     WorkflowEnv::getDomainRegistry()->registerEntry(new LocalWorkflow::LocalDomainFactory());
