@@ -12,7 +12,7 @@
 
 #include <workflow/WorkflowEnv.h>
 #include <workflow_support/CoreDataTypes.h>
-#include <workflow/TypeSet.h>
+#include <workflow/Datatype.h>
 
 namespace GB2 {
 
