@@ -11,6 +11,7 @@
 #include "LocalDomain.h"
 
 #include <workflow/Schema.h>
+#include <workflow/IntegralBusType.h>
 #include <workflow_support/WorkflowSettings.h>
 #include <core_api/Log.h>
 
@@ -21,6 +22,9 @@ const QString LocalDomainFactory::ID("domain.local.bio");
 
 static LogCategory log(ULOG_CAT_WD);
 
+/*****************************
+ * BaseWorker
+ *****************************/
 BaseWorker::BaseWorker(Actor* a, bool autoTransitBus) : actor(a) {
     foreach(Port* p, a->getPorts()) {
         if (qobject_cast<BusPort*>(p)) {
@@ -45,15 +49,7 @@ BaseWorker::BaseWorker(Actor* a, bool autoTransitBus) : actor(a) {
     failFast = WorkflowSettings::failFast();
 }
 
-bool BaseWorker::addCommunication(const QString& id, CommunicationChannel* ch) {
-    Q_UNUSED(id);
-    Q_UNUSED(ch);
-    assert(0);
-    return false;
-}
-
-BaseWorker::~BaseWorker()
-{
+BaseWorker::~BaseWorker() {
     foreach(Port* p, actor->getPorts()) {
         if (qobject_cast<BusPort*>(p)) {
             p->setPeer(NULL);
@@ -63,6 +59,62 @@ BaseWorker::~BaseWorker()
     actor->setPeer(NULL);
 }
 
+bool BaseWorker::addCommunication(const QString& id, CommunicationChannel* ch) {
+    Q_UNUSED(id);
+    Q_UNUSED(ch);
+    assert(0);
+    return false;
+}
+
+CommunicationChannel * BaseWorker::getCommunication(const QString& name) {
+    return ports.value(name);
+}
+
+ActorId BaseWorker::getActorId() const {
+    return actor->getId();
+}
+
+Message BaseWorker::getMessageAndSetupScriptValues( CommunicationChannel * channel ) {
+    assert(channel != NULL);
+    assert(channel->hasMessage());
+    bindScriptValues();
+    return channel->get();
+}
+
+void BaseWorker::bindScriptValues() {
+    foreach( IntegralBus * bus, ports.values() ) {
+        assert(bus != NULL);
+        if(!bus->hasMessage()) { // means that it is bus for output port
+            continue;
+        }
+        
+        QVariantMap busData = bus->look().getData().toMap();
+        foreach( Attribute * attribute, actor->getParameters().values() ) {
+            assert(attribute != NULL);
+            foreach(const QString & slotDesc, busData.keys()) {
+                ActorId actorId = IntegralBusType::parseSlotDesc(slotDesc);
+                QString attrId = IntegralBusType::parseAttributeIdFromSlotDesc(slotDesc);
+                QString portId = bus->getPortId();
+                BusPort * busPort = qobject_cast<BusPort*>(actor->getPort(portId));
+                assert(busPort != NULL);
+                
+                Actor * bindedAttrOwner = busPort->getLinkedActorById(actorId);
+                QString attrVarName = bindedAttrOwner->getPortAttributeShortName(attrId);
+                AttributeScript & attrScript = attribute->getAttributeScript();
+                if( attrScript.hasVarWithId(attrVarName) ) {
+                    attrScript.setVarValueWithId(attrVarName, busData.value(slotDesc));
+                }
+            }
+        }
+    }
+}
+
+/*****************************
+ * SimplestSequentialScheduler
+ *****************************/
+SimplestSequentialScheduler::SimplestSequentialScheduler(Schema* sh) : schema(sh), lastWorker(NULL), lastTask(NULL) {
+}
+
 void SimplestSequentialScheduler::init() {
     foreach(Actor* a, schema->procs) {
         a->castPeer<BaseWorker>()->init();
@@ -104,12 +156,10 @@ void SimplestSequentialScheduler::cleanup() {
     }
 }
 
-SimplestSequentialScheduler::~SimplestSequentialScheduler()
-{
+SimplestSequentialScheduler::~SimplestSequentialScheduler() {
 }
 
-GB2::Workflow::WorkerState SimplestSequentialScheduler::getWorkerState( ActorId id)
-{
+GB2::Workflow::WorkerState SimplestSequentialScheduler::getWorkerState( ActorId id) {
     Actor* a = schema->actorById(id);
     assert(a);
     BaseWorker* w = a->castPeer<BaseWorker>();
@@ -128,20 +178,53 @@ GB2::Workflow::WorkerState SimplestSequentialScheduler::getWorkerState( ActorId
     return WorkerWaiting;
 }
 
-Worker* LocalDomainFactory::createWorker(Actor* a) {
-    Worker* w = NULL;
-    DomainFactory* f = getById(a->getProto()->getId());
-    if (f) {
-        w = f->createWorker(a);
-#ifdef _DEBUG
-        assert(w);
-        BaseWorker* bw = dynamic_cast<BaseWorker*>(w);
-        assert(qobject_cast<BaseWorker*>(bw));
-        assert(bw == a->getPeer());
-#endif
-    }
-    
-    return w;    
+/*****************************
+ * SimpleQueue
+ *****************************/
+SimpleQueue::SimpleQueue() : ended(false) {
+}
+
+Message SimpleQueue::get() {
+    assert(hasMessage());
+    return que.dequeue();
+}
+
+Message SimpleQueue::look() const {
+    assert(hasMessage()); 
+    return que.head();
+}
+
+void SimpleQueue::put(const Message& m) {
+    que.enqueue(m);
+}
+
+int SimpleQueue::hasMessage() const {
+    return que.size();
+}
+
+int SimpleQueue::hasRoom(const DataType* ) const {
+    return 1000;
+}
+
+bool SimpleQueue::isEnded() const {
+    return ended && que.isEmpty();
+}
+
+void SimpleQueue::setEnded() {
+    ended = true;
+}
+
+int SimpleQueue::capacity() const {
+    return INT_MAX;
+}
+
+void SimpleQueue::setCapacity(int) {
+}
+
+/*****************************
+ * LocalDomainFactory
+ *****************************/
+LocalDomainFactory::LocalDomainFactory() : DomainFactory(ID) {
 }
 
 static CommunicationSubject* setupBus(Port* p) {
@@ -172,6 +255,22 @@ static CommunicationSubject* setupBus(Port* p) {
     return subj;
 }
 
+Worker* LocalDomainFactory::createWorker(Actor* a) {
+    Worker* w = NULL;
+    DomainFactory* f = getById(a->getProto()->getId());
+    if (f) {
+        w = f->createWorker(a);
+#ifdef _DEBUG
+        assert(w);
+        BaseWorker* bw = dynamic_cast<BaseWorker*>(w);
+        assert(qobject_cast<BaseWorker*>(bw));
+        assert(bw == a->getPeer());
+#endif
+    }
+    
+    return w;    
+}
+
 CommunicationChannel* LocalDomainFactory::createConnection(Link* l) {
     SimpleQueue* cc = NULL;
     QString srcId = l->source()->getId();
