@@ -15,6 +15,7 @@
 
 #include <QtCore/QModelIndex>
 #include <QtGui/QLineEdit>
+#include <QtGui/QToolButton>
 
 namespace GB2 {
 
@@ -24,6 +25,8 @@ public:
     DelegateEditor(const QString& s, PropertyDelegate* d) {delegates.insert(s,d);}
     virtual ~DelegateEditor() {qDeleteAll(delegates.values());}
     virtual PropertyDelegate* getDelegate(const QString& name) {return delegates.value(name);}
+    virtual PropertyDelegate* removeDelegate( const QString & name ) {return delegates.take( name );}
+    virtual void addDelegate( PropertyDelegate * del, const QString & name ) { delegates.insert( name, del ); }
     virtual void commit() {}
 protected:
     QMap<QString, PropertyDelegate*> delegates;
@@ -36,6 +39,7 @@ public:
         : QLineEdit(parent), FileFilter(filter), type(type), multi(multi) {}
 private slots:
     void sl_onBrowse();
+    
 private:
     QString FileFilter;
     QString type;
@@ -43,23 +47,27 @@ private:
 };
 
 class WCOREAPI_EXPORT URLDelegate : public PropertyDelegate {
-    
+    Q_OBJECT
 public:
     URLDelegate(const QString& filter, const QString& type, bool multi = false, QObject *parent = 0) 
-        : PropertyDelegate(parent), FileFilter(filter), type(type), multi(multi) {}
+        : PropertyDelegate(parent), FileFilter(filter), type(type), multi(multi), showButton( true ) {}
     virtual ~URLDelegate() {}
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
+    virtual QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
         const QModelIndex &index) const;
 
-    void setEditorData(QWidget *editor, const QModelIndex &index) const;
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
+    virtual void setEditorData(QWidget *editor, const QModelIndex &index) const;
+    virtual void setModelData(QWidget *editor, QAbstractItemModel *model,
         const QModelIndex &index) const;
 
+public slots:
+    void sl_showEditorButton( bool show );
+    
 protected:
     QString FileFilter;
     QString type;
     bool    multi;
+    bool    showButton;
 };
 
 class WCOREAPI_EXPORT SpinBoxDelegate : public PropertyDelegate {
@@ -99,6 +107,7 @@ private:
 };
 
 class WCOREAPI_EXPORT ComboBoxDelegate : public PropertyDelegate {
+    Q_OBJECT
 public:
     ComboBoxDelegate(const QVariantMap& items, QObject *parent = 0) : PropertyDelegate(parent), items(items) {}
     virtual ~ComboBoxDelegate() {}
@@ -110,6 +119,10 @@ public:
       void setModelData(QWidget *editor, QAbstractItemModel *model,
           const QModelIndex &index) const;
       QVariant getDisplayValue(const QVariant&) const;
+
+signals:
+    void si_valueChanged( const QString & newVal ) const;
+    
 protected:
     QVariantMap items;
 };
@@ -120,16 +133,52 @@ public:
     virtual ~FileModeDelegate() {}
 };
 
-class WCOREAPI_EXPORT ScreenedParamValidator : public ConfigurationValidator {
+class WCOREAPI_EXPORT SchemaRunModeDelegate : public ComboBoxDelegate {
+    Q_OBJECT
 public:
-    ScreenedParamValidator(const QString& id, const QString& port, const QString& slot);
-    virtual ~ScreenedParamValidator() {}
-    virtual bool validate(const Configuration*, QStringList& output) const;
-protected:
-    QString id, port, slot;
-};
+    static const QString THIS_COMPUTER_STR;
+    static const QString REMOTE_COMPUTER_STR;
+    
+public:
+    SchemaRunModeDelegate(QObject * parent = 0);
+    virtual ~SchemaRunModeDelegate() {}
 
+public slots:
+    void sl_valueChanged( const QString & val );
+    
+signals:
+    void si_showOpenFileButton( bool show );
+    
+}; // SchemaRunModeDelegate
 
+class WCOREAPI_EXPORT AttributeScriptDelegate : public PropertyDelegate {
+    Q_OBJECT
+public:
+    AttributeScriptDelegate(QObject *parent = 0);
+    virtual ~AttributeScriptDelegate();
+    
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
+    QVariant getDisplayValue(const QVariant&) const;
+
+private slots:
+    void sl_comboActivated(int);
+    
+}; // AttributeScriptDelegate
+
+//class WCOREAPI_EXPORT InputPortDataDelegate : public ComboBoxDelegate {
+//    Q_OBJECT
+//public:
+//    InputPortDataDelegate(const QVariantMap& items, QObject *parent = NULL );
+//    virtual ~InputPortDataDelegate();
+//    
+//    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+//    void setEditorData(QWidget *editor, const QModelIndex &index) const;
+//    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
+//    QVariant getDisplayValue(const QVariant&) const;
+//    
+//}; // InputPortDataDelegate
 
 }//namespace GB2
 #endif
