@@ -34,17 +34,22 @@ static const QString DATAFLOW_EL = "dataflow";
 static const QString ID_ATTR = "id";
 static const QString NAME_ATTR = "name";
 static const QString TYPE_ATTR = "type";
+static const QString NUM_IN_SCHEMA = "numberInSchema";
 static const QString SRC_PORT_ATTR = "sprt";
 static const QString SRC_PROC_ATTR = "sprc";
 static const QString DST_PORT_ATTR = "dprt";
 static const QString DST_PROC_ATTR = "dprc";
+static const QString ALIASES_EL = "paramAliases";
 
 QDomElement SchemaSerializer::saveActor(const Actor* proc, QDomElement& proj) {
     QDomElement docElement = proj.ownerDocument().createElement(PROCESS_EL);
     docElement.setAttribute(ID_ATTR, proc->getId());
     docElement.setAttribute(TYPE_ATTR, proc->getProto()->getId());
     docElement.setAttribute(NAME_ATTR, proc->getLabel());
+    docElement.setAttribute(NUM_IN_SCHEMA, proc->getNumberInSchema());
     saveConfiguration(*proc, docElement);
+    saveParamAliases( proc->getParamAliases(), docElement );
+    
     proj.appendChild(docElement);
     return docElement;
 }
@@ -64,6 +69,8 @@ Actor* SchemaSerializer::readActor(const QDomElement& procElement) {
     if (proc) {
         readConfiguration(proc, procElement);
         proc->setLabel(procElement.attribute(NAME_ATTR));
+        proc->setNumberInSchema(procElement.attribute(NUM_IN_SCHEMA).toInt());
+        readParamAliases( proc->getParamAliases(), procElement );
     }
     return proc;
 }
@@ -144,7 +151,7 @@ void SchemaSerializer::readIterations(QList<Iteration>& lst, const QDomElement&
 void SchemaSerializer::saveConfiguration(const Configuration& cfg, QDomElement& owner) {
     QVariantMap qm;
     foreach (Attribute* a, cfg.getParameters()) {
-        qm[a->getId()] = a->value;
+        qm[a->getId()] = a->toVariant();
     }
     QDomElement el = owner.ownerDocument().createElement(PARAMS_EL);
     owner.appendChild(el);
@@ -158,7 +165,36 @@ void SchemaSerializer::readConfiguration(Configuration* cfg, const QDomElement&
         QMapIterator<QString, QVariant> it(qm);
         while (it.hasNext()) {
             it.next();
-            cfg->setParameter(it.key(), it.value());
+            QString keyStr = it.key();
+            if(cfg->hasParameter(keyStr)) {
+                cfg->getParameter(keyStr)->fromVariant(it.value());
+            }
+        }
+    }
+}
+
+void SchemaSerializer::saveParamAliases(const QMap<QString, QString> & aliases, QDomElement & owner ) {
+    QDomElement el = owner.ownerDocument().createElement( ALIASES_EL );
+    
+    QMap<QString, QString>::const_iterator it = aliases.constBegin();
+    while( it != aliases.constEnd() ) {
+        el.setAttribute( it.key(), it.value() );
+        ++it;
+    }
+    owner.appendChild( el );
+}
+
+void SchemaSerializer::readParamAliases( QMap<QString, QString> & aliases, const QDomElement& owner ) {
+    QDomNodeList alisesNodes = owner.elementsByTagName( ALIASES_EL );
+    int sz = alisesNodes.size();
+    for( int i = 0; i < sz; ++i ) {
+        QDomNamedNodeMap map = alisesNodes.at( i ).toElement().attributes();
+        int mapSz = map.length();
+        for( int j = 0; j < mapSz; ++j ) {
+            QDomNode node = map.item( j );
+            QString nodeName = node.nodeName();
+            QString nodeValue = node.nodeValue();
+            aliases.insert( nodeName, nodeValue );
         }
     }
 }
@@ -213,7 +249,9 @@ QString SchemaSerializer::xml2schema(const QDomElement& projectElement, Schema*
         }
         Actor* proc = proto->createInstance();
         readConfiguration(proc, procElement);
+        readParamAliases( proc->getParamAliases(), procElement );
         proc->setLabel(procElement.attribute(NAME_ATTR));
+        proc->setNumberInSchema(procElement.attribute(NUM_IN_SCHEMA).toInt());
         procMap[id] = proc;
         schema->procs.append(proc);
 
