@@ -27,10 +27,10 @@ public:
 
     static void saveConfiguration(const Configuration&, QDomElement& );
     static void readConfiguration(Configuration*, const QDomElement& );
+    static void saveParamAliases( const QMap<QString, QString> &, QDomElement& );
+    static void readParamAliases( QMap<QString, QString> &, const QDomElement& );
     static void saveIterations(const QList<Iteration>&, QDomElement& );
     static void readIterations(QList<Iteration>&, const QDomElement&,const QMap<ActorId, ActorId>&);
-    //static void saveDescriptor(const Descriptor&, QDomElement& );
-    //static void readDescriptor(Descriptor*, const QDomElement& );
     static QDomElement saveActor(const Actor*, QDomElement&);
     static QDomElement savePort(const Port*, QDomElement&);
     static Actor* readActor(const QDomElement&);
