@@ -42,11 +42,20 @@ WProtoRegistry* WorkflowEnvImpl::initProtoRegistry() {
     return r;
 }
 
+DataTypeValueFactoryRegistry* WorkflowEnvImpl::initDataTypeValueFactoryRegistry() {
+    DataTypeValueFactoryRegistry* ret = new DataTypeValueFactoryRegistry();
+    ret->registerEntry( new StringTypeValueFactory() );
+    ret->registerEntry( new BoolTypeValueFactory() );
+    ret->registerEntry( new NumTypeValueFactory() );
+    return ret;
+}
+
 WorkflowEnvImpl::~WorkflowEnvImpl()
 {
     delete domain;
     delete proto;
     delete data;
+    delete dvfReg;
 }
 
 }//namespace Workflow
