@@ -11,6 +11,8 @@
 #include "WorkflowUtils.h"
 
 #include <workflow/Descriptor.h>
+#include <workflow/IntegralBusModel.h>
+#include <workflow/IntegralBusType.h>
 #include <workflow_support/SchemaSerializer.h>
 #include <core_api/GObject.h>
 #include <core_api/DocumentModel.h>
@@ -24,8 +26,23 @@
 
 namespace GB2 {
 
+/*****************************
+ * DesignerUtils
+ *****************************/
 QString DesignerUtils::getRichDoc(const Descriptor& d) {
-    return QString("<b>%1</b> : %2").arg(d.getDisplayName()).arg(d.getDocumentation());
+    if(d.getDisplayName().isEmpty()) {
+        if( d.getDocumentation().isEmpty() ) {
+            return QString();
+        } else {
+            return QString("%1").arg(d.getDocumentation());
+        }
+    } else {
+        if( d.getDocumentation().isEmpty() ) {
+            return QString("<b>%1</b>").arg(d.getDisplayName());
+        } else {
+            return QString("<b>%1</b> : %2").arg(d.getDisplayName()).arg(d.getDocumentation());
+        }
+    }
 }
 
 const QString DesignerUtils::SCHEMA_FILE_EXT("uws");
@@ -41,13 +58,13 @@ QString DesignerUtils::getDropUrl(QList<DocumentFormat*>& fs, const QMimeData* m
         GObject* obj = gomd->objPtr.data();
         if (obj) {
             fs << obj->getDocument()->getDocumentFormat();
-            url = obj->getDocument()->getURL();
+            url = obj->getDocument()->getURLString();
         }
     } else if (domd) {
         Document* doc = domd->objPtr.data();
         if (doc) {
             fs << doc->getDocumentFormat();
-            url = doc->getURL();
+            url = doc->getURLString();
         }
     } else if (md->hasUrls()) {
         QList<QUrl> urls = md->urls();
@@ -181,18 +198,106 @@ bool DesignerUtils::validate(const Schema& schema, QList<QMap<int, QVariant> >*
     return good;
 }
 
+QList<Descriptor> DesignerUtils::findMatchingTypes(DataTypePtr set, DataTypePtr elementDataType) {
+    QList<Descriptor> result;
+    foreach(const Descriptor& d, set->getAllDescriptors()) {
+        if (set->getDatatypeByDescriptor(d) == elementDataType) {
+            result.append(d);
+        }
+    }
+    return result;
+}
+
+QStringList DesignerUtils::findMatchingTypesAsStringList(DataTypePtr set, DataTypePtr elementDatatype) {
+    QList<Descriptor> descList = findMatchingTypes(set, elementDatatype);
+    QStringList res;
+    foreach( const Descriptor & desc, descList ) {
+        res << desc.getId();
+    }
+    return res;
+}
+
+const Descriptor EMPTY_VALUES_DESC("", DesignerUtils::tr("<empty>"), DesignerUtils::tr("Default value"));
+
+QList<Descriptor> DesignerUtils::findMatchingCandidates(DataTypePtr from, DataTypePtr elementDatatype) {
+    QList<Descriptor> candidates = findMatchingTypes(from, elementDatatype);
+    if (elementDatatype->isList()) {
+        candidates += findMatchingTypes(from, elementDatatype->getDatatypeByDescriptor());
+    } else {
+        candidates.append(EMPTY_VALUES_DESC);
+    }
+    return candidates;
+}
+
+QList<Descriptor> DesignerUtils::findMatchingCandidates(DataTypePtr from, DataTypePtr to, const Descriptor & key) {
+    return findMatchingCandidates(from, to->getDatatypeByDescriptor(key));
+}
+
+Descriptor DesignerUtils::getCurrentMatchingDescriptor(const QList<Descriptor> & candidates, DataTypePtr to, 
+                                                       const Descriptor & key, const QStrStrMap & bindings) {
+    DataTypePtr elementDatatype = to->getDatatypeByDescriptor(key);
+    if (elementDatatype->isList()) {
+        QString currentVal = bindings.value(key.getId());
+        if (!currentVal.isEmpty()) {
+            return Descriptor(currentVal, tr("<List of values>"), tr("List of values"));
+        } else {
+            return EMPTY_VALUES_DESC;
+        }
+    } else {
+        int idx = bindings.contains(key.getId()) ? candidates.indexOf(bindings.value(key.getId())) : 0;
+        return idx >= 0 ? candidates.at(idx) : candidates.first();
+    }
+}
+
+DataTypePtr DesignerUtils::getToDatatypeForBusport(BusPort * p) {
+    assert(p != NULL);
+    DataTypePtr to;
+    DataTypePtr t = to = p->getType();
+    if (!t->isMap()) {
+        QMap<Descriptor, DataTypePtr> map;
+        map.insert(*p, t);
+        to = new MapDataType(Descriptor(), map);
+        //IntegralBusType* bt = new IntegralBusType(Descriptor(), QMap<Descriptor, DataTypePtr>());
+        //bt->addOutput(t, p);
+    }
+    return to;
+}
+
+DataTypePtr DesignerUtils::getFromDatatypeForBusport(BusPort * p, DataTypePtr to) {
+    assert(p != NULL);
+    
+    DataTypePtr from;
+    if (p->isOutput() || p->getWidth() == 0) {
+        //nothing to edit, go info mode
+        from = to;
+    } else {
+        //port is input and has links, go editing mode
+        IntegralBusType* bt = new IntegralBusType(Descriptor(), QMap<Descriptor, DataTypePtr>());
+        bt->addInputs(p);
+        from = bt;
+    }
+    return from;
+}
+
+/*****************************
+* PrompterBaseImpl
+*****************************/
 QVariant PrompterBaseImpl::getParameter(const QString& id) {
     if (map.contains(id)) {
         return map.value(id);
     } else {
-        return target->getParameter(id)->value;
+        return target->getParameter(id)->getAttributePureValue();
     }
 }
 
-QString PrompterBaseImpl::getURL(const QString& id) {
+QString PrompterBaseImpl::getURL(const QString& id, bool * empty ) {
     QString url = getParameter(id).toString();
-    if (url.isEmpty()) {
+    if( empty != NULL ) { *empty = false; }
+    if( !target->getParameter(id)->getAttributeScript().isEmpty() ) {
+        url = "got from user script";
+    } else if (url.isEmpty()) {
         url = "<font color='red'>"+tr("unset")+"</font>";
+        if( empty != NULL ) { *empty = true; }
     } else if (url.indexOf(";") != -1) {
         url = tr("the list of files");
     } else {
@@ -210,14 +315,21 @@ QString PrompterBaseImpl::getRequiredParam(const QString& id) {
 }
 
 QString PrompterBaseImpl::getScreenedURL(BusPort* input, const QString& id, const QString& slot) {
-    Actor* origin = input->getProducer(slot);
-    QString url; 
-    if (origin) {
-        url = tr("file(s) alongside of input sources of <u>%1</u>").arg(origin->getLabel());
-    } else {
-        url = QString("<u>%1</u>").arg(getURL(id));
+    bool empty = false;
+    QString attrUrl = QString("<u>%1</u>").arg(getURL(id, &empty));
+    if( !empty ) {
+        return attrUrl;
     }
-    return url;
+    
+    Actor * origin = input->getProducer( slot );
+    QString slotUrl;
+    if( origin != NULL ) {
+        slotUrl = tr("file(s) alongside of input sources of <u>%1</u>").arg(origin->getLabel());
+        return slotUrl;
+    }
+    
+    assert( !attrUrl.isEmpty() );
+    return attrUrl;
 }
 
 QString PrompterBaseImpl::getProducers( const QString& port, const QString& slot )
