@@ -24,6 +24,8 @@ namespace GB2 {
 class Descriptor;
 class DocumentFormat;
 
+using namespace Workflow;
+
 class WCOREAPI_EXPORT DesignerUtils : public QObject {
     Q_OBJECT
 public:
@@ -44,9 +46,17 @@ public:
     static bool validate(const Workflow::Schema&, QList<QListWidgetItem*>* = NULL);
     //more common version of the above method. Uses *_REFs as keys. Does not create any icons
     static bool validate(const Workflow::Schema& s, QList<QMap<int, QVariant> >* infoList );
+    
+    static QList<Descriptor> findMatchingTypes(DataTypePtr set, DataTypePtr elementDataType);
+    static QStringList findMatchingTypesAsStringList(DataTypePtr set, DataTypePtr elementDatatype);
+    static QList<Descriptor> findMatchingCandidates(DataTypePtr from, DataTypePtr to, const Descriptor & key);
+    static QList<Descriptor> findMatchingCandidates(DataTypePtr from, DataTypePtr elementDatatype);
+    static Descriptor getCurrentMatchingDescriptor(const QList<Descriptor> & candidates, DataTypePtr to, const Descriptor & key,
+        const QStrStrMap & bindings);
+    static DataTypePtr getToDatatypeForBusport(BusPort * p);
+    static DataTypePtr getFromDatatypeForBusport(BusPort * p, DataTypePtr to);
 };
 
-using namespace Workflow;
 class WCOREAPI_EXPORT PrompterBaseImpl : public ActorDocument, public Prompter {
     Q_OBJECT
 public:
@@ -54,7 +64,7 @@ public:
 
     static bool isWildcardURL(const QString& url) {return url.indexOf(QRegExp("[*?\\[\\]]")) >= 0;}
 
-    QString getURL(const QString& id);
+    QString getURL(const QString& id, bool * empty = NULL );
     QString getScreenedURL(BusPort* input, const QString& id, const QString& slot);
     QString getRequiredParam(const QString& id);
     QVariant getParameter(const QString& id);
