@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -28,10 +28,7 @@ class GTest_AnnotatorSearch : public GTest {
 public:
 	SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_AnnotatorSearch, "plugin_dna-annotator-search");
 
-        ~GTest_AnnotatorSearch(){}
-	
 	void prepare();
-    void cleanup();
 	Task::ReportResult report();
 private:
 	QString seqName;
