@@ -10,7 +10,6 @@
 
 #include "CollocationWorker.h"
 
-#include <workflow/TypeSet.h>
 #include <workflow/IntegralBusModel.h>
 #include <workflow/WorkflowEnv.h>
 #include <workflow/WorkflowRegistry.h>
@@ -19,6 +18,7 @@
 #include <workflow_library/BioDatatypes.h>
 #include <workflow_library/BioActorLibrary.h>
 #include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
 
 #include <datatype/AnnotationData.h>
 #include <datatype/DNASequence.h>
@@ -35,13 +35,10 @@
 namespace GB2 {
 namespace LocalWorkflow {
 
-static const QString IN_PORT("in");
-static const QString OUT_PORT("out");
-
-static const QString NAME_ATTR("1name");
-static const QString ANN_ATTR("2annotations");
-static const QString LEN_ATTR("3minlen");
-static const QString FIT_ATTR("4mustfit");
+static const QString NAME_ATTR("a_name");
+static const QString ANN_ATTR("b_annotations");
+static const QString LEN_ATTR("c_minlen");
+static const QString FIT_ATTR("d_mustfit");
 
 const QString SEQ_SLOT = BioActorLibrary::SEQ_SLOT_ID;
 const QString FEATURE_TABLE_SLOT = BioActorLibrary::FEATURE_TABLE_SLOT_ID;
@@ -55,7 +52,7 @@ static LogCategory log(ULOG_CAT_WD);
 class CollocationValidator : public ConfigurationValidator {
 public:
     virtual bool validate(const Configuration* cfg, QStringList& output) const {
-        QString annotations = cfg->getParameter(ANN_ATTR)->value.toString();
+        QString annotations = cfg->getParameter(ANN_ATTR)->getAttributeValue<QString>();
         QSet<QString> names = QSet<QString>::fromList(annotations.split(QRegExp("\\W+"), QString::SkipEmptyParts));
         if (names.size() < 2) {
             output.append(CollocationWorker::tr("At least 2 annotations are required for collocation search."));
@@ -74,15 +71,15 @@ void CollocationWorkerFactory::init() {
         m[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
         m[BioActorLibrary::FEATURE_TABLE_SLOT()] = BioDataTypes::ANNOTATION_TABLE_LIST_TYPE();
     }
-    DataTypePtr inSet(new DataTypeSet(Descriptor("regioned.sequence"), m));
+    DataTypePtr inSet(new MapDataType(Descriptor("regioned.sequence"), m));
     DataTypeRegistry* dr = WorkflowEnv::getDataTypeRegistry();
     assert(dr);
     dr->registerEntry(inSet);
 
     QList<PortDescriptor*> p; QList<Attribute*> a;
-    p << new PortDescriptor(Descriptor(IN_PORT, CollocationWorker::tr("Input data"), CollocationWorker::tr("An input sequence and a set of annotations to search in.")), 
+    p << new PortDescriptor(Descriptor(CoreLibConstants::IN_PORT_ID, CollocationWorker::tr("Input data"), CollocationWorker::tr("An input sequence and a set of annotations to search in.")), 
         inSet, true /*input*/);
-    p << new PortDescriptor(Descriptor(OUT_PORT, CollocationWorker::tr("Group annotations"), CollocationWorker::tr("Annotated regions containing found collocations.")),
+    p << new PortDescriptor(Descriptor(CoreLibConstants::OUT_PORT_ID, CollocationWorker::tr("Group annotations"), CollocationWorker::tr("Annotated regions containing found collocations.")),
         BioDataTypes::ANNOTATION_TABLE_TYPE(), false /*input*/, true/*multi*/);
     
     {
@@ -116,10 +113,10 @@ void CollocationWorkerFactory::init() {
 }
 
 QString CollocationPrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(IN_PORT));
+    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
     Actor* seqProducer = input->getProducer(SEQ_SLOT);
     QString seqName = seqProducer ? tr(" sequence from <u>%1</u>").arg(seqProducer->getLabel()) : "";
-    QString annName = getProducers(IN_PORT, FEATURE_TABLE_SLOT);
+    QString annName = getProducers(CoreLibConstants::IN_PORT_ID, FEATURE_TABLE_SLOT);
     if (!annName.isEmpty()) {
         annName = tr(" set of annotations from <u>%1</u>").arg(annName);
     }
@@ -161,13 +158,8 @@ QString CollocationPrompter::composeRichDoc() {
 }
 
 void CollocationWorker::init() {
-    input = ports.value(IN_PORT);
-    output = ports.value(OUT_PORT);
-    cfg.distance = actor->getParameter(LEN_ATTR)->value.toInt();
-    cfg.st = actor->getParameter(FIT_ATTR)->value.toBool() ? CollocationsAlgorithm::NormalSearch : CollocationsAlgorithm::PartialSearch;
-    resultName = actor->getParameter(NAME_ATTR)->value.toString();
-    QString annotations = actor->getParameter(ANN_ATTR)->value.toString();
-    names = QSet<QString>::fromList(annotations.split(QRegExp("\\W+"), QString::SkipEmptyParts));
+    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    output = ports.value(CoreLibConstants::OUT_PORT_ID);
 }
 
 bool CollocationWorker::isReady() {
@@ -175,8 +167,16 @@ bool CollocationWorker::isReady() {
 }
 
 Task* CollocationWorker::tick() {
-    QVariantMap qm = input->get().getData().toMap();
+    Message inputMessage = getMessageAndSetupScriptValues(input);
+    cfg.distance = actor->getParameter(LEN_ATTR)->getAttributeValue<int>();
+    cfg.st = actor->getParameter(FIT_ATTR)->getAttributeValue<bool>() ? 
+        CollocationsAlgorithm::NormalSearch : CollocationsAlgorithm::PartialSearch;
+    resultName = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
+    QString annotations = actor->getParameter(ANN_ATTR)->getAttributeValue<QString>();
+    names = QSet<QString>::fromList(annotations.split(QRegExp("\\W+"), QString::SkipEmptyParts));
+    QVariantMap qm = inputMessage.getData().toMap();
     DNASequence seq = qm.value(SEQ_SLOT).value<DNASequence>();
+    
     QList<SharedAnnotationData> atl = QVariantUtils::var2ftl(qm.value(FEATURE_TABLE_SLOT).toList());
     if (!seq.isNull() && !atl.isEmpty()) {
         cfg.searchRegion.len = seq.length();
