@@ -103,7 +103,7 @@ void CollocationsDialogController::sl_plusClicked() {
         }            
         QColor c = asr->getAnnotationSettings(name)->color;
         QAction* a = m.addAction(GUIUtils::createSquareIcon(c, 10), name, this, SLOT(sl_addName()));
-        assert(a->parent() == &m);
+        assert(a->parent() == &m); Q_UNUSED(a);
     }
     if (m.isEmpty()) {
         m.addAction(tr("no_more_annotations_left"));
@@ -213,7 +213,7 @@ void CollocationsDialogController::sl_saveClicked() {
     }
     QList<SharedAnnotationData> list;
     for (int i=0, n = resultsList->count(); i<n; ++i) {
-        CDCResultItem* item = (CDCResultItem*)resultsList->item(i);
+        CDCResultItem* item = static_cast<CDCResultItem*>(resultsList->item(i));
         SharedAnnotationData data = m.data;
         data->location.append(item->r);
         data->complement = false;
@@ -262,7 +262,7 @@ void CollocationsDialogController::importResults() {
         CDCResultItem* item = new CDCResultItem(r);
         bool inserted = false;
         for(int i=0, n = resultsList->count(); i<n; i++) {
-            CDCResultItem* tmp = (CDCResultItem*)resultsList->item(i);
+            CDCResultItem* tmp = static_cast<CDCResultItem*>(resultsList->item(i));
             assert(!tmp->r.contains(r) && !r.contains(tmp->r));
             if (tmp->r.startPos > r.startPos) {
                 resultsList->insertItem(i, item);
@@ -278,7 +278,7 @@ void CollocationsDialogController::importResults() {
 
 void CollocationsDialogController::sl_onResultActivated(QListWidgetItem * item) {
     assert(item!=NULL);
-    CDCResultItem* ri = (CDCResultItem*)item;
+    CDCResultItem* ri = static_cast<CDCResultItem*>(item);
     Q_UNUSED(ri);
     //todo: add to selection?
     //ctx->getPanView()->setVisibleRange(ri->r);
