@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -12,23 +12,24 @@
 #define _GB2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
 
 #include "BioStruct3DGLRender.h"
+#include <QtOpenGL>
 
 namespace GB2 { 
 
 class BallAndStickGLRenderer : public BioStruct3DGLRenderer {
 
         
-    void drawAtoms(const BioStruct3DColorScheme* s);
+    void drawAtomsAndBonds();
     
-    void drawBonds(const BioStruct3DColorScheme* s);
-    
-    unsigned int atomDL;
+    QList<int> modelIndexList;
 
 public:
     
-	BallAndStickGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s); 
-	
+    BallAndStickGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s); 
+
     void drawBioStruct3D();
+    
+    void updateColorScheme();
 
     RENDERER_FACTORY(BallAndStickGLRenderer)
 
