@@ -29,6 +29,7 @@
 #include <core_api/DocumentModel.h>
 #include <core_api/Counter.h>
 #include <molecular_geometry/MolecularSurfaceFactoryRegistry.h>
+#include <molecular_geometry/MolecularSurface.h>
 #include <selection/DNASequenceSelection.h>
 #include <selection/AnnotationSelection.h>
 #include <time.h>
@@ -40,13 +41,16 @@
 #include "ExportImageDialog.h"
 #include "SettingsDialog.h"
 #include "MolecularSurfaceRenderer.h"
+
 #include "gl2ps/gl2ps.h"
 
+
 //disable "unsafe functions" deprecation warnings on MS VS
 #ifdef Q_OS_WIN
 #pragma warning(disable : 4996)
 #endif
 
+
 namespace GB2 { 
 
 static LogCategory log(ULOG_CAT_PLUGIN_BIOSTRUCT_3D);
@@ -54,10 +58,37 @@ static LogCategory logPerf(ULOG_CAT_PERFORMANCE);
 int BioStruct3DGLWidget::widgetCount = 0;
 
 
+static QColor DEFAULT_BACKGROUND_COLOR = Qt::black;
+static QColor DEFAULT_SELECTION_COLOR = Qt::yellow;
+
+static QColor DEFAULT_LEFT_EYE_COLOR(0, 255, 255);
+static QColor DEFAULT_RIGHT_EYE_COLOR = QColor(255, 0, 0);
+
+static int DEFAULT_RENDER_DETAIL_LEVEL = 100;
+static bool DEFAULT_ANAGLYPH = false;
+static int DEFAULT_EYES_SHIFT = 160;
+
 BioStruct3DGLWidget::BioStruct3DGLWidget(const BioStruct3DObject* obj, const AnnotatedDNAView* view, GLFrameManager* manager, QWidget *parent /* = 0*/)
     : QGLWidget(parent), biostruc(obj->getBioStruct3D()), biostrucDoc(obj->getDocument()),  
     dnaView(view), frameManager(manager), molSurface(NULL), currentModelID(obj->getBioStruct3D().pdbId), spinAngle(0), displayMenu(NULL)
 {
+    BACKGROUND_COLOR_NAME = QString("BackgroundColor");
+    PRODUCT_NAME = QString("Unipro Ugene");
+    PLUGIN_NAME = QString("BioStruct3D Viewer Plugin");
+    COLOR_SCHEME_NAME = QString("ColorScheme");
+    RENDERER_NAME = QString("GLRenderer");
+    OBJECT_ID_NAME = QString("OBJECT_ID");
+
+    SELECTION_COLOR_NAME = QString("SelectionColor");
+
+    LEFT_EYE_COLOR_NAME = QString("LeftEyeColor");
+    RIGHT_EYE_COLOR_NAME = QString("RightEyeColor");
+
+    RENDER_DETAIL_LEVEL_NAME = QString("RenderDetailLevel");
+    ANAGLYPH_NAME = QString("Anaglyph");
+    EYES_SHIFT_NAME = QString("EyesShift");
+
+
     GCOUNTER( cvar, tvar, "BioStruct3DGLWidget" );
     setObjectName(currentModelID + "-" + QString("%1").arg(++widgetCount));
     //TODO: ? setFormat(QGLFormat(QGL::DoubleBuffer | QGL::DepthBuffer));
@@ -68,21 +99,33 @@ BioStruct3DGLWidget::BioStruct3DGLWidget(const BioStruct3DObject* obj, const Ann
     createActions();
     createMenus();
     connectExternalSignals();
-    backgroundColor = Qt::black;
-    selectionColor = Qt::yellow;
+    backgroundColor = DEFAULT_BACKGROUND_COLOR;
+    selectionColor = DEFAULT_SELECTION_COLOR;
+
+    anaglyph = DEFAULT_ANAGLYPH;
+    eyesShift = DEFAULT_EYES_SHIFT;
+
+    leftEyeColor = DEFAULT_LEFT_EYE_COLOR;
+    rightEyeColor = DEFAULT_RIGHT_EYE_COLOR;
+
+    renderDetailLevel = DEFAULT_RENDER_DETAIL_LEVEL;
+
+    emptyTextureData = NULL;
+
     chainIdCache.clear();
-    
+
     // Load renderers and color schemes
     loadColorSchemes();
     loadGLRenderers();
-    
+
     // Set view settings
     float scaleFactor = 2.5;
-    cameraDistance = scaleFactor * biostruc.getMaxDistFromCenter();
-    cameraClipNear = (cameraDistance - biostruc.getMaxDistFromCenter()) * 0.66f;
-    cameraClipFar = (cameraDistance + biostruc.getMaxDistFromCenter()) * 1.2f; 
-        
-    glFrame.reset( new GLFrame(this, cameraClipNear, cameraClipFar) );
+    float camZ = scaleFactor * biostruc.getMaxDistFromCenter();
+
+    cameraClipNear = (camZ - biostruc.getMaxDistFromCenter()) * 0.66f;
+    cameraClipFar = (camZ + biostruc.getMaxDistFromCenter()) * 1.2f; 
+
+    glFrame.reset( new GLFrame(this, cameraClipNear, cameraClipFar, camZ) );
     frameManager->addGLFrame(glFrame.get());
     saveDefaultSettings();
 }
@@ -117,8 +160,10 @@ void BioStruct3DGLWidget::initializeGL()
     GLfloat light_diffuse[] = { 0.8f, 0.8f, 0.8f, 1.0 };
     GLfloat light_specular[] = { 0.6f, 0.6f, 0.6f, 1.0 };
     GLfloat mat_specular[] = { 0.6f, 0.6f, 0.6f, 1.0 };
-	GLfloat mat_shininess[] = { 90.0 };
-    DisplayLists::createAtomDisplayList();
+    GLfloat mat_shininess[] = { 90.0 };
+
+    DisplayLists::createBigDisplayList(getRenderDetailLevel(), biostruc, activeModelIndexList, &(*colorScheme));
+
     qglClearColor(backgroundColor);
     glShadeModel (GL_SMOOTH);
     glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
@@ -126,17 +171,27 @@ void BioStruct3DGLWidget::initializeGL()
     glLightfv(GL_LIGHT0, GL_DIFFUSE, light_diffuse);
     glLightfv(GL_LIGHT0, GL_SPECULAR, light_specular);
     glLightfv(GL_LIGHT0, GL_POSITION, lightPostion);
-    glEnable(GL_NORMALIZE);
-    glEnable(GL_LIGHTING);
-    glEnable(GL_LIGHT0);
-    glEnable(GL_DEPTH_TEST);
+//    glEnable(GL_NORMALIZE);
+	glEnable(GL_BLEND);                                         // Enable Blending
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-    
+
+	// Disable AutoTexture Coordinates
+//	glDisable(GL_TEXTURE_GEN_S);
+//	glDisable(GL_TEXTURE_GEN_T);
 }
 
 void BioStruct3DGLWidget::resizeGL(int width, int height)
 {
-   glFrame->updateViewPort(width, height);
+	glDeleteTextures(1, &anaglyphRenderTextureLeft);
+	glDeleteTextures(1, &anaglyphRenderTextureRight);
+	glDeleteTextures(1, &tempAnaglyphRenderTexture);
+
+    anaglyphRenderTextureLeft = getEmptyTexture(height, width);
+    anaglyphRenderTextureRight = getEmptyTexture(height, width);
+
+    tempAnaglyphRenderTexture =  getEmptyTexture(height, width);
+
+    glFrame->updateViewPort(width, height);
 }
 
 void BioStruct3DGLWidget::paintGL()
@@ -149,75 +204,222 @@ void BioStruct3DGLWidget::paintGL()
 
 void BioStruct3DGLWidget::mousePressEvent(QMouseEvent *event)
 {
-	lastPos = getTrackballMapping(event->x(), event->y());
+    lastPos = getTrackballMapping(event->x(), event->y());
 }
 
 void BioStruct3DGLWidget::mouseMoveEvent(QMouseEvent *event)
 {
     Vector3D rotCenter = biostruc.getCenter();
-	
-	if (event->buttons() & Qt::LeftButton) {
-		Vector3D curPos = getTrackballMapping(event->x(), event->y());
-		Vector3D delta = curPos - lastPos;
-		if (delta.x || delta.y || delta.z) {
-			rotAngle = 90.0f*delta.length();
-			rotAxis =  vector_cross(lastPos,curPos); 
+
+    if (event->buttons() & Qt::LeftButton) {
+        Vector3D curPos = getTrackballMapping(event->x(), event->y());
+        Vector3D delta = curPos - lastPos;
+
+        if (delta.x || delta.y || delta.z) {
+            rotAngle = 90.0f*delta.length();
+            rotAxis =  vector_cross(lastPos,curPos);
+
             bool syncLock = isSyncModeOn();
             QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.get(), syncLock);
             foreach( GLFrame* frame, frames) {
                 frame->makeCurrent();
-                frame->rotateCamera(rotAxis, rotAngle);
+
+                if (event->modifiers() & Qt::CTRL)
+                    frame->performShift(delta.x, delta.y);
+                else
+                    frame->rotateCamera(rotAxis, rotAngle);
+
                 frame->updateGL();
-            } 
+            }
         }
-		lastPos = curPos;
-	}
- 
+
+        lastPos = curPos;
+    }
 }
 
-
-void BioStruct3DGLWidget::draw()
+float BioStruct3DGLWidget::getEyesShiftMult() const
 {
+    return eyesShift/100.0f;
+}
+
+float BioStruct3DGLWidget::getRenderDetailLevel() const
+{
+    return renderDetailLevel/100.0f;
+}
+
+void BioStruct3DGLWidget::ViewOrtho()                                               // Set Up An Ortho View
+{
+    glMatrixMode(GL_PROJECTION);                                // Select Projection
+    glPushMatrix();                                             // Push The Matrix
+    glLoadIdentity();                                           // Reset The Matrix
+    glOrtho( 0, width() , height(), 0, -1, 1 );                         // Select Ortho Mode (640x480)
+    glMatrixMode(GL_MODELVIEW);                                 // Select Modelview Matrix
+    glPushMatrix();                                             // Push The Matrix
+    glLoadIdentity();                                           // Reset The Matrix
+}
+
+void BioStruct3DGLWidget::ViewPerspective()                                         // Set Up A Perspective View
+{
+    glMatrixMode( GL_PROJECTION );                              // Select Projection
+    glPopMatrix();                                              // Pop The Matrix
+    glMatrixMode( GL_MODELVIEW );                               // Select Modelview
+    glPopMatrix();                                              // Pop The Matrix
+}
+
+GLuint BioStruct3DGLWidget::getEmptyTexture(int textureHeight, int textureWidth)    // Create An Empty Texture
+{
+    GLuint txtnumber;                                           // Texture ID
+
+    glGenTextures(1, &txtnumber);                               // Create 1 Texture
+    glBindTexture(GL_TEXTURE_2D, txtnumber);                    // Bind The Texture
+    glTexImage2D(GL_TEXTURE_2D, 0, 4, textureWidth, textureHeight, 0,
+    GL_RGBA, GL_UNSIGNED_BYTE, emptyTextureData);                       // Build Texture Using Information In data
+    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
+    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
+
+    return txtnumber;                                           // Return The Texture ID
+}
+
+void BioStruct3DGLWidget::drawTexturesAnaglypth(GLuint anaglyphRenderTextureLeft, GLuint anaglyphRenderTextureRight)                                // Draw The Image
+{
+    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);      //clear color and depth buffers
+    drawTexture(anaglyphRenderTextureLeft, rightEyeColor.red(), rightEyeColor.green(), rightEyeColor.blue(), 0.5f, false); // colored left image
+
+    glBindTexture(GL_TEXTURE_2D, tempAnaglyphRenderTexture);                    // Bind To The Blur Texture
+    glCopyTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 0, 0, width(), height(), 0);// Copy Our ViewPort To The Blur Texture (From 0,0 To 128,128... No Border)
+
+    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);      //clear color and depth buffers
+    drawTexture(anaglyphRenderTextureRight, leftEyeColor.red(), leftEyeColor.green(), leftEyeColor.blue(), 0.5f, false); // colored right image
+
+    drawTexture(tempAnaglyphRenderTexture, 255, 255, 255, 1.0f, true);
+}
+
+void BioStruct3DGLWidget::drawTexture(GLuint anaglyphRenderTexture, int red, int green, int blue, float alpha, bool alphaOnly)                              // Draw The Blurred Image
+{
+	glEnable(GL_TEXTURE_2D);                                    // Enable 2D Texture Mapping
+
+    if (alphaOnly){
+        glBlendFunc(GL_ALPHA, GL_ALPHA);
+    }
+    else {
+        glBlendFunc(GL_ONE, GL_ONE);
+    }
+
+//    glEnable(GL_BLEND);                                         // Enable Blending
+    glBindTexture(GL_TEXTURE_2D, anaglyphRenderTexture);                    // Bind To The Blur Texture
+    ViewOrtho();                                                // Switch To An Ortho View
+
+    glColor4f((float)red/255, (float)green/255, (float)blue/255, alpha);                    // Set The Alpha Value (Starts At 0.2)
+    glBegin(GL_QUADS);                                          // Begin Drawing Quads
+        glTexCoord2f(0, 1);                     // Texture Coordinate   ( 0, 1 )
+        glVertex2f(0,0);                                    // First Vertex     (   0,   0 )
+
+        glTexCoord2f(0, 0);                     // Texture Coordinate   ( 0, 0 )
+        glVertex2f(0, (float)height());                                 // Second Vertex    (   0, 480 )
+
+        glTexCoord2f(1, 0);                     // Texture Coordinate   ( 1, 0 )
+        glVertex2f((float)width(), (float)height());                                // Third Vertex     ( 640, 480 )
+
+        glTexCoord2f(1, 1);                     // Texture Coordinate   ( 1, 1 )
+        glVertex2f((float)width(), 0);                                  // Fourth Vertex    ( 640,   0 )
+    glEnd();                                                    // Done Drawing Quads
+
+    ViewPerspective();                                          // Switch To A Perspective View
+
+    glDisable(GL_TEXTURE_2D);                                   // Disable 2D Texture Mapping
+//    glDisable(GL_BLEND);                                        // Disable Blending
+    glBindTexture(GL_TEXTURE_2D,0);                             // Unbind The Blur Texture
+}
+
+void BioStruct3DGLWidget::drawAll()
+{
+	glEnable(GL_DEPTH_TEST);                                    // Enable Depth Testing
+
+	glEnable(GL_LIGHTING);
+	glEnable(GL_LIGHT0);
+
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
     Vector3D rotCenter = biostruc.getCenter();
-    glMatrixMode(GL_MODELVIEW);
-	glLoadIdentity(); 
-    gluLookAt(0.0, 0.0, cameraDistance, 0,  0, 0, 0.0, 1.0, 0.0);
+
+    glTranslatef(glFrame->getCameraPosition().x, glFrame->getCameraPosition().y, 0);
+
     glMultMatrixf(glFrame->getRotationMatrix() );
     glTranslatef(-rotCenter.x ,-rotCenter.y, -rotCenter.z);
     clock_t t1 =  clock();
+
     biostructRenderer->drawBioStruct3D();
+
     if(NULL != molSurface.get())
     {
-        glEnable(GL_BLEND);
-        glEnable(GL_BLEND);
+//        glEnable(GL_BLEND);
+//        glEnable(GL_BLEND);
         glEnable(GL_CULL_FACE);
         glCullFace(GL_FRONT);
         surfaceRenderer->drawSurface(*molSurface);
         glCullFace(GL_BACK);
         surfaceRenderer->drawSurface(*molSurface);
         glDisable(GL_CULL_FACE);
-        glDisable(GL_BLEND);
+//        glDisable(GL_BLEND);
     }
+
+	glDisable(GL_LIGHTING);
+	glDisable(GL_LIGHT0);
+	glDisable(GL_DEPTH_TEST);                                   // Disable Depth Testing
+
     clock_t t2 = clock();
     logPerf.trace("BioStruct3D structure rendering time " + QString::number((float)( t2 - t1)/ CLOCKS_PER_SEC)+ " s");
+}
 
-    
+
+void BioStruct3DGLWidget::draw()
+{
+    float eyesShift = 5*getEyesShiftMult()*glFrame->getCameraPosition().z/200;
+
+    glMatrixMode(GL_MODELVIEW);
+    glLoadIdentity();
+
+    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);      //clear color and depth buffers
+
+    if (!anaglyph)
+    {
+        gluLookAt(0.0, 0.0, glFrame->getCameraPosition().z, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);
+        drawAll();
+    }
+    else
+    {
+        gluLookAt(eyesShift, 0.0, glFrame->getCameraPosition().z, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);
+        drawAll();
+
+        glBindTexture(GL_TEXTURE_2D, anaglyphRenderTextureRight);                   // Bind To The Anaglyph Texture
+        glCopyTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 0, 0, width(), height(), 0);// Copy Our ViewPort To The Blur Texture (From 0,0 To 128,128... No Border)
+
+        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+        glLoadIdentity();
+
+        gluLookAt(-eyesShift, 0.0, glFrame->getCameraPosition().z, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);
+        drawAll();
+
+        glBindTexture(GL_TEXTURE_2D, anaglyphRenderTextureLeft);                    // Bind To The Anaglyph Texture
+        glCopyTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 0, 0, width(), height(), 0);// Copy Our ViewPort To The Blur Texture (From 0,0 To 128,128... No Border)
+
+        drawTexturesAnaglypth(anaglyphRenderTextureLeft, anaglyphRenderTextureRight);
+    }
 }
 
 Vector3D BioStruct3DGLWidget::getTrackballMapping(int x, int y)
 {
     Vector3D pos;
-	/* project x,y onto a hemisphere centered within width, height */
-	pos.x = (2.0f*x - width()) / width();
-	pos.y = (height() - 2.0f*y) / height();
-	pos.z = 0;
-	float d = pos.length();
-	d = (d < 1.0) ? d : 1.0;
-	pos.z = sqrtf(1.0f - d*d);
-	pos.normalize();
-
-	return pos;
+    /* project x,y onto a hemisphere centered within width, height */
+    pos.x = (2.0f*x - width()) / width();
+    pos.y = (height() - 2.0f*y) / height();
+    pos.z = 0;
+    float d = pos.length();
+    d = (d < 1.0) ? d : 1.0;
+    pos.z = sqrtf(1.0f - d*d);
+    pos.normalize();
 
+    return pos;
 } 
 
 
@@ -231,11 +433,11 @@ void BioStruct3DGLWidget::createActions()
 {
 
     QAction* action = NULL;
-    
+
     animationTimer = new QTimer(this);
     animationTimer->setInterval(20); // fixed interval
     connect(animationTimer, SIGNAL(timeout()), this, SLOT(sl_updateAnnimation()));
-    
+
     rendererActions = new QActionGroup(this);
     connect(rendererActions, SIGNAL(triggered(QAction *)), this, SLOT(sl_selectGLRenderer(QAction *)));
     foreach(QString key, rendererFactoryMap.keys()) {
@@ -243,13 +445,13 @@ void BioStruct3DGLWidget::createActions()
         action->setCheckable(true);
     }
 
-    colorSchemeActions = new QActionGroup(this);	
-	connect(colorSchemeActions, SIGNAL(triggered(QAction *)), this, SLOT(sl_selectColorScheme(QAction *)));
+    colorSchemeActions = new QActionGroup(this);    
+    connect(colorSchemeActions, SIGNAL(triggered(QAction *)), this, SLOT(sl_selectColorScheme(QAction *)));
     foreach(QString key, colorSchemeFactoryMap.keys()) {
         action = new QAction(key, colorSchemeActions);
         action->setCheckable(true);
     }   
-    
+
     molSurfaceRenderActions = new QActionGroup(this);
     connect(molSurfaceRenderActions, SIGNAL(triggered(QAction *)), this, SLOT(sl_selectSurfaceRenderer(QAction*)));
     foreach(QString key, surfaceRendererFactoryMap.keys()) {
@@ -271,11 +473,11 @@ void BioStruct3DGLWidget::createActions()
     connect(action, SIGNAL(triggered()), this, SLOT(sl_hideSurface()));
     action->setCheckable(true);
     action->setChecked(true);
-    
+
     spinAction = new QAction(tr("Spin"), this);
     spinAction->setCheckable(true);
     connect(spinAction, SIGNAL(triggered()), this, SLOT(sl_acitvateSpin()));
-    
+
     settingsAction = new QAction(tr("Settings"), this);
     connect(settingsAction, SIGNAL(triggered()), this, SLOT(sl_settings()));
 
@@ -297,6 +499,9 @@ void BioStruct3DGLWidget::createActions()
         connect(setAllModelsActiveAction, SIGNAL(triggered()), this, SLOT(sl_setAllModelsActive()));
         setAllModelsActiveAction->setChecked(true);
     }
+
+    connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task*)), SLOT(sl_onTaskFinished(Task*)));
+
 }
 
 void BioStruct3DGLWidget::createMenus()
@@ -307,7 +512,7 @@ void BioStruct3DGLWidget::createMenus()
     
     // Color scheme selection
     selectColorSchemeMenu = new QMenu(tr("Color Scheme"));
-	selectColorSchemeMenu->addActions(colorSchemeActions->actions());
+    selectColorSchemeMenu->addActions(colorSchemeActions->actions());
     
     // Molecular surface
     QMenu* surfaceMenu = new QMenu(tr("Molecular Surface Render Style"));
@@ -363,22 +568,23 @@ void BioStruct3DGLWidget::connectExternalSignals()
 
 void BioStruct3DGLWidget::setBioStruct3DColorScheme( BioStruct3DColorScheme* clScheme )
 {
-	Q_ASSERT(clScheme != NULL);
-	biostructRenderer->setColorScheme(clScheme);
+    Q_ASSERT(clScheme != NULL);
+    biostructRenderer->setColorScheme(clScheme);
     colorScheme.reset(clScheme);
-   
+    
+    
 }
 
 void BioStruct3DGLWidget::setBioStruct3DRenderer( BioStruct3DGLRenderer* r )
 {
-	Q_ASSERT(r != NULL);
-	biostructRenderer.reset(r);
+    Q_ASSERT(r != NULL);
+    biostructRenderer.reset(r);
 
 }
 
 void BioStruct3DGLWidget::contextMenuEvent( QContextMenuEvent *event )
 {
-	QMenu menu;
+    QMenu menu;
     
     foreach(QAction* action, getDisplayMenu()->actions()) {
         menu.addAction(action);
@@ -386,20 +592,22 @@ void BioStruct3DGLWidget::contextMenuEvent( QContextMenuEvent *event )
 
     menu.addAction(closeAction);
 
-	menu.exec(event->globalPos());
+    menu.exec(event->globalPos());
 }
 
 void BioStruct3DGLWidget::sl_selectColorScheme(QAction* action)
 {
-	BioStruct3DColorScheme* colorScheme = NULL;
-	QString schemeName = action->text();
+    BioStruct3DColorScheme* colorScheme = NULL;
+    QString schemeName = action->text();
     colorScheme = createCustomColorScheme(schemeName);
-	Q_ASSERT(colorScheme != NULL);
-        colorScheme->setSelectionColor(selectionColor);
-	setBioStruct3DColorScheme(colorScheme);
+    Q_ASSERT(colorScheme != NULL);
+    colorScheme->setSelectionColor(selectionColor);
+    setBioStruct3DColorScheme(colorScheme);
     currentColorSchemeName = schemeName;
- 	updateGL();
-		
+    GLFrame* frame = frameManager->getGLWidgetFrame(this);
+    frame->makeCurrent();
+    frame->updateGL();
+        
 }
 
 void BioStruct3DGLWidget::sl_updateRenderSettings(const QStringList& list )
@@ -438,21 +646,21 @@ const QMap<int, QColor> BioStruct3DGLWidget::getChainColors() const
     QMap<int, QColor> colorMap;
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
     
-	foreach (GObject* obj, biostrucDoc->getObjects() ) {
-		if (obj->getGObjectType() == GObjectTypes::ANNOTATION_TABLE) {
-			AnnotationTableObject* ao = qobject_cast<AnnotationTableObject*>(obj);
- 			foreach(Annotation* a, ao->getAnnotations()) {
- 				QString name = a->getAnnotationName();
- 				if (name.startsWith(BioStruct3D::MoleculeAnnotationTag)) {
-					int chainId = getQualifierValueByName(a, BioStruct3D::ChainIdQualifierName).toInt();
+    foreach (GObject* obj, biostrucDoc->getObjects() ) {
+        if (obj->getGObjectType() == GObjectTypes::ANNOTATION_TABLE) {
+            AnnotationTableObject* ao = qobject_cast<AnnotationTableObject*>(obj);
+            foreach(Annotation* a, ao->getAnnotations()) {
+                QString name = a->getAnnotationName();
+                if (name.startsWith(BioStruct3D::MoleculeAnnotationTag)) {
+                    int chainId = getQualifierValueByName(a, BioStruct3D::ChainIdQualifierName).toInt();
                     Q_ASSERT(chainId != 0);
                     AnnotationSettings* as = asr->getAnnotationSettings(name);
-                    colorMap.insert(chainId, as->color);				
- 				}
- 			}
-		}
- 	}
-	
+                    colorMap.insert(chainId, as->color);
+                }
+            }
+        }
+    }
+    
     return colorMap;
 }
 
@@ -463,7 +671,10 @@ void BioStruct3DGLWidget::sl_selectGLRenderer( QAction* action )
     Q_ASSERT(renderer != NULL);
     setBioStruct3DRenderer(renderer);
     currentGLRendererName = rendererName;
-    updateGL();
+    renderer->updateColorScheme();
+    GLFrame* frame = frameManager->getGLWidgetFrame(this);
+    frame->makeCurrent();
+    frame->updateGL();
 }
 
 void BioStruct3DGLWidget::setLightPosition( const Vector3D& pos )
@@ -553,31 +764,31 @@ void BioStruct3DGLWidget::sl_onAnnotationSelectionChanged( AnnotationSelection*
     QList<LRegion> empty;
     QList<GObject*> seqObjects = dnaView->getSequenceGObjectsWithContexts();
 
-	foreach (Annotation* annotation, added) {
+    foreach (Annotation* annotation, added) {
         if (annotation->getLocation().isEmpty()) { //TODO: there must be no such annotations!
             continue;
         }
 
-		AnnotationTableObject* ao = annotation->getGObject();
+        AnnotationTableObject* ao = annotation->getGObject();
         int chainId  = getChainIdForAnnotationObject(ao);
         if (chainId!=-1) {
-		    Q_ASSERT(biostruc.moleculeMap.contains(chainId));
-		    colorScheme->updateSelectionRegion(chainId, annotation->getLocation(), empty );
+            Q_ASSERT(biostruc.moleculeMap.contains(chainId));
+            colorScheme->updateSelectionRegion(chainId, annotation->getLocation(), empty );
         }
     }
-  
+
     foreach (Annotation* annotation, removed) {
         if (annotation->getLocation().isEmpty() ) { //TODO: there must be no such annotations!
-           continue;
+            continue;
+        }
+        AnnotationTableObject* ao = annotation->getGObject();
+        int chainId  = getChainIdForAnnotationObject(ao);
+        if (chainId!=-1) {
+            Q_ASSERT(biostruc.moleculeMap.contains(chainId));
+            colorScheme->updateSelectionRegion(chainId, empty, annotation->getLocation());
         }
-	   AnnotationTableObject* ao = annotation->getGObject(); 
-	   int chainId  = getChainIdForAnnotationObject(ao);
-       if (chainId!=-1) {
-           Q_ASSERT(biostruc.moleculeMap.contains(chainId));
-           colorScheme->updateSelectionRegion(chainId, empty, annotation->getLocation());
-       }
     }
-    
+
     biostructRenderer->updateColorScheme();
     update();
 }
@@ -608,31 +819,57 @@ void BioStruct3DGLWidget::sl_updateAnnimation()
 {
     static float velocity = 0.05f;
     spinAngle = velocity* animationTimer->interval();
-    glMatrixMode(GL_MODELVIEW);
-    glLoadIdentity();
-    glRotatef(spinAngle, 0, 1, 0 );
-    glMultMatrixf(glFrame->getRotationMatrix());
-    glGetFloatv( GL_MODELVIEW_MATRIX, glFrame->getRotationMatrix());
+    Vector3D rotAxis(0,1,0);
+    bool syncLock = isSyncModeOn();
+    QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.get(), syncLock);
+    
+    foreach( GLFrame* frame, frames) {
+        frame->makeCurrent();
+        frame->rotateCamera(rotAxis, spinAngle);
+        frame->updateGL();
+        //glGetFloatv( GL_MODELVIEW_MATRIX, frame->getRotationMatrix());
+    }
     updateGL();
 }
 
+/*
+#define BACKGROUND_COLOR_NAME "BackgroundColor"
 #define PRODUCT_NAME "Unipro Ugene"
 #define PLUGIN_NAME "BioStruct3D Viewer Plugin"
 #define COLOR_SCHEME_NAME "ColorScheme"
 #define RENDERER_NAME "GLRenderer"
 #define OBJECT_ID_NAME "OBJECT_ID"
 
+#define SELECTION_COLOR_NAME "SelectionColor"
+
+#define LEFT_EYE_COLOR_NAME "LeftEyeColor"
+#define RIGHT_EYE_COLOR_NAME "RightEyeColor"
+
+#define RENDER_DETAIL_LEVEL_NAME "RenderDetailLevel"
+#define ANAGLYPH_NAME "Anaglyph"
+#define EYES_SHIFT_NAME "EyesShift"
+*/
 
 QVariantMap BioStruct3DGLWidget::getState()
 {
     QVariantMap state;
     glFrame->writeStateToMap(state);
+
     state[COLOR_SCHEME_NAME] = QVariant::fromValue(currentColorSchemeName);
     state[RENDERER_NAME] = QVariant::fromValue(currentGLRendererName);
     state[OBJECT_ID_NAME] = QVariant::fromValue(getBioStruct3DObjectName());
 
-    return state;
+    state[BACKGROUND_COLOR_NAME] = QVariant::fromValue(backgroundColor);
+    state[SELECTION_COLOR_NAME] = QVariant::fromValue(selectionColor);
 
+    state[LEFT_EYE_COLOR_NAME] = QVariant::fromValue(leftEyeColor);
+    state[RIGHT_EYE_COLOR_NAME] = QVariant::fromValue(rightEyeColor);
+
+    state[RENDER_DETAIL_LEVEL_NAME] = QVariant::fromValue(renderDetailLevel);
+    state[ANAGLYPH_NAME] = QVariant::fromValue(anaglyph);
+    state[EYES_SHIFT_NAME] = QVariant::fromValue(eyesShift);
+
+    return state;
 }
 
 void BioStruct3DGLWidget::setState( const QVariantMap& state )
@@ -642,15 +879,36 @@ void BioStruct3DGLWidget::setState( const QVariantMap& state )
         return;
     }
     glFrame->setState(state);
+
+    backgroundColor = state.value(BACKGROUND_COLOR_NAME, DEFAULT_BACKGROUND_COLOR).value<QColor>();
+    setBackgroundColor(backgroundColor);
     
+    selectionColor = state.value(SELECTION_COLOR_NAME, DEFAULT_SELECTION_COLOR).value<QColor>();
+
+    leftEyeColor = state.value(LEFT_EYE_COLOR_NAME, DEFAULT_LEFT_EYE_COLOR).value<QColor>();
+    rightEyeColor = state.value(RIGHT_EYE_COLOR_NAME, DEFAULT_RIGHT_EYE_COLOR).value<QColor>();
+
+    renderDetailLevel = state.value(RENDER_DETAIL_LEVEL_NAME, DEFAULT_RENDER_DETAIL_LEVEL).value<int>();
+    anaglyph = state.value(ANAGLYPH_NAME, DEFAULT_ANAGLYPH).value<bool>();
+    eyesShift = state.value(EYES_SHIFT_NAME, DEFAULT_EYES_SHIFT).value<int>();
+
+
+    QString previousColorSchemeName = currentColorSchemeName;
+    QString previousGLRendererName = currentGLRendererName;
+
     currentColorSchemeName = state.value(COLOR_SCHEME_NAME, BioStruct3DColorSchemeFactory::defaultFactoryName()).value<QString>();
     currentGLRendererName = state.value(RENDERER_NAME, BioStruct3DGLRendererFactory::defaultFactoryName()).value<QString>();
-    
-    setBioStruct3DColorScheme(createCustomColorScheme(currentColorSchemeName));
-    setBioStruct3DRenderer(createCustomRenderer(currentGLRendererName));
+
+    if (previousColorSchemeName!=currentColorSchemeName){
+        setBioStruct3DColorScheme(createCustomColorScheme(currentColorSchemeName));
+    }
+
+    if (previousGLRendererName!=currentGLRendererName){
+        setBioStruct3DRenderer(createCustomRenderer(currentGLRendererName));
+    }
+
     resizeGL(width(), height());
     updateGL();
-
 }
 
 const QString BioStruct3DGLWidget::getBioStruct3DObjectName() const
@@ -663,20 +921,53 @@ const QString BioStruct3DGLWidget::getBioStruct3DObjectName() const
     return ""; 
 }
 
+void BioStruct3DGLWidget::setBackgroundColor(QColor backgroundColor)
+{
+    this->backgroundColor=backgroundColor;
+    qglClearColor(backgroundColor);
+}
+
 void BioStruct3DGLWidget::sl_settings()
 {
-    SettingsDialog dialog;
+    BioStruct3DSettingsDialog dialog;
+
+    dialog.setWidget(this);
+
     dialog.setBackgroundColor(backgroundColor);
     dialog.setSelectionColor(selectionColor);
-    if(QDialog::Accepted == dialog.exec())
+    dialog.setRenderDetailLevel(renderDetailLevel);
+
+    dialog.setAnaglyph(anaglyph);
+    dialog.setEyesShift(eyesShift);
+    dialog.setGlassesColorScheme(leftEyeColor, rightEyeColor);
+
+    QVariantMap previousState = getState();
+
+    if (QDialog::Accepted == dialog.exec())
     {
         backgroundColor=dialog.getBackgroundColor();
         selectionColor=dialog.getSelectionColor();
         colorScheme->setSelectionColor(selectionColor);
+        renderDetailLevel=dialog.getRenderDetailLevel();
+        anaglyph = dialog.getAnaglyph();
+
+        eyesShift = dialog.getEyesShift();
+
+        leftEyeColor = dialog.getLeftEyeColor();
+        rightEyeColor = dialog.getRightEyeColor();
+
         this->makeCurrent();
-        qglClearColor(backgroundColor);
+        setBackgroundColor(backgroundColor);
+
+//        DisplayLists::createAtomDisplayList(getRenderDetailLevel());
+		DisplayLists::createBigDisplayList(getRenderDetailLevel(), biostruc, activeModelIndexList, &(*colorScheme));
         updateGL();
     }
+    else
+    {
+        setState(previousState);
+    }
+
 }
 
 void BioStruct3DGLWidget::sl_closeWidget()
@@ -705,6 +996,18 @@ void BioStruct3DGLWidget::zoom( float delta )
     } 
 }
 
+void BioStruct3DGLWidget::shift( float deltaX, float deltaY)
+{
+    bool syncLock = isSyncModeOn();
+    QList<GLFrame*> frames = frameManager->getActiveGLFrameList(glFrame.get(), syncLock);
+    foreach( GLFrame* frame, frames) {
+        frame->makeCurrent();
+        frame->performShift(deltaX, deltaY);
+        frame->updateViewPort();
+        frame->updateGL();
+    } 
+}
+
 void BioStruct3DGLWidget::saveDefaultSettings()
 {
     glFrame->writeStateToMap(defaultsSettings);
@@ -905,24 +1208,17 @@ bool BioStruct3DGLWidget::isSyncModeOn()
 
 void BioStruct3DGLWidget::sl_showSurface()
 {
-    {
-        // Calculate surface (only one model! too much computation for all models)
-        {
-            MolecularSurfaceFactory *factory=
-                    AppContext::getMolecularSurfaceFactoryRegistry()->getSurfaceFactory(qobject_cast<QAction *>(sender())->text());
-            molSurface.reset(factory->createInstance());
-        }
-        QList<SharedAtom> atoms;
-        int index = getActiveModelIndexList().first();
-        foreach (const SharedMolecule mol, biostruc.moleculeMap) {
-            const Molecule3DModel& model = mol->models.at(index);
-            atoms += model.atoms;
-        }
-        molSurface->calculate(atoms);
+    QList<SharedAtom> atoms;
+    int index = getActiveModelIndexList().first();
+    foreach (const SharedMolecule mol, biostruc.moleculeMap) {
+        const Molecule3DModel& model = mol->models.at(index);
+        atoms += model.atoms;
     }
-    
-    makeCurrent();
-    updateGL();
+
+    QString surfaceType = qobject_cast<QAction *>( sender() )->text();
+    surfaceCalcTask = new MolecularSurfaceCalcTask(surfaceType, atoms);
+    AppContext::getTaskScheduler()->registerTopLevelTask(surfaceCalcTask);
+
 }
 
 void BioStruct3DGLWidget::sl_hideSurface()
@@ -944,4 +1240,19 @@ void BioStruct3DGLWidget::sl_selectSurfaceRenderer(QAction*  action)
     updateGL();
 }
 
+void BioStruct3DGLWidget::sl_onTaskFinished( Task* task )
+{
+    if ( surfaceCalcTask != task || surfaceCalcTask->getState()!= Task::State_Finished) {
+        return;
+    }
+
+    molSurface.reset();
+    molSurface = surfaceCalcTask->getCalculatedSurface();
+
+    makeCurrent();
+    updateGL();
+
+
+}
+
 } //namespace
