@@ -18,6 +18,7 @@
 #include <QtGui/QColor>
 #include <QtCore/QTimer>
 
+
 #include <core_api/Vector3D.h>
 #include <core_api/LRegion.h>
 #include <memory>
@@ -37,6 +38,8 @@ class MolecularSurfaceRendererFactory;
 class AnnotatedDNAView;
 class Annotation;
 class AnnotationTableObject;
+class MolecularSurfaceCalcTask;
+class Task;
 class AnnotationSelection;
 class DNASequenceObject;
 class ADVSequenceObjectContext;
@@ -63,10 +66,28 @@ class MolecularSurfaceRenderer;
 class BioStruct3DGLWidget : public QGLWidget
 {
     Q_OBJECT
-	static const int GL_MATRIX_SIZE = 16;
-	static int widgetCount;
+    static const int GL_MATRIX_SIZE = 16;
+    static int widgetCount;
 
 public:
+    QString BACKGROUND_COLOR_NAME;
+
+    QString PRODUCT_NAME;
+    QString PLUGIN_NAME;
+    QString COLOR_SCHEME_NAME;
+    QString RENDERER_NAME;
+    QString OBJECT_ID_NAME;
+
+    QString SELECTION_COLOR_NAME;
+
+    QString LEFT_EYE_COLOR_NAME;
+    QString RIGHT_EYE_COLOR_NAME;
+
+    QString RENDER_DETAIL_LEVEL_NAME;
+    QString ANAGLYPH_NAME;
+    QString EYES_SHIFT_NAME;
+
+
     /*!
     * Constructor.
     * @param bsObj BioStruct3DObject contains 3d model for visualization
@@ -129,11 +150,17 @@ public:
     * @param delta Positive value: zoom in, negative value: zoom out.
     */
     void zoom(float delta);
+    void shift(float deltaX, float deltaY);
     /*!
     * Creates 2d vector image of BioStruct3DGLWidget contents using gl2ps.
     */
     void writeImage2DToFile(int format, int options, int nbcol, const char *fileName);
 
+    float getEyesShiftMult() const;
+    float getRenderDetailLevel() const;
+    void setBackgroundColor(QColor backgroundColor);
+    float sumCorrectColors(float a, float b);
+
 signals:
     void si_widgetClosed(BioStruct3DGLWidget* w);
 
@@ -168,7 +195,7 @@ protected:
     /*!
     * QWidget virtual function, executes context menu.
     */
-	void contextMenuEvent(QContextMenuEvent *_event);
+    void contextMenuEvent(QContextMenuEvent *_event);
     
 private:
 
@@ -201,7 +228,20 @@ private:
     int getChainIdForAnnotationObject(AnnotationTableObject* ao); 
     void switchActiveModel(bool forward);
     void connectExternalSignals();
+
+    unsigned int* emptyTextureData;
+    GLuint anaglyphRenderTextureLeft, anaglyphRenderTextureRight, tempAnaglyphRenderTexture;
+
+    void ViewOrtho();                                               // Set Up An Ortho View
+    void ViewPerspective();                                         // Set Up A Perspective View
+    GLuint getEmptyTexture(int textureHeight, int textureWidth);    // Create An Empty Texture
+
     void draw();
+    void drawTexturesAnaglypth(GLuint anaglyphRenderTextureLeft, GLuint anaglyphRenderTextureRight);                                // Draw The Image
+    void drawTexture(GLuint anaglyphRenderTexture, int red, int green, int blue, float alpha, bool alphaOnly);                              // Draw The Blurred Image
+    void drawAll();
+    void drawColoredPlane(int red, int green, int blue, float alpha);
+
     Vector3D getTrackballMapping(int x, int y);
     static QString getQualifierValueByName(const Annotation* annotation, const QString& qualifierName);
     static int getSequenceChainId(const DNASequenceObject* seqObj);
@@ -210,13 +250,14 @@ private:
     const BioStruct3D& biostruc;
     const Document* biostrucDoc;
     const AnnotatedDNAView* dnaView;
-    std::auto_ptr<MolecularSurface> molSurface;
     GLFrameManager* frameManager;
+    std::auto_ptr<MolecularSurface> molSurface;
     std::auto_ptr<GLFrame> glFrame;
     std::auto_ptr<BioStruct3DColorScheme> colorScheme;
     std::auto_ptr<BioStruct3DGLRenderer> biostructRenderer;
     std::auto_ptr<MolecularSurfaceRenderer> surfaceRenderer;
     QVariantMap defaultsSettings;
+    MolecularSurfaceCalcTask* surfaceCalcTask;
     QString currentColorSchemeName;
     QString currentGLRendererName;
     QString currentModelID;
@@ -225,7 +266,8 @@ private:
     QMap<QString, MolecularSurfaceRendererFactory*> surfaceRendererFactoryMap;
     QMap<const AnnotationTableObject*, int> chainIdCache;
     QList<int> activeModelIndexList;
-    GLfloat cameraDistance, cameraClipNear, cameraClipFar;
+    GLfloat cameraClipNear, cameraClipFar; //cameraDistance, 
+
     GLfloat rotAngle, spinAngle;
     GLfloat lightPostion[4];
     Vector3D rotAxis, lastPos;
@@ -245,8 +287,20 @@ private:
     QMenu *modelsMenu;
     QColor backgroundColor;
     QColor selectionColor;
+
     bool multipleModels;
 
+    QColor leftEyeColor;
+    QColor rightEyeColor;
+
+    int renderDetailLevel;
+    bool anaglyph;
+    int eyesShift;
+
+    void initSomething();
+    void displaySomething();
+    void drawSomething();
+
  private slots:
      void sl_selectColorScheme(QAction* action);
      void sl_selectGLRenderer(QAction* action);
@@ -264,6 +318,7 @@ private:
      void sl_showSurface();
      void sl_hideSurface();
      void sl_selectSurfaceRenderer(QAction* surfaceRenderer);
+      void sl_onTaskFinished(Task* task);
 
 
 };
