@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -18,6 +18,10 @@
 #include <QtGui/QLabel>
 #include <QtGui/QSizePolicy>
 #include <QtGui/QPixmap>
+#include <QtGui/QDesktopServices>
+#include <QtCore/QUrl>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 
 #include <core_api/AppContext.h>
 #include <core_api/DocumentModel.h>
@@ -26,11 +30,15 @@
 #include <core_api/ProjectModel.h>
 #include <gobjects/BioStruct3DObject.h>
 #include <gobjects/GObjectTypes.h>
+#include <util_tasks/LoadDocumentTask.h>
+#include <util_gui/ProjectTreeItemSelectorDialog.h>
+#include <util_gui/ProjectTreeController.h>
 #include <util_ov_annotated_dna/AnnotatedDNAView.h>
 
-
 #include "BioStruct3DSplitter.h"
 #include "BioStruct3DGLWidget.h"
+#include "GLFrameManager.h"
+
 
 namespace GB2 { 
 
@@ -40,7 +48,7 @@ static LogCategory log(ULOG_CAT_PLUGIN_BIOSTRUCT_3D);
 #define MAX_SPLITTER_HEIGHT 1000
 
 BioStruct3DSplitter::BioStruct3DSplitter(QAction* _closeAction, AnnotatedDNAView* view) 
-: ADVSplitWidget(view), parentSplitter(NULL) 
+: ADVSplitWidget(view), glFrameManager(new GLFrameManager), parentSplitter(NULL) 
 {
     closeAction = _closeAction;
 
@@ -77,26 +85,35 @@ BioStruct3DGLWidget* BioStruct3DSplitter::addBioStruct3DGLWidget( BioStruct3DObj
         adaptSize(1);
     }
 	
-    BioStruct3DGLWidget* glWidget = new BioStruct3DGLWidget(bioStructObj->getBioStruct3D(), bioStructObj->getDocument(), dnaView, this);
-    // Add widget associated action
+    BioStruct3DGLWidget* glWidget = new BioStruct3DGLWidget(bioStructObj, dnaView, getGLFrameManager(), this);
     glWidget->installEventFilter(this);
-    QString pdbId(bioStructObj->getBioStruct3D().pdbId);
-    QString actionName( tr("show_%1").arg(pdbId) );
-    QAction* action = new QAction(actionName, glWidget);
-    action->setCheckable(true);
-    action->setChecked(true);
-    connect(action, SIGNAL(triggered(bool)), SLOT(sl_toggleBioStruct3DWidget(bool)));
-    widgetActionMap.insert(glWidget, action);
     // Add widget to splitter
     biostrucViewMap.insert(bioStructObj, glWidget);
     splitter->addWidget(glWidget);
-	
-	
+		
     emit si_bioStruct3DGLWidgetAdded(glWidget);
 
     return glWidget;
 }
 
+bool BioStruct3DSplitter::eventFilter(QObject* o, QEvent* e) {
+    Q_UNUSED(o); Q_UNUSED(e);
+#ifdef Q_WS_X11
+    BioStruct3DGLWidget* glw = qobject_cast<BioStruct3DGLWidget*>(o);
+    //first variant of fix of QT4 bug: GL widget is frozen after minimize/maximize
+    if (e->type() == QEvent::Hide) {
+        glw->makeCurrent(); //these 2 lines can be removed
+        glFinish();
+        return true;
+    }
+    //second variant of fix of QT4 bug: GL widget is frozen after minimize/maximize
+    if (e->type() == QEvent::WindowActivate) {
+    //  ((QGLContext*)glw->context())->create();
+    }
+#endif
+    return false;
+}
+
 void BioStruct3DSplitter::addObject(BioStruct3DObject* bioStructObj) {
     setVisible(true);
     addBioStruct3DGLWidget(bioStructObj);
@@ -125,25 +142,6 @@ void BioStruct3DSplitter::dropEvent(QDropEvent *event)
 
 }
 
-
-bool BioStruct3DSplitter::eventFilter(QObject* o, QEvent* e) {
-    Q_UNUSED(o); Q_UNUSED(e);
-#ifdef Q_WS_X11
-    BioStruct3DGLWidget* glw = qobject_cast<BioStruct3DGLWidget*>(o);
-    //first variant of fix of QT4 bug: GL widget is frozen after minimize/maximize
-    if (e->type() == QEvent::Hide) {
-        glw->makeCurrent(); //these 2 lines can be removed
-        glFinish();
-        return true;
-    }
-    //second variant of fix of QT4 bug: GL widget is frozen after minimize/maximize
-    if (e->type() == QEvent::WindowActivate) {
-    //  ((QGLContext*)glw->context())->create();
-    }
-#endif
-    return false;
-}
-
 #define SPLITTER_STATE_MAP_NAME  "BIOSTRUCT3DSPLITTER_MAP"
 #define WIDGET_STATE_LIST_NAME  "WIDGET_STATE_MAP"
 #define OBJECT_ID_NAME "OBJECT_ID"
@@ -177,9 +175,7 @@ void BioStruct3DSplitter::updateState( const QVariantMap& m )
         delete glWidget;
     }
     biostrucViewMap.clear();
-    widgetActionMap.clear();
-    
-    
+      
     QListIterator<QVariant> iter(glWidgetStateList);
     iter.toBack();
     while (iter.hasPrevious()) {
@@ -199,7 +195,6 @@ bool BioStruct3DSplitter::removeObject(BioStruct3DObject* obj) {
     QMultiMap<BioStruct3DObject*, BioStruct3DGLWidget*>::iterator i = biostrucViewMap.find(obj);
     while (i != biostrucViewMap.end() && i.key() == obj) {
         BioStruct3DGLWidget* child = (*i);
-        widgetActionMap.remove(child);
         delete child;
         ++i;
     }
@@ -208,27 +203,6 @@ bool BioStruct3DSplitter::removeObject(BioStruct3DObject* obj) {
 	return isEmpty;
 }
 
-void BioStruct3DSplitter::sl_toggleBioStruct3DWidget(bool show) {
-    BioStruct3DGLWidget* glWidget = qobject_cast<BioStruct3DGLWidget*> (sender()->parent());
-    Q_ASSERT(glWidget != NULL);
-    int numVisibleWidgets = 0;
-    
-    glWidget->setVisible(show);
-    
-    foreach (BioStruct3DGLWidget* widget, biostrucViewMap) {
-        if (widget->isVisible()) {
-            ++numVisibleWidgets;
-        }
-    }
-    
-   
-    if ( (show == true && numVisibleWidgets == 1) ||
-        (show == false && numVisibleWidgets == 0) ) { 
-        adaptSize(numVisibleWidgets);
-    }
-   
-    header->updateActions();
-}
 
 BioStruct3DObject* BioStruct3DSplitter::findBioStruct3DObjByName( const QString& objName )
 {
@@ -284,26 +258,6 @@ void BioStruct3DSplitter::adaptSize( int numVisibleWidgets )
     }
 }
 
-const QMap<BioStruct3DGLWidget*, QAction*> BioStruct3DSplitter::getShowWidgetActionMap() const
-{
-    return widgetActionMap;
-}
-
-BioStruct3DObject* BioStruct3DSplitter::findParentBioStruct3DObject()
-{
-    QList<GObject*> objects = dnaView->getObjects();
-    BioStruct3DObject* parentObject;
-    foreach(GObject* object, objects) {
-        if (object->getGObjectType() == GObjectTypes::BIOSTRUCTURE_3D) {
-            parentObject = qobject_cast<BioStruct3DObject*>(object);
-            break;
-        }
-    }
-    Q_ASSERT(parentObject != NULL);
-    return parentObject;
-
-}
-
 const QList<QAction* > BioStruct3DSplitter::getSettingsMenuActions() const
 {
     QList<QAction*> actions;
@@ -316,12 +270,31 @@ QList<BioStruct3DGLWidget*> BioStruct3DSplitter::getChildWidgets()
     return biostrucViewMap.values();
 }
 
-void BioStruct3DSplitter::removeWidgetAction( BioStruct3DGLWidget* widget )
+int BioStruct3DSplitter::getNumVisibleWidgets()
 {
-	widgetActionMap.remove(widget);
+	int numVisibleWidgets = 0;
+	foreach (BioStruct3DGLWidget* widget, biostrucViewMap) {
+		if (widget->isVisible()) {
+			++numVisibleWidgets;
+		}
+	}
+	return numVisibleWidgets;
 }
 
+void BioStruct3DSplitter::addModelFromObject( BioStruct3DObject* obj )
+{   
+    QList<GObject*> objects = dnaView->getObjects();
+    if (objects.contains(obj)) {
+        addBioStruct3DGLWidget(obj);
+    } else {
+      dnaView->addObject(obj);
+    }
+}
 
+GLFrameManager* BioStruct3DSplitter::getGLFrameManager()
+{
+    return glFrameManager.get();
+}
 ///////////////////////////////////////////////////////////////////////////////////////////
 // Header widget toolbar
 class HBar : public QToolBar {
@@ -343,6 +316,7 @@ SplitterHeaderWidget::SplitterHeaderWidget(BioStruct3DSplitter* sp) : splitter(s
     setMinimumHeight(HEADER_HEIGHT);
     setBackgroundRole(QPalette::Window);
     setAutoFillBackground(true);
+    registerWebUrls();
     QHBoxLayout *layout = new QHBoxLayout();
     layout->setContentsMargins(10,0,0,0);
     layout->setSpacing(10);
@@ -402,20 +376,35 @@ SplitterHeaderWidget::SplitterHeaderWidget(BioStruct3DSplitter* sp) : splitter(s
     toolbar->addWidget(zoomOutButton);
     connect(zoomOutButton, SIGNAL(pressed()), this, SLOT(sl_zoomOut()));
 
+    syncLockButton = new QToolButton(this);
+    syncLockButton->setIcon(QIcon(":biostruct3d_view/images/lock.png"));
+    syncLockButton->setToolTip(tr("Multiple view synchronization lock"));
+    syncLockButton->setFixedWidth(20);
+    syncLockButton->setCheckable(true);
+    toolbar->addWidget(syncLockButton);
+    connect(syncLockButton, SIGNAL(toggled(bool)), this, SLOT(sl_toggleSyncLock(bool)));
     
     displayMenuButton = new QToolButton(this);
     displayMenuButton->setText(tr("display"));
     toolbar->addWidget(displayMenuButton);
     connect(displayMenuButton, SIGNAL(pressed()), this, SLOT(sl_showDisplayMenu()));
+    
+    if (webActionMap.count() != 0) {
+        webMenuButton = new QToolButton(this);
+        webMenuButton->setText(tr("Links"));
+        toolbar->addWidget(webMenuButton);
+        connect(webMenuButton, SIGNAL(pressed()), this, SLOT(sl_showWebMenu()));
+    }
 
-    //QToolButton* addModelButton = new QToolButton(this);
-    //addModelButton->setText(tr("add_model"));
-    // TODO: reenable after branching: toolbar->addWidget(addModelButton);
-
-
+    addModelButton = new QToolButton(this);
+    addModelButton->setText(tr("Add"));
+    toolbar->addWidget(addModelButton);
+    connect(addModelButton, SIGNAL(pressed()), this, SLOT(sl_addModel()));
+    
+    // TODO: add settings functionality
     //settingsMenuButton = new QToolButton(this);
     //settingsMenuButton->setText(tr("settings"));
-    // TODO: reenable after branching: toolbar->addWidget(settingsMenuButton);
+    // toolbar->addWidget(settingsMenuButton);
    
     widgetStateMenuButton = new QToolButton(this);
     widgetStateMenuButton->setIcon(QIcon(":core/images/adv_widget_menu.png"));
@@ -431,12 +420,13 @@ void SplitterHeaderWidget::sl_showStateMenu()
 
     QMenu m;
     
-    const QMap<BioStruct3DGLWidget*, QAction*> actionMap = splitter->getShowWidgetActionMap();
     
-    foreach (BioStruct3DGLWidget* glWidget, widgets) {
-        m.addAction(actionMap.value(glWidget));
+    foreach(BioStruct3DGLWidget* widget, widgets) {
+        QAction* action = showWidgetActionMap.value(widget);
+        m.addAction(action);
     }
-    m.addAction(splitter->getCloseAction());
+    
+    m.addAction(splitter->getCloseSplitterAction());
     m.exec(QCursor::pos());
 
     if (!widgetStateMenuButtonPtr.isNull()) { //if not self closed
@@ -493,45 +483,99 @@ void SplitterHeaderWidget::sl_showSettingsMenu()
 
 void SplitterHeaderWidget::sl_restoreDefaults()
 {
-    //TODO: consider restoring states, for every widget 
-    // fix restoring the state of multiple widgets, something is wrong with it
-    
-    //QList<BioStruct3DGLWidget*> widgets = splitter->getChildWidgets();
-    //foreach ( BioStruct3DGLWidget* w, widgets) {
     BioStruct3DGLWidget* w = getActiveWidget();    
     w->restoreDefaultSettigns();
-    //}
 }
 
 void SplitterHeaderWidget::sl_addBioStruct3DGLWidget( BioStruct3DGLWidget* glWidget )
 {
     int index = activeWidgetBox->count() + 1;
-    QString name = QString("%1: %2").arg(index).arg(glWidget->getBioStruct3D().pdbId.constData()) ;
+	const char* pdbId = glWidget->getBioStruct3D().pdbId.constData();
+    
+	QString name = QString("%1: %2").arg(index).arg(pdbId) ;
     activeWidgetBox->addItem(name);
     connect(glWidget, SIGNAL(si_widgetClosed(BioStruct3DGLWidget*)), this, SLOT(sl_closeWidget3DGLWidget(BioStruct3DGLWidget*)));
-    widgets.append(glWidget);
+    glWidget->installEventFilter(this);
+
+	// Add show widget action
+	QString actionName( tr("show_%1").arg(pdbId) );
+	QAction* action = new QAction(actionName, glWidget);
+	action->setCheckable(true);
+	action->setChecked(true);
+	connect(action, SIGNAL(triggered(bool)), SLOT(sl_toggleBioStruct3DWidget(bool)));
+	showWidgetActionMap.insert(glWidget, action);
+	
+	widgets.append(glWidget);
+	enableToolbar();
 }
 
+bool SplitterHeaderWidget::eventFilter(QObject *obj, QEvent *event)
+{   
+
+    
+    
+    if (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::Wheel) {
+        BioStruct3DGLWidget* glWidget = qobject_cast<BioStruct3DGLWidget*>(obj);
+        if (glWidget) {
+            setActiveView(glWidget);
+        } 
+    } 
+
+    return QObject::eventFilter(obj, event);
+}
+
+
+
 BioStruct3DGLWidget* SplitterHeaderWidget::getActiveWidget()
 {
     int idx = activeWidgetBox->currentIndex();
-    return widgets[idx];
+    BioStruct3DGLWidget* glWidget = widgets[idx];
+    glWidget->makeCurrent();
+    return glWidget;
 }
 
 void SplitterHeaderWidget::sl_closeWidget3DGLWidget(BioStruct3DGLWidget* glWidget) {
     int index = widgets.indexOf(glWidget);
     assert(index >= 0);
     widgets.removeAt(index);
-	activeWidgetBox->removeItem(index);
+    activeWidgetBox->removeItem(index);
+	splitter->getGLFrameManager()->removeGLWidgetFrame(glWidget);
     updateWidgetBox();
-	splitter->removeWidgetAction(glWidget);
+	showWidgetActionMap.remove(glWidget);
 	if (widgets.isEmpty()) {
-		splitter->adaptSize(0);
+		// TODO: maybe it's possible not to close splitter?
+        //splitter->adaptSize(0);
+        splitter->getCloseSplitterAction()->trigger();
+        return;
+	}
+	updateToolbar();
+}
+
+void SplitterHeaderWidget::enableToolbar() {
+	activeWidgetBox->setEnabled(true);
+	restoreDefaultsButton->setEnabled(true);
+	zoomInButton->setEnabled(true);
+	zoomOutButton->setEnabled(true);
+	displayMenuButton->setEnabled(true);
+	widgetStateMenuButton->setEnabled(true);
+    syncLockButton->setEnabled(splitter->getGLFrameManager()->getGLFrames().count() > 1);
+
+}
+
+
+void SplitterHeaderWidget::updateWidgetBox() {
+	activeWidgetBox->clear();
+	int index = 0;
+	foreach(BioStruct3DGLWidget* widget, widgets) {
+		++index;
+		const char* pdbId = widget->getBioStruct3D().pdbId.constData();
+		QString name = QString("%1: %2").arg(index).arg(pdbId);
+		activeWidgetBox->addItem(name);
 	}
 
 }
 
-void SplitterHeaderWidget::updateActions() {
+void SplitterHeaderWidget::updateToolbar() {
     int numVisibleWidgets = 0;
     foreach (BioStruct3DGLWidget* w, widgets) {
         numVisibleWidgets += w->isVisible() ? 1 : 0;
@@ -540,19 +584,204 @@ void SplitterHeaderWidget::updateActions() {
     restoreDefaultsButton->setEnabled(numVisibleWidgets > 0);
     zoomInButton->setEnabled(numVisibleWidgets > 0);
     zoomOutButton->setEnabled(numVisibleWidgets > 0);
+    syncLockButton->setEnabled(numVisibleWidgets > 1);
     displayMenuButton->setEnabled(numVisibleWidgets);
+	widgetStateMenuButton->setEnabled(!widgets.isEmpty());		
+	
+	
 }
 
-void SplitterHeaderWidget::updateWidgetBox()
+void SplitterHeaderWidget::sl_toggleBioStruct3DWidget( bool show )
 {
-    activeWidgetBox->clear();
-    int index = 0;
-    foreach(BioStruct3DGLWidget* widget, widgets) {
-        ++index;
-        const char* pdbId = widget->getBioStruct3D().pdbId.constData();
-        QString name = QString("%1: %2").arg(index).arg(pdbId);
-        activeWidgetBox->addItem(name);
+	BioStruct3DGLWidget* glWidget = qobject_cast<BioStruct3DGLWidget*> (sender()->parent());
+	Q_ASSERT(glWidget != NULL);
+	
+	glWidget->setVisible(show);
+
+	int numVisibleWidgets = splitter->getNumVisibleWidgets();
+
+	if ( (show == true && numVisibleWidgets == 1) ||
+		(show == false && numVisibleWidgets == 0) ) { 
+			splitter->adaptSize(numVisibleWidgets);
+	}
+
+	updateToolbar();
+	
+}
+
+void SplitterHeaderWidget::sl_addModel()
+{
+    QPointer<QToolButton> addModelButtonPtr(addModelButton);
+    
+    if (!addModelButtonPtr.isNull()) { //if not self closed
+        addModelButtonPtr->setDown(false);
     }
-  
+    
+    ProjectTreeControllerModeSettings settings;
+    settings.objectTypesToShow.append(GObjectTypes::BIOSTRUCTURE_3D);
+    QList<GObject*> objects = ProjectTreeItemSelectorDialog::selectObjects(settings, this);
+    
+    if (!objects.isEmpty()) {
+        foreach(GObject* obj, objects) {
+            Task* t = new AddModelToSplitterTask(obj, splitter);
+            AppContext::getTaskScheduler()->registerTopLevelTask(t);
+        }
+    }
+
+}
+
+void SplitterHeaderWidget::sl_showWebMenu()
+{
+    QPointer<QToolButton> webMenuButtonPtr(webMenuButton);
+    
+    QMenu m;
+    QString pdbId(getActiveWidget()->getBioStruct3D().pdbId);
+    
+    const QList<QAction* >& webMenuActions = webActionMap.keys();
+    foreach (QAction* action, webMenuActions) {
+        QString wikiName = action->text().split(": ", QString::SkipEmptyParts).last();
+        action->setText(pdbId+": "+wikiName);
+        m.addAction(action);
+    }
+    m.exec(QCursor::pos());
+
+    if (!webMenuButtonPtr.isNull()) { //if not self closed
+        webMenuButtonPtr->setDown(false);
+    }
+
+    
+}
+
+void SplitterHeaderWidget::registerWebUrls()
+{
+//    QSignalMapper *signalMapper = new QSignalMapper(this);
+//    connect(signalMapper, SIGNAL(mapped(const QString &)), this, SLOT(sl_openBioStructUrl(const QString&)));
+    
+    DBLinksFile linksFile;
+    if (!linksFile.load()) {
+        return;
+    }
+
+    QList<DBLink> links = linksFile.getLinks();
+    foreach (const DBLink& link, links) {
+        QAction* webAction = new QAction(link.name,this);
+        webActionMap.insert(webAction, link.url);
+        connect(webAction, SIGNAL(triggered(bool)), this, SLOT(sl_openBioStructUrl()));
+    }
+
+    //connect(signalMapper, SIGNAL(mapped(const QString &)), this, SLOT(sl_openBioStructUrl(const QString&)));
+    
+    //connect(signalMapper, SIGNAL(mapped(const QString &)),
+    //    this, SIGNAL(triggered(const QString &)));
+
+
+
+}
+
+void SplitterHeaderWidget::sl_openBioStructUrl()
+{
+    QAction* webAction = qobject_cast<QAction*>(QObject::sender());
+    if (webAction == NULL)
+        return;
+    const QString& urlHeader = webActionMap.value(webAction); 
+    QString pdbId(getActiveWidget()->getBioStruct3D().pdbId.toLower());
+    QString urlName = urlHeader.arg(pdbId);
+    QUrl url(urlName);
+    QDesktopServices::openUrl(urlName);
+
+}
+
+void SplitterHeaderWidget::setActiveView( BioStruct3DGLWidget* glWidget )
+{
+    int index = 0;
+    foreach (BioStruct3DGLWidget* widget, widgets) {
+        if (widget == glWidget ) {
+            widget->makeCurrent();
+            activeWidgetBox->setCurrentIndex(index);
+            break;
+        }
+        ++index;    
+    }
+    
+}
+
+void SplitterHeaderWidget::sl_toggleSyncLock( bool toggle )
+{
+    splitter->getGLFrameManager()->setSyncLock(toggle, widgets[0]);
+}
+///////////////////////////////////////////////////////////////////////////////////////////
+// DBLinksFile
+
+#define DB_LINKS_FILE_NAME "biostruct3d_plugin/BioStruct3DLinks.txt"
+
+bool DBLinksFile::load()
+{
+    QFile file( QString(PATH_PREFIX_DATA)+ ":" + DB_LINKS_FILE_NAME );
+    if(!file.exists() || !file.open(QIODevice::ReadOnly)){
+        log.error(SplitterHeaderWidget::tr("bs3d_links_file_not_found_%1").arg(DB_LINKS_FILE_NAME));
+        return false;
+    } 
+
+    QTextStream in(&file);
+    while (!in.atEnd()) {
+        QString line = in.readLine();
+        if(line.length()==0 || line.startsWith("#")) {
+            continue;
+        }
+        QStringList fields = line.split("|");
+        if (fields.size() != 2) {
+            log.error(SplitterHeaderWidget::tr("illegal_entry_%1").arg(line));
+            continue;
+        }
+        DBLink linkInfo(fields[0], fields[1].trimmed());
+        links.append(linkInfo);
+        
+    }
+    file.close();
+
+    return true;
+}
+
+
+///////////////////////////////////////////////////////////////////////////////////////////
+// AddModelToSplitterTask
+
+AddModelToSplitterTask::AddModelToSplitterTask( GObject* o, BioStruct3DSplitter* s ) :
+    Task("", TaskFlags_FOSCOE), doc(NULL), obj(o), bObj(NULL), splitter(s)
+{
+    setTaskName(tr("Add 3d model '%1' to BioStruct3DSplitter").arg(o->getGObjectName())); 
+}
+
+void AddModelToSplitterTask::prepare()
+{
+    if (obj->isUnloaded()) {
+        doc = obj->getDocument();
+        addSubTask(new LoadUnloadedDocumentTask(doc));
+    } 
+}
+
+void AddModelToSplitterTask::run()
+{
+    if (doc == NULL) {
+        bObj = qobject_cast<BioStruct3DObject*> (obj);
+    } else {
+        Q_ASSERT(doc->isLoaded());
+        QList<GObject*> lst = doc->findGObjectByType(GObjectTypes::BIOSTRUCTURE_3D);
+        Q_ASSERT(!lst.isEmpty());
+        bObj = qobject_cast<BioStruct3DObject*> (lst.first());
+    }
+    
+
+}
+
+Task::ReportResult AddModelToSplitterTask::report()
+{
+    if ( (bObj == NULL) || ( propagateSubtaskError() == true)  ) {
+        stateInfo.setError(tr("Model %1 wasn't added").arg(obj->getGObjectName()));
+    } else {
+        splitter->addModelFromObject(bObj);
+    }
+
+    return ReportResult_Finished;
 }
 } //namespace
