@@ -67,31 +67,11 @@ extern "C" Q_DECL_EXPORT Plugin* GB2_PLUGIN_INIT_FUNC() {
 }
 
 BioStruct3DViewPlugin::BioStruct3DViewPlugin() : Plugin(tr("biostruct3d_view_plugin"), tr("biostruct3d_view_plugin_desc")) {
-    // Add download remote PDB action
-    loadRemotePDBFileAction = new QAction(tr("Download PDB molecule..."), this);
-    loadRemotePDBFileAction->setIcon(QIcon(":biostruct3d_view/images/world_go.png"));
-    connect(loadRemotePDBFileAction, SIGNAL(triggered()), SLOT(sl_downloadRemotePDBFile()));
-    QMenu* fileMenu = AppContext::getMainWindow()->getMenuManager()->getTopLevelMenu( MWMENU_FILE );
-    QAction* beforeAction = GUIUtils::findActionAfter(fileMenu->actions(), ACTION_PROJECTSUPPORT__OPEN_PROJECT);
-    fileMenu->insertAction(beforeAction,  loadRemotePDBFileAction);
-   
     // Init plugin view context
     viewContext = new BioStruct3DViewContext(this);
     viewContext->init();
 }
 
-void BioStruct3DViewPlugin::sl_downloadRemotePDBFile() 
-{
-    QWidget *p = (QWidget*)(AppContext::getMainWindow()->getQMainWindow());
-    LoadRemotePDBFileDialog dlg(p);
-    int rc = dlg.exec();
-    if (rc == QDialog::Accepted) {
-        LoadRemoteDocumentTask* task = new LoadRemoteDocumentTask(QString("http://www.rcsb.org/pdb/files/%1.pdb").arg(dlg.getPdbId()), BaseDocumentFormats::PLAIN_PDB);
-        AppContext::getTaskScheduler()->registerTopLevelTask(task);
-    }
-    
-}
-
 BioStruct3DViewPlugin::~BioStruct3DViewPlugin()
 {
 
@@ -115,7 +95,8 @@ void BioStruct3DViewContext::initViewContext(GObjectView* v)  {
     foreach(ADVSequenceWidget* w, seqWidgets) {
         ADVSingleSequenceWidget* aw = qobject_cast<ADVSingleSequenceWidget*>(w);
         if (aw!=NULL) {
-            aw->setPanViewCollapsed(true);
+            aw->setDetViewCollapsed(true);
+			aw->setOverviewCollapsed(true);
         }
     }
     foreach(GObject* obj, biostructObjs) {
@@ -129,62 +110,45 @@ bool BioStruct3DViewContext::canHandle(GObjectView* v, GObject* o) {
     return res;
 }
 
-void BioStruct3DViewContext::onObjectAdded(GObjectView* v, GObject* obj) {
+void BioStruct3DViewContext::onObjectAdded(GObjectView* view, GObject* obj) {
     //todo: add sequence & all objects associated with sequence to the view?
 
     BioStruct3DObject* obj3d = qobject_cast<BioStruct3DObject*>(obj);
-    if (obj3d == NULL) {
+    if (obj3d == NULL || view == NULL) {
         return;
     }
-    BioStruct3DSplitter* view3d = get3DView(v, true);
-    view3d->addObject(obj3d);
+    
+    AnnotatedDNAView* av = qobject_cast<AnnotatedDNAView*>(view);
+    if (splitterMap.contains(view)) {
+        BioStruct3DSplitter* splitter = splitterMap.value(view);
+        splitter->addObject(obj3d);
+        return;
+    }
+    BioStruct3DSplitter* splitter = new BioStruct3DSplitter(getClose3DViewAction(view), av);
+    av->insertWidgetIntoSplitter(splitter);
+    splitter->addObject(obj3d);
+    splitterMap.insert(view,splitter);
 }
 
 void BioStruct3DViewContext::onObjectRemoved(GObjectView* v, GObject* obj) {
-    BioStruct3DObject* obj3d = qobject_cast<BioStruct3DObject*>(obj);
-    if (obj3d == NULL) {
-        return;
-    }
-    BioStruct3DSplitter* view3d = get3DView(v, false);
-    assert(view3d!=NULL);
-    bool close = view3d->removeObject(obj3d);
-    if (close) {
-        remove3DView(v);
-    }
+     BioStruct3DObject* obj3d = qobject_cast<BioStruct3DObject*>(obj);
+     if (obj3d == NULL) {
+         return;
+     }
+     BioStruct3DSplitter* splitter = splitterMap.value(v);
+     bool close = splitter->removeObject(obj3d);
+     if (close) {
+         remove3DView(v, splitter);
+     }
 }
 
-BioStruct3DSplitter* BioStruct3DViewContext::get3DView(GObjectView* view, bool create) {
-    BioStruct3DSplitter* view3d = NULL;
-    QList<QObject*> resources = viewResources.value(view);
-    foreach(QObject* r, resources) {
-        view3d = qobject_cast<BioStruct3DSplitter*>(r);
-        if (view3d!=NULL) {
-            return view3d;
-        }
-    }
-    if (create) {
-        AnnotatedDNAView* av = qobject_cast<AnnotatedDNAView*>(view);
-        view3d = new BioStruct3DSplitter(getClose3DViewAction(view), av);
-        av->insertWidgetIntoSplitter(view3d);
-        resources.append(view3d);
-        viewResources.insert(view, resources);
-    }
-    return view3d;
-}
-
-void BioStruct3DViewContext::remove3DView(GObjectView* view) {
-    QList<QObject*> resources = viewResources.value(view);
-    foreach(QObject* r, resources) {
-        BioStruct3DSplitter* view3d = qobject_cast<BioStruct3DSplitter*>(r);
-        if (view3d!=NULL) {
-            assert(view3d->getChildWidgets().isEmpty());
-            AnnotatedDNAView* av = qobject_cast<AnnotatedDNAView*>(view);
-            av->unregisterSplitWidget(view3d);
-            resources.removeOne(view3d);
-            viewResources.insert(view, resources);
-            delete view3d;
-        }
-    }
+void BioStruct3DViewContext::remove3DView(GObjectView* view, BioStruct3DSplitter* splitter) {
+   
+    assert(splitter->getChildWidgets().isEmpty());
+    AnnotatedDNAView* av = qobject_cast<AnnotatedDNAView*>(view);
+    av->unregisterSplitWidget(splitter);
+    splitterMap.remove(view);
+    delete splitter;
 }
 
 QAction* BioStruct3DViewContext::getClose3DViewAction(GObjectView* view) {
@@ -210,7 +174,12 @@ void BioStruct3DViewContext::sl_close3DView() {
             ov->removeObject(obj);
         }
     }
-    assert(get3DView(action->getObjectView(), false) == NULL);
+//     assert(get3DView(action->getObjectView(), false) == NULL);
+}
+
+void BioStruct3DViewContext::sl_windowClosing(MWMDIWindow* w) {
+	splitterMap.clear();
+	GObjectViewWindowContext::sl_windowClosing(w);
 }
 
 }//namespace
