@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -37,9 +37,12 @@ private slots:
 private:
     QList<QString> supportedFormats;
     BioStruct3DGLWidget* glWidget;
+    static int fileCounter;
 
     void setupComponents();
     void setupFormats();
+    static bool isVectorGraphicFormat(const QString& formatName);
+    static int getVectorFormatIdByName(const QString& formatName);
 
 
 
@@ -49,4 +52,4 @@ private:
 
 } // namespace
 
-#endif
\ No newline at end of file
+#endif
