@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -9,37 +9,46 @@
 *****************************************************************/
 
 #include <QtOpenGL>
+#include <molecular_geometry/GeomUtils.h>
+#include <math.h>
 #include "GraphicUtils.h"
+#include <core_api/Log.h>
+
+#include <datatype/BioStruct3D.h>
+#include <BioStruct3DColorScheme.h>
+
 
 namespace GB2 { 
 
+static LogCategory log("GraphUtils");
+
 ///////////////////////////////////////////////////////////////////////////////////////////
 /// Color4f
 
 Color4f::Color4f()
 {
-	color[0] = 0;
-	color[1] = 0;
-	color[2] = 0;
-	color[3] = 1.0;
+    color[0] = 0;
+    color[1] = 0;
+    color[2] = 0;
+    color[3] = 1.0;
 
 }
 
 Color4f::Color4f( float r, float g, float b )
 {
-	color[0] = r;
-	color[1] = g;
-	color[2] = b;
-	color[3] = 1.0;
+    color[0] = r;
+    color[1] = g;
+    color[2] = b;
+    color[3] = 1.0;
 
 }
 
 Color4f::Color4f( const QColor& qColor )
 {
-	color[0] = qColor.redF();
-	color[1] = qColor.greenF();
-	color[2] = qColor.blueF();
-	color[3] = qColor.alphaF();
+    color[0] = qColor.redF();
+    color[1] = qColor.greenF();
+    color[2] = qColor.blueF();
+    color[3] = qColor.alphaF();
 
 }
 
@@ -65,29 +74,56 @@ Color4f& Color4f::operator+=( const Color4f& v )
 
 Color4f& Color4f::operator/=( double f )
 {
-//Do not affect alpha channel
-    color[0]/=f; color[1]/=f; color[2]/=f;
-    return *this;
+	//Do not affect alpha channel
+	color[0]/=f; color[1]/=f; color[2]/=f;
+	return *this;
 }
 
-void glDrawCylinder(GLUquadric* pObj, const Vector3D& p1, const Vector3D& p2, double thickness)
+bool Color4f::operator==(const Color4f &a)
 {
-   
-    static int numSlices = 8;
-	static int numStacks = 1;
+	//Do not affect alpha channel
+	if (color[0]==a.color[0] && color[1]==a.color[1] && color[2]==a.color[2])
+	{
+		return true;
+	}
+	else
+	{
+		return false;
+	}
+}
+
+bool operator == (const Color4f &a, const Color4f &b)
+{
+	//Do not affect alpha channel
+	const float *aColor = a.getConstData();
+	const float *bColor = b.getConstData();
+
+	if (aColor[0]==bColor[0] && aColor[1]==bColor[1] && aColor[2]==bColor[2])
+	{
+		return true;
+	}
+	else
+	{
+		return false;
+	}
+}
+
+void glDrawCylinder(GLUquadric* pObj, const Vector3D& p1, const Vector3D& p2, double thickness, float renderDetailLevel)
+{
+    int numSlices = (8 * renderDetailLevel);
+    int numStacks = 1;
     static Vector3D zAxis(0.0, 0.0, 1.0);
 
     Vector3D vec(p2 - p1);
     float length = vec.length();
     float rotAngle = Rad2Deg* acos( vec.z / length );
     Vector3D rotAxis = vector_cross(zAxis, vec);
-    
+
     glPushMatrix();
     glTranslatef(p1.x, p1.y, p1.z);
     glRotatef(rotAngle, rotAxis.x, rotAxis.y, rotAxis.z);
     gluCylinder(pObj, thickness, thickness, length, numSlices, numStacks);
     glPopMatrix();
-       
 }
 
 
@@ -104,25 +140,31 @@ Helix3D::Helix3D(const Color4f& cl, const Vector3D& c, const Vector3D& n, float
     rotAngle = Rad2Deg* acos( vec.z / length );
     Vector3D zAxis(0.0, 0.0, 1.0);
     rotAxis = vector_cross(zAxis, vec);
-
-
 }
 
 
-void Helix3D::draw()
+void Helix3D::draw(float renderDetailLevel)
 {
     glMaterialfv(GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE, color.getConstData());
-    int numSlices = 10;
-	int numStacks = 1;
+    int numSlices = 10 * renderDetailLevel;
+    int numStacks = 1;
     static float smallLength = 1.2f;
 
+    radius=1.0f;
+
     glPushMatrix();
         glTranslatef(cterm.x, cterm.y, cterm.z);
         glRotatef(rotAngle, rotAxis.x, rotAxis.y, rotAxis.z);
-        gluDisk(pObj, 0, radius, numSlices, numSlices);
+        glPushMatrix();
+            glScalef(1,1,-1);
+            gluDisk(pObj, 0, radius, numSlices, numSlices);
+        glPopMatrix();
         gluCylinder(pObj, radius, radius, length - smallLength, numSlices, numStacks);
         glTranslatef(0, 0, length - smallLength);
-        gluDisk(pObj, 0, radius*1.2f, numSlices, numSlices);
+        glPushMatrix();
+            glScalef(1,1,-1);
+            gluDisk(pObj, 0, radius*1.2f, numSlices, numSlices);
+        glPopMatrix();
         gluCylinder(pObj, radius*1.2f, radius*0.4f, smallLength, numSlices, numStacks);
         glTranslatef(0, 0, smallLength);
         gluDisk(pObj, 0, radius*0.4f, numSlices, numStacks);
@@ -133,7 +175,7 @@ void Helix3D::draw()
 
 Helix3D::~Helix3D()
 {
-    gluDeleteQuadric(pObj);
+	gluDeleteQuadric(pObj);
 }
 
 
@@ -146,15 +188,15 @@ Strand3D::Strand3D( const Color4f& cl, const Vector3D& c, const Vector3D& n, con
     rotAngle = Rad2Deg* acos( vec.z / length );
     Vector3D zAxis(0.0, 0.0, 1.0);
     rotAxis = vector_cross(zAxis, vec);
-    
-
 
 }
 
-void Strand3D::draw()
+void Strand3D::draw(float renderDetailLevel)
 {
-    static float width = 1.5f;
-    static float height = 0.4f;
+    Q_UNUSED(renderDetailLevel);
+
+    float width = 1.5f;
+    float height = 0.4f;
     
     glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, color.getConstData());
     
@@ -162,7 +204,7 @@ void Strand3D::draw()
     glTranslatef(cterm.x, cterm.y, cterm.z);
     glRotatef(rotAngle, rotAxis.x, rotAxis.y, rotAxis.z);
     glCreateArrowPrimitive(width, height, length);
-    glPopMatrix();	
+    glPopMatrix();  
 
 }
 
@@ -172,10 +214,10 @@ Strand3D::~Strand3D()
 }
 
 
-void glDrawHalfWorm(const Vector3D *p0, const Vector3D& p1,
-                                  const Vector3D& p2, const Vector3D *p3,
+void glDrawHalfWorm(const Vector3D& p0, const Vector3D& p1,
+                                  const Vector3D& p2, const Vector3D& p3,
                                   double radius, bool cap1, bool cap2,
-                                  double tension)
+                                  double tension, float renderDetailLevel)
 {
     int i, j, k, m, offset=0;
     Vector3D R1, R2, Qt, p, dQt, H, V;
@@ -183,10 +225,6 @@ void glDrawHalfWorm(const Vector3D *p0, const Vector3D& p1,
     GLfloat *Nx=NULL, *Ny=NULL, *Nz=NULL, *Cx=NULL, *Cy=NULL, *Cz=NULL,
         *pNx=NULL, *pNy=NULL, *pNz=NULL, *pCx=NULL, *pCy=NULL, *pCz=NULL, *tmp;
 
-    if (!p0 || !p3) {
-        return;
-    }
-
     /*
     * The Hermite matrix Mh.
     */
@@ -205,8 +243,9 @@ void glDrawHalfWorm(const Vector3D *p0, const Vector3D& p1,
         c = 0,                  /* continuity (should be 0) */
         b = 0;                  /* bias       (should be 0) */
 
-    static int wormSegments = 10;
-    static int wormSides = 10;
+    int wormSegments = 10 * renderDetailLevel;
+    int wormSides = 10 * renderDetailLevel;
+
     /*
     if (wormSides % 2) {
         WARNINGMSG("worm sides must be an even number");
@@ -219,8 +258,8 @@ void glDrawHalfWorm(const Vector3D *p0, const Vector3D& p1,
     /* First, calculate the coordinate points of the center of the worm,
     * using the Kochanek-Bartels variant of the Hermite curve.
     */
-    R1 = 0.5 * (1 - a) * (1 + b) * (1 + c) * (p1 - *p0) + 0.5 * (1 - a) * (1 - b) * (1 - c) * ( p2 - p1);
-    R2 = 0.5 * (1 - a) * (1 + b) * (1 - c) * (p2 -  p1) + 0.5 * (1 - a) * (1 - b) * (1 + c) * (*p3 - p2);
+    R1 = 0.5 * (1 - a) * (1 + b) * (1 + c) * (p1 - p0) + 0.5 * (1 - a) * (1 - b) * (1 - c) * ( p2 - p1);
+    R2 = 0.5 * (1 - a) * (1 + b) * (1 - c) * (p2 -  p1) + 0.5 * (1 - a) * (1 - b) * (1 + c) * (p3 - p2);
 
     /*
     * Multiply MG=Mh.Gh, where Gh = [ P(1) P(2) R(1) R(2) ]. This
@@ -390,16 +429,15 @@ void glDrawHalfWorm(const Vector3D *p0, const Vector3D& p1,
     if (fblock) delete[] fblock;
 } 
 
-void glDrawHalfBond( GLUquadric *pObj, const Vector3D& p1, const Vector3D&p2, double thickness )
+void glDrawHalfBond( GLUquadric *pObj, const Vector3D& p1, const Vector3D&p2, double thickness, float renderDetailLevel)
 {
     Vector3D middle = (p1 + p2) / 2;
-    glDrawCylinder(pObj, p2, middle, thickness);    
-
+    glDrawCylinder(pObj, p2, middle, thickness, renderDetailLevel);
 }
 
-void glDrawAtom( GLUquadric* pObj, const Vector3D& pos, double r )
+void glDrawAtom( GLUquadric* pObj, const Vector3D& pos, double r, float renderDetailLevel)
 {
-    static int numSlices = 10;
+    int numSlices = 10  * renderDetailLevel;
     glPushMatrix();
     glTranslatef(pos.x, pos.y, pos.z);
     gluSphere(pObj, r, numSlices, numSlices);
@@ -573,25 +611,140 @@ void glCreateArrowPrimitive( float width, float height, float length )
     glVertex3fv(b11); //glNormal3fv(n03);
 
     glEnd();
-    
+
 }
 
-void DisplayLists::createAtomDisplayList()
+void accFrustum(GLdouble left, GLdouble right, GLdouble bottom,
+                GLdouble top, GLdouble _near, GLdouble _far, GLdouble pixdx, 
+                GLdouble pixdy, GLdouble eyedx, GLdouble eyedy, 
+                GLdouble focus)
 {
-    static float radius = 0.35f;
-    static int numSlices = 8;
+    GLdouble xwsize, ywsize; 
+    GLdouble dx, dy;
+    GLint viewport[4];
 
-    // Create the id for the list
-    atomDL = glGenLists(ATOM_DL_INDEX);
+    glGetIntegerv (GL_VIEWPORT, viewport);
 
-    GLUquadricObj *pObj = gluNewQuadric();  
-    gluQuadricNormals(pObj, GLU_SMOOTH);
+    xwsize = right - left;
+    ywsize = top - bottom;
+    dx = -( pixdx*xwsize / (GLdouble) viewport[2] + eyedx * _near / focus );
+    dy = -(pixdy*ywsize/(GLdouble) viewport[3] + eyedy * _near/ focus);
 
-    glNewList(atomDL,GL_COMPILE);
-    gluSphere(pObj, radius, numSlices, numSlices);
-    glEndList();
-
-    gluDeleteQuadric(pObj);
+    glMatrixMode(GL_PROJECTION);
+    glLoadIdentity();
+    glFrustum (left + dx, right + dx, bottom + dy, top + dy, _near, _far);
+    glMatrixMode(GL_MODELVIEW);
+    glLoadIdentity();
+    glTranslatef (-eyedx, -eyedy, 0.0);
 }
 
+void accPerspective(GLdouble fovy, GLdouble aspect, 
+                    GLdouble _near, GLdouble _far, GLdouble pixdx, GLdouble pixdy, 
+                    GLdouble eyedx, GLdouble eyedy, GLdouble focus)
+{
+    GLdouble fov2,left,right,bottom,top;
+    fov2 = ((fovy*PI) / 180.0) / 2.0;
+
+    top = _near / (cos(fov2) / sin(fov2));
+    bottom = -top;
+    right = top * aspect;
+    left = -right;
+
+    accFrustum (left, right, bottom, top, _near, _far, pixdx, pixdy, eyedx, eyedy, focus);
+}
+void DisplayLists::drawAtomsBonds(const Color4f &viewAtomColor, float renderDetailLevel, const Molecule3DModel &model, const BioStruct3DColorScheme* colorScheme)
+{
+	GLUquadricObj *pObj = gluNewQuadric();
+	gluQuadricNormals(pObj, GLU_SMOOTH);
+
+	glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, viewAtomColor.getConstData());
+
+	static float bondThickness = 0.15f;
+	float radius = 0.35f;
+	int numSlices = 8 * renderDetailLevel;
+
+	foreach(const SharedAtom atom, model.atoms) {
+		Color4f atomColor = colorScheme->getAtomColor(atom);
+		if (viewAtomColor==atomColor)
+		{
+			Vector3D pos = atom->coord3d;
+//			glPushMatrix();
+			glTranslatef(pos.x, pos.y, pos.z);
+			gluSphere(pObj, radius, numSlices, numSlices);
+			glTranslatef(-pos.x, -pos.y, -pos.z);
+//			glPopMatrix();
+		}
+	}
+
+	foreach (Bond bond, model.bonds) {
+		const SharedAtom a1 = bond.getAtom1();
+		const SharedAtom a2 = bond.getAtom2();
+
+		const Color4f &a1Color = colorScheme->getAtomColor(a1);
+		const Color4f &a2Color = colorScheme->getAtomColor(a2);
+
+		Vector3D middle = (a1->coord3d + a2->coord3d) / 2;
+
+		if (a1Color==viewAtomColor)
+		{
+			if (a1Color==a2Color)
+			{
+	//			glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a1Color);
+				glDrawCylinder(pObj, a1->coord3d, a2->coord3d, bondThickness, renderDetailLevel);
+			}
+			else
+			{
+//				glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a1Color);
+				glDrawCylinder(pObj, a1->coord3d, middle, bondThickness, renderDetailLevel);
+			}
+		}
+		if (a2Color == viewAtomColor)
+		{
+//			glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a2Color);
+			glDrawCylinder(pObj, middle, a2->coord3d, bondThickness, renderDetailLevel);
+		}
+	}
+
+	gluDeleteQuadric(pObj);
+}
+
+void DisplayLists::createBigDisplayList(float renderDetailLevel, const BioStruct3D& bioStruct, const QList<int> &modelIndexList, const BioStruct3DColorScheme* colorScheme)
+{
+    log.trace(QString("Disp Atom: renderDetailLevel %1").arg(renderDetailLevel));
+
+    glDeleteLists(BIG_DL_INDEX, 1);
+    // Create the id for the list
+    bigDL = glGenLists(BIG_DL_INDEX);
+
+    QList<Color4f> colors;
+
+    glNewList(bigDL,GL_COMPILE);
+
+    foreach (const SharedMolecule mol, bioStruct.moleculeMap) {
+        foreach (int index, modelIndexList) {
+            const Molecule3DModel& model = mol->models.at(index);
+
+            colors.clear();
+
+            foreach(const SharedAtom atom, model.atoms) {
+                Color4f atomColor = colorScheme->getAtomColor(atom);
+
+                if (colors.contains(atomColor))
+                {
+                    continue; // Atom and bonds with this color has been already viewed
+                }
+                else
+                {
+                    drawAtomsBonds(atomColor, renderDetailLevel, model, colorScheme);
+                    colors.push_back(atomColor);
+                }
+            }
+        }
+    }
+
+    glEndList();
+}
+
+
+
 } //namespace
