@@ -17,6 +17,9 @@ class GLUquadric;
 
 namespace GB2 { 
 
+class BioStruct3D;
+class BioStruct3DColorScheme;
+class Molecule3DModel;
 
 //! Color
 /*!
@@ -31,17 +34,20 @@ public:
     Color4f(const QColor& qColor);
     float operator [] (unsigned int i) const;
     Color4f& operator += (const Color4f& v);
-    Color4f& operator /= (double f);
+	Color4f& operator /= (double f);
+	bool operator == (const Color4f &a);
     const float* getConstData() const { return color; }
 };
 
+bool operator == (const Color4f &a, const Color4f &b);
+
 //! OpenGL drawable object
 class Object3D {
 protected:
     Color4f color;
 public:
     Object3D(const Color4f& cl) : color(cl) { }
-    virtual void draw() = 0;
+    virtual void draw(float renderDetailLevel) = 0;
     virtual ~Object3D() { }
 
 };
@@ -56,7 +62,7 @@ class Helix3D : public Object3D {
 public:
     Helix3D(const Color4f& cl, const Vector3D& c, const Vector3D& n, float r);
     ~Helix3D();
-    void draw();
+    void draw(float renderDetailLevel);
 };
 
 //! Beta Strand 3D representation
@@ -70,7 +76,7 @@ class Strand3D : public Object3D {
 public:
     Strand3D(const Color4f& cl, const Vector3D& c, const Vector3D& n, const Vector3D& up = Vector3D() );
     ~Strand3D();
-    void draw();
+    void draw(float renderDetailLevel);
 };
 
 
@@ -78,18 +84,18 @@ public:
 //! Draw arrow
 void glCreateArrowPrimitive(float width, float height, float length);
 //! Draw atom as sphere with center = pos and radius = r
-void glDrawAtom(GLUquadric* pObj, const Vector3D& pos, double r);
+void glDrawAtom(GLUquadric* pObj, const Vector3D& pos, double r, float renderDetailLevel);
 
 //! Draw cylinder from one point to another
-void glDrawCylinder(GLUquadric* pObj, const Vector3D& p1, const Vector3D& p2, double thickness);
+void glDrawCylinder(GLUquadric* pObj, const Vector3D& p1, const Vector3D& p2, double thickness, float renderDetailLevel);
 
 //! Draw a spline (worm) 
 /*! Function straight from CN3D Viewer, uses Catmull-Rom interpolation
 add a thick splined curve from point 1 *halfway* to point 2 */
 void glDrawHalfWorm(const Vector3D& p0, const Vector3D& p1, const Vector3D& p2, const Vector3D& p3,
-                  double radius, bool cap1, bool cap2, double tension);
+                  double radius, bool cap1, bool cap2, double tension, float renderDetailLevel);
 
-void glDrawHalfBond(GLUquadric *pObj, const Vector3D& p1, const Vector3D&p2, double thickness);
+void glDrawHalfBond(GLUquadric *pObj, const Vector3D& p1, const Vector3D&p2, double thickness, float renderDetailLevel);
 
 //! Project point on axis
 Vector3D projectPointOnAxis(const Vector3D& point, const Vector3D& axisUnitVector, const Vector3D& axisPoint);
@@ -98,14 +104,16 @@ Vector3D projectPointOnAxis(const Vector3D& point, const Vector3D& axisUnitVecto
 Vector3D calcMiddlePoint(const QVector<Vector3D>& points);
 
 class DisplayLists {
-    static unsigned int atomDL;
+    static unsigned int bigDL;
     static unsigned int vanDerWaalsDL;
-    static const int ATOM_DL_INDEX = 1;
+	static const int BIG_DL_INDEX = 1;
     static const int VANDERWAALS_DL_INDEX = 2;
 
+	static void drawAtomsBonds(const Color4f &viewAtomColor, float renderDetailLevel, const Molecule3DModel &model, const BioStruct3DColorScheme* colorScheme);
+
 public:
-    static void createAtomDisplayList();
-    static int getAtomDisplayList() { return atomDL; }
+	static void createBigDisplayList(float renderDetailLevel, const BioStruct3D& bioStruct, const QList<int> &modelIndexList, const BioStruct3DColorScheme* colorScheme);
+    static int getBigDisplayList() { return bigDL; }
 };
 
 
