@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -19,12 +19,15 @@
 #include <core_api/IOAdapter.h>
 #include <core_api/Log.h>
 #include <core_api/Task.h>
+#include <core_api/GUrlUtils.h>
+#include <core_api/DocumentUtils.h>
 
 #include <datatype/DNAChromatogram.h>
 
 #include <gobjects/DNASequenceObject.h>
 #include <gobjects/GObjectTypes.h>
 #include <gobjects/DNAChromatogramObject.h>
+#include <gobjects/GObjectUtils.h>
 
 #include <selection/DNASequenceSelection.h>
 
@@ -37,6 +40,8 @@
 #include <util_gui/AddNewDocumentDialogImpl.h>
 #include <util_gui/ProjectTreeController.h>
 #include <util_gui/ProjectTreeItemSelectorDialog.h>
+#include <util_tasks/TaskSignalMapper.h>
+#include <util_tasks/LoadDocumentTask.h>
 
 
 namespace GB2 {
@@ -44,36 +49,22 @@ namespace GB2 {
 ChromatogramView::ChromatogramView(QWidget* p, ADVSequenceObjectContext* v, GSequenceLineView* cv, const DNAChromatogram& chroma) 
 : GSequenceLineView(p, v), editDNASeq(NULL)
 {
+    showQVAction = new QAction(tr("Show quality bars"), this);
+    showQVAction->setCheckable(true);
+    showQVAction->setChecked(chroma.hasQV);
+    showQVAction->setEnabled(chroma.hasQV);
+    connect(showQVAction, SIGNAL(toggled(bool)), SLOT(completeUpdate()));
 
     renderArea = new ChromatogramViewRenderArea(this, chroma);
 
-    scaleBar = new QSlider(Qt::Vertical);
-    scaleBar->setRange(100,2000);
-    scaleBar->setTickPosition(QSlider::TicksLeft);
-    scaleBar->setTickInterval(100);
+    scaleBar = new ScaleBar();
+    scaleBar->slider()->setRange(100,2000);
+    scaleBar->slider()->setTickInterval(100);
     connect(scaleBar,SIGNAL(valueChanged(int)),SLOT(setRenderAreaHeight(int)));
-    scaleBar->setValue(200);//renderArea->height()-heightAreaBC in construct renderarea to def height
 
-    ra = (ChromatogramViewRenderArea *) renderArea;
+    ra = static_cast<ChromatogramViewRenderArea *>(renderArea);
     scaleBar->setValue(ra->height()-ra->getHeightAreaBC()+ra->addUpIfQVL);
 
-    minusButton = new QToolButton();
-    //icon
-    minusButton->setText(QString(tr("-")));
-    minusButton->setIcon(QIcon(":core/images/minus.png"));
-    minusButton->setFixedSize(20,20);
-    minusButton->setAutoRepeat(true);
-    minusButton->setAutoRepeatInterval(20);
-    plusButton = new QToolButton();
-    //icon
-    plusButton->setText(QString(tr("+")));
-    plusButton->setIcon(QIcon(":core/images/plus.png"));
-    plusButton->setAutoRepeat(true);
-    plusButton->setAutoRepeatInterval(20);
-    plusButton->setFixedSize(20,20);
-    connect(minusButton,SIGNAL(clicked()),SLOT(sl_minusButtonClicked()));
-    connect(plusButton,SIGNAL(clicked()),SLOT(sl_plusButtonClicked()));
-
     setConherentRangeView(cv);
     
     mP = new QMenu(this);
@@ -105,18 +96,11 @@ ChromatogramView::ChromatogramView(QWidget* p, ADVSequenceObjectContext* v, GSeq
 void ChromatogramView::pack() {
 
     assert(layout() == NULL);
-    //layout
-    QVBoxLayout *zoomLayout = new QVBoxLayout();
-    zoomLayout->addWidget(plusButton);
-    zoomLayout->addWidget(scaleBar);
-    zoomLayout->addWidget(minusButton);
-    zoomLayout->setMargin(0);
-    zoomLayout->setSpacing(0);
 
     QHBoxLayout *layout = new QHBoxLayout();
     layout->setMargin(0);
     layout->addWidget(renderArea);
-    layout->addLayout(zoomLayout);
+    layout->addWidget(scaleBar);
     setLayout(layout);
 
     scrollBar->setHidden(true); //todo: support mode without scrollbar at all??
@@ -128,19 +112,9 @@ void ChromatogramView::pack() {
 void ChromatogramView::setRenderAreaHeight(int k)
 {
     //k = chromaMax
-    ChromatogramViewRenderArea* cvra = (ChromatogramViewRenderArea*) renderArea;
+    ChromatogramViewRenderArea* cvra = static_cast<ChromatogramViewRenderArea*>(renderArea);
     cvra->setAreaHeight(k);
-    addUpdateFlags(GSLV_UF_NeedCompleteRedraw);    
-    update();
-}
-
-#define SCALEBAR_DIFF 5
-void ChromatogramView::sl_minusButtonClicked() {
-    scaleBar->setValue(scaleBar->value()-SCALEBAR_DIFF);
-}
-
-void ChromatogramView::sl_plusButtonClicked() {
-    scaleBar->setValue(scaleBar->value()+SCALEBAR_DIFF);
+    completeUpdate();
 }
 
 void ChromatogramView::buildPopupMenu(QMenu& m) {
@@ -151,6 +125,7 @@ void ChromatogramView::buildPopupMenu(QMenu& m) {
     //todo: move to submenus?
     QAction* before = GUIUtils::findActionAfter(m.actions(), ADV_MENU_ZOOM);
 
+    m.insertAction(before, showQVAction);
     m.insertSeparator(before);
     if (editDNASeq != NULL) {
         m.insertAction(before, clearEditableSequence);
@@ -196,15 +171,20 @@ void ChromatogramView::sl_onPopupMenuCkicked(QAction* a) {
         QMessageBox::critical(this, tr("error"), tr("sequence_object_was_locked"));
         return;
     }
-    switch (a->text().at(0).toAscii()) {
-        case 'A': editDNASeq->setBase(selIndex, 'A');break;
-        case 'C': editDNASeq->setBase(selIndex, 'C');break;
-        case 'G': editDNASeq->setBase(selIndex, 'G');break;
-        case 'T': editDNASeq->setBase(selIndex, 'T');break;
-        case 'N': editDNASeq->setBase(selIndex, 'N');break;
-    };
-    if (indexOfChangedChars.count(selIndex) == 0) {
-        indexOfChangedChars.push_back(selIndex);
+    char newBase = a->text().at(0).toAscii();
+    if (newBase != editDNASeq->getSequence().at(selIndex)) {
+        switch (newBase) {
+            case 'A': editDNASeq->setBase(selIndex, 'A');break;
+            case 'C': editDNASeq->setBase(selIndex, 'C');break;
+            case 'G': editDNASeq->setBase(selIndex, 'G');break;
+            case 'T': editDNASeq->setBase(selIndex, 'T');break;
+            case 'N': editDNASeq->setBase(selIndex, 'N');break;
+        };
+        indexOfChangedChars.insert(selIndex);
+        char refBase = ctx->getSequenceData().at(selIndex);
+        if (newBase == refBase) {
+            indexOfChangedChars.remove(selIndex);
+        }
     }
     ra->hasSel = false;
     update();
@@ -217,8 +197,11 @@ void ChromatogramView::sl_addNewSequenceObject() {
 
     AddNewDocumentDialogModel m;
     DocumentFormatConstraints c;
-    c.mustSupportWrite = true;
-    c.supportedObjectTypes.append(GObjectTypes::DNA_SEQUENCE);
+    
+    GUrl seqUrl = ctx->getSequenceGObject()->getDocument()->getURL();
+    m.url = GUrlUtils::rollFileName(seqUrl.dirPath() + "/" + seqUrl.baseFileName() + "_sequence.fa", DocumentUtils::getNewDocFileNameExcludesHint());
+    c.addFlagToSupport(DocumentFormatFlag_SupportWriting);
+    c.supportedObjectTypes+=GObjectTypes::SEQUENCE;
     AddNewDocumentDialogImpl::run(NULL, m, c);
     if (!m.successful) {
         return;
@@ -244,22 +227,44 @@ void ChromatogramView::sl_onAddExistingSequenceObject() {
 
     ProjectTreeControllerModeSettings s;
     s.allowMultipleSelection = false;
-    s.objectTypesToShow.append(GObjectTypes::DNA_SEQUENCE);
+    s.objectTypesToShow.append(GObjectTypes::SEQUENCE);
     DNASequenceObjectConstraints ac;
     ac.exactSequenceSize = ctx->getSequenceObject()->getSequence().length();
     s.objectConstraints.append(&ac);
     ac.alphabetType = ctx->getSequenceObject()->getAlphabet()->getType();
-    s.sorted = true;
+    s.groupMode = ProjectTreeGroupMode_Flat;
     foreach(GObject* o, ctx->getAnnotatedDNAView()->getObjects()) {
         s.excludeObjectList.append(o);
     }
 
-    QList<GObject*> objs = ProjectTreeItemSelectorDialog::selectObjects(s);
-    if (objs.size()!=0)	{
-        editDNASeq = qobject_cast<DNASequenceObject*>(objs.first());
+    QList<GObject*> objs = ProjectTreeItemSelectorDialog::selectObjects(s, this);
+    if (objs.size()!=0) {
+        GObject* go = objs.first();
+        if (go->getGObjectType() == GObjectTypes::SEQUENCE) {
+            editDNASeq = qobject_cast<DNASequenceObject*>(go);
+            QString err = ctx->getAnnotatedDNAView()->addObject(editDNASeq);
+            assert(err.isEmpty());
+            indexOfChangedChars.clear();
+        } else if (go->getGObjectType() == GObjectTypes::UNLOADED) {
+            LoadUnloadedDocumentTask* t = new LoadUnloadedDocumentTask(go->getDocument(), 
+                LoadDocumentTaskConfig(false, GObjectReference(go)));
+            connect(new TaskSignalMapper(t), SIGNAL(si_taskSucceeded(Task*)), SLOT(sl_onSequenceObjectLoaded(Task*)));
+            AppContext::getTaskScheduler()->registerTopLevelTask(t);
+        }
+    }
+}
+
+void ChromatogramView::sl_onSequenceObjectLoaded(Task* t) {
+    LoadUnloadedDocumentTask* lut = qobject_cast<LoadUnloadedDocumentTask*>(t);
+    GObject* go = GObjectUtils::selectObjectByReference(lut->getConfig().checkObjRef, 
+        lut->getDocument()->getObjects(), UOF_LoadedOnly);
+    assert(go);
+    if (go) {
+        editDNASeq = qobject_cast<DNASequenceObject*>(go);
         QString err = ctx->getAnnotatedDNAView()->addObject(editDNASeq);
         assert(err.isEmpty());
         indexOfChangedChars.clear();
+        update();
     }
 }
 
@@ -274,7 +279,7 @@ void ChromatogramView::sl_clearEditableSequence() {
     ctx->getAnnotatedDNAView()->removeObject(editDNASeq);
 }
 
-void ChromatogramView::sl_removeChanges()	{
+void ChromatogramView::sl_removeChanges()   {
     if (editDNASeq->isStateLocked()) {
         QMessageBox::critical(this, tr("error"), tr("sequence_object_was_locked"));
         return;
@@ -282,7 +287,7 @@ void ChromatogramView::sl_removeChanges()	{
 
     DNASequenceObject* seqObject = ctx->getSequenceObject();
     const QByteArray& sequence = seqObject->getSequence();
-    for (QList<int>::iterator it = indexOfChangedChars.begin(); it != indexOfChangedChars.end(); ++it)	{
+    for (QSet<int>::const_iterator it = indexOfChangedChars.constBegin(); it != indexOfChangedChars.constEnd(); ++it)  {
         editDNASeq->setBase(*it, sequence[*it]);
     }
     indexOfChangedChars.clear();
@@ -290,7 +295,7 @@ void ChromatogramView::sl_removeChanges()	{
 
 bool ChromatogramView::checkObject(GObject* obj) {
     //TODO: check state lock on modifications too!!!
-    if (obj->getGObjectType()!=GObjectTypes::DNA_SEQUENCE || obj->isStateLocked()) {
+    if (obj->getGObjectType()!=GObjectTypes::SEQUENCE || obj->isStateLocked()) {
         return false;   
     }
     DNASequenceObject* dnaObj = qobject_cast<DNASequenceObject*>(obj);
@@ -301,7 +306,7 @@ bool ChromatogramView::checkObject(GObject* obj) {
 }
 
 
-void ChromatogramView::sl_onObjectRemoved(GObjectView* view, GObject* obj)	{
+void ChromatogramView::sl_onObjectRemoved(GObjectView* view, GObject* obj)  {
     Q_UNUSED(view);
 
     if (editDNASeq==NULL || !checkObject(obj)) {
@@ -339,10 +344,10 @@ ChromatogramViewRenderArea::ChromatogramViewRenderArea(ChromatogramView* p, cons
         if (chromaMax<chroma.T[i]) chromaMax=chroma.T[i];
     }
     hasSel = false;
-    if (chroma.hasQV)	{
+    if (chroma.hasQV && p->showQV()) {
         addUpIfQVL = 0;
     }
-    else	{
+    else    {
         addUpIfQVL = heightAreaBC - 2*charHeight;
         setFixedHeight(height()-addUpIfQVL);
         areaHeight = height()-heightAreaBC + addUpIfQVL;
@@ -361,6 +366,7 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
     static const qreal dividerTraceOrBaseCallsLines = 2;
     static const qreal dividerBoolShowBaseCallsChars = 1.5;
 
+    ChromatogramView* chromaView = qobject_cast<ChromatogramView*>(view);
 
     //get sequence
     const LRegion& visible = view->getVisibleRange();
@@ -384,8 +390,8 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
             //draw basecalls
             drawOriginalBaseCalls(0, heightAreaBC-charHeight-addUpIfQVL, width(), charHeight, p, visible, ba); 
 
-            if (chroma.hasQV)	{
-                drawQualityValues(0, charHeight, width(), heightAreaBC - 2*charHeight, p, visible, ba);		
+            if (chroma.hasQV && chromaView->showQV()) {
+                drawQualityValues(0, charHeight, width(), heightAreaBC - 2*charHeight, p, visible, ba);     
             }
             //drawOriginalBaseCalls(0, 0, width(), charHeight, p, visible, qobject_cast<ChromatogramView*>(view)->fastaSeq, false);
         } else {
@@ -416,7 +422,7 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
         p.drawRect(selRect);
         hasSel = false;
     }
-    ChromatogramView* chromaView = qobject_cast<ChromatogramView*>(view);
+
     if (pd->width() / charWidth > visible.len /dividerBoolShowBaseCallsChars && chromaView->editDNASeq!=NULL) {
         drawOriginalBaseCalls(0, 0, width(), charHeight, p, visible, chromaView->editDNASeq->getSequence(), false);
     }
@@ -433,13 +439,13 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
         if (sel.size() >= 1) {
             LRegion self=sel.first();
             int i1=self.startPos,i2=self.endPos()-1;
-            if (i1!=0)	{
+            if (i1!=0)  {
                 p.drawLine((k*chroma.baseCalls[i1]+b+k*chroma.baseCalls[i1-1]+b)/2,0,
                     (k*chroma.baseCalls[i1]+b+k*chroma.baseCalls[i1-1]+b)/2,pd->height());
             }else {
                 p.drawLine(k*chroma.baseCalls[i1]+b-charWidth/2,0,k*chroma.baseCalls[i1]+b-charWidth/2,pd->height());
             }
-            if (i2!=chroma.seqLength-1)	{
+            if (i2!=chroma.seqLength-1) {
                 p.drawLine((k*chroma.baseCalls[i2]+b+k*chroma.baseCalls[i2+1]+b)/2,0,
                     (k*chroma.baseCalls[i2]+b+k*chroma.baseCalls[i2+1]+b)/2,pd->height());
             } else { 
@@ -509,7 +515,7 @@ void ChromatogramViewRenderArea::drawChromatogramTrace(qreal x, qreal y, qreal w
     p.translate(x,y+h);
 
     //drawBoundingRect
-    /*	p.drawLine(0,0,w,0);
+    /*  p.drawLine(0,0,w,0);
     p.drawLine(0,-h,w,-h);
     p.drawLine(0,0,0,-h);
     p.drawLine(w,0,w,-h);*/
@@ -570,7 +576,7 @@ void ChromatogramViewRenderArea::drawOriginalBaseCalls(qreal x, qreal y, qreal w
     qreal kLinearTransformBaseCalls = qreal (k1) / k2;
     qreal bLinearTransformBaseCalls = leftMargin - kLinearTransformBaseCalls*a1;
 
-    if (!is)	{
+    if (!is)    {
         kLinearTransformBaseCallsOfEdited = kLinearTransformBaseCalls;
         bLinearTransformBaseCallsOfEdited = bLinearTransformBaseCalls;
         xBaseCallsOfEdited = x;
@@ -579,22 +585,27 @@ void ChromatogramViewRenderArea::drawOriginalBaseCalls(qreal x, qreal y, qreal w
         hBaseCallsOfEdited = h;
     }
     ChromatogramView* cview = qobject_cast<ChromatogramView*>(view);
-    for (int i=visible.startPos;i<visible.endPos();i++)	{
-        p.setPen(Qt::black);
+    for (int i=visible.startPos;i<visible.endPos();i++) {
+        QColor color = getBaseColor(ba[i]);
+        p.setPen(color);
 
-        if (cview->indexOfChangedChars.count(i) == 1 && !is) p.setFont(fontBold); else p.setFont(font);
+        if (cview->indexOfChangedChars.contains(i) && !is) {
+            p.setFont(fontBold);
+        } else {
+            p.setFont(font);
+        }
         int xP = kLinearTransformBaseCalls*chroma.baseCalls[i] + bLinearTransformBaseCalls;
         rect.setRect(xP - charWidth/2 + linePen.width(), -h, charWidth, h);
         p.drawText(rect, Qt::AlignCenter, QString(ba[i]));
 
-        if (is)	{
+        if (is) {
             p.setPen(linePen);
             p.setRenderHint(QPainter::Antialiasing, false);
             p.drawLine(xP, 0, xP, height()-y);
         }
     }
 
-    if (is)	{
+    if (is) {
         p.setPen(linePen);
         p.setFont(QFont(QString("Courier New"), 8));
         p.drawText(charWidth*1.3, charHeight/2, QString(tr("original")));
@@ -614,51 +625,50 @@ void ChromatogramViewRenderArea::drawQualityValues(qreal x, qreal y, qreal w, qr
     p.setRenderHint(QPainter::Antialiasing, false);
     for (int i = 0; i < 5; ++i) p.drawLine(0,-h*i/4, w, -h*i/4);
 
-    QLinearGradient gradient(10, 0, 10, -h);
-    gradient.setColorAt(0, Qt::green);
-    gradient.setColorAt(0.33, Qt::yellow);
-    gradient.setColorAt(0.66, Qt::red); 
-    QBrush brush(gradient); 	
+     QLinearGradient gradient(10, 0, 10, -h);
+     gradient.setColorAt(0, Qt::green);
+     gradient.setColorAt(0.33, Qt::yellow);
+     gradient.setColorAt(0.66, Qt::red); 
+     QBrush brush(gradient);     
+ 
+     p.setBrush(brush);
+     p.setPen(Qt::black);
+     p.setRenderHint(QPainter::Antialiasing, true);
+ 
+ 
+ 
+     int a1 = chroma.baseCalls[visible.startPos];
+     int a2 = chroma.baseCalls[visible.endPos()-1];
+     qreal leftMargin, rightMargin;
+     leftMargin = rightMargin = charWidth;
+     qreal k1 = w - leftMargin  - rightMargin;
+     int k2 = a2 - a1;
+     qreal kLinearTransformQV = qreal (k1) / k2;
+     qreal bLinearTransformQV = leftMargin - kLinearTransformQV*a1;
+ 
+     for (int i=visible.startPos;i<visible.endPos();i++) {
+         int xP = kLinearTransformQV*chroma.baseCalls[i] + bLinearTransformQV - charWidth/2 + linePen.width();
+         switch (ba[i])  {
+             case 'A':
+                 rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_A[i]);
+                 break;
+             case 'C': 
+                 rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_C[i]);
+                 break;
+             case 'G': 
+                 rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_G[i]);
+                 break;
+             case 'T': 
+                 rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_T[i]);
+                 break;
+         } 
+         if (qAbs( rectangle.height() ) > h/100) {
+            p.drawRoundedRect(rectangle, 1.0, 1.0);
+         }
 
-    p.setBrush(brush);
-    p.setPen(Qt::black);
-    p.setRenderHint(QPainter::Antialiasing, true);
-
-
-
-    int a1 = chroma.baseCalls[visible.startPos];
-    int a2 = chroma.baseCalls[visible.endPos()-1];
-    qreal leftMargin, rightMargin;
-    leftMargin = rightMargin = charWidth;
-    qreal k1 = w - leftMargin  - rightMargin;
-    int k2 = a2 - a1;
-    qreal kLinearTransformQV = qreal (k1) / k2;
-    qreal bLinearTransformQV = leftMargin - kLinearTransformQV*a1;
-
-    for (int i=visible.startPos;i<visible.endPos();i++)	{
-        int xP = kLinearTransformQV*chroma.baseCalls[i] + bLinearTransformQV - charWidth/2 + linePen.width();
-        switch (ba[i])	{
-            case 'A':
-                rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_A[i]);
-                p.drawRoundedRect(rectangle, 1.0, 1.0); 
-                p.drawLine(xP, 0, xP, -h/100*chroma.prob_A[i]);
-                break;
-            case 'C': 
-                rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_C[i]);
-                p.drawRoundedRect(rectangle, 1.0, 1.0); 
-                break;
-            case 'G': 
-                rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_G[i]);
-                p.drawRoundedRect(rectangle, 1.0, 1.0); 
-                break;
-            case 'T': 
-                rectangle.setCoords(xP, 0, xP+charWidth, -h/100*chroma.prob_T[i]);
-                p.drawRoundedRect(rectangle, 1.0, 1.0); 
-                break;
-        }	
-    }
-
-    p.resetTransform();
+     }
+ 
+     p.resetTransform();
 }
 
 void ChromatogramViewRenderArea::drawChromatogramBaseCallsLines(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible, const QByteArray& ba)
@@ -670,7 +680,7 @@ void ChromatogramViewRenderArea::drawChromatogramBaseCallsLines(qreal x, qreal y
     p.resetTransform();
     p.translate(x,y+h);
 
-    /*	//drawBoundingRect
+    /*  //drawBoundingRect
     p.drawLine(0,0,w,0);
     p.drawLine(0,-h,w,-h);
     p.drawLine(0,0,0,-h);
@@ -693,7 +703,7 @@ void ChromatogramViewRenderArea::drawChromatogramBaseCallsLines(qreal x, qreal y
             break;
         }
         double x = kLinearTransformTrace*temp+bLinearTransformTrace;
-        switch (ba[j])	{
+        switch (ba[j])  {
             case 'A': 
                 yRes = -qMin<double>(chroma.A[temp]*areaHeight/chromaMax, h);
                 p.setPen(colorForIds[0]);
@@ -712,14 +722,31 @@ void ChromatogramViewRenderArea::drawChromatogramBaseCallsLines(qreal x, qreal y
                 break;
             case 'N':
                 continue;
-        };		
+        };      
         p.drawLine(x, 0, x, yRes);
     }
     p.resetTransform();
 }
 
+QColor ChromatogramViewRenderArea::getBaseColor( char base )
+{
 
-
-
+    switch(base) {
+        case 'A':
+            return Qt::darkGreen;
+        case 'C':
+            return Qt::blue;
+        case 'G':
+            return Qt::black;
+        case 'T':
+            return Qt::red;
+        default:
+            return Qt::black;
+    }
 
 }
+
+
+
+
+} // namespace
