@@ -59,7 +59,7 @@ private:
     bool checkObject(GObject* obj);
 
     DNASequenceObject*			editDNASeq;
-    QList<int>					indexOfChangedChars;
+    QSet<int>					indexOfChangedChars;
 
     ScaleBar*					scaleBar;
 	ChromatogramViewRenderArea* ra;
@@ -95,7 +95,8 @@ protected:
 	virtual void drawAll(QPaintDevice* pd);
 
 private:
-	void drawChromatogramTrace(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible);
+    QColor getBaseColor(char base);
+    void drawChromatogramTrace(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible);
 	void drawOriginalBaseCalls(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible, const QByteArray& ba, bool is = true);
 	void drawQualityValues(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible, const QByteArray& ba);
 	void drawChromatogramBaseCallsLines(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible, const QByteArray& ba);
