@@ -13,13 +13,12 @@
 
 #include <core_api/PluginModel.h>
 #include <core_api/ServiceModel.h>
-#include <core_api/ObjectViewModel.h>
-
-#include <QtCore/QMap>
-#include <QtGui/QAction>
 
 namespace GB2 {
 
+class ExportProjectViewItemsContoller;
+class ExportSequenceViewItemsController;
+
 class DNAExportPlugin : public Plugin {
     Q_OBJECT
 public:
@@ -31,41 +30,15 @@ class DNAExportService: public Service {
     Q_OBJECT
 public:
     DNAExportService();
+
 protected:
     virtual void serviceStateChangedCallback(ServiceState oldState, bool enabledStateChanged);
 
-private slots:
-    void sl_addToProjectViewMenu(QMenu&);
-    
-    void sl_saveSequencesToFasta();
-    void sl_saveSequencesToClustal();
-    void sl_saveAlignmentToFasta();
-
-private:
-
-    QAction* exportSequencesToFastaAction;
-    QAction* exportSequencesToClustalAction;
-    QAction* exportAlignmentToFastaAction;
-    
-    GObjectViewWindowContext* viewContext;
+    ExportProjectViewItemsContoller*    projectViewController;
+    ExportSequenceViewItemsController*  sequenceViewController;
 
 };
 
-class DNAExportViewContext : public GObjectViewWindowContext {
-    Q_OBJECT
-public:
-    DNAExportViewContext(QObject* p);
-
-protected slots:
-    void sl_saveAnnotationsToFasta();
-    void sl_saveSequenceToFasta();
-    void sl_saveAnnotationsToCSV();
-
-protected:
-    virtual void initViewContext(GObjectView* view);
-    virtual void buildMenu(GObjectView* v, QMenu* m);
-
-};
 
 } //namespace
 
