@@ -17,6 +17,7 @@
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
+#include <QtCore/QSet>
 
 namespace GB2 {
 
@@ -31,6 +32,7 @@ class EnzymesIO : public QObject {
     Q_OBJECT
 public:
     static QList<SEnzymeData> readEnzymes(const QString& url, TaskStateInfo& ti);
+    static void writeEnzymes(const QString& url, const QString& source, const QSet<QString>& enzymes, TaskStateInfo& ti);
     static QString getFileDialogFilter();
 
     static SEnzymeData findEnzymeById(const QString& id, const QList<SEnzymeData>& enzymes);
@@ -38,6 +40,7 @@ public:
 private:
     static EnzymeFileFormat detectFileFormat(const QString& url);
     static QList<SEnzymeData> readBairochFile(const QString& url, IOAdapterFactory* iof, TaskStateInfo& ti);
+    static void writeBairochFile(const QString& url, IOAdapterFactory* iof, const QString& source, IOAdapterFactory* srciof, const QSet<QString>& enzymes, TaskStateInfo& ti);
 };
 
 class LoadEnzymeFileTask : public Task {
@@ -51,6 +54,17 @@ public:
     QList<SEnzymeData> enzymes;
 };
 
+class SaveEnzymeFileTask : public Task {
+    Q_OBJECT
+public:
+    SaveEnzymeFileTask(const QString& url, const QString& source, const QSet<QString>& enzymes);
+    void run();
+
+    QString url;
+    QString source;
+    QSet<QString> enzymes;
+};
+
 } //namespace
 
 #endif
