@@ -34,6 +34,7 @@
 #include <QtGui/QTreeWidget>
 #include <QtGui/QMessageBox>
 #include <QtGui/QFileDialog>
+#include <QtGui/QInputDialog>
 #include <QtGui/QHeaderView>
 
 //TODO: group by TYPE, ORGANIZM
@@ -45,7 +46,7 @@ namespace GB2 {
 #define DATA_FILE_KEY           QString("plugin_enzymes/lastFile")
 #define LAST_SELECTION_KEY      QString("plugin_enzymes/selection")
 #define SEP                     (",")
-#define DEFAULT_ENZYMES_FILE    QString("rebase_v901_t2_com.bairoch.gz")
+#define DEFAULT_ENZYMES_FILE    QString("rebase_v003_t2_com.bairoch.gz")
 #define ANY_VALUE -1
 
 static LogCategory log(ULOG_ENZYME_PLUGIN);
@@ -89,10 +90,14 @@ FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
     maxHitSB->setValue(ANY_VALUE);
     minHitSB->setValue(ANY_VALUE);
 
+    minLength = 1;
+
     connect(enzymesFileButton, SIGNAL(clicked()), SLOT(sl_selectFile()));
     connect(selectAllButton, SIGNAL(clicked()), SLOT(sl_selectAll()));
     connect(selectNoneButton, SIGNAL(clicked()), SLOT(sl_selectNone()));
+    connect(selectByLengthButton, SIGNAL(clicked()), SLOT(sl_selectByLength()));
     connect(invertSelectionButton, SIGNAL(clicked()), SLOT(sl_inverseSelection()));
+    connect(saveSelectionButton, SIGNAL(clicked()), SLOT(sl_saveSelectionToFile()));
     connect(enzymeInfo, SIGNAL(clicked()), SLOT(sl_openDBPage()));
 
     CreateAnnotationModel acm;
@@ -165,6 +170,40 @@ void FindEnzymesDialog::loadFile(const QString& url) {
     setEnzymesList(enzymes);
 }
 
+void FindEnzymesDialog::saveFile(const QString& url) {
+    TaskStateInfo ti;
+    QString source = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
+    
+    GTIMER(c1,t1,"FindEnzymesDialog::saveFile [EnzymesIO::writeEnzymes]");
+    
+    QSet<QString> enzymes;
+
+    for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
+        for (int j=0, m = gi->childCount(); j < m; j++) {
+            EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
+            if (item->checkState(0) == Qt::Checked) {
+                enzymes.insert(item->enzyme->id);
+            }
+        }
+    }
+
+    EnzymesIO::writeEnzymes(url, source, enzymes, ti);
+    
+    if (ti.hasErrors()) {
+        if (isVisible()) {
+            QMessageBox::critical(NULL, tr("Error"), ti.getError());
+        } else  {
+            log.error(ti.getError());
+        }
+        return;
+    }
+    if (QMessageBox::question(this, tr("New enzymes database has been saved."),
+        tr("Do you want to work with new database?"), QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes) {
+        loadFile(url);
+    }
+}
+
 void FindEnzymesDialog::setEnzymesList(const QList<SEnzymeData>& enzymes) {
     tree->setSortingEnabled(false);
     tree->disconnect(this);
@@ -183,7 +222,7 @@ void FindEnzymesDialog::setEnzymesList(const QList<SEnzymeData>& enzymes) {
         
     }
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)tree->topLevelItem(i);
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         gi->updateVisual();
     }
     if (tree->topLevelItemCount() > 0 && tree->topLevelItem(0)->childCount() < 10) {
@@ -208,7 +247,7 @@ void FindEnzymesDialog::setEnzymesList(const QList<SEnzymeData>& enzymes) {
 
 EnzymeGroupTreeItem* FindEnzymesDialog::findGroupItem(const QString& s, bool create) {
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)tree->topLevelItem(i);
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         if (gi->s == s) {
             return gi;
         }
@@ -225,7 +264,7 @@ void FindEnzymesDialog::updateStatus() {
     int nChecked = 0;
     QStringList checkedNamesList;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
-        EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)tree->topLevelItem(i);
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         nChecked+= gi->checkedEnzymes.size();
         foreach(const EnzymeTreeItem* ci, gi->checkedEnzymes) {
             checkedNamesList.append(ci->enzyme->id);
@@ -248,9 +287,9 @@ void FindEnzymesDialog::sl_selectFile() {
 void FindEnzymesDialog::sl_selectAll() {
     ignoreItemChecks =  true;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
-        EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)tree->topLevelItem(i);
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         for (int j=0, m = gi->childCount(); j < m; j++) {
-            EnzymeTreeItem* item = (EnzymeTreeItem*)gi->child(j);
+            EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
             item->setCheckState(0, Qt::Checked);
         }
         gi->updateVisual();
@@ -262,9 +301,9 @@ void FindEnzymesDialog::sl_selectAll() {
 void FindEnzymesDialog::sl_selectNone() {
     ignoreItemChecks = true;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
-        EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)tree->topLevelItem(i);
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         for (int j=0, m = gi->childCount(); j < m; j++) {
-            EnzymeTreeItem* item = (EnzymeTreeItem*)gi->child(j);
+            EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
             item->setCheckState(0, Qt::Unchecked);
         }
         gi->updateVisual();
@@ -273,12 +312,35 @@ void FindEnzymesDialog::sl_selectNone() {
     updateStatus();
 }
 
+void FindEnzymesDialog::sl_selectByLength() {
+    bool ok;
+    int len = QInputDialog::getInt(this, tr("Minimum length"), tr("Enter minimum length of recognition sites"), minLength, 1, 20, 1, &ok);
+    if (ok) {
+        minLength = len;
+        ignoreItemChecks = true;
+        for(int i = 0, n = tree->topLevelItemCount(); i < n; i++){
+            EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
+            for (int j=0, m = gi->childCount(); j < m; j++) {
+                EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
+                if (item->enzyme->seq.length() < len) {
+                    item->setCheckState(0, Qt::Unchecked);
+                } else {
+                    item->setCheckState(0, Qt::Checked);
+                }
+            }
+            gi->updateVisual();
+        }
+        ignoreItemChecks = false;
+    }
+    updateStatus();
+}
+
 void FindEnzymesDialog::sl_inverseSelection() {
     ignoreItemChecks = true;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
-        EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)tree->topLevelItem(i);
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         for (int j=0, m = gi->childCount(); j < m; j++) {
-            EnzymeTreeItem* item = (EnzymeTreeItem*)gi->child(j);
+            EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
             Qt::CheckState oldState = item->checkState(0);
             item->setCheckState(0, oldState == Qt::Checked ? Qt::Unchecked : Qt::Checked);
         }
@@ -288,15 +350,24 @@ void FindEnzymesDialog::sl_inverseSelection() {
     updateStatus();
 }
 
+void FindEnzymesDialog::sl_saveSelectionToFile() {
+    LastOpenDirHelper dir(DATA_DIR_KEY);
+    dir.url = QFileDialog::getSaveFileName(this, tr("Select enzyme database file"), dir.dir, EnzymesIO::getFileDialogFilter());
+    if (!dir.url.isEmpty()) {
+        saveFile(dir.url);
+    }
+    updateStatus();
+}
+
 #define MAX_ENZYMES_TO_FIND 100*1000
 
 void FindEnzymesDialog::accept() {
     QList<SEnzymeData> selectedEnzymes;
     lastSelection.clear();
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
-        EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)tree->topLevelItem(i);
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         for (int j=0, m = gi->childCount(); j < m; j++) {
-            EnzymeTreeItem* item = (EnzymeTreeItem*)gi->child(j);
+            EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
             if (item->checkState(0) == Qt::Checked) {
                 selectedEnzymes.append(item->enzyme);
                 lastSelection.insert(item->enzyme->id);
@@ -347,9 +418,10 @@ void FindEnzymesDialog::accept() {
     QString group = m.groupName;
     AnnotationTableObject* obj = m.getAnnotationObject();
     assert(!group.isEmpty() && obj!=NULL);
+    bool circular = circularButton->isChecked();
     
     FindEnzymesToAnnotationsTask* task = new FindEnzymesToAnnotationsTask(obj, group, seqCtx->getSequenceObject()->getDNASequence(),
-                                                    range, selectedEnzymes, MAX_ENZYMES_TO_FIND, minHitVal, maxHitVal); 
+                                                    range, selectedEnzymes, MAX_ENZYMES_TO_FIND, minHitVal, maxHitVal, circular); 
     AppContext::getTaskScheduler()->registerTopLevelTask(task);
   
     QDialog::accept();
@@ -357,7 +429,7 @@ void FindEnzymesDialog::accept() {
 
 void FindEnzymesDialog::sl_openDBPage() {
     QTreeWidgetItem* ci = tree->currentItem();
-    EnzymeTreeItem* item = ci == NULL || ci->parent() == 0 ? NULL : (EnzymeTreeItem*)tree->currentItem();
+    EnzymeTreeItem* item = ci == NULL || ci->parent() == 0 ? NULL : static_cast<EnzymeTreeItem*>(tree->currentItem());
     if (item == NULL) {
         QMessageBox::critical(this, tr("Error!"), tr("No enzyme selected!"));
         return;
@@ -376,8 +448,8 @@ void FindEnzymesDialog::sl_itemChanged(QTreeWidgetItem* item, int col) {
     if (item->parent() == NULL  || col != 0 || ignoreItemChecks) {
         return;
     }
-    EnzymeTreeItem* ei = (EnzymeTreeItem*)item;
-    EnzymeGroupTreeItem* gi = (EnzymeGroupTreeItem*)ei->parent();
+    EnzymeTreeItem* ei = static_cast<EnzymeTreeItem*>(item);
+    EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(ei->parent());
     gi->updateVisual();
     updateStatus();
 }
@@ -418,7 +490,7 @@ void EnzymeGroupTreeItem::updateVisual() {
     int numChilds = childCount();
     checkedEnzymes.clear();
     for (int i=0; i < numChilds; i++) {
-        EnzymeTreeItem* item = (EnzymeTreeItem*)child(i);
+        EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(child(i));
         if (item->checkState(0) == Qt::Checked) {
             checkedEnzymes.insert(item);
         }
@@ -427,9 +499,9 @@ void EnzymeGroupTreeItem::updateVisual() {
     setText(0, text0);
     
     if (numChilds > 0) {
-        QString text4 = ((EnzymeTreeItem*)child(0))->enzyme->id;
+        QString text4 = (static_cast<EnzymeTreeItem*>(child(0)))->enzyme->id;
         if (childCount() > 1) {
-            text4+=" .. "+((EnzymeTreeItem*)child(numChilds-1))->enzyme->id;
+            text4+=" .. "+(static_cast<EnzymeTreeItem*>(child(numChilds-1)))->enzyme->id;
         }
         setText(4, text4);
     }
