@@ -28,6 +28,8 @@
 
 #include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
 #include <util_ov_annotated_dna/AnnotatedDNAView.h>
+#include <util_ov_annotated_dna/ADVSingleSequenceWidget.h>
+#include <util_ov_annotated_dna/PanView.h>
 #include <util_gui/CreateAnnotationDialog.h>
 #include <util_gui/CreateAnnotationWidgetController.h>
 
@@ -95,6 +97,17 @@ ORFDialog::ORFDialog(ADVSequenceObjectContext* _ctx)
     }
     connect(transCombo, SIGNAL(currentIndexChanged ( int )), SLOT(sl_translationChanged()));    
     sl_translationChanged();
+
+    foreach(ADVSequenceWidget *w, ctx->getSequenceWidgets()){
+        ADVSingleSequenceWidget* a = qobject_cast<ADVSingleSequenceWidget*>(w);
+        if(a){
+            panViewSelection = a->getPanView()->getVisibleRange();
+            if(a->isPanViewCollapsed()){
+                pbRangeToPan->setDisabled(true);
+            }
+            break;
+        }
+    }
 }
 
 static QString triplet2str(const Triplet& t) {
@@ -212,7 +225,7 @@ bool ORFDialog::eventFilter(QObject *obj, QEvent *ev) {
     if (obj == resultsTree && ev->type() == QEvent::KeyPress) {
         QKeyEvent* ke = (QKeyEvent*)ev;
         if (ke->key() == Qt::Key_Space) {
-            ORFListItem* item = (ORFListItem*)resultsTree->currentItem();
+            ORFListItem* item = static_cast<ORFListItem*>(resultsTree->currentItem());
             if (item != NULL) {
                 sl_onResultActivated(item, 0);
             }
@@ -239,7 +252,7 @@ void ORFDialog::sl_onSaveAnnotations() {
     const QString& name = m.data->name;
     QList<SharedAnnotationData> list;
     for (int i=0, n = resultsTree->topLevelItemCount(); i<n; ++i) {
-        ORFListItem* item = (ORFListItem* )resultsTree->topLevelItem(i);
+        ORFListItem* item = static_cast<ORFListItem* >(resultsTree->topLevelItem(i));
         list.append(item->res.toAnnotation(name));
     }
 
@@ -347,7 +360,7 @@ void ORFDialog::importResults() {
 void ORFDialog::sl_onResultActivated(QTreeWidgetItem* i, int col) {
     Q_UNUSED(col);
     assert(i!=NULL);
-    ORFListItem* item = (ORFListItem*)i;
+    ORFListItem* item = static_cast<ORFListItem*>(i);
     DNASequenceSelection* sel = ctx->getSequenceSelection();
     sel->clear();
     sel->addRegion(item->res.region);
@@ -365,9 +378,8 @@ void ORFDialog::sl_onRangeToSelection() {
 }
 
 void ORFDialog::sl_onRangeToPanView() {
-    /** TODO: const LRegion& vr = ctx->getPanView()->getVisibleRange();
-    sbRangeStart->setValue(vr.startPos + 1);
-    sbRangeEnd->setValue(vr.endPos());*/
+    sbRangeStart->setValue(panViewSelection.startPos + 1);
+    sbRangeEnd->setValue(panViewSelection.endPos());
 }
 
 void ORFDialog::sl_onRangeToSequence() {
