@@ -17,6 +17,7 @@
 #include <workflow_library/BioDatatypes.h>
 #include <workflow_library/BioActorLibrary.h>
 #include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
 
 #include <datatype/DNASequence.h>
 #include <core_api/DNATranslation.h>
@@ -32,27 +33,27 @@
 namespace GB2 {
 namespace LocalWorkflow {
 
-static const QString IN_PORT("in");
-static const QString OUT_PORT("out");
+static LogCategory log(ULOG_CAT_WD);
 
-static const QString NAME_ATTR("1name");
-static const QString STRAND_ATTR("2strand");
-static const QString ID_ATTR("3transid");
-static const QString LEN_ATTR("4minlen");
-static const QString FIT_ATTR("5mustfit");
-static const QString INIT_ATTR("6mustinit");
-static const QString ALT_ATTR("7altstart");
+/*****************************
+ * ORFWorkerFactory
+ *****************************/
+static const QString NAME_ATTR("a_name");
+static const QString STRAND_ATTR("b_strand");
+static const QString ID_ATTR("c_transid");
+static const QString LEN_ATTR("d_minlen");
+static const QString FIT_ATTR("e_mustfit");
+static const QString INIT_ATTR("f_mustinit");
+static const QString ALT_ATTR("g_altstart");
 
 const QString ORFWorkerFactory::ACTOR_ID("orf.marker");
 
-static LogCategory log(ULOG_CAT_WD);
-
 void ORFWorkerFactory::init() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
 
     {
-        Descriptor id(IN_PORT, ORFWorker::tr("Input sequences"), ORFWorker::tr("A nucleotide sequence to search ORFs in. Protein sequences are skipped."));
-        Descriptor od(OUT_PORT, ORFWorker::tr("ORF annotations"), ORFWorker::tr("A set of annotations marking ORFs found in the sequence."));
+        Descriptor id(CoreLibConstants::IN_PORT_ID, ORFWorker::tr("Input sequences"), ORFWorker::tr("A nucleotide sequence to search ORFs in. Protein sequences are skipped."));
+        Descriptor od(CoreLibConstants::OUT_PORT_ID, ORFWorker::tr("ORF annotations"), ORFWorker::tr("A set of annotations marking ORFs found in the sequence."));
         p << new PortDescriptor(id, BioDataTypes::DNA_SEQUENCE_TYPE(), true /*input*/);
         p << new PortDescriptor(od, BioDataTypes::ANNOTATION_TABLE_TYPE(), false /*input*/, true /*multi*/);
     }
@@ -113,9 +114,12 @@ void ORFWorkerFactory::init() {
     localDomain->registerEntry(new ORFWorkerFactory());
 }
 
+/*****************************
+ * ORFPrompter
+ *****************************/
 QString ORFPrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(IN_PORT));
-    Actor* producer = input->getProducer(IN_PORT);
+    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
+    Actor* producer = input->getProducer(CoreLibConstants::IN_PORT_ID);
     QString producerName = producer ? tr(" from %1").arg(producer->getLabel()) : "";
 
     ORFAlgorithmSettings cfg;
@@ -162,16 +166,15 @@ QString ORFPrompter::composeRichDoc() {
     return doc;
 }
 
+/*****************************
+ * ORFWorker
+ *****************************/
+ORFWorker::ORFWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL) {
+}
+
 void ORFWorker::init() {
-    input = ports.value(IN_PORT);
-    output = ports.value(OUT_PORT);
-    cfg.strand = ORFAlgorithmStrand(actor->getParameter(STRAND_ATTR)->value.toInt());
-    cfg.minLen = actor->getParameter(LEN_ATTR)->value.toInt();
-    cfg.mustFit = actor->getParameter(FIT_ATTR)->value.toBool();
-    cfg.mustInit = actor->getParameter(INIT_ATTR)->value.toBool();
-    cfg.allowAltStart = actor->getParameter(ALT_ATTR)->value.toBool();
-    resultName = actor->getParameter(NAME_ATTR)->value.toString();
-    transId = actor->getParameter(ID_ATTR)->value.toString();
+    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    output = ports.value(CoreLibConstants::OUT_PORT_ID);
 }
 
 bool ORFWorker::isReady() {
@@ -179,7 +182,24 @@ bool ORFWorker::isReady() {
 }
 
 Task* ORFWorker::tick() {
-    DNASequence seq = input->get().getData().value<DNASequence>();
+    Message inputMessage = getMessageAndSetupScriptValues(input);
+    cfg.strand = ORFAlgorithmStrand(actor->getParameter(STRAND_ATTR)->getAttributeValue<int>());
+    cfg.minLen = actor->getParameter(LEN_ATTR)->getAttributeValue<int>();
+    cfg.mustFit = actor->getParameter(FIT_ATTR)->getAttributeValue<bool>();
+    cfg.mustInit = actor->getParameter(INIT_ATTR)->getAttributeValue<bool>();
+    cfg.allowAltStart = actor->getParameter(ALT_ATTR)->getAttributeValue<bool>();
+    resultName = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
+    if(resultName.isEmpty()){
+        log.error(tr("result name is empty, default name used"));
+        resultName = "misc_feature";
+    }
+    transId = actor->getParameter(ID_ATTR)->getAttributeValue<QString>();
+	if (cfg.minLen < 0){
+		log.error(tr("Incorrect value: min-length must be greater then zero"));
+		return new FailTask(tr("Incorrect value: min-length must be greater then zero"));
+	}
+    DNASequence seq = inputMessage.getData().value<DNASequence>();
+    
     if (!seq.isNull() && seq.alphabet->getType() == DNAAlphabet_NUCL) {
         ORFAlgorithmSettings config(cfg);
         config.searchRegion.len = seq.length();
@@ -231,5 +251,8 @@ bool ORFWorker::isDone() {
     return !input || input->isEnded();
 }
 
+void ORFWorker::cleanup() {
+}
+
 } //namespace LocalWorkflow
 } //namespace GB2
