@@ -1,68 +1,30 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ru_RU">
-<defaultcodec></defaultcodec>
-<context>
-    <name>GB2::GTest</name>
-    <message>
-        <location filename="../src/ORFMarkerTests.cpp" line="142"/>
-        <source>value not set %1</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/ORFMarkerTests.cpp" line="65"/>
-        <source>wrong value for %1</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/ORFMarkerTests.cpp" line="81"/>
-        <source>value not correct %1</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/ORFMarkerTests.cpp" line="147"/>
-        <source>Unable to convert. Value wrong %1</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/ORFMarkerTests.cpp" line="156"/>
-        <source>error can&apos;t cast to sequence from GObject</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/ORFMarkerTests.cpp" line="174"/>
-        <source>Expected and Actual lists of regions are different: %1 %2</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/ORFMarkerTests.cpp" line="179"/>
-        <source>One of the expected regions not found in results</source>
-        <translation></translation>
-    </message>
-</context>
+<!DOCTYPE TS>
+<TS version="2.0" language="ru_RU">
 <context>
     <name>GB2::LocalWorkflow::ORFPrompter</name>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="108"/>
+        <location filename="../src/ORFWorker.cpp" line="109"/>
         <source> from %1</source>
         <translation> из %1</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="119"/>
+        <location filename="../src/ORFWorker.cpp" line="120"/>
         <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
         <translation>, допускать ORF &lt;u&gt;начинающиеся с любого кодона&lt;/u&gt; кроме терминатора</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="121"/>
+        <location filename="../src/ORFWorker.cpp" line="122"/>
         <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
         <translation>, принимать во внимание &lt;u&gt;альтернативные старт-кодоны&lt;/u&gt;</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="124"/>
+        <location filename="../src/ORFWorker.cpp" line="125"/>
         <source>, &lt;u&gt;ignore non-terminated&lt;/u&gt; ORFs</source>
         <translation>, &lt;u&gt;исключать нетерминированные&lt;/u&gt; ORF</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="144"/>
+        <location filename="../src/ORFWorker.cpp" line="142"/>
         <source>For each nucleotide sequence&lt;u&gt;%1&lt;/u&gt;, find ORFs in &lt;u&gt;%2&lt;/u&gt; using the &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Detect only ORFs &lt;u&gt;not shorter than %4 bps&lt;/u&gt;%5.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%6&lt;/u&gt;.</source>
         <translation>Искать ORF в каждой нуклеотидной последовательности&lt;u&gt;%1&lt;/u&gt;. Рассматривать &lt;u&gt;%2 стренды&lt;/u&gt;, используя &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Учитывать только ORF &lt;u&gt;не короче чем %4 нк&lt;/u&gt;%5.&lt;br&gt;Выдать список найденых ORF аннотированных как &lt;u&gt;%6&lt;/u&gt;.</translation>
     </message>
@@ -70,7 +32,7 @@
 <context>
     <name>GB2::LocalWorkflow::ORFWorker</name>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="205"/>
+        <location filename="../src/ORFWorker.cpp" line="216"/>
         <source>Found %1 ORFs</source>
         <translation>Найдено %1 ORF регионов</translation>
     </message>
@@ -84,11 +46,6 @@
         <source>ORF annotations</source>
         <translation>ORF аннотации</translation>
     </message>
-    <message>
-        <location filename="../src/ORFWorker.cpp" line="50"/>
-        <source>Result annotation</source>
-        <translation>Аннотации</translation>
-    </message>
     <message>
         <location filename="../src/ORFWorker.cpp" line="51"/>
         <source>Search in</source>
@@ -99,11 +56,6 @@
         <source>Genetic code</source>
         <translation>Код трансляции</translation>
     </message>
-    <message>
-        <location filename="../src/ORFWorker.cpp" line="53"/>
-        <source>Min length, bp</source>
-        <translation>Мин длина, нк</translation>
-    </message>
     <message>
         <location filename="../src/ORFWorker.cpp" line="54"/>
         <source>Require stop codon</source>
@@ -125,17 +77,20 @@
         <translation>Поиск ORF</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="129"/>
+        <location filename="../src/ORFWorker.cpp" line="83"/>
+        <location filename="../src/ORFWorker.cpp" line="130"/>
         <source>both strands</source>
         <translation>все</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="130"/>
+        <location filename="../src/ORFWorker.cpp" line="84"/>
+        <location filename="../src/ORFWorker.cpp" line="131"/>
         <source>direct strand</source>
         <translation>только прямые</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="131"/>
+        <location filename="../src/ORFWorker.cpp" line="85"/>
+        <location filename="../src/ORFWorker.cpp" line="132"/>
         <source>complement strand</source>
         <translation>только комплементарные</translation>
     </message>
@@ -165,66 +120,86 @@
         <translation>Выбор генетического кода (таблицы трансляции в протеины) для входных последовательностей</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="74"/>
+        <location filename="../src/ORFWorker.cpp" line="68"/>
         <source>Finds Open Reading Frames (ORFs) in each supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any supplied to input.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
         <translation>Поиск открытых рамок считывания (ОRF). ORF ищутся в каждой нуклеотидной последовательности, поданной на вход задачи; найденные регионы выдаются как набор аннотаций. 
 &lt;p&gt; Протеиновые последовательности на входе допустимы но не обрабатываются.</translation>
     </message>
+    <message>
+        <location filename="../src/ORFWorker.cpp" line="50"/>
+        <source>Annotate as</source>
+        <translation>Аннотации</translation>
+    </message>
+    <message>
+        <location filename="../src/ORFWorker.cpp" line="53"/>
+        <source>Min length</source>
+        <translation>Мин длина</translation>
+    </message>
+    <message>
+        <location filename="../src/ORFWorker.cpp" line="79"/>
+        <source> bp</source>
+        <translation>нк</translation>
+    </message>
+    <message>
+        <location filename="../src/ORFWorker.cpp" line="193"/>
+        <source>Bad sequence supplied to ORFWorker: %1</source>
+        <translation>Неверная последовательность для поиска ORF: %1</translation>
+    </message>
 </context>
 <context>
     <name>GB2::ORFDialog</name>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="174"/>
+        <location filename="../src/ORFDialog.cpp" line="177"/>
         <source>cancel_button</source>
         <translation>Остановить</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="174"/>
+        <location filename="../src/ORFDialog.cpp" line="177"/>
         <source>close_button</source>
         <translation>Закрыть</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="192"/>
+        <location filename="../src/ORFDialog.cpp" line="195"/>
         <source>progress_%1%</source>
         <translation>Прогресс %1</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="194"/>
+        <location filename="../src/ORFDialog.cpp" line="197"/>
         <source>%1_results_found.</source>
         <translation>Найдено %1</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="244"/>
+        <location filename="../src/ORFDialog.cpp" line="247"/>
         <source>warning</source>
         <translation>Подтверждение</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="244"/>
+        <location filename="../src/ORFDialog.cpp" line="247"/>
         <source>results_list_not_empty_ask_clear</source>
         <translation>Сбросить предыдущие результаты?</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="135"/>
+        <location filename="../src/ORFDialog.cpp" line="138"/>
         <source>start_codons</source>
         <translation>Старт-кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="136"/>
+        <location filename="../src/ORFDialog.cpp" line="139"/>
         <source>alt_start_codons</source>
         <translation>Альтернативные кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="137"/>
+        <location filename="../src/ORFDialog.cpp" line="140"/>
         <source>stop_codons</source>
         <translation>Стоп-кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="372"/>
+        <location filename="../src/ORFDialog.cpp" line="376"/>
         <source>complem_strand</source>
         <translation>комплeментарный</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="372"/>
+        <location filename="../src/ORFDialog.cpp" line="376"/>
         <source>direct_strand</source>
         <translation>прямой</translation>
     </message>
@@ -232,12 +207,12 @@
 <context>
     <name>GB2::ORFMarkerPlugin</name>
     <message>
-        <location filename="../src/ORFMarkerPlugin.cpp" line="33"/>
+        <location filename="../src/ORFMarkerPlugin.cpp" line="34"/>
         <source>orfname</source>
         <translation>Поиск ORF</translation>
     </message>
     <message>
-        <location filename="../src/ORFMarkerPlugin.cpp" line="33"/>
+        <location filename="../src/ORFMarkerPlugin.cpp" line="34"/>
         <source>orfdesc</source>
         <translation>Поиск открытых рамок считывания (ORF)</translation>
     </message>
@@ -245,8 +220,8 @@
 <context>
     <name>GB2::ORFViewContext</name>
     <message>
-        <location filename="../src/ORFMarkerPlugin.cpp" line="69"/>
-        <source>find_orfs</source>
+        <location filename="../src/ORFMarkerPlugin.cpp" line="66"/>
+        <source>Find ORFs</source>
         <translation>Искать рамки считывания (ORF)</translation>
     </message>
 </context>
@@ -273,6 +248,7 @@
         <translation>Все</translation>
     </message>
     <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="81"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="84"/>
         <source>strand_direct_wit</source>
         <translation>Искать только в прямой последовательности</translation>
@@ -283,6 +259,7 @@
         <translation>Прямые</translation>
     </message>
     <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="100"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="103"/>
         <source>strand_complement_wit</source>
         <translation>Искать только в комплeментарной последовательности</translation>
@@ -363,58 +340,55 @@
         <translation>Конец региона поиска: </translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="476"/>
-        <source>sel_button</source>
-        <translation>Выбранный регион</translation>
-    </message>
-    <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="489"/>
-        <source>pv_button</source>
-        <translation>Видимый регион</translation>
-    </message>
-    <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="502"/>
-        <source>wh_seq_button</source>
-        <translation>Вся последовательность</translation>
-    </message>
-    <message>
+        <location filename="../src/ORFWorker.cpp" line="53"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="133"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="136"/>
         <source>min_len_tip</source>
         <translation>Не учитывать ORF короче указанной длины</translation>
     </message>
     <message>
+        <location filename="../src/ORFWorker.cpp" line="54"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="182"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="185"/>
         <source>must_fit_tip</source>
         <translation>Не учитывать ORF продолжающиеся за пределы поcледовательности (или региона поиска).</translation>
     </message>
     <message>
+        <location filename="../src/ORFWorker.cpp" line="55"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="195"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="198"/>
         <source>must_init_tip</source>
         <translation>Допускать или нет ORF начинающиеся с любого кодона кроме терминатора.
 Т.е. искать ORF от одного терминатора до другого (или от границы региона до ближайшего терминатора).</translation>
     </message>
     <message>
+        <location filename="../src/ORFWorker.cpp" line="56"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="214"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="217"/>
         <source>allow_alt_tip</source>
         <translation>Учитывать ORF начинающиеся с неканонических стартовых кодонов,
 указанных в выбранной таблице трансляции.</translation>
     </message>
     <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="65"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="68"/>
         <source>strand_both_wit</source>
         <translation>Искать в прямой и комплeментарной последовательностях</translation>
     </message>
     <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="470"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="473"/>
         <source>sel_bt_tip</source>
         <translation>Искать в селектированном регионе</translation>
     </message>
     <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="483"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="486"/>
         <source>pv_bt_tip</source>
         <translation>Установить регион поиска к отображаемому в панораме</translation>
     </message>
     <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="496"/>
         <location filename="../src/ui/ORFDialogUI.ui" line="499"/>
         <source>seq_bt_tip</source>
         <translation>Искать во всей последовательности</translation>
@@ -439,5 +413,20 @@
         <source>len</source>
         <translation>Длина</translation>
     </message>
+    <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="476"/>
+        <source>Selection range</source>
+        <translation>Выбранный регион</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="489"/>
+        <source>Overview range</source>
+        <translation>Видимый регион</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="502"/>
+        <source>Sequence range</source>
+        <translation>Вся последовательность</translation>
+    </message>
 </context>
 </TS>
