@@ -12,6 +12,7 @@
 #include "RepeatFinderTests.h"
 #include "RepeatWorker.h"
 #include "FindRepeatsDialog.h"
+#include "FindTandemsDialog.h"
 
 #include <core_api/DNAAlphabet.h>
 #include <util_gui/GUIUtils.h>
@@ -28,6 +29,9 @@
 #include <QtGui/QMenu>
 #include <QtGui/QAction>
 
+#include <core_api/RepeatFinderTaskFactoryRegistry.h>
+#include "RFTaskFactory.h"
+
 #include <cstdio>
 
 namespace GB2 {
@@ -57,6 +61,9 @@ RepeatFinderPlugin::RepeatFinderPlugin() : Plugin("Repeats Finder", "Search for
         assert(res); Q_UNUSED(res);
     }
 
+	RepeatFinderTaskFactoryRegistry *rfTfr = AppContext::getRepeatFinderTaskFactoryRegistry();
+	Q_ASSERT(rfTfr);
+	rfTfr->registerFactory(new RFTaskFactory(), "");
 }
 
 RepeatViewContext::RepeatViewContext(QObject* p) : 
@@ -69,6 +76,9 @@ void RepeatViewContext::initViewContext(GObjectView* v) {
     ADVGlobalAction* a = new ADVGlobalAction(av, QIcon(":repeat_finder/images/repeats.png"), tr("Find Repeats"), 40);
     a->addAlphabetFilter(DNAAlphabet_NUCL);
     connect(a, SIGNAL(triggered()), SLOT(sl_showDialog()));
+        ADVGlobalAction* a2 = new ADVGlobalAction(av, QIcon(":repeat_finder/images/repeats_tandem.png"), tr("Find Tandems"), 41);
+	a2->addAlphabetFilter(DNAAlphabet_NUCL);
+	connect(a2, SIGNAL(triggered()), SLOT(sl_showTandemDialog()));
 }
 
 void RepeatViewContext::sl_showDialog() {
@@ -81,4 +91,14 @@ void RepeatViewContext::sl_showDialog() {
     d.exec();
 }
 
+void RepeatViewContext::sl_showTandemDialog() {
+	QAction* a = (QAction*)sender();
+	GObjectViewAction* viewAction = qobject_cast<GObjectViewAction*>(a);
+	AnnotatedDNAView* av = qobject_cast<AnnotatedDNAView*>(viewAction->getObjectView());
+	ADVSequenceObjectContext* sctx = av->getSequenceInFocus();
+	assert(sctx!=NULL && sctx->getAlphabet()->isNucleic());
+	FindTandemsDialog d(sctx);
+	d.exec();
+}
+
 }//namespace
