@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -20,8 +20,7 @@ class RepeatFinderPlugin : public Plugin {
 	Q_OBJECT
 public:
     RepeatFinderPlugin();
-	~RepeatFinderPlugin();
-
+	
 private:
     GObjectViewWindowContext* viewCtx;
 };
@@ -32,12 +31,11 @@ public:
     RepeatViewContext(QObject* p);
 
 protected slots:
-        void sl_showDialog();
+    void sl_showDialog();
+	void sl_showTandemDialog();
 
 protected:
     virtual void initViewContext(GObjectView* view);
-    //virtual void buildMenu(GObjectView* v, QMenu* m);
-
 };
 
 
