@@ -4,140 +4,252 @@
 <context>
     <name>FindRepeatsDialog</name>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="16"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="17"/>
         <source>Find repeats</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="22"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="27"/>
         <source>Repeat parameters</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="34"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="39"/>
         <source>Minimum repeat length</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="69"/>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="234"/>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="294"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="74"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="239"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="299"/>
         <source>bp</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="97"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="102"/>
         <source>Heuristic based selection of repeat length so the number of repeats in the sequence will not exceed 1000</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="100"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="105"/>
         <source>1k</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="107"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="112"/>
         <source>Repeats  identity</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="142"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="147"/>
         <source>%</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="164"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="169"/>
         <source>Resets repeats identity to 100%</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="167"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="172"/>
         <source>100</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="206"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="211"/>
         <source>Minimum distance between repeats</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="253"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="258"/>
         <source>Maximum distance between repeats</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="313"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="318"/>
         <source>Custom algorithm</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="340"/>
-        <source>Search only repeats inside of annotated region</source>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="345"/>
+        <source>Search only for repeats that lie inside of an annotated region</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="382"/>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="431"/>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="480"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="387"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="436"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="485"/>
         <source>...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="389"/>
-        <source>Search only repeats with annotated region inside</source>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="394"/>
+        <source>Search only for repeats that have an annotated region inside</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="438"/>
-        <source>Filter repeats with annotated region inside</source>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="443"/>
+        <source>Filter repeats that have an annotated region inside</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="487"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="492"/>
         <source>Do not filter nested repeats</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="507"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="512"/>
         <source>Search for inverted repeats</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="530"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="535"/>
         <source>Region to process</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="536"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="541"/>
         <source>Whole sequence</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="559"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="564"/>
         <source>Selection</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="579"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="584"/>
         <source>Custom range</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="605"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="610"/>
         <source>-</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="676"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="681"/>
         <source>Start</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/FindRepeatsDialog.ui" line="686"/>
+        <location filename="../src/ui/FindRepeatsDialog.ui" line="691"/>
         <source>Cancel</source>
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>FindTandemsDialog</name>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="17"/>
+        <source>Find tandems</source>
+        <translation>Find tandems</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="27"/>
+        <source>Repeat parameters</source>
+        <translation>Repeat parameters</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="39"/>
+        <source>Tandem preset</source>
+        <translation>Tandem preset</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="84"/>
+        <source>Min period</source>
+        <translation>Min period</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="104"/>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="137"/>
+        <source> n</source>
+        <translation> n</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="117"/>
+        <source>Max period</source>
+        <translation>Max period</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="153"/>
+        <source>Repeats  identity</source>
+        <translation>Repeats identity</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="197"/>
+        <source>%</source>
+        <translation>%</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="213"/>
+        <source>Algorithm</source>
+        <translation>Algorithm</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="243"/>
+        <source>Minimum tandem size</source>
+        <translation>Minimum tandem size</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="276"/>
+        <source>Minimum repeat count</source>
+        <translation>Minimum repeat count</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="296"/>
+        <source>x</source>
+        <translation>x</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="325"/>
+        <source>Show overlapped tandems</source>
+        <translation>Show overlapped tandems</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="335"/>
+        <source>Region to process</source>
+        <translation>Region to process</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="341"/>
+        <source>Whole sequence</source>
+        <translation>Whole sequence</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="364"/>
+        <source>Selection</source>
+        <translation>Selection</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="384"/>
+        <source>Custom range</source>
+        <translation>Custom range</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="410"/>
+        <source>-</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="481"/>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/FindTandemsDialog.ui" line="491"/>
+        <source>Cancel</source>
+        <translation>Cancel</translation>
+    </message>
+</context>
+<context>
+    <name>GB2::ExactSizedTandemFinder</name>
+    <message>
+        <location filename="../src/RF_SArray_TandemFinder.h" line="126"/>
+        <source>Find %1-period tandems</source>
+        <translation>Find %1-period tandems</translation>
+    </message>
+</context>
 <context>
     <name>GB2::FindRepeatsDialog</name>
     <message>
@@ -180,32 +292,32 @@
 <context>
     <name>GB2::FindRepeatsTask</name>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="48"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="49"/>
         <source>Find repeats in a single sequence</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="60"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="62"/>
         <source>Rev-complementing sequence</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="86"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="87"/>
         <source>Searching repeats ...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="100"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="101"/>
         <source>Filtering nested results</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="111"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="112"/>
         <source>Repeat search time %1 sec</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="171"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="172"/>
         <source>Nested repeats filtering time %1 sec, results before: %2, filtered: %3, after %4</source>
         <translation></translation>
     </message>
@@ -213,7 +325,7 @@
 <context>
     <name>GB2::FindRepeatsToAnnotationsTask</name>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="273"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="274"/>
         <source>Find repeats to annotations</source>
         <translation></translation>
     </message>
@@ -223,6 +335,84 @@
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>GB2::FindTandemsDialog</name>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="57"/>
+        <source>Suffix array</source>
+        <translation>Suffix array</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="58"/>
+        <source>Suffix array (optimized)</source>
+        <translation>Suffix array (optimized)</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="61"/>
+        <source>All</source>
+        <translation>All</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="62"/>
+        <source>Micro-satellites</source>
+        <translation>Micro-satellites</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="63"/>
+        <source>Mini-satellites</source>
+        <translation>Mini-satellites</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="64"/>
+        <source>Big-period tandems</source>
+        <translation>Big-period tandems</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="65"/>
+        <source>Custom</source>
+        <translation>Custom</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="181"/>
+        <location filename="../src/FindTandemsDialog.cpp" line="206"/>
+        <source>Error</source>
+        <translation>Error</translation>
+    </message>
+    <message>
+        <location filename="../src/FindTandemsDialog.cpp" line="181"/>
+        <source>No annotations found: %1</source>
+        <translation>&quot;No annotations found: %1</translation>
+    </message>
+    <message>
+        <source>Estimated repeats count: %1</source>
+        <translation type="obsolete">Estimated repeats count: %1</translation>
+    </message>
+    <message>
+        <source>Estimated repeats count hint is based on the active settings and random sequence model</source>
+        <translation type="obsolete">Estimated repeats count hint is based on the active settings and random sequence model&quot;</translation>
+    </message>
+</context>
+<context>
+    <name>GB2::FindTandemsToAnnotationsTask</name>
+    <message>
+        <location filename="../src/RF_SArray_TandemFinder.cpp" line="18"/>
+        <source>Find repeats to annotations</source>
+        <translation>Find repeats to annotations</translation>
+    </message>
+    <message>
+        <location filename="../src/RF_SArray_TandemFinder.cpp" line="37"/>
+        <source>Found %1 repeat regions</source>
+        <translation>Found %1 repeat regions</translation>
+    </message>
+</context>
+<context>
+    <name>GB2::LargeSizedTandemFinder</name>
+    <message>
+        <location filename="../src/RF_SArray_TandemFinder.h" line="172"/>
+        <source>Find big-period tandems</source>
+        <translation>Find big-period tandems</translation>
+    </message>
+</context>
 <context>
     <name>GB2::LocalWorkflow::RepeatPrompter</name>
     <message>
@@ -424,7 +614,7 @@
 <context>
     <name>GB2::RFSArrayWSubtask</name>
     <message>
-        <location filename="../src/RFSArray.cpp" line="319"/>
+        <location filename="../src/RFSArray.cpp" line="320"/>
         <source>Find repeats subtask (suffix)</source>
         <translation></translation>
     </message>
@@ -432,22 +622,49 @@
 <context>
     <name>GB2::RepeatViewContext</name>
     <message>
-        <location filename="../src/RepeatFinderPlugin.cpp" line="59"/>
+        <location filename="../src/RepeatFinderPlugin.cpp" line="60"/>
         <source>Find Repeats</source>
-        <translation></translation>
+        <translation>Find repeats</translation>
+    </message>
+    <message>
+        <location filename="../src/RepeatFinderPlugin.cpp" line="63"/>
+        <source>Find Tandems</source>
+        <translation>Find Tandems</translation>
     </message>
 </context>
 <context>
     <name>GB2::RevComplSequenceTask</name>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="22"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="23"/>
         <source>Reverse complement sequence</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/FindRepeatsTask.cpp" line="29"/>
+        <location filename="../src/FindRepeatsTask.cpp" line="30"/>
         <source>Can&apos;t find complement translation for alphabet: %1</source>
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>GB2::TandemFinder</name>
+    <message>
+        <location filename="../src/RF_SArray_TandemFinder.cpp" line="112"/>
+        <source>Find tandems finished %1</source>
+        <translation>Find tandems finished %1</translation>
+    </message>
+    <message>
+        <location filename="../src/RF_SArray_TandemFinder.cpp" line="72"/>
+        <location filename="../src/RF_SArray_TandemFinder.cpp" line="105"/>
+        <source>Find tandems</source>
+        <translation>Find tandems</translation>
+    </message>
+</context>
+<context>
+    <name>GB2::TandemFinder_Region</name>
+    <message>
+        <location filename="../src/RF_SArray_TandemFinder.h" line="91"/>
+        <source>Find tandems in %1 region</source>
+        <translation>Find tandems in %1 region</translation>
+    </message>
+</context>
 </TS>
