@@ -15,6 +15,8 @@
 #include <core_api/MainWindow.h>
 #include <core_api/Log.h>
 #include <core_api/Settings.h>
+#include <cmdline/CMDLineCoreOptions.h>
+#include <cmdline/CMDLineUtils.h>
 
 #include <test_framework/GTest.h>
 
@@ -41,15 +43,96 @@ extern "C" Q_DECL_EXPORT Plugin* GB2_PLUGIN_INIT_FUNC() {
 
 
 TestRunnerPlugin::TestRunnerPlugin() : Plugin(tr("test_runner_plug_name"), tr("test_runner_desc")) {
-    TestRunnerScriptModule* sm=new TestRunnerScriptModule();
-    sm->moduleName=QString("QTest");
-    AppContext::getScriptModuleRegistry()->registerGScriptModule(sm);
-    services.push_back(new TestRunnerService());
+	if (AppContext::getCMDLineRegistry()->hasParameter( CMDLineCoreOptions::SUITE_URLS )) {
+		connect( AppContext::getPluginSupport(), SIGNAL( si_allStartUpPluginsLoaded() ), SLOT(sl_startTestRunner()));
+	}
+	else {
+		services.push_back(new TestRunnerService());
+	}
 }
+
+void TestRunnerPlugin::sl_startTestRunner() {
+	CMDLineRegistry *cmdReg = AppContext::getCMDLineRegistry();
+	//QString param = cmdReg->getParameterValue(CMDLineCoreOptions::SUITE_URLS);
+	QStringList suiteUrls = CMDLineRegistryUtils::getParameterValuesByWords( CMDLineCoreOptions::SUITE_URLS );
+	
+	TestRunnerService *srv = new TestRunnerService();
+	srv->setEnvironment();
+
+	if(cmdReg->hasParameter(CMDLineCoreOptions::TEST_THREADS)) {
+		QString val = cmdReg->getParameterValue(CMDLineCoreOptions::TEST_THREADS);
+		bool isOk;
+		val.toInt(&isOk);
+		if(!isOk) {
+			printf("Incorrect number of threads\n");
+			AppContext::getTaskScheduler()->cancelAllTasks();
+			AppContext::getMainWindow()->getQMainWindow()->close();
+			return;
+		}
+		srv->setVar(NUM_THREADS_VAR, val);
+	}
+	
+    foreach(const QString &param, suiteUrls) {
+		QString dir;
+		if(param.contains(":")||param[0]=='.') {
+			dir = param;
+		}
+		else {
+			dir = "../../test/";
+			dir.append(param);
+		}
+
+		if (param.split(".").last()=="xml") {
+			QString error;
+			GTestSuite *suite = GTestSuite::readTestSuite(dir,error);
+			if(error!="") {
+				printf("%s\n",tr("Can't load suite %1").arg(param).toAscii().constData());
+				AppContext::getTaskScheduler()->cancelAllTasks();
+				AppContext::getMainWindow()->getQMainWindow()->close();
+				return;
+			}
+			srv->addTestSuite(suite);
+		} else {
+			if(param.split(".").last()=="list") {
+				QStringList errs;
+				QList<GTestSuite*> lst = GTestSuite::readTestSuiteList(dir, errs);
+				if (!errs.isEmpty()) {
+					printf("%s\n",tr("Can't load suite %1").arg(param).toAscii().constData());
+					AppContext::getTaskScheduler()->cancelAllTasks();
+					AppContext::getMainWindow()->getQMainWindow()->close();
+					
+					return;
+				}
+				foreach(GTestSuite* ts, lst){
+					QString urlfs = ts->getURL();
+					if (srv->findTestSuiteByURL(urlfs)!=NULL) {
+						delete ts;
+					}else{
+						srv->addTestSuite(ts);
+					}
+				}
+			}
+			else {
+				printf("Not a test suite\n");
+				AppContext::getTaskScheduler()->cancelAllTasks();
+				AppContext::getMainWindow()->getQMainWindow()->close();
+				return;
+			}
+		}
+	}
+	
+	TestViewController *view = new TestViewController(srv,true);
+	AppContext::getMainWindow()->getMDIManager()->addMDIWindow(view);
+	//AppContext::getMainWindow()->getMDIManager()->activateWindow(view);
+	//view->addTestSuite(suite);
+	//view->reporterForm = new TestViewReporter(view,view->tree,view->time);
+	view->sl_runAllSuitesAction();
+}
+
 //////////////////////////////////////////////////////////////////////////
 // service
 TestRunnerService::TestRunnerService() 
-: Service(Service_TestRunner, tr("sname"), tr("sdesc"))
+: Service(Service_TestRunner, tr("sname"), tr("sdesc")), env(NULL)
 {
     windowAction = NULL;
     view = NULL;
@@ -59,6 +142,15 @@ TestRunnerService::~TestRunnerService() {
     assert(suites.isEmpty());
 }
 
+void TestRunnerService::setVar(const QString& varName, const QString& val) {
+	env->setVar(varName,val);
+}
+
+void TestRunnerService::setEnvironment() {
+	env = new GTestEnvironment();
+	readBuiltInVars();
+}
+
 void TestRunnerService::serviceStateChangedCallback(ServiceState oldState, bool enabledStateChanged) {
     Q_UNUSED(oldState);
 
@@ -143,9 +235,9 @@ void TestRunnerService::addTestSuite(GTestSuite *ts) {
 
 void TestRunnerService::updateDefaultEnvValues(GTestSuite* ts) {
     QMap<QString, QString> vars = env->getVars();
-    if (vars.contains("COMMON_DATA_DIR") && vars.value("COMMON_DATA_DIR").isEmpty()) {
+    //if (vars.contains("COMMON_DATA_DIR") && vars.value("COMMON_DATA_DIR").isEmpty()) {
         env->setVar("COMMON_DATA_DIR", QFileInfo(ts->getURL()).absoluteDir().absolutePath() + "/_common_data");
-    }
+  //  }
 
     if (vars.contains("TEMP_DATA_DIR") && vars.value("TEMP_DATA_DIR").isEmpty()) {
         env->setVar("TEMP_DATA_DIR", QFileInfo(ts->getURL()).absoluteDir().absolutePath()+"/_tmp");
@@ -248,7 +340,7 @@ void TestRunnerService::sl_refresh()
 }
 //////////////////////////////////////////////////////////////////////////
 // Script Module
-void TestRunnerScriptModule::setup(QScriptEngine *engine) const{
+/*void TestRunnerScriptModule::setup(QScriptEngine *engine) const{
     GTestScriptWrapper::setQTest(engine);
-}
+}*/
 }//namespace
