@@ -14,7 +14,7 @@
 #include <core_api/PluginModel.h>
 #include <core_api/AppContext.h>
 #include <core_api/ServiceModel.h>
-#include <script/GScriptModuleRegistry.h>
+//#include <script/GScriptModuleRegistry.h>
 #include <test_framework/TestRunnerTask.h>
 #include <QtScript>
 #include <QtGui/QAction>
@@ -31,7 +31,9 @@ class GTestEnvironment;
 class TestRunnerPlugin : public Plugin {
 	Q_OBJECT
 public:
-    TestRunnerPlugin();    
+    TestRunnerPlugin();   
+private slots:
+	void sl_startTestRunner();
 };
 
 class TestRunnerService : public Service {
@@ -46,6 +48,8 @@ public:
     GTestSuite* findTestSuiteByURL(const QString& url);
 
     GTestEnvironment* getEnv() { return env;}
+	void setVar(const QString& varName, const QString& val);
+	void setEnvironment();
 
 signals:
     void si_testSuiteAdded(GTestSuite* ts);
@@ -76,10 +80,10 @@ private:
     QList<GTestSuite*>          suites;
     GTestEnvironment*           env;
 };
-class TestRunnerScriptModule : public GScriptModule
+/*class TestRunnerScriptModule : public GScriptModule
 {
     virtual void setup(QScriptEngine *engine) const;
-};
+};*/
 } //namespace
 
 #endif
