@@ -19,6 +19,7 @@
 #include <test_framework/GTest.h>
 #include <test_framework/GTestFrameworkComponents.h>
 #include <core_api/IOAdapter.h>
+#include <cmdline/CMDLineCoreOptions.h>
 #include <memory>
 
 #include <QtGui/QFileDialog>
@@ -50,7 +51,7 @@ namespace GB2 {
 
 static LogCategory log(ULOG_CAT_PLUGIN_TEST_RUNNER);
 
-TestViewController::TestViewController(TestRunnerService* s) : MWMDIWindow(tr("Test runner")), service(s)
+TestViewController::TestViewController(TestRunnerService* s, bool _cmd) : MWMDIWindow(tr("Test runner")), service(s), cmd(_cmd)
 {
     task=NULL;
     reporterForm=NULL;
@@ -177,9 +178,9 @@ void TestViewController::setupViewMenu(QMenu* m) {
 
 TVTSItem* TestViewController::findTestSuiteItem(GTestSuite* ts) const {
     for (int i=0, n=tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->type == TVItem_TestSuite);
-        TVTSItem* tsi = (TVTSItem*)item;
+        TVTSItem* tsi = static_cast<TVTSItem*>(item);
         if (tsi->ts == ts) {
             return tsi;
         }
@@ -189,9 +190,9 @@ TVTSItem* TestViewController::findTestSuiteItem(GTestSuite* ts) const {
 
 TVTestItem* TestViewController::findTestViewItem(GTestRef* testRef) const {
     for (int i=0, n=tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->type == TVItem_TestSuite);
-        TVTSItem* sItem = (TVTSItem*)item;
+        TVTSItem* sItem = static_cast<TVTSItem*>(item);
         TVTestItem* rezult = findTestViewItemRecursive(testRef,sItem);
         if(rezult)return rezult;
     }
@@ -199,16 +200,15 @@ TVTestItem* TestViewController::findTestViewItem(GTestRef* testRef) const {
 }
 TVTestItem* TestViewController::findTestViewItemRecursive(GTestRef* testRef,TVItem* sItem) const {
     for(int j = 0, m = sItem->childCount(); j<m; j++) {
-        TVItem* item = (TVItem*)sItem->child(j);
+        TVItem* item = static_cast<TVItem*>(sItem->child(j));
         if(item->isTest()){
-            TVTestItem* tItem  = (TVTestItem*)item;
+            TVTestItem* tItem  = static_cast<TVTestItem*>(item);
             if (tItem->testState->getTestRef() == testRef) {
                 return tItem;
             }
-        }
-        else{
+        } else {
             assert(item->isSuite());
-            TVTestItem* rezult = findTestViewItemRecursive(testRef,(TVTSItem*)item);
+            TVTestItem* rezult = findTestViewItemRecursive(testRef,static_cast<TVTSItem*>(item));
             if(rezult)return rezult;
         }
     }
@@ -217,9 +217,9 @@ TVTestItem* TestViewController::findTestViewItemRecursive(GTestRef* testRef,TVIt
 
 TVTSItem* TestViewController::getFolder(TVItem* element,const QString* firstDirName)const{
     for(int j = 0, m = element->childCount(); j<m; j++) {
-        TVItem* item = (TVItem*)element->child(j);
-        if(item->isSuite()){
-            TVTSItem *ditem= (TVTSItem *)item;
+        TVItem* item = static_cast<TVItem*>(element->child(j));
+        if (item->isSuite()){
+            TVTSItem *ditem= static_cast<TVTSItem *>(item);
             if(ditem->name==firstDirName){
                 return ditem;
             }
@@ -245,14 +245,12 @@ void TestViewController::addTestSuite(GTestSuite* ts) {
         QString firstDirName=t->getShortName().section('/', 0 , 0 );//find first directory name
         if(t->getShortName()==firstDirName){
             addTest(tsi, t,true);
-        }
-        else{
+        } else {
             TVTSItem* curDir=getFolder(tsi,&firstDirName);
             QString otherPath=t->getShortName().section('/', 1 );//find other path
             if(curDir){//find if dir already exist
                 addFolderTests(curDir,t,&otherPath,true);  
-            }
-            else{
+            } else {
                 TVTSItem* newDir=new TVTSItem(firstDirName);
                 tsi->addChild(newDir);
                 addFolderTests(newDir,t,&otherPath,true);
@@ -261,18 +259,15 @@ void TestViewController::addTestSuite(GTestSuite* ts) {
     }
     //add to tree Tests to run
     foreach(GTestRef* t, ts->getTests()) {
-
         QString firstDirName=t->getShortName().section('/', 0 , 0 );//find first directory name
-        if(t->getShortName()==firstDirName){
+        if (t->getShortName()==firstDirName){
             addTest(tsi, t,false);
-        }
-        else{
+        } else {
             TVTSItem* curDir=getFolder(tsi,&firstDirName);
             QString otherPath=t->getShortName().section('/', 1 );//find other path
             if(curDir){//find if dir already exist
                 addFolderTests(curDir,t,&otherPath,false);  
-            }
-            else{
+            } else {
                 TVTSItem* newDir=new TVTSItem(firstDirName);
                 tsi->addChild(newDir);
                 addFolderTests(newDir,t,&otherPath,false);
@@ -289,14 +284,12 @@ void TestViewController::addFolderTests(TVTSItem* tsi, GTestRef* testRef,const Q
     QString firstDirName=curPath->section('/', 0 , 0 );
     if(*curPath==firstDirName){
         addTest(tsi, testRef,haveExcludedTests);
-    }
-    else{
+    } else {
         TVTSItem* curDir=getFolder(tsi,&firstDirName);
         QString otherPath=curPath->section('/', 1 );//find other path
         if(curDir){//find if dir already exist
             addFolderTests(curDir,testRef,&otherPath,haveExcludedTests);  
-        }
-        else{
+        } else {
             TVTSItem* newDir=new TVTSItem(firstDirName);
             newDir->excludedTests=haveExcludedTests;
             tsi->addChild(newDir);
@@ -322,7 +315,10 @@ void TestViewController::sl_suiteAdded(GTestSuite* ts) {
 
 void TestViewController::sl_suiteRemoved(GTestSuite* ts) {
     TVTSItem* item = findTestSuiteItem(ts);
-    assert(item);
+    assert(item!=NULL && item->parent() == NULL);
+	// need this way of removal to avoid crash in destructor if 
+	// child item of the suite is selected and is asked for rich desc during parent removal
+	tree->takeTopLevelItem(tree->indexOfTopLevelItem(item)); 
     delete item;
     updateState();
 }
@@ -330,18 +326,18 @@ void TestViewController::sl_suiteRemoved(GTestSuite* ts) {
 void TestViewController::sl_treeCustomContextMenuRequested(const QPoint & pos) {
     Q_UNUSED(pos);
 
-    QMenu* menu = new QMenu(tree);    
-    menu->addAction(addTestSuiteAction);
-    menu->addAction(removeTestSuiteAction);
-    menu->addAction(refreshAction);
-    menu->addAction(runAllSuitesAction);
-    menu->addAction(runSelectedSuitesAction);
-    menu->addAction(stopSuitesActions);
-    menu->addAction(setEnvAction);
-    menu->addAction(report);
-    menu->addAction(setTestsChangeExcludedAction);
-    menu->addAction(saveSelectedSuitesAction);
-    menu->exec(QCursor::pos());
+    QMenu menu(tree);    
+    menu.addAction(addTestSuiteAction);
+    menu.addAction(removeTestSuiteAction);
+    menu.addAction(refreshAction);
+    menu.addAction(runAllSuitesAction);
+    menu.addAction(runSelectedSuitesAction);
+    menu.addAction(stopSuitesActions);
+    menu.addAction(setEnvAction);
+    menu.addAction(report);
+    menu.addAction(setTestsChangeExcludedAction);
+    menu.addAction(saveSelectedSuitesAction);
+    menu.exec(QCursor::pos());
 }
 
 void TestViewController::sl_treeItemSelectionChanged() {
@@ -352,9 +348,9 @@ QList<TVTSItem*> TestViewController::getSelectedSuiteItems() const {
     QList<TVTSItem*> res;
     QList<QTreeWidgetItem*> items = tree->selectedItems();
     foreach(QTreeWidgetItem* i, items) {
-        TVItem* item = (TVItem*)i;
+        TVItem* item = static_cast<TVItem*>(i);
         if (item->isSuite()) {
-            res.append((TVTSItem*)item);
+            res.append(static_cast<TVTSItem*>(item));
         }
     }
     return res;
@@ -364,9 +360,9 @@ QList<TVTestItem*> TestViewController::getSelectedTestItems() const {
     QList<TVTestItem*> res;
     QList<QTreeWidgetItem*> items = tree->selectedItems();
     foreach(QTreeWidgetItem* i, items) {
-        TVItem* item = (TVItem*)i;
+        TVItem* item = static_cast<TVItem*>(i);
         if (item->isTest()) {
-            res.append((TVTestItem*)item);
+            res.append(static_cast<TVTestItem*>(item));
         }
     }
     return res;
@@ -393,7 +389,7 @@ void TestViewController::updateState() {
     stopSuitesActions->setEnabled( task!=NULL);
 
     if (tree->currentItem()!=NULL) {
-        TVItem* i = (TVItem*)tree->currentItem();
+        TVItem* i = static_cast<TVItem*>(tree->currentItem());
         contextInfoEdit->setText(i->getRichDesc());
     }
 }
@@ -461,10 +457,10 @@ void TestViewController::sl_removeTestSuiteAction() {
         return;
     }
     for (int i=tree->topLevelItemCount()-1, n = 0 ; i>=n; i--) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         if(item->isSelected()){
-            TVTSItem* sItem = (TVTSItem*)item;
+            TVTSItem* sItem = static_cast<TVTSItem*>(item);
             service->removeTestSuite(sItem->ts);
         }
     }
@@ -474,7 +470,7 @@ void TestViewController::sl_selectAllSuiteAction() {
         return;
     }
     for (int i=tree->topLevelItemCount()-1, n = 0 ; i>=n; i--) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         item->setSelected("true");
     }
@@ -485,7 +481,7 @@ void TestViewController::sl_setTestsEnabledAction(){
     assert(task==NULL);
 
     for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         bool allSelected=false;
         bool newState=false;
@@ -497,7 +493,7 @@ void TestViewController::sl_setTestsDisabledAction(){
     assert(task==NULL);
 
     for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         bool allSelected=false;
         bool newState=true;
@@ -509,7 +505,7 @@ void TestViewController::sl_setTestsChangeExcludedAction(){
     assert(task==NULL);
 
     for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         bool allSelected=false;
         if(item->isSelected())allSelected=true;
@@ -523,14 +519,14 @@ void TestViewController::sl_saveSelectedSuitesAction(){
         QList<GTestState*> testsToRun;
         QList<GTestRef*> testsToEx;
         QList<GTestRef*> oldToAdd;
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         bool runAll=false;
         bool mustBeSaved=false;
         if(item->isSelected())runAll=true;
         testsToRun+= getSubTestToRun(item,runAll);
         testsToEx+= getSubRefToExclude(item,runAll);
-        TVTSItem* tlItem=(TVTSItem*)item;
+        TVTSItem* tlItem=static_cast<TVTSItem*>(item);
         if(testsToEx.isEmpty()&&testsToRun.isEmpty()){
         //in current suite no selected elements 
         }else{           
@@ -545,7 +541,7 @@ void TestViewController::sl_saveSelectedSuitesAction(){
                         break;
                     }
                 }
-                if(flag){//if old value-exclude not changet to enabled
+                if(flag){//if the old exclude-value is not changed to enabled
                     if(testsToEx.isEmpty()){
                     oldToAdd+=t;
                     }else{
@@ -699,21 +695,19 @@ QStringList TestViewController::findAllTestFilesInDir(const QString& dirPath, co
     return res;
 }
 void TestViewController::setExcludedState(TVItem* sItem,bool allSelected, bool newState){
-    for(int j = 0, m = sItem->childCount(); j<m; j++) {
-        TVItem* item = (TVItem*)sItem->child(j);
-        if(item->isTest()){
-            TVTestItem* tItem  = (TVTestItem*)item;
+    for (int j = 0, m = sItem->childCount(); j<m; j++) {
+        TVItem* item = static_cast<TVItem*>(sItem->child(j));
+        if (item->isTest()){
+            TVTestItem* tItem  = static_cast<TVTestItem*>(item);
             if(tItem->isSelected()||allSelected){
                 tItem->excludedTests=newState;
                 tItem->updateVisual();
-                TVTSItem* temp_parent=(TVTSItem*)tItem->parent();
+                TVTSItem* temp_parent=static_cast<TVTSItem*>(tItem->parent());
                 temp_parent->updateVisual();
             }
-        }
-        
-        else{
+        } else {
             assert(item->isSuite());
-            TVTSItem* tItem2  = (TVTSItem*)item;
+            TVTSItem* tItem2  = static_cast<TVTSItem*>(item);
             if(tItem2->isSelected()){
                 setExcludedState(tItem2,true,newState);
             }
@@ -723,26 +717,23 @@ void TestViewController::setExcludedState(TVItem* sItem,bool allSelected, bool n
         }
     }
 }
-void TestViewController::setExcludedState(TVItem* sItem,bool allSelected){
+void TestViewController::setExcludedState(TVItem* sItem, bool allSelected){
     for(int j = 0, m = sItem->childCount(); j<m; j++) {
-        TVItem* item = (TVItem*)sItem->child(j);
-        if(item->isTest()){
-            TVTestItem* tItem  = (TVTestItem*)item;
+        TVItem* item = static_cast<TVItem*>(sItem->child(j));
+        if (item->isTest()){
+            TVTestItem* tItem  = static_cast<TVTestItem*>(item);
             if(tItem->isSelected()||allSelected){
                 tItem->excludedTests=!tItem->excludedTests;
                 tItem->updateVisual();
-                TVTSItem* temp_parent=(TVTSItem*)tItem->parent();
+                TVTSItem* temp_parent=static_cast<TVTSItem*>(tItem->parent());
                 temp_parent->updateVisual();
             }
-        }
-        
-        else{
+        } else {
             assert(item->isSuite());
-            TVTSItem* tItem2  = (TVTSItem*)item;
+            TVTSItem* tItem2  = static_cast<TVTSItem*>(item);
             if(tItem2->isSelected()){
                 setExcludedState(tItem2,true);
-            }
-            else{
+            } else {
                 setExcludedState(tItem2,allSelected);
             }
         }
@@ -759,7 +750,7 @@ void TestViewController::sl_runAllSuitesAction() {
     }
     QList<GTestState*> testsToRun;
     for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         bool runAll=true;
         testsToRun+= getSubTestToRun(item,runAll);
@@ -779,7 +770,7 @@ void TestViewController::sl_runSelectedSuitesAction() {
     }
     QList<GTestState*> testsToRun;
     for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));
         assert(item->isSuite());
         bool runAll=false;
         if(item->isSelected())runAll=true;
@@ -793,27 +784,24 @@ void TestViewController::sl_runSelectedSuitesAction() {
 QList<GTestState*> TestViewController::getSubTestToRun(TVItem* sItem,bool runAll)const{   
     QList<GTestState*> testsToRun;
     for(int j = 0, m = sItem->childCount(); j<m; j++) {
-        TVItem* item = (TVItem*)sItem->child(j);
-        if(item->isTest()){
-            TVTestItem* tItem  = (TVTestItem*)item;
-            if(!tItem->excludedTests){
+        TVItem* item = static_cast<TVItem*>(sItem->child(j));
+        if (item->isTest()){
+            TVTestItem* tItem  = static_cast<TVTestItem*>(item);
+            if (!tItem->excludedTests){
                 if(tItem->isSelected() || runAll){
                     testsToRun.append(tItem->testState);
                 }
-            }else{
+            } else {
                 log.info(QString("##teamcity[testStarted name='%1 : %2']").arg(tItem->testState->getTestRef()->getSuite()->getName(),tItem->testState->getTestRef()->getShortName()));
                 log.info(QString("##teamcity[testIgnored name='%1 : %2' message='was ignored']").arg(tItem->testState->getTestRef()->getSuite()->getName(),tItem->testState->getTestRef()->getShortName()));
                 log.info(QString("##teamcity[testFinished name='%1 : %2']").arg(tItem->testState->getTestRef()->getSuite()->getName(),tItem->testState->getTestRef()->getShortName()));
             }
-        }
-        
-        else{
+        } else {
             assert(item->isSuite());
-            TVTSItem* tItem2  = (TVTSItem*)item;
+            TVTSItem* tItem2  = static_cast<TVTSItem*>(item);
             if(tItem2->isSelected()){
                 testsToRun+= getSubTestToRun(tItem2,true);
-            }
-            else{
+            } else{
                 testsToRun+= getSubTestToRun(tItem2,runAll);
             }
         }
@@ -823,23 +811,20 @@ return testsToRun;
 QList<GTestRef*> TestViewController::getSubRefToExclude(TVItem* sItem,bool runAll)const{   
     QList<GTestRef*> testsToEx;
     for(int j = 0, m = sItem->childCount(); j<m; j++) {
-        TVItem* item = (TVItem*)sItem->child(j);
+        TVItem* item = static_cast<TVItem*>(sItem->child(j));
         if(item->isTest()){
-            TVTestItem* tItem  = (TVTestItem*)item;
-            if(tItem->excludedTests){
+            TVTestItem* tItem  = static_cast<TVTestItem*>(item);
+            if(tItem->excludedTests) {
                 if(tItem->isSelected() || runAll){
                     testsToEx.append(tItem->testState->getTestRef());
                 }
             }
-        }
-        
-        else{
+        } else{
             assert(item->isSuite());
-            TVTSItem* tItem2  = (TVTSItem*)item;
-            if(tItem2->isSelected()){
+            TVTSItem* tItem2  = static_cast<TVTSItem*>(item);
+            if (tItem2->isSelected()){
                 testsToEx+= getSubRefToExclude(tItem2,true);
-            }
-            else{
+            } else{
                 testsToEx+= getSubRefToExclude(tItem2,runAll);
             }
         }
@@ -858,7 +843,9 @@ void TestViewController::createAndRunTask(const QList<GTestState*>& testsToRun)
     *temp=QTime::currentTime();
     startRunTime = temp;
     int numberTestsToRun= service->getEnv()->getVar("NUM_THREADS").toInt(&ok);
-    if(!ok || numberTestsToRun <= 0 ){numberTestsToRun=5;}
+    if (!ok || numberTestsToRun <= 0 ){
+		numberTestsToRun=5;
+	}
     TestRunnerTask* ttask = new TestRunnerTask(testsToRun, service->getEnv(),numberTestsToRun);
 
     task = ttask;
@@ -882,6 +869,21 @@ void TestViewController::sl_taskStateChanged(Task* t) {
     delete endRunTime;delete startRunTime;
     endRunTime=NULL;startRunTime=NULL;
     updateState();
+	if(cmd) {
+		if(!t->isCanceled()) {
+			QString repDir;
+			if(AppContext::getCMDLineRegistry()->hasParameter(CMDLineCoreOptions::TEST_REPORT)) {
+				repDir = AppContext::getCMDLineRegistry()->getParameterValue(CMDLineCoreOptions::TEST_REPORT);
+			}
+			else {
+				repDir = "test_report.html";
+			}
+			reporterForm = new TestViewReporter(this,tree,time);
+			reporterForm->saveAs(repDir,reporterForm->getReportText());
+		}
+		AppContext::getTaskScheduler()->cancelAllTasks();
+		AppContext::getMainWindow()->getQMainWindow()->close();
+	}
 }
 
 void TestViewController::sl_setEnvAction() {
@@ -960,7 +962,7 @@ void TestViewController::sl_testStateChanged(GTestState* ts) {
     TVTestItem* tItem = findTestViewItem(ts->getTestRef());
     assert(tItem);
     tItem->updateVisual();
-    TVTSItem* temp_parent=(TVTSItem*)tItem->parent();
+    TVTSItem* temp_parent=static_cast<TVTSItem*>(tItem->parent());
     temp_parent->updateVisual();
 }
 
@@ -992,19 +994,19 @@ void TVTSItem::updateVisual() {
     }
     setText(0, text0);
     
-    int none = 0;
+    int notrun = 0;
     int passed = 0;
     int failed = 0;
     int excluded = 0;
-    getTestsState(&passed,&failed,&none,&excluded);
-    int total = passed + failed + none + excluded;
+    getTestsState(&passed,&failed,&notrun,&excluded);
+    int total = passed + failed + notrun + excluded;
 
     QString text1;
     text1+="T:"+QString::number(total)+" [";
     if (excluded != total) {
         text1+=" P:"+QString::number(passed);
         text1+=" F:"+QString::number(failed);
-        text1+=" N:"+QString::number(none);
+        text1+=" N:"+QString::number(notrun);
     }
     if (excluded) {
         text1+=" X:"+QString::number(excluded);
@@ -1014,27 +1016,28 @@ void TVTSItem::updateVisual() {
     setText(1, text1);  
     //add icon
     if(failed){
-    this->setIcon (0, ICON_FAILD_DIR);
-    }
-    else{
-        if(none){
+		this->setIcon (0, ICON_FAILD_DIR);
+    } else{
+        if (notrun){
             this->setIcon (0, ICON_NOTRUN_DIR);
-        }
-        else if(passed){
+        } else if (passed){
             this->setIcon (0, ICON_SUCCES_DIR);
-        }else{
+        } else {
             this->setIcon (0, ICON_NOTRUN_DIR);   
         }
     }
     if(this->parent() != NULL){
-        ((TVTSItem*)parent())->updateVisual();
+        (static_cast<TVTSItem*>(parent()))->updateVisual();
     }
 }
 
 QString TVTSItem::getRichDesc() const {
     //todo:
-    if(ts!=NULL) return ts->getName();       
-    else return getUrl();
+	if(ts!=NULL) {
+		return ts->getName();       
+	} else {
+		return getURL();
+	}
 }
 
 void TVTSItem::getTestsState(int * rPassed,int * rFailed,int * rNone,int *excluded){    
@@ -1043,10 +1046,10 @@ void TVTSItem::getTestsState(int * rPassed,int * rFailed,int * rNone,int *exclud
     int failed = 0;
     int exclud = 0;
     for(int i = 0; i < childCount(); i++) {
-        TVItem* item = (TVItem*)child(i);
+        TVItem* item = static_cast<TVItem*>(child(i));
         if(item->isTest()){
             total++;
-            TVTestItem* tItem  = (TVTestItem*)item;
+            TVTestItem* tItem  = static_cast<TVTestItem*>(item);
             GTestState* testState = tItem->testState;
             if(tItem->excludedTests){
                 exclud++;
@@ -1055,11 +1058,9 @@ void TVTSItem::getTestsState(int * rPassed,int * rFailed,int * rNone,int *exclud
             } else if (testState->isPassed()) {
                 passed++;
             } 
-        }
-
-        else{
+        } else {
             assert(item->isSuite());
-            TVTSItem* tItem  = (TVTSItem*)item;
+            TVTSItem* tItem  = static_cast<TVTSItem*>(item);
             tItem->getTestsState(rPassed,rFailed,rNone,excluded);      
         }
     } 
@@ -1067,19 +1068,16 @@ void TVTSItem::getTestsState(int * rPassed,int * rFailed,int * rNone,int *exclud
     *rFailed=*rFailed+failed;
     *excluded=*excluded+exclud;
     *rNone=(((*rNone+total)-passed)-failed)-exclud;
-    /*if (ts) {
-        *excluded += ts->getExcludedTests().size(); 
-        *rNone=*rNone-*excluded;
-    }else{
-    exclud
-    }*/
-
-    return ;
+    
+	return ;
 }
 
-QString TVTSItem::getUrl() const{
-    if(ts!=NULL)return name;    
-    else return (((TVTSItem*)parent())->getUrl()+name+"/");
+QString TVTSItem::getURL() const{
+	if(ts!=NULL){
+		return name;
+	} else {
+		return ((static_cast<TVTSItem*>(parent()))->getURL()+name+"/");
+	}
         
 } 
 //---------------------------------------------------------------------------
