@@ -13,8 +13,10 @@
 
 #include <core_api/MainWindow.h>
 #include <ui/ui_TestView.h>
+#include <cmdline/CMDLineRegistry.h>
 
 #include <QtGui/QTreeWidgetItem>
+#include <QtGui/QMainWindow>
 
 namespace GB2 {
 
@@ -33,7 +35,7 @@ class TestViewReporter;
 class TestViewController : public MWMDIWindow, Ui::TestView {
     Q_OBJECT
 public:
-    TestViewController(TestRunnerService* s);
+    TestViewController(TestRunnerService* s, bool cmd = false);
 
     virtual void setupMDIToolbar(QToolBar* tb);
     virtual void setupViewMenu(QMenu* n);
@@ -116,6 +118,9 @@ private:
     QTime* startRunTime ;
     QTime* endRunTime;
     int time;
+	bool cmd;
+
+	friend class TestRunnerPlugin;
 };
 
 enum TVItemType {
@@ -125,15 +130,15 @@ enum TVItemType {
 
 class TVItem : public QTreeWidgetItem {
 public:
-    bool excludedTests;
-
-    TVItem(TVItemType t) : type(t) {}
+    TVItem(TVItemType t) : type(t), excludedTests(false) {}
     
     virtual void updateVisual() = 0;
 
     virtual QString getRichDesc() const = 0;
 
     const TVItemType type;
+
+	bool excludedTests;
     
     bool isSuite() const {return type == TVItem_TestSuite;}
     
@@ -156,7 +161,7 @@ public:
 
     QString name;
 
-    QString getUrl() const;
+    QString getURL() const;
 
     void getTestsState(int *passed,int *failed,int *none,int *excluded);
 
