@@ -56,9 +56,9 @@ const QString TestViewReporter::prepareHTMLText(QTreeWidget* tree,int runTime){
         int tnone = 0;
         int texcluded = 0;
         for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-            TVItem* item = (TVItem*)tree->topLevelItem(i);     
+            TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));     
             assert(item->isSuite());
-            TVTSItem* tItem  = (TVTSItem*)item;
+            TVTSItem* tItem  = static_cast<TVTSItem*>(item);
 
             int passed=0,failed=0,none=0;
             int excluded = 0;
@@ -234,9 +234,9 @@ const QString TestViewReporter::getHTMLErrorTables(QTreeWidget* tree){
     int testIndex=1;
     int testIndex2=1;
     for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-        TVItem* item = (TVItem*)tree->topLevelItem(i);     
+        TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));     
         assert(item->isSuite());
-        TVTSItem* tItem  = (TVTSItem*)item;
+        TVTSItem* tItem  = static_cast<TVTSItem*>(item);
         QList<TVTestItem*> failedTests = getFailedTests(tItem);
         if(!failedTests.isEmpty()){
             rezult+=getHTMLSuiteName(tItem);
@@ -249,9 +249,9 @@ const QString TestViewReporter::getHTMLErrorTables(QTreeWidget* tree){
         rezult+="</table>";
         rezult+="<tr><td><br><br><br><br><br><hr></td></tr>";
         for (int i=0, n = tree->topLevelItemCount(); i<n; i++) {
-            TVItem* item = (TVItem*)tree->topLevelItem(i);     
+            TVItem* item = static_cast<TVItem*>(tree->topLevelItem(i));     
             assert(item->isSuite());
-            TVTSItem* tItem  = (TVTSItem*)item;
+            TVTSItem* tItem  = static_cast<TVTSItem*>(item);
             QList<TVTestItem*> failedTests = getFailedTests(tItem);
             if(!failedTests.isEmpty()){
                 rezult+="<table>";
@@ -406,15 +406,15 @@ bool TestViewReporter::setColorInTestText(QString* inputData){
 QList<TVTestItem*> TestViewReporter::getFailedTests(TVTSItem* Root){    
     QList<TVTestItem*> rezult;
     for(int i = 0; i < Root->childCount(); i++) {
-        TVItem* item = (TVItem*)Root->child(i);
+        TVItem* item = static_cast<TVItem*>(Root->child(i));
         if(item->isTest()){ 
-            TVTestItem* tItem  = (TVTestItem*)item;
+            TVTestItem* tItem  = static_cast<TVTestItem*>(item);
             if(tItem->testState->isFailed())rezult.append(tItem);
         }
 
         else{
             assert(item->isSuite());
-            TVTSItem* tItem  = (TVTSItem*)item;
+            TVTSItem* tItem  = static_cast<TVTSItem*>(item);
             rezult+=getFailedTests(tItem);      
         }
     } 
