@@ -203,7 +203,7 @@ void ExtendedProcStyle::refresh() {
             if ((h/w < 0.6 && w > (MINW+MAXW)/2)  //doc is disproportionately wide
                 || (h/w > 1.6 && w < MAXW)        //doc is disproportionately long and can be widen
                 || (w < MINW || w > MAXW)) {      //width is out of bounds
-                doc->setTextWidth(qBound(MINW, h/1.6, MAXW-MARGIN*2));            
+                doc->setTextWidth(qBound(MINW, (qreal)(h/1.6), MAXW-MARGIN*2));            
             }
         } while (true);
 
@@ -334,7 +334,7 @@ bool ExtendedProcStyle::sceneEventFilter( QGraphicsItem * watched, QEvent * even
                 if (resizing & HResize 
                     &&  // border is either "pulled" or "pushed" by mouse pointer
                         // in the latter case pointer should be close to the border
-                        (p2.x() < 0 && b2.right() > p.x() 
+                        ((p2.x() < 0 && b2.right() > p.x()) 
                         || (p2.x() > 0 && b2.right() < p.x())
                         || (qAbs(b2.right() - p.x()) < RESIZE_AREA)))
                 {
@@ -348,7 +348,7 @@ bool ExtendedProcStyle::sceneEventFilter( QGraphicsItem * watched, QEvent * even
                     }
                 }
                 if (resizing & VResize 
-                    && (p2.y() < 0 && b2.bottom() > p.y() 
+                    && ((p2.y() < 0 && b2.bottom() > p.y()) 
                         || (p2.y() > 0 && b2.bottom() < p.y())
                         || (qAbs(b2.bottom() - p.y()) < RESIZE_AREA)))
                 {
