@@ -13,7 +13,7 @@
 #include "WorkflowDocument.h"
 #include "WorkflowSettingsController.h"
 #include "library/CoreLib.h"
-#include <workflow_support/WorkflowTests.h>
+#include <tests/WorkflowTests.h>
 #include "WorkflowSamples.h"
 
 #include <workflow/WorkflowEnv.h>
@@ -24,6 +24,12 @@
 #include <core_api/Settings.h>
 #include <core_api/Task.h>
 
+#include <cmdline/CMDLineRegistry.h>
+#include <cmdline/CMDLineHelpProvider.h>
+#include <cmdline/CMDLineUtils.h>
+#include <cmdline/WorkflowCMDLineTasks.h>
+
+#include <util_tasks/TaskStarter.h>
 #include <util_algorithm/GAutoDeleteList.h>
 #include <test_framework/xmltest/XMLTestFormat.h>
 #include <test_framework/GTest.h>
@@ -45,6 +51,8 @@ static LogCategory log(ULOG_CAT_WD);
 
 #define PLUGIN_SETTINGS QString("workflowview/")
 
+const QString WorkflowDesignerPlugin::RUN_WORKFLOW              = "task";
+const QString WorkflowDesignerPlugin::REMOTE_MACHINE            = "task-remote-machine";
 
 WorkflowDesignerPlugin::WorkflowDesignerPlugin() 
 : Plugin(tr("Workflow Designer"), tr("Workflow Designer allows to create complex computational workflows."))
@@ -69,6 +77,46 @@ WorkflowDesignerPlugin::WorkflowDesignerPlugin()
         assert(res);
         Q_UNUSED(res);
     }
+    
+    // Workflow simple local task
+    LocalTaskFactoryRegistry * ltfr = AppContext::getLocalTaskFactoryRegistry();
+    assert( NULL != ltfr );
+    ltfr->registerLocalTaskFactory( &workflowSimpleTaskFactory );
+
+    registerCMDLineHelp();
+    processCMDLineOptions();
+}
+
+void WorkflowDesignerPlugin::processCMDLineOptions() {
+    CMDLineRegistry * cmdlineReg = AppContext::getCMDLineRegistry();
+    assert(cmdlineReg != NULL);
+    
+    if( cmdlineReg->hasParameter( RUN_WORKFLOW ) || !CMDLineRegistryUtils::getPureValues().isEmpty() ) {
+        Task * t = NULL;
+        if( cmdlineReg->hasParameter(REMOTE_MACHINE) ) {
+            t = new WorkflowRemoteRunFromCMDLineTask();
+        } else {
+            t = new WorkflowRunFromCMDLineTask();
+        }
+        connect(AppContext::getPluginSupport(), SIGNAL(si_allStartUpPluginsLoaded()), new TaskStarter(t), SLOT(registerTask()));
+    }
+}
+
+void WorkflowDesignerPlugin::registerCMDLineHelp() {
+    CMDLineRegistry * cmdLineRegistry = AppContext::getCMDLineRegistry();
+    assert( NULL != cmdLineRegistry );
+    
+    CMDLineHelpProvider * taskSectionArguments = new CMDLineHelpProvider( RUN_WORKFLOW, 
+        "<path-to-schema or schema-name> [schema arguments ...]" );
+    CMDLineHelpProvider * taskSection = new CMDLineHelpProvider( RUN_WORKFLOW, tr( "run given workflow schema" ) );
+    
+    CMDLineHelpProvider * remoteMachineSectionArguments = new CMDLineHelpProvider( REMOTE_MACHINE, "<path-to-machine-file>");
+    CMDLineHelpProvider * remoteMachineSection = new CMDLineHelpProvider( REMOTE_MACHINE, tr("run provided tasks on given remote machine") );
+    
+    cmdLineRegistry->registerCMDLineHelpProvider( taskSectionArguments );
+    cmdLineRegistry->registerCMDLineHelpProvider( taskSection );
+    cmdLineRegistry->registerCMDLineHelpProvider( remoteMachineSectionArguments );
+    cmdLineRegistry->registerCMDLineHelpProvider( remoteMachineSection );
 }
 
 class CloseDesignerTask : public Task {
