@@ -15,6 +15,8 @@
 #include <core_api/ServiceModel.h>
 #include <core_api/Task.h>
 
+#include <wd_local_task/WorkflowSimpleLocalTask.h>
+
 class QAction;
 class QEvent;
 
@@ -22,9 +24,20 @@ namespace GB2 {
 
 class WorkflowDesignerPlugin : public Plugin {
 	Q_OBJECT
+public:
+    static const QString RUN_WORKFLOW;
+    static const QString REMOTE_MACHINE;
+    
 public:
     WorkflowDesignerPlugin ();
 	//~WorkflowDesignerPlugin ();
+private:
+    void registerCMDLineHelp();
+    void processCMDLineOptions();
+    
+private:
+    WorkflowSimpleLocalTaskFactory workflowSimpleTaskFactory;
+    
 };
 
 class WorkflowDesignerService : public Service {
