@@ -15,13 +15,14 @@
 #include <core_api/AppContext.h>
 #include <core_api/MainWindow.h>
 #include <core_api/IOAdapter.h>
+#include <core_api/L10n.h>
 #include <core_api/Task.h>
+
 #include <selection/SelectionUtils.h>
 #include <workflow_support/SchemaSerializer.h>
-#include <util_gui/GUIUtils.h>
+
 #include <QtCore/QFile>
 #include <QtXml/qdom.h>
-#include <memory>
 
 /* TRANSLATOR GB2::IOAdapter */
 
@@ -53,6 +54,15 @@ GObject* WorkflowGObject::clone() const {
     return copy;
 }
 
+//////////////////////////////////////////////////////////////////////////
+/// Workflow document format
+
+WorkflowDocFormat::WorkflowDocFormat(QObject* p) 
+: DocumentFormat(p, DocumentFormatFlags_W1, QStringList("uws")), formatName(tr("Workflow Schema")) 
+{
+	supportedObjectTypes += WorkflowGObject::TYPE;
+}
+
 Document* WorkflowDocFormat::createNewDocument(IOAdapterFactory* io, const QString& url, const QVariantMap& fs) {
     Document* d = DocumentFormat::createNewDocument(io, url, fs);
     GObject* o = new WorkflowGObject(tr("Workflow Schema"), QDomDocument());
@@ -60,20 +70,23 @@ Document* WorkflowDocFormat::createNewDocument(IOAdapterFactory* io, const QStri
     return d;
 }
 
-Document* WorkflowDocFormat::loadExistingDocument(IOAdapterFactory* iof, const QString& url, TaskStateInfo& ti, const QVariantMap& fs) {
-    assert(iof->getAdapterId() == BaseIOAdapters::LOCAL_FILE); //FIXME as utility
-    QFile f(url);
-    if (!f.open(QIODevice::ReadOnly)) {
-        ti.setError(  Translations::errorOpeningFileRead(url) );
-        return NULL;
-    }
-    QByteArray  xmlData = f.readAll();
-    f.close();
+#define BUFF_SIZE 1024
 
+Document* WorkflowDocFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode) {
+    Q_UNUSED(mode);
+    QByteArray  xmlData;
+    QByteArray block(BUFF_SIZE, '\0');
+    int blockLen = 0;
+    while ((blockLen = io->readBlock(block.data(), BUFF_SIZE)) > 0) {
+        //todo: text.append can fail on realloc for large sizes
+        xmlData.append(QString::fromLocal8Bit(block.data(), blockLen));
+        ti.progress = io->getProgress();
+    }
+    
     QDomDocument xml;
     bool res = xml.setContent(xmlData);
     if (!res || xml.doctype().name() != Workflow::SchemaSerializer::WORKFLOW_DOC) {
-        ti.setError(  tr("Invalid content: %1").arg(url) );
+        ti.setError(  tr("Invalid content: %1").arg(io->toString()) );
         xml.clear();
     }
 
@@ -82,19 +95,15 @@ Document* WorkflowDocFormat::loadExistingDocument(IOAdapterFactory* iof, const Q
     GObject* o = new WorkflowGObject(tr("Workflow Schema"), xml);
     QList<GObject*> objects;
     objects.append(o);
-    Document* d = new Document(this, iof, url, objects, fs);
+    Document* d = new Document(this, io->getFactory(), io->getURL(), objects, fs);
     return d;
 }
 
-void WorkflowDocFormat::storeDocument(Document* d, TaskStateInfo& ti, IOAdapterFactory* iof, const QString& newDocURL) {
+void WorkflowDocFormat::storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io) {
+    Q_UNUSED(ts)
     assert(d->getDocumentFormat() == this);
     assert(d->getObjects().size() ==1);
 
-    if (iof == NULL) {
-        iof = d->getIOAdapterFactory();
-    }
-    assert(iof);
-    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
     WorkflowGObject* wo = qobject_cast<WorkflowGObject*>(d->getObjects().first());
     assert(wo && wo->getView());
 
@@ -105,11 +114,6 @@ void WorkflowDocFormat::storeDocument(Document* d, TaskStateInfo& ti, IOAdapterF
     SchemaSerializer::saveMeta((const Metadata* ) &metadata , elem);
     QByteArray rawData = xmlDoc.toByteArray();
 
-    QString url = newDocURL.isEmpty() ? d->getURL() : newDocURL;
-    if (!io->open(url, IOAdapterMode_Write)) {
-        ti.setError(  ti.getError() = Translations::errorOpeningFileWrite(url) );
-        return;
-    }
     int nWritten = 0;
     int nTotal = rawData.size();
     while(nWritten < nTotal) {
@@ -122,28 +126,9 @@ void WorkflowDocFormat::storeDocument(Document* d, TaskStateInfo& ti, IOAdapterF
 }
 
 
-bool WorkflowDocFormat::isDataFormatSupported(const char* data, int size) const {
-    Q_UNUSED(size);
-    return QString(data).startsWith("<!DOCTYPE GB2WORKFLOW>"); //TODO improve
-}
-
-bool WorkflowDocFormat::isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const{
-    Q_UNUSED(d);
-    Q_UNUSED(op);
-    Q_UNUSED(t);
-    return false;//(t == GObjectTypes::TEXT && (op == DocObjectOp_Remove || d->getObjects().isEmpty()));
-}
-
-bool WorkflowDocFormat::checkConstraints(const DocumentFormatConstraints& c) const {
-    foreach (GObjectType t, c.supportedObjectTypes) {
-        if (t!=WorkflowGObject::TYPE) {
-            return false;
-        }
-    }
-    if (c.checkRawData) {
-        return isDataFormatSupported(c.rawData.constData(), c.rawData.size());
-    }
-    return true;
+bool WorkflowDocFormat::checkRawData(const QByteArray& data) const {
+    bool headerOk =  QString(data).startsWith("<!DOCTYPE GB2WORKFLOW>"); //TODO improve
+    return headerOk ?  true : false;
 }
 
 bool WorkflowViewFactory::canCreateView(const MultiGSelection& multiSelection) {
