@@ -29,25 +29,19 @@ class WorkflowView;
 class WorkflowDocFormat : public DocumentFormat {
     Q_OBJECT
 public:
-    WorkflowDocFormat(QObject* p) : DocumentFormat(p), formatName(tr("Workflow Schema")) {}
+    WorkflowDocFormat(QObject* p);
 
 	virtual DocumentFormatId getFormatId() const {return "WorkflowDocFormat";}
 
 	virtual const QString& getFormatName() const {return formatName;}
 
-    virtual QStringList getSupportedDocumentFileExtensions() {return (QStringList() << "uws");}
-
 	virtual Document* createNewDocument(IOAdapterFactory* io, const QString& url, const QVariantMap& fs = QVariantMap());
 	
-	virtual Document* loadExistingDocument(IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& fs);
+	virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);
 
-	virtual void storeDocument(Document* d, TaskStateInfo& ti, IOAdapterFactory* io = NULL, const QString& newDocURL = QString::null);
+    virtual void storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io);
 
-	virtual bool isDataFormatSupported(const char* data, int size) const;
-
-	virtual bool isObjectOpSupported(const Document* d , DocumentFormat::DocObjectOp op, GObjectType t) const;
-
-	virtual bool checkConstraints(const DocumentFormatConstraints& c) const;
+	virtual bool checkRawData(const QByteArray& rawData) const;
 
 private:
 	QString formatName;
