@@ -11,27 +11,61 @@
 #include "WorkflowEditor.h"
 #include "WorkflowViewController.h"
 #include "IterationListWidget.h"
+#include "WorkflowEditorDelegates.h"
 
 #include "ActorCfgModel.h"
 
 #include <core_api/Settings.h>
+#include <core_api/Log.h>
+#include <workflow_support/WorkflowUtils.h>
 
 #include <QtGui/QAction>
 #include <QtGui/QHeaderView>
 
+#define MAIN_SPLITTER "main.splitter"
+#define TAB_SPLITTER "tab.splitter"
+
 namespace GB2 {
 
-class SuperDelegate : public ProxyDelegate {
-public:
-    SuperDelegate(WorkflowEditor *parent) : ProxyDelegate(parent), owner(parent) {}
+static LogCategory log(ULOG_CAT_WD);
 
-    virtual bool handlePropertyValueList(const QString& name, QVariant list) const {
-        return owner->iterationList->expandList(owner->actor->getId(), name, list);
-    }
+WorkflowEditor::WorkflowEditor(WorkflowView *p) 
+: QWidget(p), owner(p), custom(NULL), customWidget(NULL), subject(NULL), actor(NULL)
+{
+    setupUi(this);
 
-private:
-    WorkflowEditor* owner;
-};
+    caption->setMinimumHeight(nameEdit->sizeHint().height());
+
+    iterationList = new IterationListWidget(this);
+    iterationBox->layout()->addWidget(iterationList);
+
+    actorModel = new ActorCfgModel(this, iterationList->list());
+    table->setModel(actorModel);
+    table->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
+    
+    table->horizontalHeader()->setStretchLastSection(true);
+    /*table->horizontalHeader()->setStretchLastSection(false);
+    table->horizontalHeader()->setResizeMode(0, QHeaderView::ResizeToContents);
+    table->horizontalHeader()->setResizeMode(1, QHeaderView::Interactive);
+    table->horizontalHeader()->setResizeMode(2, QHeaderView::Stretch);*/
+    
+    table->horizontalHeader()->setClickable(false);
+    table->verticalHeader()->hide();
+    table->verticalHeader()->setDefaultSectionSize(QFontMetrics(QFont()).height() + 6);
+    table->setItemDelegate(new SuperDelegate(this));
+
+    reset();
+    
+    connect(iterationList, SIGNAL(iterationListAboutToChange()), SLOT(finishPropertyEditing()));
+    connect(iterationList, SIGNAL(selectionChanged()), SLOT(updateIterationData()));
+    connect(iterationList, SIGNAL(listChanged()), SLOT(commitIterations()));
+    connect(iterationList, SIGNAL(selectionChanged()), SIGNAL(iterationSelected()));
+
+    connect(nameEdit, SIGNAL(editingFinished()), SLOT(editingLabelFinished()));
+
+    connect(table->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)), SLOT(sl_showPropDoc()));
+    connect(table->model(), SIGNAL(dataChanged(QModelIndex, QModelIndex)), SLOT(handleDataChanged(QModelIndex, QModelIndex)));
+}
 
 void WorkflowEditor::handleDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight) {
     if (topLeft == bottomRight) {
@@ -55,38 +89,6 @@ void WorkflowEditor::updateIterationData() {
     actorModel->selectIteration(iterationList->current());
 }
 
-
-WorkflowEditor::WorkflowEditor(WorkflowView *p) 
-: QWidget(p), owner(p), custom(NULL), customWidget(NULL), subject(NULL), actor(NULL)
-{
-    setupUi(this);
-
-    caption->setMinimumHeight(nameEdit->sizeHint().height());
-
-    iterationList = new IterationListWidget(this);
-    iterationBox->layout()->addWidget(iterationList);
-
-    actorModel = new ActorCfgModel(this, iterationList->list());
-    table->setModel(actorModel);
-    table->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
-    table->horizontalHeader()->setStretchLastSection(true);
-    table->verticalHeader()->hide();
-    table->verticalHeader()->setDefaultSectionSize(QFontMetrics(QFont()).height() + 6);
-    table->setItemDelegate(new SuperDelegate(this));
-
-    reset();
-
-    connect(iterationList, SIGNAL(iterationListAboutToChange()), SLOT(finishPropertyEditing()));
-    connect(iterationList, SIGNAL(selectionChanged()), SLOT(updateIterationData()));
-    connect(iterationList, SIGNAL(listChanged()), SLOT(commitIterations()));
-    connect(iterationList, SIGNAL(selectionChanged()), SIGNAL(iterationSelected()));
-
-    connect(nameEdit, SIGNAL(editingFinished()), SLOT(editingLabelFinished()));
-
-    connect(table->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)), SLOT(sl_showPropDoc()));
-    connect(table->model(), SIGNAL(dataChanged(QModelIndex, QModelIndex)), SLOT(handleDataChanged(QModelIndex, QModelIndex)));
-}
-
 void WorkflowEditor::sl_showPropDoc() {
     QModelIndex current = table->selectionModel()->currentIndex();
     if (current.isValid()) {
@@ -192,9 +194,6 @@ void WorkflowEditor::edit(Configuration* cfg) {
     }
 }
 
-#define MAIN_SPLITTER "main.splitter"
-#define TAB_SPLITTER "tab.splitter"
-
 QVariant WorkflowEditor::saveState() const {
     QVariantMap m;
     m.insert(MAIN_SPLITTER, splitter->saveState());
@@ -208,5 +207,4 @@ void WorkflowEditor::restoreState(const QVariant& v) {
     tableSplitter->restoreState(m.value(TAB_SPLITTER).toByteArray());
 }
 
-
 }//namespace
