@@ -188,15 +188,26 @@ void WorkflowPalette::mouseMoveEvent(QMouseEvent * event) {
     }
     QTreeWidgetItem* prev = overItem;
     overItem = itemAt(event->pos());
-    if (prev) update(indexFromItem(prev));
-    if (overItem) update(indexFromItem(overItem));
+    if (prev) {
+        update(indexFromItem(prev));
+    }
+    if (overItem) {
+        update(indexFromItem(overItem));
+    }
+
+    QTreeWidget::mouseMoveEvent(event);
 }
 
 void WorkflowPalette::leaveEvent(QEvent *) {
-    if (!hasMouseTracking()) return;
+    if (!hasMouseTracking()) {
+        return;
+    }
     QTreeWidgetItem* prev = overItem;
     overItem = NULL;
-    if (prev) update(indexFromItem(prev));
+    if (prev) {
+        QModelIndex index = indexFromItem(prev);
+        update(index);
+    };
 }
 
 void WorkflowPalette::mousePressEvent(QMouseEvent * event) {
