@@ -19,18 +19,27 @@
 #include "WorkflowMetaDialog.h"
 #include "ChooseItemDialog.h"
 #include "SchemaConfigurationDialog.h"
+#include "SchemaAliasesConfigurationDialogImpl.h"
 #include "WorkflowSamples.h"
 #include "GlassView.h"
+#include <wd_local_task/WorkflowSimpleLocalTask.h>
 
 #include <workflow/WorkflowModel.h>
 #include <workflow/WorkflowRegistry.h>
 #include <workflow/IntegralBusModel.h>
 #include <workflow/WorkflowEnv.h>
 #include <workflow/WorkflowManager.h>
-#include <workflow_support/TypeMapEditor.h>
+#include <workflow_support/MapDatatypeEditor.h>
 #include <workflow_support/WorkflowUtils.h>
 #include <workflow_support/WorkflowRunTask.h>
 #include <workflow_support/WorkflowSettings.h>
+#include <workflow_support/CoreDataTypes.h>
+#include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
+
+#include <distributed_computing/RemoteMachine.h>
+#include <util_gui/RemoteMachineMonitorDialogImpl.h>
+#include <distributed_computing/DistributedComputingUtil.h>
 
 #include <core_api/AppContext.h>
 #include <core_api/MainWindow.h>
@@ -39,6 +48,9 @@
 
 #include <util_tasks/TaskSignalMapper.h>
 
+#include <algorithm>
+#include <functional>
+
 #include <QtGui/QMenu>
 #include <QtGui/QBoxLayout>
 #include <QtGui/QSplitter>
@@ -78,9 +90,26 @@ static LogCategory log(ULOG_CAT_WD);
 enum {ElementsTab,SamplesTab};
 
 #define WS 1000
-WorkflowView::WorkflowView(WorkflowGObject* go) : MWMDIWindow(tr("Workflow Designer")), go(go),
-         currentProc(NULL), pasteCount(0)
-{
+
+static QString percentStr = WorkflowView::tr("%");
+
+/********************************
+* PercentValidator
+********************************/
+class PercentValidator : public QRegExpValidator {
+public:
+    PercentValidator(QObject* parent) : QRegExpValidator(QRegExp("[1-9][0-9]*"+percentStr), parent) {}
+    void fixup(QString& input) const {
+        if (!input.endsWith(percentStr)) {
+            input.append(percentStr);
+        }
+    }
+}; // PercentValidator
+
+/********************************
+* WorkflowView
+********************************/
+WorkflowView::WorkflowView(WorkflowGObject* go) : MWMDIWindow(tr("Workflow Designer")), go(go), currentProc(NULL), pasteCount(0) {
     scene = new WorkflowScene(this);
     scene->setSceneRect(QRectF(-WS, -WS, WS, WS));
     connect(scene, SIGNAL(processItemAdded()), SLOT(sl_procItemAdded()));
@@ -88,8 +117,7 @@ WorkflowView::WorkflowView(WorkflowGObject* go) : MWMDIWindow(tr("Workflow Desig
 
     palette = new WorkflowPalette(WorkflowEnv::getProtoRegistry()/*, this*/);
     palette->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored));
-    connect(palette, SIGNAL(processSelected(Workflow::ActorPrototype*)), 
-        SLOT(sl_selectProcess(Workflow::ActorPrototype*)));
+    connect(palette, SIGNAL(processSelected(Workflow::ActorPrototype*)), SLOT(sl_selectProcess(Workflow::ActorPrototype*)));
 
     infoList = new QListWidget(this);
     connect(infoList, SIGNAL(itemDoubleClicked(QListWidgetItem*)), SLOT(sl_pickInfo(QListWidgetItem*)));
@@ -169,13 +197,15 @@ WorkflowView::WorkflowView(WorkflowGObject* go) : MWMDIWindow(tr("Workflow Desig
             QList<Iteration> lst;
             SchemaSerializer::readIterations(lst, go->getXML().documentElement(), remapping);
             //if (!lst.isEmpty()) 
-                scene->setIterations(lst);
+            scene->setIterations(lst);
             SchemaSerializer::readMeta(&meta, go->getXML().documentElement());
-            if (go->getDocument())
-                meta.url = go->getDocument()->getURL();
+			if (go->getDocument()) {
+                meta.url = go->getDocument()->getURLString();
+			}
             sl_updateTitle();
             propertyEditor->resetIterations();
             scene->setModified(false);
+            sl_refreshActorDocs();
         }
     } else {
         sl_newScene();
@@ -189,18 +219,6 @@ WorkflowView::~WorkflowView() {
     log.trace("~WorkflowView");
 }
 
-static QString percentStr = WorkflowView::tr("%");
-
-class PercentValidator : public QRegExpValidator {
-public:
-	PercentValidator(QObject* parent) : QRegExpValidator(QRegExp("[1-9][0-9]*"+percentStr), parent) {}
-	void fixup(QString& input) const {
-		if (!input.endsWith(percentStr)) {
-			input.append(percentStr);
-		}
-	}
-};
-
 void WorkflowView::sl_rescaleScene(const QString &scale)
 {
 	int percentPos = scale.indexOf(percentStr);
@@ -251,11 +269,15 @@ void WorkflowView::createActions() {
     deleteAction->setShortcuts(QKeySequence::Delete);
     connect(deleteAction, SIGNAL(triggered()), scene, SLOT(sl_deleteItem()));
 
-    configureAction = new QAction(tr("Configure iterations"), this);
-    configureAction->setIcon(QIcon(":workflow_designer/images/tag.png"));
-    //configureAction ->setShortcut(QKeySequence::Delete);
-    connect(configureAction , SIGNAL(triggered()), SLOT(sl_configure()));
-
+    configureIterationsAction = new QAction(tr("Configure iterations"), this);
+    configureIterationsAction->setIcon(QIcon(":workflow_designer/images/tag.png"));
+    //configureIterationsAction ->setShortcut(QKeySequence::Delete);
+    connect(configureIterationsAction , SIGNAL(triggered()), SLOT(sl_configureIterations()));
+    
+    configureAliasesAction = new QAction(tr("Configure command line aliases"), this);
+    configureAliasesAction->setIcon(QIcon(":workflow_designer/images/cmdline.png"));
+    connect(configureAliasesAction, SIGNAL(triggered()), SLOT(sl_configureAliases()));
+    
     selectAction = new QAction(tr("Select all items"), this);
 	selectAction->setShortcuts(QKeySequence::SelectAll);
     connect(selectAction, SIGNAL(triggered()), scene, SLOT(sl_selectAll()));
@@ -299,7 +321,17 @@ void WorkflowView::createActions() {
     extStyle->setData(QVariant(ItemStyles::EXTENDED));
     connect(extStyle, SIGNAL(triggered()), SLOT(sl_setStyle()));
     styleActions << simpleStyle << extStyle;
-
+    
+    QAction * localHostRunMode = new QAction( tr( "Local host" ), this );
+    localHostRunMode->setCheckable( true );
+    localHostRunMode->setChecked( LOCAL_HOST == meta.runMode );
+    connect( localHostRunMode, SIGNAL( triggered() ), SLOT( sl_setRunMode() ) );
+    QAction * remoteMachineRunMode = new QAction( tr( "Remote machine" ), this );
+    remoteMachineRunMode->setCheckable( true );
+    remoteMachineRunMode->setChecked( REMOTE_MACHINE == meta.runMode );
+    connect( remoteMachineRunMode, SIGNAL( triggered() ), SLOT( sl_setRunMode() ) );
+    runModeActions << localHostRunMode << remoteMachineRunMode;
+    
     unlockAction = new QAction(tr("Unlock Scene"), this);
     unlockAction->setCheckable(true);
     unlockAction->setChecked(true);
@@ -324,10 +356,11 @@ void WorkflowView::sl_toggleLock(bool b) {
     loadAction->setEnabled(b);
     //newAction->setEnabled(b);
 
-    configureAction->setEnabled(b);
+    configureIterationsAction->setEnabled(b);
     runAction->setEnabled(b);
     validateAction->setEnabled(b);
-
+    configureAliasesAction->setEnabled(b);
+    
     propertyEditor->setEnabled(b);
     palette->setEnabled(b);
 
@@ -346,21 +379,84 @@ void WorkflowView::sl_setStyle() {
             case WorkflowProcessItemType:
             case WorkflowPortItemType:
             case WorkflowBusItemType:
-            ((StyledItem*)it)->setStyle(s);
+            (static_cast<StyledItem*>(it))->setStyle(s);
         }
     }
     //update();
 }
 
+// FIXME: move to utils classes
+static void removeUrlLocationParameter( Actor * actor ) {
+    assert( NULL != actor );
+    Attribute * attr = actor->getParameter( CoreLibConstants::URL_LOCATION_ATTR_ID );
+    if( NULL != attr ) {
+        Attribute * removed = actor->removeParameter( CoreLibConstants::URL_LOCATION_ATTR_ID );
+        assert( attr == removed );
+        delete attr;
+        delete actor->getEditor()->removeDelegate( CoreLibConstants::URL_LOCATION_ATTR_ID );
+    }
+    URLDelegate * urlDelegate = qobject_cast<URLDelegate*>( actor->getEditor()->getDelegate( CoreLibConstants::URL_IN_ATTR_ID ) );
+    if( NULL != urlDelegate ) {
+        urlDelegate->sl_showEditorButton( true );
+    }
+}
+
+// FIXME: move to utils classes
+static void addUrlLocationParameter( Actor * actor ) {
+    assert( NULL != actor );
+    Attribute * urlAttr = actor->getParameter( CoreLibConstants::URL_IN_ATTR_ID );
+    Attribute * urlLocationAttr = actor->getParameter( CoreLibConstants::URL_LOCATION_ATTR_ID );
+    if( NULL != urlAttr && NULL == urlLocationAttr ) {
+        actor->addParameter( CoreLibConstants::URL_LOCATION_ATTR_ID, 
+            new Attribute( CoreLibConstants::URL_LOCATION_ATTR(), CoreDataTypes::BOOL_TYPE(), false, true ) );
+        SchemaRunModeDelegate * runModeDelegate = new SchemaRunModeDelegate();
+        URLDelegate * urlDelegate = qobject_cast<URLDelegate*>
+            ( actor->getEditor()->getDelegate( CoreLibConstants::URL_IN_ATTR_ID ) );
+        QObject::connect( runModeDelegate, SIGNAL( si_showOpenFileButton( bool ) ), urlDelegate, SLOT( sl_showEditorButton( bool ) ) );
+        actor->getEditor()->addDelegate( runModeDelegate, CoreLibConstants::URL_LOCATION_ATTR_ID );
+    }
+}
+
+void WorkflowView::sl_setRunMode() {
+    QAction * a = qobject_cast<QAction*>( sender() );
+    if( runModeActions[0] == a ) { // local host run mode
+        meta.runMode = LOCAL_HOST;
+    } else if( runModeActions[1] == a ) { // remote machine run mode
+        meta.runMode = REMOTE_MACHINE;
+    } else {
+        // no sender. smbdy called it like a function
+    }
+    
+    runModeActions[0]->setChecked( LOCAL_HOST == meta.runMode );
+    runModeActions[1]->setChecked( REMOTE_MACHINE == meta.runMode );
+    
+    // change actors that are on pallete now
+    QList<Actor*> actorsOnBoard = scene->getAllProcs();
+    foreach( Actor * actor, actorsOnBoard ) {
+        switch( meta.runMode ) {
+        case LOCAL_HOST:
+            removeUrlLocationParameter( actor );
+            break;
+        case REMOTE_MACHINE:
+            addUrlLocationParameter( actor );
+            break;
+        default:
+            assert( false );
+        }
+    }
+    
+    scene->sl_deselectAll();
+}
+
 void WorkflowView::sl_toggleStyle() {
     foreach(QGraphicsItem* it, scene->selectedItems()) {
-        StyleId s = ((StyledItem*)it)->getStyle();
+        StyleId s = (static_cast<StyledItem*>(it))->getStyle();
         if (s == ItemStyles::SIMPLE) {
             s = ItemStyles::EXTENDED;
         } else {
             s = ItemStyles::SIMPLE;
         }
-        ((StyledItem*)it)->setStyle(s);
+        (static_cast<StyledItem*>(it))->setStyle(s);
     }
     //update();
 }
@@ -382,7 +478,8 @@ void WorkflowView::setupMDIToolbar(QToolBar* tb) {
     tb->addSeparator();
     tb->addAction(validateAction);
     tb->addAction(runAction);
-    tb->addAction(configureAction);
+    tb->addAction(configureIterationsAction);
+    tb->addAction(configureAliasesAction);
     tb->addSeparator();
 	tb->addAction(copyAction);
 	tb->addAction(pasteAction);
@@ -402,6 +499,15 @@ void WorkflowView::setupMDIToolbar(QToolBar* tb) {
     tt->setDefaultAction(ttMenu->menuAction());
     tt->setPopupMode(QToolButton::InstantPopup);
     tb->addWidget(tt);
+    
+    QToolButton * runModeToolButton = new QToolButton(tb);
+    QMenu * runModeMenu = new QMenu( tr( "Run mode" ), this );
+    foreach( QAction * a, runModeActions ) {
+        runModeMenu->addAction( a );
+    }
+    runModeToolButton->setDefaultAction( runModeMenu->menuAction() );
+    runModeToolButton->setPopupMode( QToolButton::InstantPopup );
+    tb->addWidget( runModeToolButton );
 }
 
 void WorkflowView::setupViewMenu(QMenu* m) {
@@ -422,7 +528,8 @@ void WorkflowView::setupViewMenu(QMenu* m) {
     m->addAction(exportAction);
     m->addSeparator();
     m->addAction(validateAction);
-    m->addAction(configureAction);
+    m->addAction(configureIterationsAction);
+    m->addAction(configureAliasesAction);
     m->addAction(runAction);
     m->addSeparator();
 
@@ -431,7 +538,13 @@ void WorkflowView::setupViewMenu(QMenu* m) {
         ttMenu->addAction(a);
     }
     m->addMenu(ttMenu);
-
+    
+    QMenu * runModeMenu = new QMenu( tr( "Run mode" ) );
+    foreach( QAction * a, runModeActions ) {
+        runModeMenu->addAction( a );
+    }
+    m->addMenu( runModeMenu );
+    
     if (!unlockAction->isChecked()) {
         m->addSeparator();
         m->addAction(unlockAction);
@@ -470,6 +583,13 @@ void WorkflowView::setupContextMenu(QMenu* m) {
         }
         m->addMenu(ttMenu);
         m->addSeparator();
+        
+        QMenu * runModeMenu = new QMenu( tr( "Run mode" ) );
+        foreach( QAction * a, runModeActions ) {
+            runModeMenu->addAction( a );
+        }
+        m->addMenu( runModeMenu );
+        m->addSeparator();
     }
     m->addAction(selectAction);
     m->addMenu(palette->createMenu(tr("Add item")));
@@ -480,7 +600,7 @@ void WorkflowView::sl_pickInfo(QListWidgetItem* info) {
     foreach(QGraphicsItem* it, scene->items()) {
         if (it->type() == WorkflowProcessItemType)
         {
-            WorkflowProcessItem* proc = (WorkflowProcessItem*)it;
+            WorkflowProcessItem* proc = static_cast<WorkflowProcessItem*>(it);
             if (proc->getProcess()->getId() != id) {
                 continue;
             } 
@@ -531,7 +651,7 @@ bool WorkflowView::sl_validate(bool notify) {
     return good;
 }
 
-void WorkflowView::sl_launch() {
+void WorkflowView::localHostLaunch() {
     if (!sl_validate(false)) {
         return;
     }
@@ -540,6 +660,7 @@ void WorkflowView::sl_launch() {
         //|TODO user choice
         sh.domain = WorkflowEnv::getDomainRegistry()->getAllIds().value(0);
     }
+    
     WorkflowRunTask* t = new WorkflowRunTask(sh, scene->getIterations());
     t->setReportingEnabled(true);
     if (WorkflowSettings::monitorRun()) {
@@ -551,7 +672,61 @@ void WorkflowView::sl_launch() {
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
-void WorkflowView::sl_configure() {
+void WorkflowView::remoteLaunch() {
+    if( !sl_validate(false) ) {
+        return;
+    }
+    Schema sh = scene->getSchema();
+    if( sh.domain.isEmpty() ) {
+        sh.domain = WorkflowEnv::getDomainRegistry()->getAllIds().value( 0 );
+    }
+    
+    int ret = 0;
+    RemoteMachineSettings * settings = NULL;
+    do {
+        RemoteMachineMonitor * rmm = AppContext::getRemoteMachineMonitor();
+        assert( NULL != rmm );
+        RemoteMachineMonitorDialogImpl dlg( QApplication::activeWindow(), rmm->getRemoteMachineMonitorItems(), 
+            WorkflowSimpleLocalTaskFactory::ID );
+        ret = dlg.exec();
+        if( QDialog::Rejected == ret ) {
+            return;
+        }
+        assert( QDialog::Accepted == ret );
+        QList< RemoteMachineMonitorDialogItem > dlgModel = dlg.getModel();
+        DistributedComputingUtil::applyChangesForRemoteMachineMonitor( rmm, dlgModel );
+        QList< RemoteMachineSettings* > selectedMachines = rmm->getSelectedMachines();
+        int howManyMachines = selectedMachines.size();
+        if( 0 == howManyMachines ) {
+            QMessageBox::critical( this, tr( "Selecting machines error!" ), tr( "You didn't select a machine to run remote task!" ) );
+            continue;
+        } else if( 1 != howManyMachines ) {
+            QMessageBox::critical( this, tr( "Selecting machines error!" ), 
+                tr( "Distributed run on many machines is not supported yet. Select 1 machine" ) );
+            continue;
+        }
+        assert( 1 == howManyMachines );
+        settings = selectedMachines.first();
+        break;
+    } while( QDialog::Accepted == ret );
+    
+    AppContext::getTaskScheduler()->registerTopLevelTask( new WorkflowRemoteRunTask( settings, sh, scene->getIterations() ) );
+}
+
+void WorkflowView::sl_launch() {
+    switch( meta.runMode ) {
+    case LOCAL_HOST:
+        localHostLaunch();
+        break;
+    case REMOTE_MACHINE:
+        remoteLaunch();
+        break;
+    default:
+        assert( false );
+    }
+}
+
+void WorkflowView::sl_configureIterations() {
     propertyEditor->commit();
     SchemaConfigurationDialog d(scene->getSchema(), scene->getIterations(), this);
     int ret = d.exec();
@@ -564,6 +739,49 @@ void WorkflowView::sl_configure() {
     }
 }
 
+static Actor* findActorById( const Schema & sc, const ActorId & id ) {
+    Actor * ret = NULL;
+    foreach( Actor * a, sc.procs ) {
+        assert( a != NULL );
+        if( id == a->getId() ) {
+            return a;
+        }
+    }
+    return ret;
+}
+
+void WorkflowView::sl_configureAliases() {
+    SchemaAliasesConfigurationDialogImpl dlg( scene->getSchema(), this );
+    int ret = QDialog::Accepted;
+    do {
+        ret = dlg.exec();
+        if( ret == QDialog::Accepted ) {
+            if( !dlg.validateModel() ) {
+                QMessageBox::critical( this, tr("Bad input!"), tr("Aliases for schema parameters should be different!") );
+                continue;
+            }
+            SchemaAliasesCfgDlgModel model = dlg.getModel();
+            SchemaAliasesCfgDlgModel::const_iterator it = model.constBegin();
+            while( it != model.constEnd() ) {
+                QMap<Descriptor, QString>::const_iterator aliasIt = it.value().constBegin();
+                while( aliasIt != it.value().constEnd() ) {
+                    assert( !aliasIt.value().isEmpty() );
+                    Actor * actor = findActorById( scene->getSchema(), it.key() );
+                    assert( actor != NULL );
+                    actor->getParamAliases().insert( aliasIt.key().getId(), aliasIt.value() );
+                    ++aliasIt;
+                }
+                ++it;
+            }
+            break;
+        } else if( ret == QDialog::Rejected ) {
+            break;
+        } else {
+            assert(false);
+        }
+    } while( ret == QDialog::Accepted );
+}
+
 void WorkflowView::sl_selectProcess(Workflow::ActorPrototype* p) {
     currentProc = p;
     propertyEditor->reset();
@@ -618,11 +836,13 @@ void WorkflowView::sl_pasteSample(const QString& s) {
    if (scene->items().isEmpty()) {
         sl_pasteItems(s);
         SchemaSerializer::readMeta(&meta, xml.documentElement());
+        sl_setRunMode();
         sl_updateTitle();
     } else {
         saveState();
         WorkflowGObject* smpl = new WorkflowGObject("Sample", xml);
         WorkflowView* view = new WorkflowView(smpl);
+        view->sl_setRunMode();
         AppContext::getMainWindow()->getMDIManager()->addMDIWindow(view);
         AppContext::getMainWindow()->getMDIManager()->activateWindow(view);
     }
@@ -707,7 +927,6 @@ void WorkflowView::sl_showEditor() {
 }
 
 void WorkflowView::sl_editItem() {
-    //QList<Actor*> list = scene->getSelectedProcItems();
     QList<QGraphicsItem*> list = scene->selectedItems();
     if (list.size() == 1) {
         QGraphicsItem* it = list.at(0);
@@ -881,9 +1100,35 @@ bool WorkflowView::confirmModified() {
     return true;
 }
 
+/********************************
+ * WorkflowScene
+ ********************************/
+static bool canDrop(const QMimeData* m, QList<ActorPrototype*>& lst) {
+    if (m->hasFormat(WorkflowPalette::MIME_TYPE)) {
+        QString id(m->data(WorkflowPalette::MIME_TYPE));
+        ActorPrototype* proto = WorkflowEnv::getProtoRegistry()->getProto(id);
+        if (proto) {
+            lst << proto;
+        }
+    } else {
+        foreach(QList<ActorPrototype*> l, WorkflowEnv::getProtoRegistry()->getProtos().values()) {
+            foreach(ActorPrototype* proto, l) {
+                if (proto->isAcceptableDrop(m)) {
+                    lst << proto;
+                }
+            }
+        }
+    }
+    //foreach(ActorPrototype* a, lst) {log.debug("drop acceptable: " + a->getId());}
+    return !lst.isEmpty();
+}
 
 WorkflowScene::WorkflowScene(WorkflowView *parent) 
-: QGraphicsScene(parent), controller(parent), modified(false), locked(false), runner(NULL) {
+: QGraphicsScene(parent), controller(parent), modified(false), locked(false), runner(NULL), hint(0), nextActorNumber(0) {
+}
+
+WorkflowScene::~WorkflowScene() {
+    sl_reset();
 }
 
 Schema WorkflowScene::getSchema() const {
@@ -891,11 +1136,11 @@ Schema WorkflowScene::getSchema() const {
     foreach(QGraphicsItem* it, items()) {
         if (it->type() == WorkflowProcessItemType) 
         {
-            schema.procs << ((WorkflowProcessItem*)it)->getProcess();
+            schema.procs << (static_cast<WorkflowProcessItem*>(it))->getProcess();
         } 
         else if (it->type() == WorkflowBusItemType) 
         {
-            schema.flows << ((WBusItem*)it)->getBus();
+            schema.flows << (static_cast<WBusItem*>(it))->getBus();
         }
     }
     schema.iterations = iterations;
@@ -955,6 +1200,17 @@ QList<Actor*> WorkflowScene::getSelectedProcItems() const {
     return list;
 }
 
+QList<Actor*> WorkflowScene::getAllProcs() const {
+    QList<Actor*> res;
+    foreach( QGraphicsItem * item, items() ) {
+        assert( NULL != item );
+        if (item->type() == WorkflowProcessItemType) {
+            res << static_cast<WorkflowProcessItem*>(item)->getProcess();
+        }
+    }
+    return res;
+}
+
 void WorkflowScene::contextMenuEvent(QGraphicsSceneContextMenuEvent * e) {
     QMenu menu;
     controller->setupContextMenu(&menu);
@@ -969,26 +1225,6 @@ void WorkflowScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * mouseEvent)
     QGraphicsScene::mousePressEvent(mouseEvent);
 }
 
-static bool canDrop(const QMimeData* m, QList<ActorPrototype*>& lst) {
-    if (m->hasFormat(WorkflowPalette::MIME_TYPE)) {
-        QString id(m->data(WorkflowPalette::MIME_TYPE));
-        ActorPrototype* proto = WorkflowEnv::getProtoRegistry()->getProto(id);
-        if (proto) {
-            lst << proto;
-        }
-    } else {
-        foreach(QList<ActorPrototype*> l, WorkflowEnv::getProtoRegistry()->getProtos().values()) {
-            foreach(ActorPrototype* proto, l) {
-                if (proto->isAcceptableDrop(m)) {
-                    lst << proto;
-                }
-            }
-        }
-    }
-    //foreach(ActorPrototype* a, lst) {log.debug("drop acceptable: " + a->getId());}
-    return !lst.isEmpty();
-}
-
 void WorkflowScene::dragEnterEvent(QGraphicsSceneDragDropEvent * event) {
     QList<ActorPrototype*> lst;
     if (!locked && canDrop(event->mimeData(), lst)) {
@@ -1036,7 +1272,7 @@ void WorkflowScene::dropEvent(QGraphicsSceneDragDropEvent * event) {
             if (proto) {
                 QVariantMap params;
                 proto->isAcceptableDrop(event->mimeData(), &params);
-                addProcess(proto->createInstance(params), event->scenePos());
+                addProcess( createActor( proto, params), event->scenePos());
                 event->setDropAction(Qt::CopyAction);
             }
         }
@@ -1045,25 +1281,38 @@ void WorkflowScene::dropEvent(QGraphicsSceneDragDropEvent * event) {
 }
 
 
-static int count = 0;
 void WorkflowScene::addProcess(Actor* proc, const QPointF& pos) {
     WorkflowProcessItem* it = new WorkflowProcessItem(proc);
     it->setPos(pos);
-    bool first = items().isEmpty();
     addItem(it);
-    Actor* a = it->getProcess();
-    a->setLabel(proc->getProto()->getDisplayName() + QString(" %1").arg(++count));
     modified = true;
+
     emit processItemAdded();
-    if (first) {
+    
+    //if(items().isEmpty()) {
         // erase drop hint
-        update();
+    update();
+    //}
+}
+
+Actor * WorkflowScene::createActor( ActorPrototype * proto, const QVariantMap & params ) {
+    assert( NULL != proto );
+    Actor * actor = proto->createInstance( params );
+    assert( NULL != actor );
+    
+    nextActorNumber++;
+    actor->setLabel(proto->getDisplayName() + QString(" %1").arg(nextActorNumber));
+    actor->setNumberInSchema(nextActorNumber);
+    
+    if( REMOTE_MACHINE == controller->getMeta().runMode ) {
+        addUrlLocationParameter( actor );
     }
+    return actor;
 }
 
 void WorkflowScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent) {
     if (!locked && !mouseEvent->isAccepted() && controller->selectedProto() && (mouseEvent->button() == Qt::LeftButton)) {
-        addProcess(controller->selectedProto()->createInstance(), mouseEvent->scenePos());
+        addProcess( createActor( controller->selectedProto() ), mouseEvent->scenePos());
     }
     QGraphicsScene::mousePressEvent(mouseEvent);
 }
@@ -1119,6 +1368,12 @@ void WorkflowScene::sl_selectAll() {
     }
 }
 
+void WorkflowScene::sl_deselectAll() {
+    foreach(QGraphicsItem* it, items()) {
+        it->setSelected( false );
+    }
+}
+
 void WorkflowScene::sl_reset() {
     QList<QGraphicsItem*> list;
     foreach(QGraphicsItem* it, items()) {
@@ -1134,11 +1389,6 @@ void WorkflowScene::sl_reset() {
     iterations.clear();
 }
 
-WorkflowScene::~WorkflowScene()
-{
-    sl_reset();
-}
-
 void WorkflowScene::drawBackground(QPainter * painter, const QRectF & rect)
 {
     if (WorkflowSettings::showGrid()) {
