@@ -47,6 +47,7 @@ public:
     void setRunner(WorkflowRunTask* r) {runner = r;}
 
     QList<Actor*> getSelectedProcItems() const;
+    QList<Actor*> getAllProcs() const;
     
     Actor* getActor(ActorId) const;
 
@@ -55,12 +56,16 @@ public:
     void setIterations(const QList<Iteration>& lst);
 
     void addProcess(Actor*, const QPointF&);
-
+    Actor * createActor( ActorPrototype * proto, const QVariantMap & params = QVariantMap() );
+    
+    void setNextActorsNum( int howMany ) {nextActorNumber = howMany;}
+    
 public slots:
     void sl_deleteItem();
     void sl_bringToFront();
     void sl_sendToBack();
     void sl_selectAll();
+    void sl_deselectAll();
     void sl_reset();
     void setLocked(bool b) {locked = b;}
     void setModified(bool b) {modified = b;}
@@ -92,11 +97,9 @@ private:
 
     WorkflowRunTask* runner;
     int hint;
-};
-
-//class WorkflowView : public GObjectView {
-//public:
-//virtual QWidget* createWidget();
+    int nextActorNumber; // usually: how many actors in scene. need to name actors like: "Sequence reader 5"
+    
+}; // WorkflowScene
 
 class WorkflowView : public MWMDIWindow {
     friend class WorkflowScene;
@@ -141,11 +144,14 @@ private slots:
     void sl_setStyle();
     void sl_toggleStyle();
     void sl_refreshActorDocs();
-
+    
+    void sl_setRunMode();
+    
     bool sl_validate(bool notify = true);
     void sl_pickInfo(QListWidgetItem*);
     void sl_launch();
-    void sl_configure();
+    void sl_configureIterations();
+    void sl_configureAliases();
 
     void sl_toggleLock(bool = true);
 
@@ -155,7 +161,10 @@ protected:
 private:
     void createActions();
     void saveState();
-
+    
+    void localHostLaunch();
+    void remoteLaunch();
+    
     WorkflowGObject* go;
     WorkflowScene* scene;
     Workflow::Metadata meta;
@@ -179,12 +188,14 @@ private:
     QAction* loadAction;
     QAction* newAction;
     
-    QAction* configureAction;
+    QAction* configureIterationsAction;
+    QAction* configureAliasesAction;
     QAction* runAction;
     QAction* validateAction;
 
     QList<QAction*> styleActions;
-
+    QList<QAction*> runModeActions;
+    
     QAction* unlockAction;
 
     QSplitter*      splitter;
