@@ -42,6 +42,9 @@ WorkflowProcessItem::WorkflowProcessItem(Actor* prc) : process(prc) {
     setToolTip(process->getProto()->getDocumentation());
     setFlag(QGraphicsItem::ItemIsMovable, true);
     setFlag(QGraphicsItem::ItemIsSelectable, true);
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 6, 0))
+    setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
+#endif
     setAcceptHoverEvents(true);
 
     styles[ItemStyles::SIMPLE] = new SimpleProcStyle(this);
@@ -483,14 +486,14 @@ static bool checkTypes(Port* p1, Port* p2) {
     DataTypePtr idt = ip->getType();
     DataTypePtr odt = op->getType();
     if (idt->isSingle() && odt->isMap()) {
-        foreach(Descriptor d, odt->getElements()) {
-            if (idt == odt->getElement(d)) return true;
+        foreach(Descriptor d, odt->getAllDescriptors()) {
+            if (idt == odt->getDatatypeByDescriptor(d)) return true;
         }
     }
     if (idt->isMap() && odt->isMap()) {
-        foreach(Descriptor d1, idt->getElements()) {
-            foreach(Descriptor d2, odt->getElements()) {
-                if (idt->getElement(d1) == odt->getElement(d2)) return true;
+        foreach(Descriptor d1, idt->getAllDescriptors()) {
+            foreach(Descriptor d2, odt->getAllDescriptors()) {
+                if (idt->getDatatypeByDescriptor(d1) == odt->getDatatypeByDescriptor(d2)) return true;
             }
         }
     }
@@ -920,6 +923,7 @@ void WBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem * opti
         pen.setColor(Qt::red);
     }
 	drawArrow(painter, pen, p2, p1);
+    update();
 
     painter->setRenderHint(QPainter::NonCosmeticDefaultPen);
     QColor yc = QColor(Qt::yellow).lighter();yc.setAlpha(127);
