@@ -22,19 +22,21 @@ class DocumentFormat;
 
 namespace LocalWorkflow {
 
-class LocalDocReader : public BaseWorker {
+class BaseDocReader : public BaseWorker {
     Q_OBJECT
 public:
-    LocalDocReader(Actor* a, const QString& tid, const DocumentFormatId& fid);
-    virtual ~LocalDocReader() {}
+    BaseDocReader(Actor* a, const QString& tid, const DocumentFormatId& fid);
+    virtual ~BaseDocReader() {}
+    
     virtual void init() ;
     virtual bool isReady();
     virtual Task* tick() ;
     virtual bool isDone() ;
     virtual void cleanup() ;
-
+    
 protected:
     virtual void doc2data(Document* ) = 0;
+    
 protected:
     CommunicationChannel* ch;
     DocumentFormatId fid;
@@ -42,13 +44,15 @@ protected:
     bool done, attachDoc2Proj;
     QList<Message> cache;
     DataTypePtr mtype;
+    
 };
 
-class LocalDocWriter : public BaseWorker {
+class BaseDocWriter : public BaseWorker {
     Q_OBJECT
 public:
-    LocalDocWriter(Actor* a, const DocumentFormatId& fid);
-    virtual ~LocalDocWriter(){}
+    BaseDocWriter(Actor* a, const DocumentFormatId& fid);
+    BaseDocWriter( Actor * a );
+    virtual ~BaseDocWriter(){}
     virtual void init() ;
     virtual bool isReady();
     virtual Task* tick() ;
@@ -56,7 +60,7 @@ public:
     virtual void cleanup() ;
 
 protected:
-    virtual void data2doc(Document*, const QVariantMap&) {}
+    virtual void data2doc(Document*, const QVariantMap&) = 0;
     Task* processDocs();
 protected:
     CommunicationChannel* ch;
@@ -68,14 +72,6 @@ protected:
     uint fileMode;
 };
 
-class DataWorkerFactory : public DomainFactory {
-public:
-    DataWorkerFactory(const Descriptor& d) : DomainFactory(d) {}
-    virtual ~DataWorkerFactory() {}
-    virtual Worker* createWorker(Actor*);
-    static void init();
-};
-
 }//Workflow namespace
 }//GB2 namespace
 
