@@ -11,6 +11,8 @@
 #ifndef _GB2_WORKFLOW_DOC_ACTORS_H_
 #define _GB2_WORKFLOW_DOC_ACTORS_H_
 
+#include <core_api/core_api.h>
+
 #include <workflow/Attribute.h>
 #include <workflow/IntegralBusModel.h>
 #include <workflow_support/WorkflowUtils.h>
@@ -21,11 +23,39 @@ namespace Workflow {
 
 class DocActorProto : public BusActorPrototype {
 public:
-    DocActorProto(const DocumentFormatId& fid, bool multi, const Descriptor& desc, const QList<PortDescriptor*>& ports, 
+    DocActorProto(const DocumentFormatId& _fid, const Descriptor& desc, const QList<PortDescriptor*>& ports, 
         const QList<Attribute*>& attrs = QList<Attribute*>());
-    virtual bool isAcceptableDrop(const QMimeData*, QVariantMap*) const;
+    DocActorProto(const Descriptor& desc, const GObjectType& t, const QList<PortDescriptor*>& ports, 
+        const QList<Attribute*>& attrs = QList<Attribute*>());
+    
+    virtual bool isAcceptableDrop(const QMimeData*, QVariantMap*) const = 0;
+    bool isAcceptableDrop(const QMimeData*, QVariantMap*, const QString & urlAttrId ) const;
+protected:
+    QString prepareDocumentFilter();
+    
 protected:
     DocumentFormatId fid;
+    GObjectType type;
+};
+
+class ReadDocActorProto : public DocActorProto {
+public:
+    ReadDocActorProto( const DocumentFormatId& fid, const Descriptor& desc, const QList<PortDescriptor*>& ports, 
+        const QList<Attribute*>& attrs = QList<Attribute*>() );
+    virtual bool isAcceptableDrop(const QMimeData*, QVariantMap*) const;
+};
+
+class WriteDocActorProto : public DocActorProto {
+public:
+    WriteDocActorProto( const DocumentFormatId& fid, const Descriptor& desc, const QList<PortDescriptor*>& ports, 
+        const QList<Attribute*>& attrs = QList<Attribute*>() );
+    WriteDocActorProto(const Descriptor& desc, const GObjectType & t, const QList<PortDescriptor*>& ports, 
+        const QList<Attribute*>& attrs = QList<Attribute*>() );
+
+private:
+    void construct();
+    
+    virtual bool isAcceptableDrop(const QMimeData*, QVariantMap*) const;
 };
 
 class ReadDocPrompter;
@@ -37,7 +67,7 @@ public:
     ReadDocPrompter(const QString& s) : spec(s) {}
     ReadDocPrompter(Actor* p = 0) : ReadDocPrompterBase(p) {}
     virtual ActorDocument* createDescription(Actor* a) {
-        ReadDocPrompter* doc = (ReadDocPrompter*) ReadDocPrompterBase::createDescription(a);
+        ReadDocPrompter* doc = static_cast<ReadDocPrompter*>(ReadDocPrompterBase::createDescription(a));
         doc->spec = this->spec;
         return doc;
     }
@@ -55,7 +85,7 @@ public:
     WriteDocPrompter(const QString& spec, const QString& slot) : spec(spec), slot(slot) {}
     WriteDocPrompter(Actor* p = 0) : WriteDocPrompterBase(p) {}
     virtual ActorDocument* createDescription(Actor* a) {
-        WriteDocPrompter* doc = (WriteDocPrompter*)WriteDocPrompterBase::createDescription(a);
+        WriteDocPrompter* doc = static_cast<WriteDocPrompter*>(WriteDocPrompterBase::createDescription(a));
         doc->spec = this->spec;
         doc->slot = this->slot;
         return doc;
