@@ -10,7 +10,6 @@
 
 #include "FindWorker.h"
 
-#include <workflow/TypeSet.h>
 #include <workflow/IntegralBusModel.h>
 #include <workflow/WorkflowEnv.h>
 #include <workflow/WorkflowRegistry.h>
@@ -18,6 +17,7 @@
 #include <workflow_library/BioDatatypes.h>
 #include <workflow_library/BioActorLibrary.h>
 #include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
 
 #include <datatype/DNASequence.h>
 #include <core_api/DNATranslation.h>
@@ -35,34 +35,34 @@
 namespace GB2 {
 namespace LocalWorkflow {
 
-static const QString IN_PORT("in");
-static const QString OUT_PORT("out");
+static LogCategory log(ULOG_CAT_WD);
 
-static const QString STRAND_ATTR("4strand");
-static const QString NAME_ATTR("1name");
-static const QString PATTERN_ATTR("2pattern");
-static const QString ERR_ATTR("3maxerr");
-static const QString ALGO_ATTR("6algorithm");
-static const QString AMINO_ATTR("5translate");
+/***************************
+ * FindWorkerFactory
+ ***************************/
+static const QString STRAND_ATTR("d_strand");
+static const QString NAME_ATTR("a_name");
+static const QString PATTERN_ATTR("b_pattern");
+static const QString ERR_ATTR("c_maxerr");
+static const QString ALGO_ATTR("f_algorithm");
+static const QString AMINO_ATTR("e_translate");
 
 const QString FindWorkerFactory::ACTOR_ID("find.pattern");
 
-static LogCategory log(ULOG_CAT_WD);
-
 void FindWorkerFactory::init() {
 
     QMap<Descriptor, DataTypePtr> m;
     m[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
     m[BioActorLibrary::FEATURE_TABLE_SLOT()] = BioDataTypes::ANNOTATION_TABLE_TYPE();
-    DataTypePtr inSet(new DataTypeSet(Descriptor("regioned.sequence"), m));
+    DataTypePtr inSet(new MapDataType(Descriptor("regioned.sequence"), m));
     DataTypeRegistry* dr = WorkflowEnv::getDataTypeRegistry();
     assert(dr);
     dr->registerEntry(inSet);
 
     QList<PortDescriptor*> p; QList<Attribute*> a;
     {
-        Descriptor ind(IN_PORT, FindWorker::tr("Input data"), FindWorker::tr("An input sequence and set of regions to search in."));
-        Descriptor oud(OUT_PORT, FindWorker::tr("Pattern annotations"), FindWorker::tr("Found regions"));
+        Descriptor ind(CoreLibConstants::IN_PORT_ID, FindWorker::tr("Input data"), FindWorker::tr("An input sequence and set of regions to search in."));
+        Descriptor oud(CoreLibConstants::OUT_PORT_ID, FindWorker::tr("Pattern annotations"), FindWorker::tr("Found regions"));
         p << new PortDescriptor(ind, inSet, true);
         p << new PortDescriptor(oud, BioDataTypes::ANNOTATION_TABLE_TYPE(), false, true);
     }
@@ -112,8 +112,12 @@ void FindWorkerFactory::init() {
     localDomain->registerEntry(new FindWorkerFactory());
 }
 
+
+/***************************
+ * FindPrompter
+ ***************************/
 QString FindPrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(IN_PORT));
+    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
     Actor* seqProducer = input->getProducer(BioActorLibrary::SEQ_SLOT_ID);
     Actor* annProducer = input->getProducer(BioActorLibrary::FEATURE_TABLE_SLOT_ID);
 
@@ -153,45 +157,30 @@ QString FindPrompter::composeRichDoc() {
     return doc;
 }
 
+/***************************
+ * FindWorker
+ ***************************/
+FindWorker::FindWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL) {
+}
 
 void FindWorker::init() {
-    input = ports.value(IN_PORT);
-    output = ports.value(OUT_PORT);
-    cfg.strand = FindAlgorithmStrand(actor->getParameter(STRAND_ATTR)->value.toInt());
-    cfg.maxErr = actor->getParameter(ERR_ATTR)->value.toInt();
-    cfg.insDelAlg = actor->getParameter(ALGO_ATTR)->value.toBool();
-    resultName = actor->getParameter(NAME_ATTR)->value.toString();
-    cfg.pattern = actor->getParameter(PATTERN_ATTR)->value.toString().toAscii();
+    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    output = ports.value(CoreLibConstants::OUT_PORT_ID);
 }
 
 bool FindWorker::isReady() {
     return (input && input->hasMessage());
 }
 
-
-FindAllRegionsTask::FindAllRegionsTask(const FindAlgorithmTaskSettings& s, const QList<SharedAnnotationData>& l) :
-Task(tr("FindAllRegionsTask"), TaskFlag_NoRun), cfg(s), regions(l) {}
-
-void FindAllRegionsTask::prepare() {
-    foreach(SharedAnnotationData sd, regions) {
-        foreach(LRegion lr, sd->location) {
-            cfg.searchRegion = lr;
-            addSubTask(new FindAlgorithmTask(cfg));
-        }
-    }
-}
-
-QList<FindAlgorithmResult> FindAllRegionsTask::getResult() {
-    QList<FindAlgorithmResult> lst;
-    foreach(Task* t, getSubtasks()) {
-        FindAlgorithmTask* ft = qobject_cast<FindAlgorithmTask*>(t);
-        lst += ft->popResults();
-    }
-    return lst;
-}
-
 Task* FindWorker::tick() {
+    Message inputMessage = getMessageAndSetupScriptValues(input);
+    cfg.strand = FindAlgorithmStrand(actor->getParameter(STRAND_ATTR)->getAttributeValue<int>());
+    cfg.maxErr = actor->getParameter(ERR_ATTR)->getAttributeValue<int>();
+    cfg.insDelAlg = actor->getParameter(ALGO_ATTR)->getAttributeValue<bool>();
+    resultName = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
+    cfg.pattern = actor->getParameter(PATTERN_ATTR)->getAttributeValue<QString>().toAscii();
     QVariantMap qm = input->get().getData().toMap();
+    
     DNASequence seq = qm.value(BioActorLibrary::SEQ_SLOT_ID).value<DNASequence>();
     if (!seq.isNull()) {
         FindAlgorithmTaskSettings config(cfg);
@@ -205,7 +194,7 @@ Task* FindWorker::tick() {
                 config.strand = FindAlgorithmStrand_Direct;
             }
         }
-        if (actor->getParameter(AMINO_ATTR)->value.toBool()) {
+        if (actor->getParameter(AMINO_ATTR)->getAttributeValue<bool>()) {
             DNATranslationType tt = (seq.alphabet->getType() == DNAAlphabet_NUCL) ? DNATranslationType_NUCL_2_AMINO : DNATranslationType_RAW_2_AMINO;
             QList<DNATranslation*> TTs = AppContext::getDNATranslationRegistry()->lookupTranslation(seq.alphabet, tt);
             if (!TTs.isEmpty()) config.proteinTT = TTs.first(); //FIXME let user choose or use hints ?
@@ -255,5 +244,33 @@ bool FindWorker::isDone() {
     return !input || input->isEnded();
 }
 
+void FindWorker::cleanup() {
+}
+
+
+/***************************
+ * FindAllRegionsTask
+ ***************************/
+FindAllRegionsTask::FindAllRegionsTask(const FindAlgorithmTaskSettings& s, const QList<SharedAnnotationData>& l) :
+Task(tr("FindAllRegionsTask"), TaskFlag_NoRun), cfg(s), regions(l) {}
+
+void FindAllRegionsTask::prepare() {
+    foreach(SharedAnnotationData sd, regions) {
+        foreach(LRegion lr, sd->location) {
+            cfg.searchRegion = lr;
+            addSubTask(new FindAlgorithmTask(cfg));
+        }
+    }
+}
+
+QList<FindAlgorithmResult> FindAllRegionsTask::getResult() {
+    QList<FindAlgorithmResult> lst;
+    foreach(Task* t, getSubtasks()) {
+        FindAlgorithmTask* ft = qobject_cast<FindAlgorithmTask*>(t);
+        lst += ft->popResults();
+    }
+    return lst;
+}
+
 } //namespace LocalWorkflow
 } //namespace GB2
