@@ -31,12 +31,14 @@ protected:
 class FindWorker : public BaseWorker {
     Q_OBJECT
 public:
-    FindWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL) {}
-    virtual void init() ;
+    FindWorker(Actor* a);
+    
+    virtual void init();
     virtual bool isReady();
-    virtual Task* tick() ;
-    virtual bool isDone() ;
-    virtual void cleanup() {}
+    virtual Task* tick();
+    virtual bool isDone();
+    virtual void cleanup();
+    
 private slots:
     void sl_taskFinished(Task*);
 
@@ -44,6 +46,7 @@ protected:
     CommunicationChannel *input, *output;
     QString resultName,transId;
     FindAlgorithmSettings cfg;
+    
 }; 
 
 class FindWorkerFactory : public DomainFactory {
