@@ -12,10 +12,10 @@
 #include "CoreLib.h"
 #include "DocActors.h"
 
-#include <workflow/TypeSet.h>
 #include <workflow/WorkflowEnv.h>
 #include <workflow_support/CoreDataTypes.h>
 #include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
 #include <workflow_library/BioDatatypes.h>
 #include <workflow_library/BioActorLibrary.h>
 
@@ -44,22 +44,22 @@ const QString GenericMAActorProto::TYPE("generic.ma");
 
 #define ICOLOR QColor(85,85,255)
 
-GenericSeqActorProto::GenericSeqActorProto() : BusActorPrototype(CoreLib::GENERIC_SEQ_ACTOR)
+GenericSeqActorProto::GenericSeqActorProto() : BusActorPrototype(CoreLibConstants::GENERIC_READ_SEQ_ACTOR)
 {    
     setDisplayName(GB2::Workflow::CoreLib::tr("Sequence reader"));
     desc = GB2::Workflow::CoreLib::tr("Reads sequences (and annotations if any) from files of any format supported by UGENE. " 
         "The files can be local or Internet URLs.");
     QMap<Descriptor, DataTypePtr> m;
-    m[CoreLib::READ_URL_SLOT()] = CoreDataTypes::STRING_TYPE();
+    m[CoreLibConstants::READ_URL_SLOT()] = CoreDataTypes::STRING_TYPE();
     m[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
     m[BioActorLibrary::FEATURE_TABLE_SLOT()] = BioDataTypes::ANNOTATION_TABLE_TYPE();
 
-    DataTypePtr seqTypeset(new DataTypeSet(Descriptor(TYPE), m));
+    DataTypePtr seqTypeset(new MapDataType(Descriptor(TYPE), m));
     bool treg = WorkflowEnv::getDataTypeRegistry()->registerEntry(seqTypeset);
     Q_UNUSED(treg);assert(treg);
 
     ports << new PortDescriptor(
-        Descriptor(CoreLib::DATA_PORT_ID, 
+        Descriptor(CoreLibConstants::DATA_PORT_ID, 
         GB2::Workflow::CoreLib::tr("Sequence"), 
         GB2::Workflow::CoreLib::tr("A sequence of any type (nucleotide, protein).")), 
         seqTypeset, false, true);
@@ -74,7 +74,7 @@ GenericSeqActorProto::GenericSeqActorProto() : BusActorPrototype(CoreLib::GENERI
         Descriptor acd(GenericSeqActorProto::ACC_ATTR, SeqReadPrompter::tr("Accession filter"), 
             SeqReadPrompter::tr("Only report sequence with the specified accession (id)."));
 
-        attrs << new Attribute(CoreLib::URL_ATTR(), CoreDataTypes::STRING_TYPE(), true);
+        attrs << new Attribute(CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true);
         attrs << new Attribute(md, CoreDataTypes::NUM_TYPE(), true, SPLIT);
         attrs << new Attribute(gd, CoreDataTypes::NUM_TYPE(), false, 10);
         attrs << new Attribute(acd, CoreDataTypes::STRING_TYPE(), false);
@@ -89,33 +89,33 @@ GenericSeqActorProto::GenericSeqActorProto() : BusActorPrototype(CoreLib::GENERI
         QVariantMap m; m["minimum"] = 0; m["maximum"] = INT_MAX;
         delegates[GAP_ATTR] = new SpinBoxDelegate(m);
     }
-    delegates[CoreLib::URL_ATTR_ID] = new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(), true);
+    delegates[CoreLibConstants::URL_IN_ATTR_ID] = new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(), true);
     setEditor(new DelegateEditor(delegates));
     setPrompter(new ReadDocPrompter(GB2::Workflow::CoreLib::tr("Read all sequences from <u>%1</u> and output each in turn.")));
     setIcon( GUIUtils::createRoundIcon(ICOLOR, 22) );
 }
 
-GenericMAActorProto::GenericMAActorProto() : BusActorPrototype(CoreLib::GENERIC_MA_ACTOR) 
+GenericMAActorProto::GenericMAActorProto() : BusActorPrototype(CoreLibConstants::GENERIC_READ_MA_ACTOR) 
 {
     setDisplayName(GB2::Workflow::CoreLib::tr("Alignment reader"));
     desc = GB2::Workflow::CoreLib::tr("Reads alignments from files of any format supported by UGENE. The files can be local or Internet URLs."
         "<p>Besides the known alignment formats, supports composing an alignment from a set of sequences in a corresponing file (e.g. FASTA or Genbank).");
 
     QMap<Descriptor, DataTypePtr> m;
-    m[CoreLib::READ_URL_SLOT()] = CoreDataTypes::STRING_TYPE();
+    m[CoreLibConstants::READ_URL_SLOT()] = CoreDataTypes::STRING_TYPE();
     m[BioActorLibrary::MA_SLOT()] = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE();
-    DataTypePtr blockTypeset(new DataTypeSet(Descriptor(TYPE), m));
+    DataTypePtr blockTypeset(new MapDataType(Descriptor(TYPE), m));
     bool treg = WorkflowEnv::getDataTypeRegistry()->registerEntry(blockTypeset);
     Q_UNUSED(treg);assert(treg);
 
     ports << new PortDescriptor(
-        Descriptor(CoreLib::DATA_PORT_ID, 
+        Descriptor(CoreLibConstants::DATA_PORT_ID, 
         GB2::Workflow::CoreLib::tr("Multiple sequence alignment"), 
         ""), 
         blockTypeset, false, true);
 
-    attrs << new Attribute(CoreLib::URL_ATTR(), CoreDataTypes::STRING_TYPE(), true);
-    setEditor(new DelegateEditor(CoreLib::URL_ATTR_ID, new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(),true)));
+    attrs << new Attribute(CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true);
+    setEditor(new DelegateEditor(CoreLibConstants::URL_IN_ATTR_ID, new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(),true)));
     setPrompter(new ReadDocPrompter(GB2::Workflow::CoreLib::tr("Read MSA (multiple sequence alignment) blocks from <u>%1</u>.")));
     setIcon( GUIUtils::createRoundIcon(ICOLOR, 22) );
 }
@@ -123,18 +123,16 @@ GenericMAActorProto::GenericMAActorProto() : BusActorPrototype(CoreLib::GENERIC_
 bool GenericMAActorProto::isAcceptableDrop(const QMimeData* md, QVariantMap* params) const {
     QList<DocumentFormat*> fs;
     QString url = DesignerUtils::getDropUrl(fs, md);
-    DocumentFormatConstraints mc;
-    mc.supportedObjectTypes.append(GObjectTypes::MULTIPLE_ALIGNMENT);
     foreach(DocumentFormat* f, fs) {
-        if (f->checkConstraints(mc)) {
-            if (params) {
-                params->insert(CoreLib::URL_ATTR_ID, url);
+        if (f->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
+            if (params != NULL) {
+                params->insert(CoreLibConstants::URL_IN_ATTR_ID, url);
             }
             return true;
         }
     }
     /*DocumentFormatConstraints sc;
-    sc.supportedObjectTypes.append(GObjectTypes::DNA_SEQUENCE);
+    sc.supportedObjectTypes.append(GObjectTypes::SEQUENCE);
     foreach(DocumentFormat* f, fs) {
         if (f->checkConstraints(sc)) {
             if (params) {
@@ -145,7 +143,7 @@ bool GenericMAActorProto::isAcceptableDrop(const QMimeData* md, QVariantMap* par
     }*/
     if (QFileInfo(url).isDir()) {
         if (params) {
-            params->insert(CoreLib::URL_ATTR_ID, url + "/*");
+            params->insert(CoreLibConstants::URL_IN_ATTR_ID, url + "/*");
         }
         return true;
     }
@@ -159,7 +157,7 @@ bool GenericSeqActorProto::isAcceptableDrop(const QMimeData* md, QVariantMap* pa
     if (gomd && params) {
         const DNASequenceObject* obj = qobject_cast<const DNASequenceObject*>(gomd->objPtr.data());
         if (obj) {
-            params->insert(CoreLib::URL_ATTR_ID, obj->getDocument()->getURL());
+            params->insert(CoreLibConstants::URL_IN_ATTR_ID, obj->getDocument()->getURLString());
             QString acc = DNAInfo::getPrimaryAccession(obj->getDNASequence().info);
             if (acc.isEmpty()) {
                 acc = obj->getDNASequence().getName();
@@ -169,19 +167,17 @@ bool GenericSeqActorProto::isAcceptableDrop(const QMimeData* md, QVariantMap* pa
     }
 
     QString url = DesignerUtils::getDropUrl(fs, md);
-    DocumentFormatConstraints constraints;
-    constraints.supportedObjectTypes.append(GObjectTypes::DNA_SEQUENCE);
     foreach(DocumentFormat* f, fs) {
-        if (f->checkConstraints(constraints)) {
+		if (f->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
             if (params) {
-                params->insert(CoreLib::URL_ATTR_ID, url);
+                params->insert(CoreLibConstants::URL_IN_ATTR_ID, url);
             }
             return true;
         }
     }
     if (QFileInfo(url).isDir()) {
         if (params) {
-            params->insert(CoreLib::URL_ATTR_ID, url + "/*");
+            params->insert(CoreLibConstants::URL_IN_ATTR_ID, url + "/*");
         }
         return true;
     }
@@ -192,7 +188,7 @@ bool GenericSeqActorProto::isAcceptableDrop(const QMimeData* md, QVariantMap* pa
 QString SeqReadPrompter::composeRichDoc() {
     //TODO finish
     //BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLib::DATA_PORT_ID));
-    QString url = getURL(CoreLib::URL_ATTR_ID);
+    QString url = getURL(CoreLibConstants::URL_IN_ATTR_ID);
     return QString("%1").arg(url);
 }
 
