@@ -13,6 +13,7 @@
 #include "CoreLib.h"
 #include <workflow_library/BioActorLibrary.h>
 #include <workflow/WorkflowEnv.h>
+#include <workflow_support/CoreLibConstants.h>
 #include <core_api/AppContext.h>
 #include <core_api/ProjectModel.h>
 #include <core_api/Log.h>
@@ -33,9 +34,12 @@ namespace LocalWorkflow {
 
 static LogCategory log(ULOG_CAT_WD);
 
+/**************************
+ * GenericMSAReader
+ **************************/
 void GenericMSAReader::init() {
     mtype = WorkflowEnv::getDataTypeRegistry()->getById(GenericMAActorProto::TYPE);
-    urls = DesignerUtils::expandToUrls(actor->getParameter("URL")->value.toString());
+    urls = DesignerUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR_ID)->getAttributeValue<QString>());
     assert(ports.size() == 1);
     ch = ports.values().first();
 }
@@ -71,50 +75,54 @@ void GenericMSAReader::sl_taskFinished() {
     }
     foreach(MAlignment ma, t->results) {
         QVariantMap m;
-        m.insert(CoreLib::URL_SLOT_ID, t->url);
+        m.insert(CoreLibConstants::URL_SLOT_ID, t->url);
         m.insert(BioActorLibrary::MA_SLOT_ID, qVariantFromValue<MAlignment>(ma)); 
         cache.append(Message(mtype, m));
     }
 }
 
+/**************************
+ * LoadMSATask
+ **************************/
 void LoadMSATask::run() {
-    DocumentFormatConstraints mc;
-    mc.supportedObjectTypes.append(GObjectTypes::MULTIPLE_ALIGNMENT);
+    QFileInfo fi(url);
+    if(!fi.exists()){
+        stateInfo.setError(  tr("File not exists") );
+        return;
+    }
     DocumentFormat* format = NULL;
     QList<DocumentFormat*> fs = DocumentFormatUtils::detectFormat(url);
     foreach(DocumentFormat* f, fs) {
-        if (f->checkConstraints(mc)) {
+        if (f->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
             format = f;
             break;
         }
     }
-    if (!format) {
-        DocumentFormatConstraints sc;
-        sc.supportedObjectTypes.append(GObjectTypes::DNA_SEQUENCE);
+    if (format == NULL) {
         foreach(DocumentFormat* f, fs) {
-            if (f->checkConstraints(sc)) {
+			if (f->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
                 format = f;
                 break;
             }
         }
     }
-    if (!format) {
+    if (format == NULL) {
         stateInfo.setError(  tr("Unsupported document format") );
         return;
     }
     log.info(tr("Reading MSA from %1 [%2]").arg(url).arg(format->getFormatName()));
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(url));
-    Document *doc = format->loadExistingDocument(iof, url, stateInfo, QVariantMap());
+    Document *doc = format->loadDocument(iof, url, stateInfo, QVariantMap());
     assert(isCanceled() || doc!=NULL || hasErrors());
     assert(doc == NULL || doc->isLoaded());
-    if (!isCanceled() && doc && doc->isLoaded()) {
-        if (format->checkConstraints(mc)) {
+    if (!isCanceled() && doc!=NULL && doc->isLoaded()) {
+		if (format->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
             foreach(GObject* go, doc->findGObjectByType(GObjectTypes::MULTIPLE_ALIGNMENT)) {
                 results.append(((MAlignmentObject*)go)->getMAlignment());
             }
         } else {
             QString err;
-            MAlignment ma = MSAUtils::seq2ma(doc->findGObjectByType(GObjectTypes::DNA_SEQUENCE), err);
+            MAlignment ma = MSAUtils::seq2ma(doc->findGObjectByType(GObjectTypes::SEQUENCE), err);
             if (err.isEmpty()) {
                 results.append(ma);
             } else {
@@ -122,20 +130,24 @@ void LoadMSATask::run() {
             }
         }
     }
-    if (doc && doc->isLoaded()) {
+    if (doc != NULL && doc->isLoaded()) {
         doc->unload();
     }
 }
 
+/**************************
+ * GenericSeqReader
+ **************************/
 void GenericSeqReader::init() {
     GenericMSAReader::init();
     mtype = WorkflowEnv::getDataTypeRegistry()->getById(GenericSeqActorProto::TYPE);
-    GenericSeqActorProto::Mode mode = GenericSeqActorProto::Mode(actor->getParameter(GenericSeqActorProto::MODE_ATTR)->value.toInt());
+    GenericSeqActorProto::Mode mode = GenericSeqActorProto::Mode(actor->getParameter(
+                                                                    GenericSeqActorProto::MODE_ATTR)->getAttributeValue<int>());
     if (GenericSeqActorProto::MERGE == mode) {
         QString mergeToken = MERGE_MULTI_DOC_GAP_SIZE_SETTINGS;
-        cfg[mergeToken] = actor->getParameter(GenericSeqActorProto::GAP_ATTR)->value.toInt();
+        cfg[mergeToken] = actor->getParameter(GenericSeqActorProto::GAP_ATTR)->getAttributeValue<int>();
     }
-    selector.acc = actor->getParameter(GenericSeqActorProto::ACC_ATTR)->value.toString();
+    selector.acc = actor->getParameter(GenericSeqActorProto::ACC_ATTR)->getAttributeValue<QString>();
 }
 
 void GenericSeqReader::sl_taskFinished() {
@@ -148,45 +160,45 @@ void GenericSeqReader::sl_taskFinished() {
     }
 }
 
+/**************************
+ * LoadSeqTask
+ **************************/
 void LoadSeqTask::run() {
-    DocumentFormat* format = NULL;
+    QFileInfo fi(url);
+    if(!fi.exists()){
+        stateInfo.setError(  tr("File not exists") );
+        return;
+    }
     QList<DocumentFormat*> fs = DocumentFormatUtils::detectFormat(url);
-    DocumentFormatConstraints constraints;
-    constraints.supportedObjectTypes.append(GObjectTypes::DNA_SEQUENCE);
-    DocumentFormatConstraints mc;
-    mc.supportedObjectTypes.append(GObjectTypes::MULTIPLE_ALIGNMENT);
-    foreach(DocumentFormat* f, fs) {
-        if (f->checkConstraints(mc)) {
+    DocumentFormat* format = NULL;
+
+    foreach( DocumentFormat * f, fs ) {
+		const QSet<GObjectType>& types = f->getSupportedObjectTypes();
+		if (types.contains(GObjectTypes::SEQUENCE) || types.contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
             format = f;
             break;
         }
     }
-    if (!format) {
-        foreach(DocumentFormat* f, fs) {
-            if (f->checkConstraints(constraints)) {
-                format = f;
-                break;
-            }
-        }
-    }
-    if (!format) {
+
+    if (format == NULL) {
         stateInfo.setError(  tr("Unsupported document format") );
         return;
     }
     log.info(tr("Reading sequences from %1 [%2]").arg(url).arg(format->getFormatName()));
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(url));
-    Document *doc = format->loadExistingDocument(iof, url, stateInfo, cfg);
+    Document *doc = format->loadDocument(iof, url, stateInfo, cfg);
     assert(isCanceled() || doc!=NULL || hasErrors());
     assert(doc == NULL || doc->isLoaded());
-    if (!isCanceled() && doc && doc->isLoaded()) {
-        if (format->checkConstraints(constraints)) {
-            foreach(GObject* go, doc->findGObjectByType(GObjectTypes::DNA_SEQUENCE)) {
+    if (!isCanceled() && doc!=NULL && doc->isLoaded()) {
+		const QSet<GObjectType>& types = format->getSupportedObjectTypes();
+		if (types.contains(GObjectTypes::SEQUENCE)) {
+            foreach(GObject* go, doc->findGObjectByType(GObjectTypes::SEQUENCE)) {
                 const DNASequence& dna = ((DNASequenceObject*)go)->getDNASequence();
                 if (!selector->matches(dna)) {
                     continue;
                 }
                 QVariantMap m;
-                m.insert(CoreLib::URL_SLOT_ID, url);
+                m.insert(CoreLibConstants::URL_SLOT_ID, url);
                 m.insert(BioActorLibrary::SEQ_SLOT_ID, qVariantFromValue<DNASequence>(dna));
                 QList<GObject*> allLoadedAnnotations = doc->findGObjectByType(GObjectTypes::ANNOTATION_TABLE);
                 QList<GObject*> annotations = GObjectUtils::findObjectsRelatedToObjectByRole(go, 
@@ -214,21 +226,22 @@ void LoadSeqTask::run() {
                         continue;
                     }
                     QVariantMap m;
-                    m.insert(CoreLib::URL_SLOT_ID, url);
+                    m.insert(CoreLibConstants::URL_SLOT_ID, url);
                     m.insert(BioActorLibrary::SEQ_SLOT_ID, qVariantFromValue<DNASequence>(s));
                     results.append(m);
                 }
             }
         }
     }
-    if (doc && doc->isLoaded()) {
+    if (doc!=NULL && doc->isLoaded()) {
         doc->unload();
     }
 }
 
-
-bool DNASelector::matches( const DNASequence& dna)
-{
+/**************************
+ * DNASelector
+ **************************/
+bool DNASelector::matches( const DNASequence& dna) {
     if (acc.isEmpty()) {
         return true;
     }
