@@ -13,12 +13,15 @@
 #include "TaskLocalStorage.h"
 
 #include <core_api/IOAdapter.h>
+#include <core_api/L10n.h>
 #include <core_api/Task.h>
+#include <core_api/GUrlUtils.h>
 #include <core_api/AppContext.h>
 #include <core_api/Settings.h>
 #include <util_text/TextUtils.h>
+#include <util_tasks/SaveDocumentTask.h>
 #include <util_gui/DialogUtils.h>
-#include <util_gui/GUIUtils.h>
+
 #include <memory>
 #include <QtCore/QtAlgorithms>
 namespace GB2 {
@@ -159,12 +162,12 @@ void HMMIO::writeHMM2(IOAdapterFactory* iof, const QString& url, TaskStateInfo&
     res+="//\n";
     std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
     if (!io->open(url, IOAdapterMode_Write)) {
-        si.setError(Translations::errorOpeningFileWrite(url));
+        si.setError(L10N::errorOpeningFileWrite(url));
         return;
     }
     int len = io->writeBlock(res.toAscii());
     if (len != res.length()) {
-        si.setError(Translations::errorWritingFile(url));
+        si.setError(L10N::errorWritingFile(url));
         return;
     }
     io->close();
@@ -187,7 +190,7 @@ void HMMIO::readHMM2(IOAdapterFactory* iof, const QString& url, TaskStateInfo& s
     struct plan7_s *hmm = NULL;
     std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
     if (!io->open(url, IOAdapterMode_Read)) {
-        si.setError(Translations::errorOpeningFileRead(url));
+        si.setError(L10N::errorOpeningFileRead(url));
         return;
     }
     const QByteArray& upper = TextUtils::UPPER_CASE_MAP;
@@ -659,7 +662,7 @@ HMMWriteTask::HMMWriteTask(const QString& url, plan7_s* s, uint f)
 void HMMWriteTask::run() {
     TaskLocalData::createHMMContext(getTaskId(), true);
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(url));
-    if (fileMode & SaveDoc_Roll && !DialogUtils::rollFile(url, stateInfo)) {
+    if (fileMode & SaveDoc_Roll && !GUrlUtils::renameFileWithNameRoll(url, stateInfo)) {
         return;
     }
     HMMIO::writeHMM2(iof, url, stateInfo, hmm);
