@@ -11,7 +11,7 @@
 
 #include <QtCore/QByteArray>
 
-#include <util_gui/GUIUtils.h>
+#include <core_api/L10n.h>
 #include <util_text/TextUtils.h>
 
 #include "uHMMFormatReader.h"
@@ -314,7 +314,7 @@ UHMMFormatReader::UHMMFormatReader( IOAdapter * i, TaskStateInfo & tsi ) : io( i
     }
     
     if( NULL == io || !io->isOpen() ) {
-        ti.setError( HMM_FORMAT_READER_ERROR_PREFIX + Translations::badArgument( "io adapter" ) );
+        ti.setError( HMM_FORMAT_READER_ERROR_PREFIX + L10N::badArgument( "io adapter" ) );
         return;
     }
 }
@@ -484,7 +484,7 @@ P7_HMM * UHMMFormatReader::readHMMER3ASCII() {
                 UHMMFormatReader::tr( "failed_to_create_alphabet" ) );
         }
         
-        if( p7_hmm_CreateBody( hmm, hmm->M, abc ) != eslOK ) {
+        if( p7_hmm_CreateBody( hmm, hmm->M, abc->type ) != eslOK ) {
             throw UHMMFormatReader::UHMMFormatReaderException(
                 UHMMFormatReader::tr( "failed_to_allocate_body_of_hmm" ) );
         }
@@ -729,7 +729,7 @@ P7_HMM * UHMMFormatReader::readHMMER2ASCII() {
         readLine( io, line );
         readLine( io, line, &tokens );
         
-        if( p7_hmm_CreateBody(hmm, hmm->M, abc) != eslOK ) {
+        if( p7_hmm_CreateBody(hmm, hmm->M, abc->type ) != eslOK ) {
             throw UHMMFormatReaderException( tr( "Failed to allocate body of the new HMM" ) );
         }
         if( (bg = p7_bg_Create( abc )) == NULL ) {
@@ -771,9 +771,9 @@ P7_HMM * UHMMFormatReader::readHMMER2ASCII() {
                 tok1 = getNextToken( tokens );
                 hmm->mat[k][x] = h2ascii2prob(tok1, null[x]);
             }
-            tok1 = getNextToken( tokens );
             if (hmm->flags & p7H_MAP) {
                 int n = 0;
+                tok1 = getNextToken( tokens );
                 setInteger( n, tok1 );
                 hmm->map[k] = n;
             }
