@@ -13,11 +13,11 @@
 * and simple and mixture Dirichlet priors.
 * 
 * SRE, Tue Nov  2 13:42:59 2004 [St. Louis]
-* SVN $Id: esl_dirichlet.c 326 2009-02-28 15:49:07Z eddys $
+ * SVN $Id: esl_dirichlet.c 440 2009-11-13 17:02:49Z eddys $
 */
 
 #include <hmmer3/easel/esl_config.h>
-
+#include <assert.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
@@ -71,9 +71,106 @@ ERROR:
     return NULL;
 }
 
+/* Function:  esl_mixdchlet_PerfectBipartiteMatchExists()
+ * Synopsis:  Given a 2D table representing presence of edges between vertices represented by
+ * 			the rows and columns, test whether a perfect matching exists.
+ * 			Note 1: this doesn't find a perfect matching, just checks if one exists.
+ * 			Note 2: written as a private function for use by esl_mixdchlet_Compare
+ * Incept:    TW, Fri Nov  6 14:23:23 EST 2009 [janelia]
+ *
+ * Args:      A      - 2-dimensional square table representing presence of edges between vertices
+ *            N      - size of that table
+
+ * Returns:   <eslOK> if a perfect matching exists; <eslFAIL> otherwise.
+ */
+int
+esl_mixdchlet_PerfectBipartiteMatchExists (int** A, int N ) {
+	/*
+	Basic idea:
+		-Scan through the rows, and create a matching edge any time a row has only
+		one matching column (i.e. a single column with eslOK value)
+		    * This is conservative: if the row isn't matched with this column, no perfect matching is possible.
+		-Repeat, this time scanning columns.
+	    -Repeat  rows then columns - until no rows or columns are found with a single eslOK value.
+
+		-If a row or column is found with no possible matches, then no complete matching is possible.
+		-If a point is reached where all rows and all columns have more than one match, I'm pretty sure a
+		 perfect matching is guaranteed.
+			- This is unproven; the intuition is that for any imperfect matching an augmenting path
+			  should (I think) exist: it will contain an edge from one unmatched element to a matched
+			  element, followed by the existing edge from that element to it's mate, followed by a 2nd
+			  edge from that mate to another, and so on.
+
+		 It's a O(n^3) algorithm, though it'll typically run fast in practice
+	   */
+	  
+	  // ! CODE CHANGED: current c++ standard doesn't support arrays with not constant size !
+	  int * matched_row = (int*)malloc( sizeof( int ) * N );
+	  int * matched_col = (int*)malloc( sizeof( int ) * N );
+
+	  esl_vec_ISet(matched_row, N, 0);
+	  esl_vec_ISet(matched_col, N, 0);
+
+	  int i,j;
+	  int unassigned = N;
+	  int do_row = 1; // otherwise, do_column
+	  while (unassigned > 0) {
+		  int changed = 0;
+
+		  for (i=0; i<N; i++) {
+			  int match_cnt = 0;
+			  int match = -1;
+
+			  if ( 1 == (do_row == 1 ? matched_row[i] : matched_col[i]) ) continue;
+
+			  for (j=0; j<N; j++) {
+				  if ( eslOK == (do_row == 1 ? A[i][j] : A[j][i] ) ) {
+					  match_cnt++;
+					  match = j;
+				  }
+			  }
+
+			  if (match_cnt == 0) return eslFAIL;  // mixtures can't possibly match
+			  if (match_cnt == 1) { // found a pair s.t. only this col can match this row within tol.
+				  changed++;
+				  if (do_row == 1  ) {
+					  matched_row[i] = matched_col[match] = 1;
+					  for (j=0; j<N; j++)
+						  A[j][match] = eslFAIL; // don't allow the matched col to match other rows, too.
+				  } else {
+					  matched_col[i] = matched_row[match] = 1;
+					  for (j=0; j<N; j++)
+						  A[match][j] = eslFAIL; // don't allow the matched rwo to match other cols, too.
+				  }
+			  }
+			  //if (match_cnt > 1), leave it for a later pass
+		  }
+		  unassigned -= changed;
+
+
+		  if (changed == 0) { // All had multiple hits, so (I think) we are guaranteed of being able to pick some mapping that will be legal
+			  // ! CODE ADDED !
+			  free( matched_row );
+			  free( matched_col );
+			  return eslOK;
+		  }
+		  do_row = 1 - do_row; // flip value
+
+	  }
+	  //got here, all mapping must've been done
+	  // ! CODE ADDED !
+	  free( matched_row );
+	  free( matched_col );
+	  return eslOK;
+}
+
 /* Function:  esl_mixdchlet_Compare()
 * Synopsis:  Compare two mixture Dirichlets for equality.
 * Incept:    SRE, Sat May 30 09:37:40 2009 [Stockholm]
+ * Modified:  TW, Fri Nov  6 10:55:20 EST 2009 [janelia]
+ *            (the original comparison assumed that component order
+ *             was in agreement between the two mixtures. This need
+ *             not be the case for mixtures to be isomorphic)
 *
 * Purpose:   Compare mixture Dirichlet objects <d1> and <d2> 
 *            for equality. For real numbered values, equality
@@ -85,17 +182,44 @@ ERROR:
 int
 esl_mixdchlet_Compare(ESL_MIXDCHLET *d1, ESL_MIXDCHLET *d2, double tol)
 {
-    int q;
+  int i,j;
+  int status;
 
     if (d1->N != d2->N) return eslFAIL;
     if (d1->K != d2->K) return eslFAIL;
 
-    if (esl_vec_DCompare(d1->pq, d2->pq, d1->N, tol) != eslOK) return eslFAIL;
 
-    for (q = 0; q < d1->N; q++)
-        if (esl_vec_DCompare(d1->alpha[q], d2->alpha[q], d1->K, tol) != eslOK) return eslFAIL;    
+  //set up a 2-D matrix, to store the pairs of components that meet tolerance requirements
+  int **A;
+  ESL_ALLOC_WITH_TYPE(A, int**, d1->N * sizeof(int*));
+  for (i=0; i<d1->N; i++)
+	  ESL_ALLOC_WITH_TYPE(A[i], int*, d1->N * sizeof(int) );
+
+  // Fill in matrix - OK if component i from d1 is a viable match with component q from d2
+  for (i=0; i<d1->N; i++)
+  {
+	  for (j=0; j<d1->N; j++)
+	  {
+		  A[i][j] = esl_DCompare( d1->pq[i], d2->pq[j], tol);
+		  if (A[i][j] == eslOK)
+			  A[i][j] = esl_vec_DCompare(d1->alpha[i], d2->alpha[j], d1->K, tol) ;
+	  }
+  }
+
+  /* In most cases, there should be only a one-to-one mapping (if any), which is easy to test.
+   But in the unlikely case of a many-to-one mapping, we need to do a little more.
+   The problem amounts to asking whether there exists a perfect bipartite matching (aka the marriage problem)
+  */
+  status = esl_mixdchlet_PerfectBipartiteMatchExists( A, d1->N);
+
+  ERROR:
+
+  for (i=0; i<d1->N; i++)
+	  free (A[i]);
+  free (A);
+
+  return status;
 
-    return eslOK;
 }
 
 /* Function:  esl_mixdchlet_Copy()
@@ -148,21 +272,21 @@ esl_mixdchlet_Destroy(ESL_MIXDCHLET *pri)
 *
 * Purpose:   Dump the mixture Dirichlet <d>.
 */
-//int
-//esl_mixdchlet_Dump(FILE *fp, ESL_MIXDCHLET *d)
-//{
-//    int  q;  /* counter over mixture components */
-//    int  i;  /* counter over params */
-//
-//    fprintf(fp, "Mixture Dirichlet: N=%d K=%d\n", d->N, d->K);
-//    for (q = 0; q < d->N; q++) {
-//        printf("q[%d] %f\n", q, d->pq[q]);
-//        for (i = 0; i < d->K; i++)
-//            fprintf(fp, "alpha[%d][%d] %f\n", q, i, d->alpha[q][i]);
-//    }
-//
-//    return eslOK;
-//}
+int
+esl_mixdchlet_Dump(FILE *fp, ESL_MIXDCHLET *d)
+{
+    int  q;  /* counter over mixture components */
+    int  i;  /* counter over params */
+
+    fprintf(fp, "Mixture Dirichlet: N=%d K=%d\n", d->N, d->K);
+    for (q = 0; q < d->N; q++) {
+        printf("q[%d] %f\n", q, d->pq[q]);
+        for (i = 0; i < d->K; i++)
+            fprintf(fp, "alpha[%d][%d] %f\n", q, i, d->alpha[q][i]);
+    }
+
+    return eslOK;
+}
 
 
 /* Function:  esl_mixdchlet_MPParameters()
@@ -277,7 +401,7 @@ esl_dirichlet_LogProbData(double *c, double *alpha, int K, double *ret_answer)
 *
 * Purpose:   Given an observed count vector $c[0..K-1]$, 
 *            and a mixture Dirichlet density parameterized by
-*            $\alpha_1[0..K-1]$ ... $\alpha_N[0..K-1]$;
+ *			  $\alpha_1[0..K-1]$ ... $\alpha_N[0..K-1]$,
 *            calculate $\log \sum_i pq_i * P(c \mid \alpha_i)$.
 *            
 *
@@ -315,6 +439,38 @@ ERROR:
     return status;
 }
 
+
+/* Function:  esl_dirichlet_LogProbDataSet_Mixture()
+ * Incept:    TW, Wed Nov  4 14:10:22 EST 2009 [janelia]
+ *
+ * Purpose:   Given an observed set of count vectors $c[0..N-1][0..K-1]$, 
+ *            and a mixture Dirichlet density parameterized by
+ *			  $\alpha_1[0..K-1]$ ... $\alpha_N[0..K-1]$,
+ *            calculate $ \sum_n \log \sum_i pq_i * P(c[n] \mid \alpha_i)$.
+ *            This is a convenience function, which simply wraps
+ *            esl_dirichlet_LogProbData_Mixture
+ *            
+ *
+ * Args:      ntrials      - number of count vectors (aka N)
+ *            counts      - count vector set, [0..N-1][0..K-1]
+ *            md      - Dirichlet parameters
+ *            ret_answer - RETURN: log P(c | \alpha)
+ *
+ * Returns:   <eslOK> on success, and puts result $\log P(c \mid \alpha)$
+ *            in <ret_answer>.
+ */
+static int esl_dirichlet_LogProbDataSet_Mixture (int ntrials, double** counts, ESL_MIXDCHLET* md, double *ret_answer) {
+        *ret_answer = 0;
+        double val;
+        int i;
+        for (i = 0; i < ntrials; i++) {
+          esl_dirichlet_LogProbData_Mixture(counts[i], md, &val);
+          *ret_answer += val;
+        }
+        return eslOK;
+}
+
+
 /* Function:  esl_dirichlet_LogProbProbs()
 * Incept:    SRE, Sat Apr  9 14:35:17 2005 [St. Louis]
 *
@@ -403,8 +559,12 @@ struct mixdchlet_data {
 *     pq : length N,   [0..N-1]
 *  alpha : length NxK, [0..N-1][0..K-1].
 *
-* The case N=1 is special:
-* the only variables to optimize are the K alphas
+ * Special cases:
+ *
+ * - For (N >= 1 && K == 1) there is nothing to optimize.
+ *  
+ * - For (N == 1 && K >  1) the only variables to optimize are the K alphas
+ *
 *              [0 ... K-1] 
 *                 alpha    
 *
@@ -415,20 +575,21 @@ struct mixdchlet_data {
 static void
 mixdchlet_pack_paramvector(double *p, int np, ESL_MIXDCHLET *d)
 {
+  int nq;        /* number the mixture components to optimize */
     int q;	 /* counter over mixture components */
     int x;         /* counter in alphabet size */
-    int dimq;      /* dimension of the mixtures to optimize */
 
-    dimq = (d->N > 1)? d->N : 0;
+  nq = (d->N > 1)? d->N : 0;
 
     /* the mixture coeficients */
-    for (q = 0; q < dimq; q++)
-        p[q] = log(-log(d->pq[q]));
+  for (q = 0; q < nq; q++)
+	  p[q] = log(d->pq[q]);
+    //p[q] = log(-log(d->pq[q]));  TW changed to the above; this was causing fit to fail
 
     /* the dirichlet parameters */
     for (q = 0; q < d->N; q++)
         for (x = 0; x < d->K; x++)
-            p[dimq + q*d->K + x] = log(d->alpha[q][x]);
+      p[nq + q*d->K + x] = log(d->alpha[q][x]);
 
 }
 
@@ -439,21 +600,22 @@ mixdchlet_pack_paramvector(double *p, int np, ESL_MIXDCHLET *d)
 static void
 mixdchlet_unpack_paramvector(double *p, int np, ESL_MIXDCHLET *d)
 {
+  int nq;        /* number the mixture components to optimize */
     int q;	 /* counter over mixture components */
     int x;         /* counter in alphabet size */
-    int dimq;      /* dimension of the mixtures to optimize */
 
-    dimq = (d->N > 1)? d->N : 0;
+  nq = (d->N > 1)? d->N : 0;
 
     /* the mixture coeficients */
-    for (q = 0; q < dimq; q++) 
-        d->pq[q] = exp(-exp(p[q]));
+  for (q = 0; q < nq; q++) 
+	d->pq[q] = exp(p[q]);
+	//d->pq[q] = exp(-exp(p[q])); TW changed to the above; this was causing fit to fail
     esl_vec_DNorm(d->pq, d->N);
 
     /* the dirichlet parameters */
     for (q = 0; q < d->N; q++)
         for (x = 0; x < d->K; x++) 
-            d->alpha[q][x] = exp(p[dimq + q*d->K + x]);      
+      d->alpha[q][x] = exp(p[nq + q*d->K + x]);      
 
     /*esl_mixdchlet_Dump(stdout, d);*/
 
@@ -483,65 +645,88 @@ mixdchlet_complete_func(double *p, int np, void *dptr)
 }
 
 /* The gradient of the NLL w.r.t. each free parameter in p.
+ * Modified by ER 11/03/09 to compute derivative of log(alpha) instead of alpha
+ * (committed by TW)
 */
 static void
 mixdchlet_complete_gradient(double *p, int np, void *dptr, double *dp)
 {
     struct mixdchlet_data *data = (struct mixdchlet_data *) dptr;
     ESL_MIXDCHLET         *d    = data->d;
-    double  sum_alpha;
-    double  sum_c;
-    double  val1;
-    double  val2;
-    double  ratio1;
-    double  ratio2;
-    double  psi1, psi2, psi3, psi4;
+  double  sum_alpha;             /* \sum_x alpha[q][x]                        */
+  double  sum_c;                 /* \sum_x c[m][x]                            */
+  double  val;                   /* val    is         p_q * P(c_m | alpha_q)  */
+  double *valsum;                /* valsum is  sum_q [p_q * P(c_m | alpha_q)] */
+  double  term;                  /* term   is  q * P(alpha_q | c_m)           */
+  double  psi1;                  /* Psi(sum_alpha[q])                         */
+  double  psi2;                  /* Psi(sum_alpha[q] + sum_c[m])              */
+  double  psi3;                  /* Psi(sum_alpha[q][x]+ c[m][x])             */
+  double  psi4;                  /* Psi(sum_alpha[q][x])                      */
+  int     nq;                    /* number the mixture components to optimize */
     int     m;                     /* counter over count samples */
     int     q;		 	 /* counter over mixture components */
     int     x;                     /* counter in alphabet size */
-    int     dimq;                  /* dimension of the mixtures to optimize */
 
-    dimq = (d->N > 1)? d->N : 0;
+  nq = (d->N > 1)? d->N : 0;
 
     mixdchlet_unpack_paramvector(p, np, d);
 
     /* initialize */
+  valsum = (double*)malloc(sizeof(double) * data->nc);
     esl_vec_DSet(dp, np, 0.0);
 
+  /* Some precalculation of sums for efficiency.
+   * valsum is  sum_q [p_q * P(c_m | alpha_q)]
+   */
+   for (m = 0; m < data->nc; m++)
+    esl_dirichlet_LogProbData_Mixture(data->c[m], d, &(valsum[m]));
+
     for (q = 0; q < d->N; q++) {
 
         sum_alpha = esl_vec_DSum(d->alpha[q], d->K);
-        esl_stats_Psi(sum_alpha, &psi1);
+     esl_stats_Psi(sum_alpha, &psi1);  /* psi1 = Psi(sum_alpha[q]) */
 
         for (m = 0; m < data->nc; m++) {
             sum_c = esl_vec_DSum(data->c[m], d->K);
-            esl_stats_Psi(sum_alpha+sum_c, &psi2);
+       esl_stats_Psi(sum_alpha+sum_c, &psi2); /* psi2 = Psi(sum_alpha[q] + sum_c[m]) */
 
-            esl_dirichlet_LogProbData(data->c[m], d->alpha[q], d->K, &val1);
-            esl_dirichlet_LogProbData_Mixture(data->c[m], d, &val2);
+      /* val is pq * P(c_m | alpha_q)    */
+       esl_dirichlet_LogProbData(data->c[m], d->alpha[q], d->K, &val);
 
-            ratio1 = exp(val1 - val2);
-            ratio2 = ratio1 * d->pq[q];
 
             /* derivative respect to the mixture coeficients */
-            dp[q] += ratio1;
+       /* term is  pq * P(alpha_q | c_m) */
+       term = exp(val - valsum[m] + log(d->pq[q]));
+       if (nq > 0) dp[q] += term - d->pq[q];
+
 
             /* derivative respect to the dirichlet parameters */
             for (x = 0; x < d->K; x++) {
-                esl_stats_Psi(d->alpha[q][x]+data->c[m][x], &psi3);
-                esl_stats_Psi(d->alpha[q][x],               &psi4);
+         esl_stats_Psi(d->alpha[q][x]+data->c[m][x], &psi3); /* psi3 = Psi(sum_alpha[q][x]+ c[m][x]) */
+         esl_stats_Psi(d->alpha[q][x],               &psi4); /* psi4 = Psi(sum_alpha[q][x]+ c[m][x]) */
+
+         dp[nq + q*d->K + x] += term * d->alpha[q][x] * (psi1 - psi2 + psi3 - psi4);
+
 
-                dp[dimq + q*d->K + x] += ratio2 * (psi1 - psi2 + psi3 - psi4);
             }              
         }
     }
 
-    /* check */
-    for (q = 0; q < d->N; q++) {
+
+
+   /* Return the negative, because we're minimizing the NLP, not maximizing.
+    */
+   for (q = 0; q < nq; q++) {
         if (isnan(dp[q])) esl_fatal("dp for pq[%d] is NaN", q);
-        for (x = 0; x < d->K; x++) 
-            if(isnan(dp[dimq + q*d->K + x])) esl_fatal("dp for alpha[%d][%d] is NaN", q, x);
+     dp[q] *= -1.;
+   }
+   for (q = 0; q < d->N; q++)
+     for (x = 0; x < d->K; x++) {
+       if(isnan(dp[nq + q*d->K + x])) esl_fatal("dp for alpha[%d][%d] is NaN", q, x);
+       dp[nq + q*d->K + x] *= -1.0;
     }
+
+   free(valsum);
 }
 
 /* Function:  esl_mixdchlet_Fit()
@@ -567,21 +752,24 @@ esl_mixdchlet_Fit(double **c, int nc, ESL_MIXDCHLET *d, int be_verbose)
     double *u   = NULL;
     double *wrk = NULL;
     double  tol;
-    int     np;
     double  fx;
-    int     dimq;      /* dimension of the mixtures to optimize */
+  int     np;      /* number of parameters to optimize */
+  int     nq;      /* number the mixture components to optimize */
     int     i;
     int     status;
 
+  /* nothing to optimize for a dirichlet of K = 1 (alphabet size = 1)*/
+  if (d->K == 1) return eslOK;
+
     tol = 1e-6;
 
     /* Allocate parameters
     */
-    dimq = (d->N > 1)? d->N : 0;
-    np   = dimq + d->N*d->K;
-    ESL_ALLOC(p,   sizeof(double) * np);
-    ESL_ALLOC(u,   sizeof(double) * np);
-    ESL_ALLOC(wrk, sizeof(double) * np * 4);
+  nq = (d->N > 1)? d->N : 0;
+  np = nq + d->N*d->K;
+    ESL_ALLOC_WITH_TYPE(p, double*,   sizeof(double) * np);
+    ESL_ALLOC_WITH_TYPE(u, double*,   sizeof(double) * np);
+    ESL_ALLOC_WITH_TYPE(wrk, double*, sizeof(double) * np * 4);
 
     /* Copy shared info into the "data" structure
     */
@@ -603,7 +791,8 @@ esl_mixdchlet_Fit(double **c, int nc, ESL_MIXDCHLET *d, int be_verbose)
         &mixdchlet_complete_func, 
         &mixdchlet_complete_gradient,
         (void *) (&data), tol, wrk, &fx);
-    if (status != eslOK) goto ERROR;
+  if (status != eslOK && status != eslENOHALT) // eslENOHALT? Then take what we've got - it's probably pretty good
+	  goto ERROR;
 
     /* Convert the final parameter vector back to a mixdchlet
     */
@@ -620,6 +809,98 @@ ERROR:
     if (wrk != NULL) free(wrk);
     return status;
 }
+
+
+/* Function:  esl_mixdchlet_Fit_Multipass()
+ * Incept:    TW, Wed Nov  4 15:00:02 EST 2009 [Janelia]
+ *
+ * Purpose:   Given a set of count vectors <c>, find maximum
+ *            likelihood mixdchlet parameters. A number <reps>
+ *            of initial guesses <d> for a mixdchlet are used,
+ *            with conjugate gradient descent performed for
+ *            each guess. The mixdchlet returned is the one
+ *            among these multiple local searches with
+ *            best likelihood.  This is a convenience
+ *            function, which simply wraps esl_mixdchlet_Fit
+ *            for multiple start points.
+ *
+ * Args:      r  - pointer to random generator
+ * 			  c  - set of count vectors, [0..M-1][0..N-1]
+ * 			  nc - number of count samples
+ *            reps - number of random starting points
+ *            best_md  - an initialized mixdchlet, which will
+ *            		contain the correct q and alpha values
+ *            		at completion
+ *            verbose - if >0, output is verbose
+ *
+ * Returns:   <eslOK> on success, and <best_md> contains the fitted
+ *            mixdchlet parameters with best likelihood.
+ *
+ * Throws:    <eslEMEM> on allocation error, and <d> is left in
+ *            in its initial state.
+ */
+int
+esl_mixdchlet_Fit_Multipass(ESL_RANDOMNESS *r, double **c, int nc, int reps, ESL_MIXDCHLET *best_md, int verbose)
+{
+	int i, q, k, status;
+	double best_lk = -eslINFINITY;
+	double lk;
+	ESL_MIXDCHLET *md = esl_mixdchlet_Create(best_md->N, best_md->K);
+
+	int err_cnt = 0;
+
+	for (i=0; i<reps; i++) {
+
+		//for each pass, establish a new random starting point
+		for (q = 0; q < md->N; q++) {
+	    md->pq[q] = esl_rnd_UniformPositive(r);
+
+	     for (k = 0; k < md->K; k++)
+	       md->alpha[q][k] = 10.0*esl_rnd_UniformPositive(r);
+	  }
+	  esl_vec_DNorm(md->pq, md->N);
+
+	  //then use Fit to do local search
+	  status = esl_mixdchlet_Fit(c, nc, md, 0);
+	  if (status != eslOK) {
+		  err_cnt++;
+		  if (err_cnt==2*reps) {
+			  goto ERROR;
+		  } else {
+			  i--; // try another starting point
+			  continue;
+		  }
+	  }
+
+	  esl_dirichlet_LogProbDataSet_Mixture (nc, c, md, &lk);
+
+	  if (verbose>0) {
+		  fprintf(stderr, "Repetition # %d\n------------\n", i);
+		  esl_mixdchlet_Dump(stderr, md);
+		  fprintf(stderr, "llk = %.3f  (vs best = %.3f)\n", lk, best_lk);
+	  }
+
+	  if (lk > best_lk) {
+		  if (verbose>0)
+			  fprintf(stderr, "... so copy md -> best_md\n");
+		  best_lk = lk;
+		  esl_mixdchlet_Copy(md, best_md);
+	  }
+	}
+
+	if (verbose>0) {
+		fprintf(stdout, "\n\n----------------\nbest mixture:\n");
+		esl_mixdchlet_Dump(stdout, best_md);
+		fprintf(stdout, "llk = %.3f", best_lk);
+	}
+
+
+	ERROR:
+	  if (md   != NULL) free(md);
+	  return status;
+
+}
+
 #endif /*eslAUGMENT_MINIMIZER*/
 /*----------- end, Dirichlet Maximum likelihood fit from counts ---------------*/
 
@@ -627,6 +908,7 @@ ERROR:
 /*****************************************************************
 *# 3. Sampling from Dirichlets: requires <esl_random>
 *****************************************************************/
+#ifdef eslAUGMENT_RANDOM
 /* Function:  esl_dirichlet_DSample()
 * Incept:    SRE, Tue Nov  2 14:30:31 2004 [St. Louis]
 *
@@ -729,11 +1011,12 @@ esl_dirichlet_SampleBeta(ESL_RANDOMNESS *r, double theta1, double theta2, double
     *ret_answer = p / (p+q);
     return eslOK;
 }
+#endif /*eslAUGMENT_RANDOM*/
 /*---------------- end, Dirichlet sampling ----------------------*/
 
 /*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
-* Version h3.0b2; June 2009
+ * Version h3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
