@@ -670,60 +670,60 @@ esl_vec_ISortDecreasing(int *vec, int n)
 *
 * Returns:   <eslOK> on success.
 */
-//int
-//esl_vec_DDump(FILE *ofp, double *v, int n, char *label)
-//{
-//    int a;
-//
-//    fprintf(ofp, "     ");
-//    if (label != NULL) 
-//        for (a = 0; a < n; a++) fprintf(ofp, "         %c ", label[a]);
-//    else
-//        for (a = 0; a < n; a++) fprintf(ofp, "%10d ", a+1);
-//    fprintf(ofp, "\n");
-//
-//    fprintf(ofp, "      ");
-//    for (a = 0; a < n; a++) fprintf(ofp, "%10.6f ", v[a]);
-//    fprintf(ofp, "\n");
-//
-//    return eslOK;
-//}
-//int
-//esl_vec_FDump(FILE *ofp, float *v, int n, char *label)
-//{
-//    int a;
-//
-//    fprintf(ofp, "     ");
-//    if (label != NULL) 
-//        for (a = 0; a < n; a++) fprintf(ofp, "         %c ", label[a]);
-//    else
-//        for (a = 0; a < n; a++) fprintf(ofp, "%10d ", a+1);
-//    fprintf(ofp, "\n");
-//
-//    fprintf(ofp, "      ");
-//    for (a = 0; a < n; a++) fprintf(ofp, "%10.6f ", v[a]);
-//    fprintf(ofp, "\n");
-//
-//    return eslOK;
-//}
-//int
-//esl_vec_IDump(FILE *ofp, int *v, int n, char *label)
-//{
-//    int a;
-//
-//    fprintf(ofp, "     ");
-//    if (label != NULL) 
-//        for (a = 0; a < n; a++) fprintf(ofp, "       %c ", label[a]);
-//    else
-//        for (a = 0; a < n; a++) fprintf(ofp, "%8d ", a+1);
-//    fprintf(ofp, "\n");
-//
-//    fprintf(ofp, "      ");
-//    for (a = 0; a < n; a++) fprintf(ofp, "%8d ", v[a]);
-//    fprintf(ofp, "\n");
-//
-//    return eslOK;
-//}
+int
+esl_vec_DDump(FILE *ofp, double *v, int n, char *label)
+{
+    int a;
+
+    fprintf(ofp, "     ");
+    if (label != NULL) 
+        for (a = 0; a < n; a++) fprintf(ofp, "         %c ", label[a]);
+    else
+        for (a = 0; a < n; a++) fprintf(ofp, "%10d ", a+1);
+    fprintf(ofp, "\n");
+
+    fprintf(ofp, "      ");
+    for (a = 0; a < n; a++) fprintf(ofp, "%10.6f ", v[a]);
+    fprintf(ofp, "\n");
+
+    return eslOK;
+}
+int
+esl_vec_FDump(FILE *ofp, float *v, int n, char *label)
+{
+    int a;
+
+    fprintf(ofp, "     ");
+    if (label != NULL) 
+        for (a = 0; a < n; a++) fprintf(ofp, "         %c ", label[a]);
+    else
+        for (a = 0; a < n; a++) fprintf(ofp, "%10d ", a+1);
+    fprintf(ofp, "\n");
+
+    fprintf(ofp, "      ");
+    for (a = 0; a < n; a++) fprintf(ofp, "%10.6f ", v[a]);
+    fprintf(ofp, "\n");
+
+    return eslOK;
+}
+int
+esl_vec_IDump(FILE *ofp, int *v, int n, char *label)
+{
+    int a;
+
+    fprintf(ofp, "     ");
+    if (label != NULL) 
+        for (a = 0; a < n; a++) fprintf(ofp, "       %c ", label[a]);
+    else
+        for (a = 0; a < n; a++) fprintf(ofp, "%8d ", a+1);
+    fprintf(ofp, "\n");
+
+    fprintf(ofp, "      ");
+    for (a = 0; a < n; a++) fprintf(ofp, "%8d ", v[a]);
+    fprintf(ofp, "\n");
+
+    return eslOK;
+}
 
 /* Function:  esl_vec_D2F()
 * Synopsis:  Convert between single-precision and double-precision vectors.            
@@ -1145,7 +1145,7 @@ ERROR:
 
 /*****************************************************************  
 * Easel - a library of C functions for biological sequence analysis
-* Version h3.0b2; June 2009
+ * Version h3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
