@@ -16,7 +16,7 @@
 *   5. Copyright and license information
 * 
 * SRE, Mon Aug  6 13:00:06 2007
-* SVN $Id: evalues.c 2825 2009-06-12 14:59:39Z eddys $
+ * SVN $Id: evalues.c 3041 2009-11-12 12:58:09Z eddys $
 */
 #include <hmmer3/p7_config.h>
 
@@ -67,6 +67,7 @@
 *
 * Xref:      J4/41
 */
+// ! CODE CHANGED: added taskstateinfo to function !
 int
 p7_Calibrate(P7_HMM *hmm, P7_BUILDER *cfg_b, ESL_RANDOMNESS **byp_rng, P7_BG **byp_bg, P7_PROFILE **byp_gm, P7_OPROFILE **byp_om,
              int percents, GB2::TaskStateInfo & ti)
@@ -106,8 +107,7 @@ p7_Calibrate(P7_HMM *hmm, P7_BUILDER *cfg_b, ESL_RANDOMNESS **byp_rng, P7_BG **b
     */
     if ((esl_byp_IsInternal(byp_gm) && ! esl_byp_IsProvided(byp_om)) || esl_byp_IsReturned(byp_gm)) {
         if  ( (gm     = p7_profile_Create(hmm->M, hmm->abc))          == NULL)  ESL_XFAIL(eslEMEM, errbuf, "failed to allocate profile");
-        status = p7_ProfileConfig(hmm, bg, gm, EvL, p7_LOCAL);
-        if  ( status != eslOK) { ESL_XFAIL(status,  errbuf, "failed to configure profile"); }
+    if  ( (status = p7_ProfileConfig(hmm, bg, gm, EvL, p7_LOCAL)) != eslOK) ESL_XFAIL(status,  errbuf, "failed to configure profile");
     }
 
     if (om == NULL) {
@@ -117,7 +117,8 @@ p7_Calibrate(P7_HMM *hmm, P7_BUILDER *cfg_b, ESL_RANDOMNESS **byp_rng, P7_BG **b
 
     /* The calibration steps themselves */
     if ((status = p7_Lambda(hmm, bg, &lambda))                       != eslOK) ESL_XFAIL(status,  errbuf, "failed to determine lambda");
-    if ((status = p7_MSVMu    (r, om, bg, EmL, EmN, lambda, &mmu, ti )) == eslCANCELED) {
+    // ! CODE ADDED: check if task is canceled !
+	if ((status = p7_MSVMu    (r, om, bg, EmL, EmN, lambda, &mmu, ti )) == eslCANCELED) {
         goto ERROR;
     } else if( eslOK != status ) {
         ESL_XFAIL(status,  errbuf, "failed to determine msv mu");
@@ -270,7 +271,9 @@ p7_MSVMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lam
     double  *xv      = NULL;
     int      i;
     float    sc, nullsc;
+#ifndef p7_IMPL_DUMMY
     float    maxsc   = (255 - om->base_b) / om->scale_b; /* if score overflows, use this */
+#endif
     int      status;
 
     if (ox == NULL) { status = eslEMEM; goto ERROR; }
@@ -287,8 +290,10 @@ p7_MSVMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lam
         
         status = p7_MSVFilter(dsq, L, om, ox, &sc, 0, ti );
         if( eslCANCELED == status ) { goto ERROR; }
-        if      (status == eslERANGE) sc = maxsc;
-        else if (status != eslOK)     goto ERROR;
+#ifndef p7_IMPL_DUMMY
+		if      (status == eslERANGE) { sc = maxsc; status = eslOK;}
+#endif
+		if (status != eslOK)     goto ERROR;
 
         xv[i] = (sc - nullsc) / eslCONST_LOG2;
     }
@@ -340,7 +345,9 @@ p7_ViterbiMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double
     double  *xv      = NULL;
     int      i;
     float    sc, nullsc;
+#ifndef p7_IMPL_DUMMY
     float    maxsc   = (32767.0 - om->base_w) / om->scale_w; /* if score overflows, use this [J4/139] */
+#endif
     int      status;
 
     if (ox == NULL) { status = eslEMEM; goto ERROR; }
@@ -356,9 +363,12 @@ p7_ViterbiMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double
         if ((status = p7_bg_NullOne(bg, dsq, L, &nullsc))          != eslOK) goto ERROR;   
         
         status = p7_ViterbiFilter(dsq, L, om, ox, &sc, 0, ti ); 
-        if      (status == eslERANGE) sc = maxsc;
-        else if (status != eslOK)     goto ERROR;
-        
+        if( eslCANCELED == status ) { goto ERROR; }
+#ifndef p7_IMPL_DUMMY
+		if      (status == eslERANGE) { sc = maxsc; status = eslOK;}
+#endif
+		if (status != eslOK)     goto ERROR;
+
         xv[i] = (sc - nullsc) / eslCONST_LOG2;
     }
 
@@ -491,7 +501,7 @@ ERROR:
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
