@@ -34,14 +34,14 @@
 * structure for an optimized profile.
 * 
 * SRE, Wed Jan  3 13:46:42 2007 [Janelia] [Philip Glass, The Fog of War]
-* SVN $Id: hmmer.h 2830 2009-06-16 18:24:14Z eddys $
+ * SVN $Id: hmmer.h 3048 2009-11-13 14:11:46Z eddys $
 */
 #ifndef P7_HMMERH_INCLUDED
 #define P7_HMMERH_INCLUDED
 
 #include <hmmer3/p7_config.h>
-#include <sys/types.h>
-//#include <stdio.h>		/* FILE */
+
+#include <stdio.h>		/* FILE */
 
 #ifdef HAVE_MPI
 #include "mpi.h"
@@ -267,6 +267,12 @@ typedef struct p7_profile_s {
     float  cutoff[p7_NCUTOFFS]; 	/* per-seq/per-domain bit score cutoffs, or UNSET         */
     float  compo[p7_MAXABET];	/* per-model HMM filter composition, or UNSET             */
 
+  /* Disk offset information for hmmpfam's fast model retrieval                           */
+  off_t  offs[p7_NOFFSETS];     /* p7_{MFP}OFFSET, or -1                                  */
+
+  off_t  roff;                  /* record offset (start of record); -1 if none            */
+  off_t  eoff;                  /* offset to last byte of record; -1 if unknown           */
+
     const ESL_ALPHABET *abc;	/* copy of pointer to appropriate alphabet                */
 } P7_PROFILE;
 
@@ -304,12 +310,15 @@ typedef struct p7_bg_s {
 * 
 * A "profile" trace uniquely has S,N,C,T,J states and their
 * transitions; it also can have B->Mk and Mk->E internal entry/exit
-* transitions for local alignments. A "core" trace uniquely has I0,
-* IM, and D1 states and their transitions. A "core" trace can also
-* have B->X->Mk and Mk->X->E transitions as a special hack in a build
-* procedure, to deal with the case of a local alignment fragment
-* implied by an input alignment, which is "impossible" for a core
-* model.
+ * transitions for local alignments. 
+ *
+ * A "core" trace may contain I0, IM, and D1 states and their
+ * transitions. A "core" trace can also have B->X->{MDI}k and
+ * {MDI}k->X->E transitions as a special hack in a build procedure, to
+ * deal with the case of a local alignment fragment implied by an
+ * input alignment, which is "impossible" for a core model.
+ * X "states" only appear in core traces, and only at these
+ * entry/exit places; some code depends on this.
 *   
 * A profile's N,C,J states emit on transition, not on state, so a
 * path of N emits 0 residues, NN emits 1 residue, NNN emits 2
@@ -360,31 +369,7 @@ typedef struct p7_trace_s {
 } P7_TRACE;
 
 
-/*****************************************************************
-* 5. P7_HMMFILE:  an HMM save file or database, open for reading.
-*****************************************************************/
-
-//typedef struct p7_hmmfile_s {
-//    FILE         *f;		 /* pointer to stream for reading models                 */
-//    char         *fname;	         /* (fully qualified) name of the HMM file; [STDIN] if - */
-//    ESL_SSI      *ssi;		 /* open SSI index for model file <f>; NULL if none.     */
-//
-//    int           do_gzip;	/* TRUE if f is "gzip -dc |" (will pclose(f))           */ 
-//    int           do_stdin;       /* TRUE if f is stdin (won't close f)                   */
-//    int           newly_opened;	/* TRUE if we just opened the stream (and parsed magic) */
-//    int           is_pressed;	/* TRUE if a pressed HMM database file (Pfam or equiv)  */
-//
-//    int (*parser)(struct p7_hmmfile_s *, ESL_ALPHABET **, P7_HMM **);  /* parsing function */
-//    ESL_FILEPARSER *efp;
-//
-//    /* If <is_pressed>, we can read optimized profiles directly, via:  */
-//    FILE         *ffp;		/* MSV part of the optimized profile */
-//    FILE         *pfp;		/* rest of the optimized profile     */
-//
-//    char          errbuf[eslERRBUFSIZE];
-//} P7_HMMFILE;
-
-
+// ! here were P7_HMMFILE definition. we don't need it !
 
 /*****************************************************************
 * 6. P7_GMX: a "generic" dynamic programming matrix
@@ -525,6 +510,7 @@ typedef struct p7_alidisplay_s {
     long  sqto;		        /* end position on sequence   (1..L)    */
     long  L;			/* length of sequence                   */
 
+  int   memsize;                /* size of allocated block of memory    */
     char *mem;			/* memory used for the char data above  */
 } P7_ALIDISPLAY;
 
@@ -719,7 +705,6 @@ typedef struct p7_pipeline_s {
     int     incdom_by_E;		/* TRUE to threshold domain inclusion by E  */
     double  incdomE;		/* per-domain inclusion E-value threshold   */
     double  incdomT;		/* per-domain inclusion E-value threshold   */
-    int     incuse_bit_cutoffs;	/* (FALSE | p7H_GA | p7H_TC | p7H_NC)       */
 
     /* Tracking search space sizes for E value calculations                   */
     double  Z;			/* eff # targs searched (per-target E-val)  */
@@ -746,11 +731,14 @@ typedef struct p7_pipeline_s {
     uint64_t      n_past_fwd;	/* # comparisons that pass ForwardFilter()  */
 
     enum p7_pipemodes_e mode;    	/* p7_SCAN_MODELS | p7_SEARCH_SEQS          */
+  int           show_accessions;/* TRUE to output accessions not names      */
+  int           show_alignments;/* TRUE to output alignments (default)      */
 
-    //    P7_HMMFILE   *hfp;		/* COPY of open HMM database (if scan mode) */
     char          errbuf[eslERRBUFSIZE];
 } P7_PIPELINE;
 
+// ! CODE ADDED: ugene's hmmer search settings !
+
 typedef struct _UHMM3SearchSettings {
     double e;           // -E: report sequences <= this e-value treshold in output
     double t;           // -T: report sequences >= this score treshold in output
@@ -761,23 +749,20 @@ typedef struct _UHMM3SearchSettings {
     int useBitCutoffs;  // --cut_ga: use profile's GA gathering cutoffs to set -T, --domT
     // --cut_nc: use profile's NC noising cutoffs to set -T, --domT
     // --cut_tc: use profile's TC trusted cutoffs to set -T, --domT
-
+	
     double incE;        // --incE: include sequences <= this e-value threshold in output ali
     double incT;        // --incT: include sequences >= this score threshold in output ali
     double incDomE;     // --incdomE: include domains <= this e-value threshold in output ali
     double incDomT;     // --incdomT: include domains >= this score threshold in output ali
-    int incuseBitCutoffs;   // --inc_ga: use profile's GA gathering cutoffs to set --incT, --incdomT
-    // --inc_nc: use profile's NC noising cutoffs to set --incT, --incdomT
-    // --inc_tc: use profile's GA trusted cutoffs to set --incT, --incdomT
-
+    
     double f1;          // --F1: Stage 1 (MSV) threshold: promote hits w/ P <= F1
     double f2;          // --F2: Stage 2 (Vit) threshold: promote hits w/ P <= F2
     double f3;          // --F3: Stage 3 (Fwd) threshold: promote hits w/ P <= F3
-
+	
     int doMax;          // --max: Turn all heuristic filters off ( less speed more power )
     int noBiasFilter;   // --nobias: turn off composition bias filter
     int noNull2;        // --nonull2: turn off biased composition score corrections
-
+	
     int seed; // --seed : set RNG seed ( if 0: one-time arbitrary seed )
 } UHMM3SearchSettings;
 
@@ -837,6 +822,7 @@ typedef struct p7_builder_s {
     char errbuf[eslERRBUFSIZE];            /* informative message on model construction failure      */
 } P7_BUILDER;
 
+// CODE ADDED: ugene's hmmer build settings
 
 typedef struct _UHMM3BuildSettings {
     enum p7_archchoice_e archStrategy;   // model construction strategies
@@ -888,7 +874,7 @@ extern int p7_Fastmodelmaker(ESL_MSA *msa, float symfrac, P7_HMM **ret_hmm, P7_T
 /* emit.c */
 extern int p7_CoreEmit   (ESL_RANDOMNESS *r, const P7_HMM *hmm,                                        ESL_SQ *sq, P7_TRACE *tr);
 extern int p7_ProfileEmit(ESL_RANDOMNESS *r, const P7_HMM *hmm, const P7_PROFILE *gm, const P7_BG *bg, ESL_SQ *sq, P7_TRACE *tr);
-//extern int p7_emit_SimpleConsensus(const P7_HMM *hmm, ESL_SQ *sq);
+extern int p7_emit_SimpleConsensus(const P7_HMM *hmm, ESL_SQ *sq);
 
 /* errors.c */
 extern void p7_Die (char *format, ...);
@@ -905,56 +891,26 @@ extern int p7_Tau       (ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, i
 /* eweight.c */
 extern int p7_EntropyWeight(const P7_HMM *hmm, const P7_BG *bg, const P7_PRIOR *pri, double infotarget, double *ret_Neff);
 
-/* generic_decoding.c */
-//extern int p7_GDecoding      (const P7_PROFILE *gm, const P7_GMX *fwd,       P7_GMX *bck, P7_GMX *pp);
-//extern int p7_GDomainDecoding(const P7_PROFILE *gm, const P7_GMX *fwd, const P7_GMX *bck, P7_DOMAINDEF *ddef);
-
-/* generic_fwdback.c */
-//extern int p7_GForward     (const ESL_DSQ *dsq, int L, const P7_PROFILE *gm,       P7_GMX *gx, float *ret_sc);
-//extern int p7_GBackward    (const ESL_DSQ *dsq, int L, const P7_PROFILE *gm,       P7_GMX *gx, float *ret_sc);
-//extern int p7_GHybrid      (const ESL_DSQ *dsq, int L, const P7_PROFILE *gm,       P7_GMX *gx, float *opt_fwdscore, float *opt_hybscore);
-
-/* generic_msv.c */
-//extern int p7_GMSV         (const ESL_DSQ *dsq, int L, const P7_PROFILE *gm,       P7_GMX *gx, float *ret_sc);
-
-/* generic_null2.c */
-//extern int p7_GNull2_ByExpectation(const P7_PROFILE *gm, P7_GMX *pp, float *null2);
-//extern int p7_GNull2_ByTrace      (const P7_PROFILE *gm, const P7_TRACE *tr, int zstart, int zend, P7_GMX *wrk, float *null2);
-
-/* generic_optacc.c */
-//extern int p7_GOptimalAccuracy(const P7_PROFILE *gm, const P7_GMX *pp,       P7_GMX *gx, float *ret_e);
-//extern int p7_GOATrace        (const P7_PROFILE *gm, const P7_GMX *pp, const P7_GMX *gx, P7_TRACE *tr);
-
-/* generic_stotrace.c */
-//extern int p7_GStochasticTrace(ESL_RANDOMNESS *r, const ESL_DSQ *dsq, int L, const P7_PROFILE *gm, const P7_GMX *gx, P7_TRACE *tr);
-
-/* generic_viterbi.c */
-//extern int p7_GViterbi     (const ESL_DSQ *dsq, int L, const P7_PROFILE *gm,       P7_GMX *gx, float *ret_sc);
-
-/* generic_vtrace.c */
-//extern int p7_GTrace       (const ESL_DSQ *dsq, int L, const P7_PROFILE *gm, const P7_GMX *gx, P7_TRACE *tr);
+// here were definitions of generic versions of algorithms. we use only sse2 optimized
 
 /* heatmap.c (evolving now, intend to move this to Easel in the future) */
-//extern double dmx_upper_max(ESL_DMATRIX *D);
-//extern double dmx_upper_min(ESL_DMATRIX *D);
-//extern double dmx_upper_element_sum(ESL_DMATRIX *D);
-//extern double dmx_upper_norm(ESL_DMATRIX *D);
-//extern int    dmx_Visualize(FILE *fp, ESL_DMATRIX *D, double min, double max);
+// ! removed unused definitions !
 
 /* island.c */
-//extern int   p7_island_Viterbi(ESL_DSQ *dsq, int L, P7_PROFILE *gm, P7_GMX *mx, ESL_HISTOGRAM *h);
+// ! removed unused definitions !
 
 /* h2_io.c */
-//extern int   p7_h2io_WriteASCII(FILE *fp, P7_HMM *hmm);
+// ! removed unused definitions !
 
 /* hmmer.c */
-//extern void  p7_banner(FILE *fp, char *progname, char *banner);
-//extern float p7_SILO2Lod(int silo);
+// ! removed unused definitions !
+
 extern int   p7_AminoFrequencies(float *f);
 
 /* logsum.c */
 extern float p7_FLogsum(float a, float b );
 extern float p7_FLogsumError(float a, float b);
+// ! removed unused definitions !
 
 /* modelconfig.c */
 extern int p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int mode);
@@ -963,12 +919,9 @@ extern int p7_ReconfigMultihit(P7_PROFILE *gm, int L);
 extern int p7_ReconfigUnihit  (P7_PROFILE *gm, int L);
 
 /* modelstats.c */
-//extern double p7_MeanMatchInfo           (const P7_HMM *hmm, const P7_BG *bg);
-//extern double p7_MeanMatchEntropy        (const P7_HMM *hmm);
 extern double p7_MeanMatchRelativeEntropy(const P7_HMM *hmm, const P7_BG *bg);
-//extern double p7_MeanForwardScore        (const P7_HMM *hmm, const P7_BG *bg);
-//extern int    p7_MeanPositionRelativeEntropy(const P7_HMM *hmm, const P7_BG *bg, double *ret_entropy);
-//extern int    p7_hmm_CompositionKLDist(P7_HMM *hmm, P7_BG *bg, float *ret_KL, float **opt_avp);
+// ! removed unused definitions !
+// here were mpi support definitions. we don't need them
 
 /* tracealign.c */
 extern int p7_tracealign_Seqs(ESL_SQ **sq,           P7_TRACE **tr, int nseq, int M, int optflags, ESL_MSA **ret_msa);
@@ -979,7 +932,7 @@ extern P7_ALIDISPLAY *p7_alidisplay_Create(const P7_TRACE *tr, int which, const
 extern void           p7_alidisplay_Destroy(P7_ALIDISPLAY *ad);
 extern char           p7_alidisplay_EncodePostProb(float p);
 extern float          p7_alidisplay_DecodePostProb(char pc);
-//extern int            p7_alidisplay_Print(FILE *fp, P7_ALIDISPLAY *ad, int min_aliwidth, int linewidth);
+extern int            p7_alidisplay_Print(FILE *fp, P7_ALIDISPLAY *ad, int min_aliwidth, int linewidth, int show_accessions);
 extern int            p7_alidisplay_Backconvert(const P7_ALIDISPLAY *ad, const ESL_ALPHABET *abc, ESL_SQ **ret_sq, P7_TRACE **ret_tr);
 
 /* p7_bg.c */
@@ -987,7 +940,7 @@ extern int            p7_alidisplay_Backconvert(const P7_ALIDISPLAY *ad, const E
 extern P7_BG *p7_bg_Create(const ESL_ALPHABET *abc);
 
 extern P7_BG *p7_bg_CreateUniform(const ESL_ALPHABET *abc);
-//extern int    p7_bg_Dump(FILE *ofp, const P7_BG *bg);
+extern int    p7_bg_Dump(FILE *ofp, const P7_BG *bg);
 extern void   p7_bg_Destroy(P7_BG *bg);
 extern int    p7_bg_SetLength(P7_BG *bg, int L);
 extern int    p7_bg_NullOne(const P7_BG *bg, const ESL_DSQ *dsq, int L, float *ret_sc);
@@ -1008,10 +961,10 @@ extern int p7_SingleBuilder(P7_BUILDER *bld, ESL_SQ *sq,   P7_BG *bg, P7_HMM **o
 extern P7_DOMAINDEF *p7_domaindef_Create (ESL_RANDOMNESS *r);
 extern int           p7_domaindef_Fetch  (P7_DOMAINDEF *ddef, int which, int *opt_i, int *opt_j, float *opt_sc, P7_ALIDISPLAY **opt_ad);
 extern int           p7_domaindef_Reuse  (P7_DOMAINDEF *ddef);
-//extern int           p7_domaindef_DumpPosteriors(FILE *ofp, P7_DOMAINDEF *ddef);
+extern int           p7_domaindef_DumpPosteriors(FILE *ofp, P7_DOMAINDEF *ddef);
 extern void          p7_domaindef_Destroy(P7_DOMAINDEF *ddef);
 
-//extern int p7_domaindef_ByViterbi            (P7_PROFILE *gm, const ESL_SQ *sq, P7_GMX *gx1, P7_GMX *gx2, P7_DOMAINDEF *ddef);
+extern int p7_domaindef_ByViterbi            (P7_PROFILE *gm, const ESL_SQ *sq, P7_GMX *gx1, P7_GMX *gx2, P7_DOMAINDEF *ddef);
 extern int p7_domaindef_ByPosteriorHeuristics(const ESL_SQ *sq, P7_OPROFILE *om, P7_OMX *oxf, P7_OMX *oxb,
                                               P7_OMX *fwd, P7_OMX *bck, P7_DOMAINDEF *ddef, int percentBorder, GB2::TaskStateInfo & ti );
 
@@ -1019,17 +972,22 @@ extern int p7_domaindef_ByPosteriorHeuristics(const ESL_SQ *sq, P7_OPROFILE *om,
 /* p7_gmx.c */
 extern P7_GMX *p7_gmx_Create(int allocM, int allocL);
 extern int     p7_gmx_GrowTo(P7_GMX *gx, int allocM, int allocL);
+extern int     p7_gmx_Reuse(P7_GMX *gx);
 extern void    p7_gmx_Destroy(P7_GMX *gx);
 extern int     p7_gmx_Compare(P7_GMX *gx1, P7_GMX *gx2, float tolerance);
-//extern int     p7_gmx_Dump(FILE *fp, P7_GMX *gx);
-//extern int     p7_gmx_DumpWindow(FILE *fp, P7_GMX *gx, int istart, int iend, int kstart, int kend, int show_specials);
+extern int     p7_gmx_Dump(FILE *fp, P7_GMX *gx);
+extern int     p7_gmx_DumpWindow(FILE *fp, P7_GMX *gx, int istart, int iend, int kstart, int kend, int show_specials);
 
 
 /* p7_hmm.c */
 /*      1. The P7_HMM object: allocation, initialization, destruction. */
+// CODE CHANGED: hmm creation changed
 extern P7_HMM *p7_hmm_Create(int M, const ESL_ALPHABET *abc);
+extern P7_HMM *p7_hmm_Create(int M, int alType, int flags );
 extern P7_HMM *p7_hmm_CreateShell(void);
-extern int     p7_hmm_CreateBody(P7_HMM *hmm, int M, const ESL_ALPHABET *abc);
+//extern int     p7_hmm_CreateBody(P7_HMM *hmm, int M, const ESL_ALPHABET *abc);
+extern int     p7_hmm_CreateBody(P7_HMM *hmm, int M, int alType );
+
 extern void    p7_hmm_Destroy(P7_HMM *hmm);
 extern int     p7_hmm_CopyParameters(const P7_HMM *src, P7_HMM *dest);
 extern P7_HMM *p7_hmm_Clone(const P7_HMM *hmm);
@@ -1048,7 +1006,7 @@ extern int     p7_hmm_SetComposition(P7_HMM *hmm);
 extern int     p7_hmm_Rescale(P7_HMM *hmm, float scale);
 extern int     p7_hmm_Renormalize(P7_HMM *hmm);
 /*      4. Debugging and development code. */
-//extern int     p7_hmm_Dump(FILE *fp, P7_HMM *hmm);
+extern int     p7_hmm_Dump(FILE *fp, P7_HMM *hmm);
 extern int     p7_hmm_Sample          (ESL_RANDOMNESS *r, int M, const ESL_ALPHABET *abc, P7_HMM **ret_hmm);
 extern int     p7_hmm_SampleUngapped  (ESL_RANDOMNESS *r, int M, const ESL_ALPHABET *abc, P7_HMM **ret_hmm);
 extern int     p7_hmm_SampleEnumerable(ESL_RANDOMNESS *r, int M, const ESL_ALPHABET *abc, P7_HMM **ret_hmm);
@@ -1061,31 +1019,25 @@ extern int     p7_hmm_CalculateOccupancy(const P7_HMM *hmm, float *mocc, float *
 
 
 /* p7_hmmfile.c */
-//extern int  p7_hmmfile_Open(char *filename, char *env, P7_HMMFILE **ret_hfp);
-//extern void p7_hmmfile_Close(P7_HMMFILE *hfp);
-//extern int  p7_hmmfile_WriteBinary(FILE *fp, P7_HMM *hmm);
-//extern int  p7_hmmfile_WriteASCII (FILE *fp, P7_HMM *hmm);
-//extern int  p7_hmmfile_Read(P7_HMMFILE *hfp, ESL_ALPHABET **ret_abc,  P7_HMM **opt_hmm);
-//extern int  p7_hmmfile_PositionByKey(P7_HMMFILE *hfp, const char *key);
+// we don't need hmmfile functions
 
 /* p7_pipeline.c */
-//extern P7_PIPELINE *p7_pipeline_Create(ESL_GETOPTS *go, int M_hint, int L_hint, enum p7_pipemodes_e mode);
 extern P7_PIPELINE* p7_pipeline_Create( const UHMM3SearchSettings* settings, int M_hint, int L_hint, enum p7_pipemodes_e mode );
 extern int          p7_pipeline_Reuse  (P7_PIPELINE *pli);
 extern void         p7_pipeline_Destroy(P7_PIPELINE *pli);
-//extern void         p7_pipeline_Dump( FILE* out, P7_PIPELINE* pli );
+extern int          p7_pipeline_Merge  (P7_PIPELINE *p1, P7_PIPELINE *p2);
 
+// ! CODE CHANGED: reporting by double values !
 extern int p7_pli_TargetReportable(P7_PIPELINE *pli, float score,     double Pval);
 extern int p7_pli_DomainReportable(P7_PIPELINE *pli, float dom_score, double Pval);
 extern int p7_pli_TargetIncludable(P7_PIPELINE *pli, float score,     double Pval);
 extern int p7_pli_DomainIncludable(P7_PIPELINE *pli, float dom_score, double Pval);
 extern int p7_pli_NewModel        (P7_PIPELINE *pli, const P7_OPROFILE *om, P7_BG *bg);
+extern int p7_pli_NewModelThresholds(P7_PIPELINE *pli, const P7_OPROFILE *om);
 extern int p7_pli_NewSeq          (P7_PIPELINE *pli, const ESL_SQ *sq);
 extern int p7_Pipeline            (P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_TOPHITS *th, int percentPerFilters,
                                    GB2::TaskStateInfo & ti );
 
-//extern int p7_pli_Statistics(FILE *ofp, P7_PIPELINE *pli, ESL_STOPWATCH *w);
-
 
 /* p7_prior.c */
 extern P7_PRIOR  *p7_prior_CreateAmino(void);
@@ -1137,13 +1089,18 @@ extern int         p7_tophits_Add(P7_TOPHITS *h,
 extern int         p7_tophits_Sort(P7_TOPHITS *h);
 extern int         p7_tophits_Merge(P7_TOPHITS *h1, P7_TOPHITS *h2);
 extern int         p7_tophits_GetMaxNameLength(P7_TOPHITS *h);
+extern int         p7_tophits_GetMaxAccessionLength(P7_TOPHITS *h);
+extern int         p7_tophits_GetMaxShownLength(P7_TOPHITS *h);
 extern void        p7_tophits_Destroy(P7_TOPHITS *h);
 
 extern int p7_tophits_Threshold(P7_TOPHITS *th, P7_PIPELINE *pli);
-//extern int p7_tophits_CompareRanking(P7_TOPHITS *th, ESL_KEYHASH *kh, int *opt_nnew);
+extern int p7_tophits_CompareRanking(P7_TOPHITS *th, ESL_KEYHASH *kh, int *opt_nnew);
+extern int p7_tophits_Targets(FILE *ofp, P7_TOPHITS *th, P7_PIPELINE *pli, int textw);
+extern int p7_tophits_Domains(FILE *ofp, P7_TOPHITS *th, P7_PIPELINE *pli, int textw);
 extern int p7_tophits_Alignment(const P7_TOPHITS *th, const ESL_ALPHABET *abc, 
                                 ESL_SQ **inc_sqarr, P7_TRACE **inc_trarr, int inc_n, int optflags,
                                 ESL_MSA **ret_msa);
+// removed unused definitions
 
 
 /* p7_trace.c */
@@ -1163,8 +1120,8 @@ extern int  p7_trace_GetDomainCoords  (const P7_TRACE *tr, int which, int *ret_i
                                        int *ret_k1, int *ret_k2);
 
 extern int   p7_trace_Validate(const P7_TRACE *tr, const ESL_ALPHABET *abc, const ESL_DSQ *dsq, char *errbuf);
-//extern int   p7_trace_Dump(FILE *fp, const P7_TRACE *tr, const P7_PROFILE *gm, const ESL_DSQ *dsq);
-//extern int   p7_trace_Compare(P7_TRACE *tr1, P7_TRACE *tr2, float pptol);
+extern int   p7_trace_Dump(FILE *fp, const P7_TRACE *tr, const P7_PROFILE *gm, const ESL_DSQ *dsq);
+extern int   p7_trace_Compare(P7_TRACE *tr1, P7_TRACE *tr2, float pptol);
 extern int   p7_trace_Score(P7_TRACE *tr, ESL_DSQ *dsq, P7_PROFILE *gm, float *ret_sc);
 extern int   p7_trace_SetPP(P7_TRACE *tr, const P7_GMX *pp);
 extern float p7_trace_GetExpectedAccuracy(const P7_TRACE *tr);
@@ -1193,7 +1150,7 @@ extern int p7_Seqmodel(const ESL_ALPHABET *abc, ESL_DSQ *dsq, int M, char *name,
 
 /************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
