@@ -12,7 +12,7 @@
 * routines: structures, declarations, and macros.
 * 
 * SRE, Sun Nov 25 11:23:02 2007
-* SVN $Id: impl_sse.h 2794 2009-04-29 13:05:07Z eddys $
+ * SVN $Id: impl_sse.h 3018 2009-10-29 17:33:06Z farrarm $
 */
 #ifndef P7_IMPL_SSE_INCLUDED
 #define P7_IMPL_SSE_INCLUDED
@@ -84,7 +84,7 @@ enum p7o_tsc_e          { p7O_BM   = 0, p7O_MM   = 1,  p7O_IM = 2,  p7O_DM = 3,
 
 typedef struct p7_oprofile_s {
     /* MSVFilter uses scaled, biased uchars: 16x unsigned byte vectors                 */
-    __m128i **rb;     		/* match scores [x][q]: rm, rm[0] are allocated      */
+  __m128i **rbv;     		/* match scores [x][q]: rm, rm[0] are allocated      */
     uint8_t   tbm_b;		/* constant B->Mk cost:    scaled log 2/M(M+1)       */
     uint8_t   tec_b;		/* constant E->C  cost:    scaled log 0.5            */
     uint8_t   tjb_b;		/* constant NCJ move cost: scaled log 3/(L+3)        */
@@ -93,8 +93,8 @@ typedef struct p7_oprofile_s {
     uint8_t   bias_b;		/* positive bias to emission scores, make them >=0   */
 
     /* ViterbiFilter uses scaled swords: 8x signed 16-bit integer vectors              */
-    __m128i **rw;			/* [x][q]: rw, rw[0] are allocated  [Kp][Q8]         */
-    __m128i  *tw;			/* transition score blocks          [8*Q8]           */ 
+  __m128i **rwv;		/* [x][q]: rw, rw[0] are allocated  [Kp][Q8]         */
+  __m128i  *twv;		/* transition score blocks          [8*Q8]           */ 
     int16_t   xw[p7O_NXSTATES][p7O_NXTRANS]; /* NECJ state transition costs            */
     float     scale_w;            /* score units: typically 500 / log(2), 1/500 bits   */
     int16_t   base_w;             /* offset of sword scores: typically +12000          */
@@ -102,25 +102,29 @@ typedef struct p7_oprofile_s {
     float     ncj_roundoff;	/* missing precision on NN,CC,JJ after rounding      */
 
     /* Forward, Backward use IEEE754 single-precision floats: 4x vectors               */
-    __m128 **rf;     		/* [x][q]:  rf, rf[0] are allocated [Kp][Q4]         */
-    __m128  *tf;	    		/* transition probability blocks    [8*Q4]     */
+  __m128 **rfv;     		/* [x][q]:  rf, rf[0] are allocated [Kp][Q4]         */
+  __m128  *tfv;	    		/* transition probability blocks    [8*Q4]           */
     float    xf[p7O_NXSTATES][p7O_NXTRANS]; /* NECJ transition costs                   */
 
     /* Our actual vector mallocs, before we align the memory                     */
-    __m128i  *rb_mem;
-    __m128i  *rw_mem;
-    __m128i  *tw_mem;
-    __m128   *tf_mem;
-    __m128   *rf_mem;
+  __m128i  *rbv_mem;
+  __m128i  *rwv_mem;
+  __m128i  *twv_mem;
+  __m128   *tfv_mem;
+  __m128   *rfv_mem;
 
     /* Disk offset information for hmmpfam's fast model retrieval                */
     off_t  offs[p7_NOFFSETS];     /* p7_{MFP}OFFSET, or -1                       */
 
+  /* Disk offset bookkeeping for h3f:                                                */
+  off_t  roff;                  /* record offset (start of record); -1 if none       */
+  off_t  eoff;                  /* offset to last byte of record; -1 if unknown      */
+
     /* Information, annotation copied from parent profile:                             */
     char  *name;			/* unique name of model                            */
     char  *acc;			/* unique accession of model, or NULL              */
     char  *desc;                  /* brief (1-line) description of model, or NULL    */
-    char  *ref;                   /* reference line           1..M; *ref=0: unused   */
+  char  *rf;                    /* reference line           1..M; *ref=0: unused     */
     char  *cs;                    /* consensus structure line 1..M, *cs=0: unused    */
     char  *consensus;		/* consensus residues for ali display, 1..M        */
     float  evparam[p7_NEVPARAM]; 	/* parameters for determining E-values, or UNSET   */
@@ -137,8 +141,17 @@ typedef struct p7_oprofile_s {
     int    allocQ16;		/* p7_NQB(allocM): alloc size for rb                 */
     int    mode;			/* currently must be p7_LOCAL                        */
     float  nj;			/* expected # of J's: 0 or 1, uni vs. multihit     */
+
+  int    clone;                 /* this optimized profile structure is just a copy   */
+                                /* of another profile structre.  all pointers of     */
+                                /* this structure should not be freed.               */
 } P7_OPROFILE;
 
+typedef struct {
+  int            count;       /* number of <P7_OPROFILE> objects in the block */
+  int            listSize;    /* maximum number elements in the list          */
+  P7_OPROFILE  **list;        /* array of <P7_OPROFILE> objects               */
+} P7_OM_BLOCK;
 
 /* retrieve match odds ratio [k][x]
 * this gets used in p7_alidisplay.c, when we're deciding if a residue is conserved or not */
@@ -149,7 +162,7 @@ p7_oprofile_FGetEmission(const P7_OPROFILE *om, int k, int x)
     int   Q = p7O_NQF(om->M);
     int   q = ((k-1) % Q);
     int   r = (k-1)/Q;
-    u.v = om->rf[x][q];
+  u.v = om->rfv[x][q];
     return u.p[r];
 }
 
@@ -264,6 +277,8 @@ extern int          p7_omx_DumpFBRow(P7_OMX *ox, int logify, int rowi, int width
 extern P7_OPROFILE *p7_oprofile_Create(int M, const ESL_ALPHABET *abc);
 extern int          p7_oprofile_IsLocal(const P7_OPROFILE *om);
 extern void         p7_oprofile_Destroy(P7_OPROFILE *om);
+extern P7_OPROFILE *p7_oprofile_Copy(P7_OPROFILE *om);
+extern P7_OPROFILE *p7_oprofile_Clone(const P7_OPROFILE *om);
 
 extern int          p7_oprofile_Convert(const P7_PROFILE *gm, P7_OPROFILE *om);
 extern int          p7_oprofile_ReconfigLength    (P7_OPROFILE *om, int L);
@@ -286,6 +301,7 @@ extern int p7_Decoding      (const P7_OPROFILE *om, const P7_OMX *oxf,       P7_
 extern int p7_DomainDecoding(const P7_OPROFILE *om, const P7_OMX *oxf, const P7_OMX *oxb, P7_DOMAINDEF *ddef);
 
 /* fwdback.c */
+// ! ADDED PERCENTS and TASKSTATEINFO !
 extern int p7_Forward       (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *fwd, float *opt_sc,
                              int percentBorder, GB2::TaskStateInfo & ti);
 extern int p7_ForwardParser (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *fwd, float *opt_sc,
@@ -295,10 +311,7 @@ extern int p7_Backward      (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, c
 extern int p7_BackwardParser(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, const P7_OMX *fwd, P7_OMX *bck, float *opt_sc,
                              int percentBorder, GB2::TaskStateInfo & ti );
 
-/* io.c */
-//extern int p7_oprofile_Write(FILE *ffp, FILE *pfp, P7_OPROFILE *om);
-//extern int p7_oprofile_ReadMSV (P7_HMMFILE *hfp, ESL_ALPHABET **ret_abc, P7_OPROFILE **ret_om);
-//extern int p7_oprofile_ReadRest(P7_HMMFILE *hfp, P7_OPROFILE *om);
+// here were definitions of io functions. we don't need them
 
 
 /* msvfilter.c */
@@ -320,14 +333,14 @@ extern int p7_StochasticTrace(ESL_RANDOMNESS *rng, const ESL_DSQ *dsq, int L, co
 extern int p7_ViterbiFilter(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc, int percentBorder, GB2::TaskStateInfo & ti);
 
 /* vitscore.c */
-//extern int p7_ViterbiScore (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc);
+extern int p7_ViterbiScore (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc);
 
 
 #endif /* P7_IMPL_SSE_INCLUDED */
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
