@@ -109,7 +109,7 @@ p7_omx_Create(int allocM, int allocL, int allocXL)
     }
 
     ox->allocXR = allocXL+1;
-    ESL_ALLOC(ox->x_mem,  sizeof(float) * ox->allocXR * p7X_NXCELLS + 15); 
+    ESL_ALLOC_WITH_TYPE(ox->x_mem, void*,  sizeof(float) * ox->allocXR * p7X_NXCELLS + 15); 
     ox->xmx = (float *) ( ( (unsigned long int) ((char *) ox->x_mem  + 15) & (~0xf)));
 
     ox->M              = 0;
@@ -166,7 +166,7 @@ p7_omx_GrowTo(P7_OMX *ox, int allocM, int allocL, int allocXL)
     */
     if (ncells > ox->ncells)
     {
-        ESL_RALLOC(ox->dp_mem, p, sizeof(__m128) * (allocL+1) * nqf * p7X_NSCELLS + 15);
+        ESL_RALLOC_WITH_TYPE(ox->dp_mem, void*, p, sizeof(__m128) * (allocL+1) * nqf * p7X_NSCELLS + 15);
         ox->ncells = ncells;
         reset_row_pointers = TRUE;
     }
@@ -174,7 +174,7 @@ p7_omx_GrowTo(P7_OMX *ox, int allocM, int allocL, int allocXL)
     /* If the X beams are too small, reallocate them. */
     if (allocXL+1 >= ox->allocXR)
     {
-        ESL_RALLOC(ox->x_mem, p,  sizeof(float) * (allocXL+1) * p7X_NXCELLS + 15); 
+        ESL_RALLOC_WITH_TYPE(ox->x_mem, void*, p,  sizeof(float) * (allocXL+1) * p7X_NXCELLS + 15); 
         ox->allocXR = allocXL+1;
         ox->xmx     = (float *) ( ( (unsigned long int) ((char *) ox->x_mem  + 15) & (~0xf)));
     }
@@ -633,7 +633,7 @@ ERROR:
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
