@@ -22,7 +22,7 @@
 *   8. Copyright and license information.
 *   
 * SRE, Wed Jul 30 11:00:04 2008 [Janelia]
-* SVN $Id: p7_oprofile.c 2832 2009-06-18 13:01:14Z eddys $
+ * SVN $Id: p7_oprofile.c 3018 2009-10-29 17:33:06Z farrarm $
 */
 #include <hmmer3/p7_config.h>
 
@@ -66,40 +66,41 @@ p7_oprofile_Create(int allocM, const ESL_ALPHABET *abc)
 
     /* level 0 */
     ESL_ALLOC_WITH_TYPE(om, P7_OPROFILE*, sizeof(P7_OPROFILE));
-    om->rb_mem = NULL;
-    om->rw_mem = NULL;
-    om->tw_mem = NULL;
-    om->rf_mem = NULL;
-    om->tf_mem = NULL;
-    om->rb     = NULL;
-    om->rw     = NULL;
-    om->tw     = NULL;
-    om->rf     = NULL;
-    om->tf     = NULL;
+    om->rbv_mem = NULL;
+    om->rwv_mem = NULL;
+    om->twv_mem = NULL;
+    om->rfv_mem = NULL;
+    om->tfv_mem = NULL;
+    om->rbv     = NULL;
+    om->rwv     = NULL;
+    om->twv     = NULL;
+    om->rfv     = NULL;
+    om->tfv     = NULL;
+  om->clone   = 0;
 
     /* level 1 */
-    ESL_ALLOC_WITH_TYPE(om->rb_mem, __m128i*, sizeof(__m128i) * nqb  * abc->Kp          +15);	/* +15 is for manual 16-byte alignment */
-    ESL_ALLOC_WITH_TYPE(om->rw_mem, __m128i*, sizeof(__m128i) * nqw  * abc->Kp          +15);                     
-    ESL_ALLOC_WITH_TYPE(om->tw_mem,__m128i*,  sizeof(__m128i) * nqw  * p7O_NTRANS       +15);   
-    ESL_ALLOC_WITH_TYPE(om->rf_mem,__m128*,   sizeof(__m128)  * nqf  * abc->Kp          +15);                     
-    ESL_ALLOC_WITH_TYPE(om->tf_mem,__m128*,   sizeof(__m128)  * nqf  * p7O_NTRANS       +15);    
+    ESL_ALLOC_WITH_TYPE(om->rbv_mem, __m128i*, sizeof(__m128i) * nqb  * abc->Kp          +15);	/* +15 is for manual 16-byte alignment */
+    ESL_ALLOC_WITH_TYPE(om->rwv_mem, __m128i*, sizeof(__m128i) * nqw  * abc->Kp          +15);                     
+    ESL_ALLOC_WITH_TYPE(om->twv_mem,__m128i*,  sizeof(__m128i) * nqw  * p7O_NTRANS       +15);   
+    ESL_ALLOC_WITH_TYPE(om->rfv_mem,__m128*,   sizeof(__m128)  * nqf  * abc->Kp          +15);                     
+    ESL_ALLOC_WITH_TYPE(om->tfv_mem,__m128*,   sizeof(__m128)  * nqf  * p7O_NTRANS       +15);    
 
-    ESL_ALLOC_WITH_TYPE(om->rb, __m128i**, sizeof(__m128i *) * abc->Kp); 
-    ESL_ALLOC_WITH_TYPE(om->rw, __m128i**, sizeof(__m128i *) * abc->Kp); 
-    ESL_ALLOC_WITH_TYPE(om->rf, __m128**,  sizeof(__m128  *) * abc->Kp); 
+    ESL_ALLOC_WITH_TYPE(om->rbv, __m128i**, sizeof(__m128i *) * abc->Kp); 
+    ESL_ALLOC_WITH_TYPE(om->rwv, __m128i**, sizeof(__m128i *) * abc->Kp); 
+    ESL_ALLOC_WITH_TYPE(om->rfv, __m128**,  sizeof(__m128  *) * abc->Kp); 
 
     /* align vector memory on 16-byte boundaries */
-    om->rb[0] = (__m128i *) (((unsigned long int) om->rb_mem + 15) & (~0xf));
-    om->rw[0] = (__m128i *) (((unsigned long int) om->rw_mem + 15) & (~0xf));
-    om->tw    = (__m128i *) (((unsigned long int) om->tw_mem + 15) & (~0xf));
-    om->rf[0] = (__m128  *) (((unsigned long int) om->rf_mem + 15) & (~0xf));
-    om->tf    = (__m128  *) (((unsigned long int) om->tf_mem + 15) & (~0xf));
+  om->rbv[0] = (__m128i *) (((unsigned long int) om->rbv_mem + 15) & (~0xf));
+  om->rwv[0] = (__m128i *) (((unsigned long int) om->rwv_mem + 15) & (~0xf));
+  om->twv    = (__m128i *) (((unsigned long int) om->twv_mem + 15) & (~0xf));
+  om->rfv[0] = (__m128  *) (((unsigned long int) om->rfv_mem + 15) & (~0xf));
+  om->tfv    = (__m128  *) (((unsigned long int) om->tfv_mem + 15) & (~0xf));
 
     /* set the rest of the row pointers for match emissions */
     for (x = 1; x < abc->Kp; x++) {
-        om->rb[x] = om->rb[0] + (x * nqb);
-        om->rw[x] = om->rw[0] + (x * nqw);
-        om->rf[x] = om->rf[0] + (x * nqf);
+    om->rbv[x] = om->rbv[0] + (x * nqb);
+    om->rwv[x] = om->rwv[0] + (x * nqw);
+    om->rfv[x] = om->rfv[0] + (x * nqf);
     }
     om->allocQ16  = nqb;
     om->allocQ8   = nqw;
@@ -132,10 +133,10 @@ p7_oprofile_Create(int allocM, const ESL_ALPHABET *abc)
     * we initialize all this memory to zeros to shut valgrind up about 
     * fwrite'ing uninitialized memory in the io functions.
     */
-    ESL_ALLOC_WITH_TYPE(om->ref, char*,         sizeof(char) * (allocM+2)); 
+    ESL_ALLOC_WITH_TYPE(om->rf, char*,         sizeof(char) * (allocM+2)); 
     ESL_ALLOC_WITH_TYPE(om->cs, char*,         sizeof(char) * (allocM+2));
     ESL_ALLOC_WITH_TYPE(om->consensus, char*,   sizeof(char) * (allocM+2));
-    memset(om->ref,      '\0', sizeof(char) * (allocM+2));
+    memset(om->rf,      '\0', sizeof(char) * (allocM+2));
     memset(om->cs,       '\0', sizeof(char) * (allocM+2));
     memset(om->consensus,'\0', sizeof(char) * (allocM+2));
 
@@ -174,22 +175,187 @@ p7_oprofile_Destroy(P7_OPROFILE *om)
 {
     if (om == NULL) return;
 
-    if (om->rb_mem    != NULL) free(om->rb_mem);
-    if (om->rw_mem    != NULL) free(om->rw_mem);
-    if (om->tw_mem    != NULL) free(om->tw_mem);
-    if (om->rf_mem    != NULL) free(om->rf_mem);
-    if (om->tf_mem    != NULL) free(om->tf_mem);
-    if (om->rb        != NULL) free(om->rb);
-    if (om->rw        != NULL) free(om->rw);
-    if (om->rf        != NULL) free(om->rf);
+  if (om->clone == 0)
+    {
+      if (om->rbv_mem   != NULL) free(om->rbv_mem);
+      if (om->rwv_mem   != NULL) free(om->rwv_mem);
+      if (om->twv_mem   != NULL) free(om->twv_mem);
+      if (om->rfv_mem   != NULL) free(om->rfv_mem);
+      if (om->tfv_mem   != NULL) free(om->tfv_mem);
+      if (om->rbv       != NULL) free(om->rbv);
+      if (om->rwv       != NULL) free(om->rwv);
+      if (om->rfv       != NULL) free(om->rfv);
     if (om->name      != NULL) free(om->name);
     if (om->acc       != NULL) free(om->acc);
     if (om->desc      != NULL) free(om->desc);
-    if (om->ref       != NULL) free(om->ref);
+      if (om->rf        != NULL) free(om->rf);
     if (om->cs        != NULL) free(om->cs);
     if (om->consensus != NULL) free(om->consensus);
+    }
+
     free(om);
 }
+
+/* Function:  p7_oprofile_Copy()
+ * Synopsis:  Allocate an optimized profile structure.
+ * Incept:    SRE, Sun Nov 25 12:03:19 2007 [Casa de Gatos]
+ *
+ * Purpose:   Allocate for profiles of up to <allocM> nodes for digital alphabet <abc>.
+ *
+ * Throws:    <NULL> on allocation error.
+ */
+P7_OPROFILE *
+p7_oprofile_Copy(P7_OPROFILE *om1)
+{
+  int           x, y;
+  int           status;
+
+  int           nqb  = p7O_NQB(om1->allocM); /* # of uchar vectors needed for query */
+  int           nqw  = p7O_NQW(om1->allocM); /* # of sword vectors needed for query */
+  int           nqf  = p7O_NQF(om1->allocM); /* # of float vectors needed for query */
+
+  size_t        size = sizeof(char) * (om1->allocM+2);
+
+  P7_OPROFILE  *om2  = NULL;
+  
+  const ESL_ALPHABET *abc = om1->abc;
+
+  /* level 0 */
+  ESL_ALLOC_WITH_TYPE(om2, P7_OPROFILE*, sizeof(P7_OPROFILE));
+  om2->rbv_mem = NULL;
+  om2->rwv_mem = NULL;
+  om2->twv_mem = NULL;
+  om2->rfv_mem = NULL;
+  om2->tfv_mem = NULL;
+  om2->rbv     = NULL;
+  om2->rwv     = NULL;
+  om2->twv     = NULL;
+  om2->rfv     = NULL;
+  om2->tfv     = NULL;
+
+  /* level 1 */
+  ESL_ALLOC_WITH_TYPE(om2->rbv_mem, __m128i*, sizeof(__m128i) * nqb  * abc->Kp    +15);	/* +15 is for manual 16-byte alignment */
+  ESL_ALLOC_WITH_TYPE(om2->rwv_mem, __m128i*, sizeof(__m128i) * nqw  * abc->Kp    +15);                     
+  ESL_ALLOC_WITH_TYPE(om2->twv_mem, __m128i*, sizeof(__m128i) * nqw  * p7O_NTRANS +15);   
+  ESL_ALLOC_WITH_TYPE(om2->rfv_mem, __m128*,  sizeof(__m128)  * nqf  * abc->Kp    +15);                     
+  ESL_ALLOC_WITH_TYPE(om2->tfv_mem, __m128*,  sizeof(__m128)  * nqf  * p7O_NTRANS +15);    
+
+  ESL_ALLOC_WITH_TYPE(om2->rbv, __m128i**,  sizeof(__m128i *) * abc->Kp); 
+  ESL_ALLOC_WITH_TYPE(om2->rwv, __m128i**,  sizeof(__m128i *) * abc->Kp); 
+  ESL_ALLOC_WITH_TYPE(om2->rfv, __m128**,   sizeof(__m128  *) * abc->Kp); 
+
+  /* align vector memory on 16-byte boundaries */
+  om2->rbv[0] = (__m128i *) (((unsigned long int) om2->rbv_mem + 15) & (~0xf));
+  om2->rwv[0] = (__m128i *) (((unsigned long int) om2->rwv_mem + 15) & (~0xf));
+  om2->twv    = (__m128i *) (((unsigned long int) om2->twv_mem + 15) & (~0xf));
+  om2->rfv[0] = (__m128  *) (((unsigned long int) om2->rfv_mem + 15) & (~0xf));
+  om2->tfv    = (__m128  *) (((unsigned long int) om2->tfv_mem + 15) & (~0xf));
+
+  /* copy the vector data */
+  memcpy(om2->rbv[0], om1->rbv[0], sizeof(__m128i) * nqb  * abc->Kp);
+  memcpy(om2->rwv[0], om1->rwv[0], sizeof(__m128i) * nqw  * abc->Kp);
+  memcpy(om2->rfv[0], om1->rfv[0], sizeof(__m128i) * nqf  * abc->Kp);
+
+  /* set the rest of the row pointers for match emissions */
+  for (x = 1; x < abc->Kp; x++) {
+    om2->rbv[x] = om2->rbv[0] + (x * nqb);
+    om2->rwv[x] = om2->rwv[0] + (x * nqw);
+    om2->rfv[x] = om2->rfv[0] + (x * nqf);
+  }
+  om2->allocQ16  = nqb;
+  om2->allocQ8   = nqw;
+  om2->allocQ4   = nqf;
+
+  /* Remaining initializations */
+  om2->tbm_b     = om1->tbm_b;
+  om2->tec_b     = om1->tec_b;
+  om2->tjb_b     = om1->tjb_b;
+  om2->scale_b   = om1->scale_b;
+  om2->base_b    = om1->base_b;
+  om2->bias_b    = om1->bias_b;
+
+  om2->scale_w      = om1->scale_w;
+  om2->base_w       = om1->base_w;
+  om2->ddbound_w    = om1->ddbound_w;
+  om2->ncj_roundoff = om1->ncj_roundoff;	
+
+  for (x = 0; x < p7_NOFFSETS; x++) om2->offs[x]    = om1->offs[x];
+  for (x = 0; x < p7_NEVPARAM; x++) om2->evparam[x] = om1->evparam[x];
+  for (x = 0; x < p7_NCUTOFFS; x++) om2->cutoff[x]  = om1->cutoff[x];
+  for (x = 0; x < p7_MAXABET;  x++) om2->compo[x]   = om1->compo[x];
+
+  for (x = 0; x < nqw  * p7O_NTRANS; ++x) om2->twv[x] = om1->twv[x];
+  for (x = 0; x < nqf  * p7O_NTRANS; ++x) om2->tfv[x] = om1->tfv[x];
+
+  for (x = 0; x < p7O_NXSTATES; x++)
+    for (y = 0; y < p7O_NXTRANS; y++)
+      {
+	om2->xw[x][y] = om1->xw[x][y];
+	om2->xf[x][y] = om1->xf[x][y];
+      }
+
+  if ((status = esl_strdup(om1->name, -1, &om2->name)) != eslOK) goto ERROR;
+  if ((status = esl_strdup(om1->acc,  -1, &om2->acc))  != eslOK) goto ERROR;
+  if ((status = esl_strdup(om1->desc, -1, &om2->desc)) != eslOK) goto ERROR;
+
+  /* in a P7_OPROFILE, we always allocate for the optional RF, CS annotation.  
+   * we only rely on the leading \0 to signal that it's unused, but 
+   * we initialize all this memory to zeros to shut valgrind up about 
+   * fwrite'ing uninitialized memory in the io functions.
+   */
+  ESL_ALLOC_WITH_TYPE(om2->rf, char*,          size); 
+  ESL_ALLOC_WITH_TYPE(om2->cs, char*,          size);
+  ESL_ALLOC_WITH_TYPE(om2->consensus, char*,  size);
+
+  memcpy(om2->rf,        om1->rf,        size);
+  memcpy(om2->cs,        om1->cs,        size);
+  memcpy(om2->consensus, om1->consensus, size);
+
+  om2->abc       = om1->abc;
+  om2->L         = om1->L;
+  om2->M         = om1->M;
+  om2->allocM    = om1->allocM;
+  om2->mode      = om1->mode;
+  om2->nj        = om1->nj;
+
+  om2->clone     = om1->clone;
+
+  return om2;
+
+ ERROR:
+  p7_oprofile_Destroy(om2);
+  return NULL;
+}
+
+/* Function:  p7_oprofile_Clone()
+ * Synopsis:  Allocate a cloned copy of the optimized profile structure.  All
+ *            allocated memory from the original profile is not reallocated.
+ *            The cloned copy will point to the same memory as the original.
+ * Incept:    SRE, Sun Nov 25 12:03:19 2007 [Casa de Gatos]
+ *
+ * Purpose:   Quick copy of an optimized profile used in mutiple threads.
+ *
+ * Throws:    <NULL> on allocation error.
+ */
+P7_OPROFILE *
+p7_oprofile_Clone(const P7_OPROFILE *om1)
+{
+  int           status;
+
+  P7_OPROFILE  *om2  = NULL;
+
+  ESL_ALLOC_WITH_TYPE(om2, P7_OPROFILE*, sizeof(P7_OPROFILE));
+  memcpy(om2, om1, sizeof(P7_OPROFILE));
+
+  om2->clone  = 1;
+
+  return om2;
+
+ ERROR:
+  p7_oprofile_Destroy(om2);
+  return NULL;
+}
+
 /*----------------- end, P7_OPROFILE structure ------------------*/
 
 
@@ -276,15 +442,15 @@ mf_conversion(const P7_PROFILE *gm, P7_OPROFILE *om)
     */
     for (x = 0; x < gm->abc->K; x++)  max = ESL_MAX(max, esl_vec_FMax(gm->rsc[x], (M+1)*2));
     om->scale_b = 3.0 / eslCONST_LOG2;                    /* scores in units of third-bits */
-    om->base_b  = 195;
-    om->bias_b  = -1 * unbiased_byteify(om, max);
+  om->base_b  = 190;
+  om->bias_b  = unbiased_byteify(om, -1.0 * max);
 
     /* striped match costs: start at k=1.  */
     for (x = 0; x < gm->abc->Kp; x++)
         for (q = 0, k = 1; q < nq; q++, k++)
         {
             for (z = 0; z < 16; z++) tmp.i[z] = ((k+ z*nq <= M) ? biased_byteify(om, p7P_MSC(gm, k+z*nq, x)) : 255);
-            om->rb[x][q]   = tmp.v;	
+	om->rbv[x][q]   = tmp.v;	
         }
 
         /* transition costs */
@@ -337,7 +503,7 @@ vf_conversion(const P7_PROFILE *gm, P7_OPROFILE *om)
         for (k = 1, q = 0; q < nq; q++, k++)
         {
             for (z = 0; z < 8; z++) tmp.i[z] = ((k+ z*nq <= M) ? wordify(om, p7P_MSC(gm, k+z*nq, x)) : -32768);
-            om->rw[x][q]   = tmp.v;
+	om->rwv[x][q]   = tmp.v;
         }
 
         /* Transition costs, all but the DD's. */
@@ -359,7 +525,7 @@ vf_conversion(const P7_PROFILE *gm, P7_OPROFILE *om)
                     val      = ((kb+ z*nq < M) ? wordify(om, p7P_TSC(gm, kb+ z*nq, tg)) : -32768);
                     tmp.i[z] = (val <= maxval) ? val : maxval; /* do not allow an II transition cost of 0, or hell may occur. */
                 }
-                om->tw[j++] = tmp.v;
+	  om->twv[j++] = tmp.v;
             }
         }
 
@@ -367,7 +533,7 @@ vf_conversion(const P7_PROFILE *gm, P7_OPROFILE *om)
         for (k = 1, q = 0; q < nq; q++, k++)
         {
             for (z = 0; z < 8; z++) tmp.i[z] = ((k+ z*nq < M) ? wordify(om, p7P_TSC(gm, k+ z*nq, p7P_DD)) : -32768);
-            om->tw[j++] = tmp.v;
+      om->twv[j++] = tmp.v;
         }
 
         /* Specials. (Actually in same order in om and gm, but we copy in general form anyway.)  */
@@ -430,7 +596,7 @@ fb_conversion(const P7_PROFILE *gm, P7_OPROFILE *om)
         for (k = 1, q = 0; q < nq; q++, k++)
         {
             for (z = 0; z < 4; z++) tmp.x[z] = (k+ z*nq <= M) ? p7P_MSC(gm, k+z*nq, x) : -eslINFINITY;
-            om->rf[x][q] = esl_sse_expf(tmp.v);
+	om->rfv[x][q] = esl_sse_expf(tmp.v);
         }
 
         /* Transition scores, all but the DD's. */
@@ -449,7 +615,7 @@ fb_conversion(const P7_PROFILE *gm, P7_OPROFILE *om)
                 }
 
                 for (z = 0; z < 4; z++) tmp.x[z] = (kb+z*nq < M) ? p7P_TSC(gm, kb+z*nq, tg) : -eslINFINITY;
-                om->tf[j++] = esl_sse_expf(tmp.v);
+	  om->tfv[j++] = esl_sse_expf(tmp.v);
             }
         }
 
@@ -457,7 +623,7 @@ fb_conversion(const P7_PROFILE *gm, P7_OPROFILE *om)
         for (k = 1, q = 0; q < nq; q++, k++)
         {
             for (z = 0; z < 4; z++) tmp.x[z] = (k+z*nq < M) ? p7P_TSC(gm, k+z*nq, p7P_DD) : -eslINFINITY;
-            om->tf[j++] = esl_sse_expf(tmp.v);
+      om->tfv[j++] = esl_sse_expf(tmp.v);
         }
 
         /* Specials. (These are actually in exactly the same order in om and
@@ -510,7 +676,7 @@ p7_oprofile_Convert(const P7_PROFILE *gm, P7_OPROFILE *om)
     if ((status = esl_strdup(gm->name, -1, &(om->name))) != eslOK) goto ERROR;
     if ((status = esl_strdup(gm->acc,  -1, &(om->acc)))  != eslOK) goto ERROR;
     if ((status = esl_strdup(gm->desc, -1, &(om->desc))) != eslOK) goto ERROR;
-    strcpy(om->ref,       gm->rf);
+  strcpy(om->rf,        gm->rf);
     strcpy(om->cs,        gm->cs);
     strcpy(om->consensus, gm->consensus);
     for (z = 0; z < p7_NEVPARAM; z++) om->evparam[z] = gm->evparam[z];
@@ -715,7 +881,7 @@ oprofile_dump_mf(FILE *fp, const P7_OPROFILE *om)
         for (q = 0; q < nq; q++)
         {
             fprintf(fp, "[ ");
-            _mm_store_si128(&tmp.v, om->rb[x][q]);
+	  _mm_store_si128(&tmp.v, om->rbv[x][q]);
             for (z = 0; z < 16; z++) fprintf(fp, "%4d ", tmp.i[z]);
             fprintf(fp, "]");
         }
@@ -775,7 +941,7 @@ oprofile_dump_vf(FILE *fp, const P7_OPROFILE *om)
         for (q = 0; q < nq; q++)
         {
             fprintf(fp, "[ ");
-            _mm_store_si128(&tmp.v, om->rw[x][q]);
+	  _mm_store_si128(&tmp.v, om->rwv[x][q]);
             for (z = 0; z < 8; z++) fprintf(fp, "%6d ", tmp.i[z]);
             fprintf(fp, "]");
         }
@@ -817,7 +983,7 @@ oprofile_dump_vf(FILE *fp, const P7_OPROFILE *om)
         for (q = 0; q < nq; q++)
         {
             fprintf(fp, "[ ");
-            _mm_store_si128(&tmp.v, om->tw[q*7 + t]);
+	  _mm_store_si128(&tmp.v, om->twv[q*7 + t]);
             for (z = 0; z < 8; z++) fprintf(fp, "%6d ", tmp.i[z]);
             fprintf(fp, "]");
         }
@@ -838,7 +1004,7 @@ oprofile_dump_vf(FILE *fp, const P7_OPROFILE *om)
     for (j = nq*7, q = 0; q < nq; q++, j++)
     {
         fprintf(fp, "[ ");
-        _mm_store_si128(&tmp.v, om->tw[j]);
+      _mm_store_si128(&tmp.v, om->twv[j]);
         for (z = 0; z < 8; z++) fprintf(fp, "%6d ", tmp.i[z]);
         fprintf(fp, "]");
     }
@@ -895,7 +1061,7 @@ oprofile_dump_fb(FILE *fp, const P7_OPROFILE *om, int width, int precision)
         for (q = 0; q < nq; q++)
         {
             fprintf(fp, "[ ");
-            tmp.v = om->rf[x][q];
+	  tmp.v = om->rfv[x][q];
             for (z = 0; z < 4; z++) fprintf(fp, "%*.*f ", width, precision, tmp.x[z]);
             fprintf(fp, "]");
         }
@@ -935,7 +1101,7 @@ oprofile_dump_fb(FILE *fp, const P7_OPROFILE *om, int width, int precision)
         for (q = 0; q < nq; q++)
         {
             fprintf(fp, "[ ");
-            tmp.v = om->tf[q*7 + t];
+	  tmp.v = om->tfv[q*7 + t];
             for (z = 0; z < 4; z++) fprintf(fp, "%*.*f ", width, precision, tmp.x[z]);
             fprintf(fp, "]");
         }
@@ -956,7 +1122,7 @@ oprofile_dump_fb(FILE *fp, const P7_OPROFILE *om, int width, int precision)
     for (j = nq*7, q = 0; q < nq; q++, j++)
     {
         fprintf(fp, "[ ");
-        tmp.v = om->tf[j];
+      tmp.v = om->tfv[j];
         for (z = 0; z < 4; z++) fprintf(fp, "%*.*f ", width, precision, tmp.x[z]);
         fprintf(fp, "]");
     }
@@ -1093,7 +1259,7 @@ p7_oprofile_Compare(const P7_OPROFILE *om1, const P7_OPROFILE *om2, float tol, c
     int Q16 = p7O_NQB(om1->M);
     int q, r, x, y;
     union { __m128i v; uint8_t c[16]; } a16, b16;
-    union { __m128i v; int16_t w[16]; } a8,  b8;
+  union { __m128i v; int16_t w[8];  } a8,  b8;
     union { __m128  v; float   x[4];  } a4,  b4;
 
     if (om1->mode      != om2->mode)      ESL_FAIL(eslFAIL, errmsg, "comparison failed: mode");
@@ -1106,7 +1272,7 @@ p7_oprofile_Compare(const P7_OPROFILE *om1, const P7_OPROFILE *om2, float tol, c
     for (x = 0; x < om1->abc->Kp; x++)
         for (q = 0; q < Q16; q++)
         {
-            a16.v = om1->rb[x][q]; b16.v = om2->rb[x][q];
+	a16.v = om1->rbv[x][q]; b16.v = om2->rbv[x][q];
             for (r = 0; r < 16; r++) if (a16.c[r] != b16.c[r]) ESL_FAIL(eslFAIL, errmsg, "comparison failed: rb[%d] elem %d", q, r);
         }
         if (om1->tbm_b     != om2->tbm_b)     ESL_FAIL(eslFAIL, errmsg, "comparison failed: tbm_b");
@@ -1120,12 +1286,12 @@ p7_oprofile_Compare(const P7_OPROFILE *om1, const P7_OPROFILE *om2, float tol, c
         for (x = 0; x < om1->abc->Kp; x++)
             for (q = 0; q < Q8; q++)
             {
-                a8.v = om1->rw[x][q]; b8.v = om2->rw[x][q];
+	a8.v = om1->rwv[x][q]; b8.v = om2->rwv[x][q];
                 for (r = 0; r < 8; r++) if (a8.w[r] != b8.w[r]) ESL_FAIL(eslFAIL, errmsg, "comparison failed: rw[%d] elem %d", q, r);
             }
             for (q = 0; q < 8*Q16; q++)
             {
-                a8.v = om1->tw[q]; b8.v = om2->tw[q];
+      a8.v = om1->twv[q]; b8.v = om2->twv[q];
                 for (r = 0; r < 8; r++) if (a8.w[r] != b8.w[r]) ESL_FAIL(eslFAIL, errmsg, "comparison failed: tw[%d] elem %d", q, r);
             }
             for (x = 0; x < p7O_NXSTATES; x++)
@@ -1140,12 +1306,12 @@ p7_oprofile_Compare(const P7_OPROFILE *om1, const P7_OPROFILE *om2, float tol, c
             for (x = 0; x < om1->abc->Kp; x++)
                 for (q = 0; q < Q4; q++)
                 {
-                    a4.v = om1->rf[x][q]; b4.v = om2->rf[x][q];
+	a4.v = om1->rfv[x][q]; b4.v = om2->rfv[x][q];
                     for (r = 0; r < 4; r++) if (esl_FCompare(a4.x[r], b4.x[r], tol) != eslOK)  ESL_FAIL(eslFAIL, errmsg, "comparison failed: rf[%d] elem %d", q, r);
                 }
                 for (q = 0; q < 8*Q4; q++)
                 {
-                    a4.v = om1->tf[q]; b4.v = om2->tf[q];
+      a4.v = om1->tfv[q]; b4.v = om2->tfv[q];
                     for (r = 0; r < 4; r++) if (a4.x[r] != b4.x[r]) ESL_FAIL(eslFAIL, errmsg, "comparison failed: tf[%d] elem %d", q, r);
                 }
                 for (x = 0; x < p7O_NXSTATES; x++)
@@ -1157,7 +1323,7 @@ p7_oprofile_Compare(const P7_OPROFILE *om1, const P7_OPROFILE *om2, float tol, c
                 if (esl_strcmp(om1->name,      om2->name)      != 0) ESL_FAIL(eslFAIL, errmsg, "comparison failed: name");
                 if (esl_strcmp(om1->acc,       om2->acc)       != 0) ESL_FAIL(eslFAIL, errmsg, "comparison failed: acc");
                 if (esl_strcmp(om1->desc,      om2->desc)      != 0) ESL_FAIL(eslFAIL, errmsg, "comparison failed: desc");
-                if (esl_strcmp(om1->ref,       om2->ref)       != 0) ESL_FAIL(eslFAIL, errmsg, "comparison failed: ref");
+   if (esl_strcmp(om1->rf,        om2->rf)        != 0) ESL_FAIL(eslFAIL, errmsg, "comparison failed: ref");
                 if (esl_strcmp(om1->cs,        om2->cs)        != 0) ESL_FAIL(eslFAIL, errmsg, "comparison failed: cs");
                 if (esl_strcmp(om1->consensus, om2->consensus) != 0) ESL_FAIL(eslFAIL, errmsg, "comparison failed: consensus");
 
@@ -1280,168 +1446,11 @@ p7_profile_SameAsVF(const P7_OPROFILE *om, P7_PROFILE *gm)
 
 
 
-/*****************************************************************
-* 4. Benchmark driver.
-*****************************************************************/
-
-#ifdef p7OPROFILE_BENCHMARK
-/* Timing profile conversion.
-gcc -o benchmark-oprofile -std=gnu99 -g -Wall -msse2 -I.. -L.. -I../../easel -L../../easel -Dp7OPROFILE_BENCHMARK\
-p7_oprofile.c -lhmmer -leasel -lm 
-icc -o benchmark-oprofile -O3 -static -I.. -L.. -I../../easel -L../../easel -Dp7OPROFILE_BENCHMARK p7_oprofile.c -lhmmer -leasel -lm 
-./benchmark-sse <hmmfile>         runs benchmark
-*/
-#include "p7_config.h"
-
-#include "easel.h"
-#include "esl_alphabet.h"
-#include "esl_getopts.h"
-#include "esl_random.h"
-#include "esl_stopwatch.h"
-
-#include "hmmer.h"
-#include "impl_sse.h"
-
-static ESL_OPTIONS options[] = {
-    /* name           type      default  env  range toggles reqs incomp  help                                       docgroup*/
-    { "-h",        eslARG_NONE,   FALSE, NULL, NULL,  NULL,  NULL, NULL, "show brief help on version and usage",             0 },
-    { "-L",        eslARG_INT,    "400", NULL, NULL,  NULL,  NULL, NULL, "length of target sequence",                        0 },
-    { "-N",        eslARG_INT, "100000", NULL, NULL,  NULL,  NULL, NULL, "number of conversions to time",                    0 },
-    {  0, 0, 0, 0, 0, 0, 0, 0, 0, 0 },
-};
-static char usage[]  = "[-options] <hmmfile>";
-static char banner[] = "benchmark driver for the generic implementation";
-
-int 
-main(int argc, char **argv)
-{
-    ESL_GETOPTS    *go      = esl_getopts_CreateDefaultApp(options, 1, argc, argv, banner, usage);
-    char           *hmmfile = esl_opt_GetArg(go, 1);
-    ESL_STOPWATCH  *w       = esl_stopwatch_Create();
-    ESL_ALPHABET   *abc     = NULL;
-    P7_HMMFILE     *hfp     = NULL;
-    P7_HMM         *hmm     = NULL;
-    P7_BG          *bg      = NULL;
-    P7_PROFILE     *gm      = NULL;
-    P7_OPROFILE    *om      = NULL;
-    int             L       = esl_opt_GetInteger(go, "-L");
-    int             N       = esl_opt_GetInteger(go, "-N");
-    int             i;
-
-    if (p7_hmmfile_Open(hmmfile, NULL, &hfp) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
-    if (p7_hmmfile_Read(hfp, &abc, &hmm)     != eslOK) p7_Fail("Failed to read HMM");
-
-    bg = p7_bg_Create(abc);
-    p7_bg_SetLength(bg, L);
-    gm = p7_profile_Create(hmm->M, abc);
-    p7_ProfileConfig(hmm, bg, gm, L, p7_LOCAL);
-    om = p7_oprofile_Create(gm->M, abc);
-
-    esl_stopwatch_Start(w);
-    for (i = 0; i < N; i++)
-        p7_oprofile_Convert(gm, om);
-    esl_stopwatch_Stop(w);
-    esl_stopwatch_Display(stdout, w, "# CPU time: ");
-    printf("# M = %d\n", gm->M);
-
-    p7_oprofile_Destroy(om);
-    p7_profile_Destroy(gm);
-    p7_bg_Destroy(bg);
-    p7_hmm_Destroy(hmm);
-    p7_hmmfile_Close(hfp);
-    esl_alphabet_Destroy(abc);
-    esl_stopwatch_Destroy(w);
-    esl_getopts_Destroy(go);
-    return 0;
-}
-#endif /*p7OPROFILE_BENCHMARK*/
-/*---------------- end, benchmark driver ------------------------*/
-
-
-
-
-
-/*****************************************************************
-* 5. Unit tests
-*****************************************************************/
-#ifdef p7OPROFILE_TESTDRIVE
-
-
-#endif /*p7OPROFILE_TESTDRIVE*/
-/*------------------- end, unit tests ---------------------------*/
-
-
-
-
-/*****************************************************************
-* 6. Test driver
-*****************************************************************/
-#ifdef p7OPROFILE_TESTDRIVE
-
-
-#endif /*p7OPROFILE_TESTDRIVE*/
-/*------------------- end, test driver --------------------------*/
-
-
-/*****************************************************************
-* 7. Example
-*****************************************************************/
-#ifdef p7OPROFILE_EXAMPLE
-/* gcc -std=gnu99 -g -Wall -Dp7OPROFILE_EXAMPLE -I.. -I../../easel -L.. -L../../easel -o p7_oprofile_example p7_oprofile.c -lhmmer -leasel -lm
-* ./p7_oprofile_example <hmmfile>
-*/
-#include "p7_config.h"
-#include <stdlib.h>
-#include "easel.h"
-#include "hmmer.h"
-
-int
-main(int argc, char **argv)
-{
-    char         *hmmfile = argv[1];
-    ESL_ALPHABET *abc     = NULL;
-    P7_HMMFILE   *hfp     = NULL;
-    P7_HMM       *hmm     = NULL;
-    P7_BG        *bg      = NULL;
-    P7_PROFILE   *gm      = NULL;
-    P7_OPROFILE  *om      = NULL;
-    int           status;
-
-    status = p7_hmmfile_Open(hmmfile, NULL, &hfp);
-    if      (status == eslENOTFOUND) esl_fatal("Failed to open HMM file %s for reading.\n",                   hmmfile);
-    else if (status == eslEFORMAT)   esl_fatal("File %s does not appear to be in a recognized HMM format.\n", hmmfile);
-    else if (status != eslOK)        esl_fatal("Unexpected error %d in opening HMM file %s.\n",       status, hmmfile);  
-
-    status = p7_hmmfile_Read(hfp, &abc, &hmm);
-    if      (status == eslEFORMAT)   esl_fatal("Bad file format in HMM file %s:\n%s\n",          hfp->fname, hfp->errbuf);
-    else if (status == eslEINCOMPAT) esl_fatal("HMM in %s is not in the expected %s alphabet\n", hfp->fname, esl_abc_DecodeType(abc->type));
-    else if (status == eslEOF)       esl_fatal("Empty HMM file %s? No HMM data found.\n",        hfp->fname);
-    else if (status != eslOK)        esl_fatal("Unexpected error in reading HMMs from %s\n",     hfp->fname);
-
-    bg = p7_bg_Create(abc);
-    gm = p7_profile_Create(hmm->M, abc);   
-    om = p7_oprofile_Create(hmm->M, abc);
-    p7_ProfileConfig(hmm, bg, gm, 400, p7_LOCAL);
-    p7_oprofile_Convert(gm, om);
-
-    p7_oprofile_Dump(stdout, om);
-
-    p7_oprofile_Destroy(om);
-    p7_profile_Destroy(gm);
-    p7_bg_Destroy(bg);
-    p7_hmm_Destroy(hmm);
-    p7_hmmfile_Close(hfp);
-    esl_alphabet_Destroy(abc);
-    return eslOK;
-}
-#endif /*p7OPROFILE_EXAMPLE*/
-/*----------------------- end, example --------------------------*/
-
 
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
