@@ -23,7 +23,7 @@
 * SRE, Mon May  2 10:55:16 2005 [St. Louis]
 * SRE, Fri Jan 12 08:06:33 2007 [Janelia] [Kate Bush, Aerial]
 * SRE, Tue Jul 10 13:19:46 2007 [Janelia] [HHGTTG]
-* SVN $Id: modelconfig.c 2832 2009-06-18 13:01:14Z eddys $
+ * SVN $Id: modelconfig.c 3041 2009-11-12 12:58:09Z eddys $
 */
 #include <hmmer3/p7_config.h>
 
@@ -76,6 +76,11 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     /* Copy some pointer references and other info across from HMM  */
     gm->M      = hmm->M;
     gm->mode   = mode;
+  gm->roff   = -1;
+  gm->eoff   = -1;
+  gm->offs[p7_MOFFSET] = -1;
+  gm->offs[p7_FOFFSET] = -1;
+  gm->offs[p7_POFFSET] = -1;
     if (gm->name != NULL) free(gm->name);
     if (gm->acc  != NULL) free(gm->acc);
     if (gm->desc != NULL) free(gm->desc);
@@ -156,9 +161,8 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     sc[hmm->abc->Kp-2]  = -eslINFINITY; /* nonresidue character */
     sc[hmm->abc->Kp-1]  = -eslINFINITY; /* missing data character */
     for (k = 1; k <= hmm->M; k++) {
-        for (x = 0; x < hmm->abc->K; x++)  {
+    for (x = 0; x < hmm->abc->K; x++) 
             sc[x] = log(hmm->mat[k][x] / bg->f[x]);
-        }
         esl_abc_FExpectScVec(hmm->abc, sc, bg->f); 
         for (x = 0; x < hmm->abc->Kp; x++) {
             rp = gm->rsc[x] + k * p7P_NR;
@@ -563,7 +567,7 @@ p7_ReconfigUnihit(P7_PROFILE *gm, int L)
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
