@@ -14,7 +14,7 @@
 *   1. The P7_ALIDISPLAY object
 * 
 * SRE, Sun Dec 30 09:12:47 2007
-* SVN $Id: p7_alidisplay.c 2818 2009-06-03 12:31:02Z eddys $
+ * SVN $Id: p7_alidisplay.c 3018 2009-10-29 17:33:06Z farrarm $
 */
 
 #include <hmmer3/p7_config.h>
@@ -98,7 +98,7 @@ p7_alidisplay_Create(const P7_TRACE *tr, int which, const P7_OPROFILE *om, const
     * bookkeeping.  
     */
     n = (z2-z1+2) * 3;                     /* model, mline, aseq mandatory         */
-    if (om->ref[0] != 0)    n += z2-z1+2;  /* optional reference line              */
+  if (om->rf[0]  != 0)    n += z2-z1+2;  /* optional reference line              */
     if (om->cs[0]  != 0)    n += z2-z1+2;  /* optional structure line              */
     if (tr->pp     != NULL) n += z2-z1+2;  /* optional posterior prob line         */
     hmm_namelen = strlen(om->name);                           n += hmm_namelen + 1;
@@ -112,8 +112,9 @@ p7_alidisplay_Create(const P7_TRACE *tr, int which, const P7_OPROFILE *om, const
     ad->mem = NULL;
 
     pos = 0; 
-    ESL_ALLOC_WITH_TYPE(ad->mem, char*, sizeof(char) * n);
-    if (om->ref[0] != 0) { ad->rfline = ad->mem + pos; pos += z2-z1+2; } else { ad->rfline = NULL; }
+    ad->memsize = sizeof(char) * n;
+	ESL_ALLOC_WITH_TYPE(ad->mem, char*, sizeof(char) * ad->memsize);
+    if (om->rf[0] != 0) { ad->rfline = ad->mem + pos; pos += z2-z1+2; } else { ad->rfline = NULL; }
     if (om->cs[0]  != 0) { ad->csline = ad->mem + pos; pos += z2-z1+2; } else { ad->csline = NULL; }
     ad->model   = ad->mem + pos;  pos += z2-z1+2;
     ad->mline   = ad->mem + pos;  pos += z2-z1+2;
@@ -143,7 +144,7 @@ p7_alidisplay_Create(const P7_TRACE *tr, int which, const P7_OPROFILE *om, const
 
     /* optional rf line */
     if (ad->rfline != NULL) {
-        for (z = z1; z <= z2; z++) ad->rfline[z-z1] = ((tr->st[z] == p7T_I) ? '.' : om->ref[tr->k[z]]);
+    for (z = z1; z <= z2; z++) ad->rfline[z-z1] = ((tr->st[z] == p7T_I) ? '.' : om->rf[tr->k[z]]);
         ad->rfline[z-z1] = '\0';
     }
 
@@ -274,83 +275,7 @@ p7_alidisplay_DecodePostProb(char pc)
 
 
 
-/* Function:  p7_alidisplay_Print()
-* Synopsis:  Human readable output of <P7_ALIDISPLAY>
-* Incept:    SRE, Thu Jan  3 10:02:05 2008 [Janelia]
-*
-* Purpose:   Prints alignment <ad> to stream <fp>.
-*            
-*            Put at least <min_aliwidth> alignment characters per
-*            line; try to make lines no longer than <linewidth>
-*            characters, including name, coords, and spacing.  The
-*            width of lines may exceed <linewidth>, if that's what it
-*            takes to put a name, coords, and <min_aliwidth>
-*            characters of alignment on a line.
-*            
-*            As a special case, if <linewidth> is negative or 0, then
-*            alignments are formatted in a single block of unlimited
-*            line length.
-*/
-//int
-//p7_alidisplay_Print(FILE *fp, P7_ALIDISPLAY *ad, int min_aliwidth, int linewidth)
-//{
-//  char *buf = NULL;
-//  int   namewidth, coordwidth, aliwidth;
-//  int   pos;
-//  int   status;
-//  int   ni, nk;
-//  int   z;
-//  long  i1,i2;
-//  int   k1,k2;
-//
-//  /* Dynamically determine our field widths on the lines */
-//  namewidth  = ESL_MAX(strlen(ad->hmmname), strlen(ad->sqname));
-//  coordwidth = ESL_MAX(ESL_MAX(integer_textwidth(ad->hmmfrom),
-//			       integer_textwidth(ad->hmmto)),
-//		       ESL_MAX(integer_textwidth(ad->sqfrom),
-//			       integer_textwidth(ad->sqto)));
-//  aliwidth   = (linewidth > 0) ? linewidth - namewidth - 2*coordwidth - 5 : ad->N;
-//  if (aliwidth < ad->N && aliwidth < min_aliwidth) aliwidth = min_aliwidth; /* at least, regardless of some silly linewidth setting */
-//  ESL_ALLOC(buf, sizeof(char) * (aliwidth+1));
-//  buf[aliwidth] = 0;
-//
-//  /* Break the alignment into multiple blocks of width aliwidth for printing */
-//  i1 = ad->sqfrom;
-//  k1 = ad->hmmfrom;
-//  for (pos = 0; pos < ad->N; pos += aliwidth)
-//    {
-//      if (pos > 0) fprintf(fp, "\n"); /* blank line betweeen blocks */
-//
-//      ni = nk = 0; 
-//      for (z = pos; z < pos + aliwidth && z < ad->N; z++) {
-//	if (ad->model[z] != '.') nk++; /* k advances except on insert states */
-//	if (ad->aseq[z]  != '-') ni++; /* i advances except on delete states */
-//      }
-//      i2 = i1+ni-1;
-//      k2 = k1+nk-1;
-//
-//      if (ad->csline != NULL) { strncpy(buf, ad->csline+pos, aliwidth); fprintf(fp, "  %*s %s CS\n", namewidth+coordwidth+1, "", buf); }
-//      if (ad->rfline != NULL) { strncpy(buf, ad->rfline+pos, aliwidth); fprintf(fp, "  %*s %s RF\n", namewidth+coordwidth+1, "", buf); }
-//
-//      strncpy(buf, ad->model+pos, aliwidth); fprintf(fp, "  %*s %*d %s %-*d\n", namewidth,  ad->hmmname, coordwidth, k1, buf, coordwidth, k2);
-//      strncpy(buf, ad->mline+pos, aliwidth); fprintf(fp, "  %*s %s\n", namewidth+coordwidth+1, " ", buf);
-//
-//      if (ni > 0) { strncpy(buf, ad->aseq+pos, aliwidth); fprintf(fp, "  %*s %*ld %s %-*ld\n", namewidth, ad->sqname, coordwidth, i1,  buf, coordwidth, i2);  }
-//      else        { strncpy(buf, ad->aseq+pos, aliwidth); fprintf(fp, "  %*s %*s %s %*s\n",    namewidth, ad->sqname, coordwidth, "-", buf, coordwidth, "-"); }
-//
-//      if (ad->ppline != NULL) { strncpy(buf, ad->ppline+pos, aliwidth); fprintf(fp, "  %*s %s PP\n", namewidth+coordwidth+1, "", buf); }
-//
-//      i1 += ni;
-//      k1 += nk;
-//    }
-//  fflush(fp);
-//  free(buf);
-//  return eslOK;
-//
-// ERROR:
-//  if (buf != NULL) free(buf);
-//  return status;
-//}  
+// ! removed unused function: p7_alidisplay_Print !
 
 
 /* Function:  p7_alidisplay_Backconvert()
@@ -394,7 +319,7 @@ p7_alidisplay_Backconvert(const P7_ALIDISPLAY *ad, const ESL_ALPHABET *abc, ESL_
 
     /* Make a first pass over <ad> just to calculate subseq length */
     for (a = 0; a < ad->N; a++)
-        if (esl_abc_CIsResidue(abc, ad->aseq[a])) subL++;
+    if (! esl_abc_CIsGap(abc, ad->aseq[a])) subL++;
 
     /* Allocations */
     if ((sq = esl_sq_CreateDigital(abc)) == NULL)   { status = eslEMEM; goto ERROR; }
@@ -428,13 +353,13 @@ p7_alidisplay_Backconvert(const P7_ALIDISPLAY *ad, const ESL_ALPHABET *abc, ESL_
     sq->dsq[i] = eslDSQ_SENTINEL;
 
     /* some sanity checks */
-    if (tr->N != ad->N + 6)      ESL_XEXCEPTION(eslECORRUPT, "backconverted trace ended up with unexpected size");
-    if (k     != ad->hmmto + 1)  ESL_XEXCEPTION(eslECORRUPT, "backconverted trace didn't end at expected place on model");
-    if (i     != subL + 1)       ESL_XEXCEPTION(eslECORRUPT, "backconverted subseq didn't end at expected length");
+  if (tr->N != ad->N + 6)      ESL_XEXCEPTION(eslECORRUPT, "backconverted trace ended up with unexpected size (%s/%s)",         ad->sqname, ad->hmmname);
+  if (k     != ad->hmmto + 1)  ESL_XEXCEPTION(eslECORRUPT, "backconverted trace didn't end at expected place on model (%s/%s)", ad->sqname, ad->hmmname);
+  if (i     != subL + 1)       ESL_XEXCEPTION(eslECORRUPT, "backconverted subseq didn't end at expected length (%s/%s)",        ad->sqname, ad->hmmname);
 
     /* Set up <sq> annotation as a subseq of a source sequence */
-    if ((status = esl_sq_SetName  (sq, "%s/%ld-%ld", ad->sqname, ad->sqfrom, ad->sqto))                      != eslOK) goto ERROR;
-    if ((status = esl_sq_SetDesc  (sq, "[subseq from] %s", ad->sqdesc[0] != '\0' ? ad->sqdesc : ad->sqname)) != eslOK) goto ERROR;
+  if ((status = esl_sq_FormatName(sq, "%s/%ld-%ld", ad->sqname, ad->sqfrom, ad->sqto))                      != eslOK) goto ERROR;
+  if ((status = esl_sq_FormatDesc(sq, "[subseq from] %s", ad->sqdesc[0] != '\0' ? ad->sqdesc : ad->sqname)) != eslOK) goto ERROR;
     if ((status = esl_sq_SetSource(sq, ad->sqname))                                                          != eslOK) goto ERROR;
     if (ad->sqacc[0]  != '\0') { if ((status = esl_sq_SetAccession  (sq, ad->sqacc)) != eslOK) goto ERROR; }
     sq->n     = subL;
@@ -461,7 +386,7 @@ ERROR:
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
