@@ -15,7 +15,7 @@
 *    4. Copyright and license information.
 * 
 * SRE, Fri Dec 28 07:14:54 2007 [Janelia] [Enigma, MCMXC a.D.]
-* SVN $Id: p7_tophits.c 2818 2009-06-03 12:31:02Z eddys $
+ * SVN $Id: p7_tophits.c 3047 2009-11-13 12:31:16Z eddys $
 */
 
 #include <hmmer3/p7_config.h>
@@ -208,6 +208,11 @@ ERROR:
 * 
 * Note:      Is this actually used anywhere? (SRE, 10 Dec 08) 
 *            I think it's not up to date.
+ *            
+ *            That's right. This function is completely obsolete.
+ *            It is used in benchmark and test code, so you can't
+ *            delete it yet; benchmarks and test code should be
+ *            revised (SRE, 26 Oct 09)
 */
 int
 p7_tophits_Add(P7_TOPHITS *h,
@@ -228,7 +233,22 @@ p7_tophits_Add(P7_TOPHITS *h,
     if ((status = esl_strdup(desc, -1, &(h->unsrt[h->N].desc))) != eslOK) return status;
     h->unsrt[h->N].sortkey  = sortkey;
     h->unsrt[h->N].score    = score;
+  h->unsrt[h->N].pre_score  = 0.0;
+  h->unsrt[h->N].sum_score  = 0.0;
     h->unsrt[h->N].pvalue   = pvalue;
+  h->unsrt[h->N].pre_pvalue = 0.0;
+  h->unsrt[h->N].sum_pvalue = 0.0;
+  h->unsrt[h->N].nexpected  = 0;
+  h->unsrt[h->N].nregions   = 0;
+  h->unsrt[h->N].nclustered = 0;
+  h->unsrt[h->N].noverlaps  = 0;
+  h->unsrt[h->N].nenvelopes = 0;
+  h->unsrt[h->N].ndom       = ndom;
+  h->unsrt[h->N].flags      = 0;
+  h->unsrt[h->N].nreported  = 0;
+  h->unsrt[h->N].nincluded  = 0;
+  h->unsrt[h->N].best_domain= 0;
+  h->unsrt[h->N].dcl        = NULL;
     h->N++;
 
     if (h->N >= 2) h->is_sorted = FALSE;
@@ -244,7 +264,7 @@ hit_sorter(const void *vh1, const void *vh2)
 
     if      (h1->sortkey < h2->sortkey)  return  1;
     else if (h1->sortkey > h2->sortkey)  return -1;
-    else                                 return  0;
+  else                                return  strcmp(h1->name, h2->name);
 }
 
 /* Function:  p7_tophits_Sort()
@@ -313,7 +333,7 @@ p7_tophits_Merge(P7_TOPHITS *h1, P7_TOPHITS *h2)
 
     /* Merge the sorted hit lists */
     for (i=0,j=0,k=0; i < h1->N && j < h2->N ; k++)
-        new_hit[k] = (h2->hit[j]->sortkey > h1->hit[i]->sortkey) ? new2 + (h2->hit[j++] - h2->unsrt) : h1->hit[i++];
+    new_hit[k] = (hit_sorter(&h1->hit[i], &h2->hit[j]) > 0) ? new2 + (h2->hit[j++] - h2->unsrt) : h1->hit[i++];
     while (i < h1->N) new_hit[k++] = h1->hit[i++];
     while (j < h2->N) new_hit[k++] = new2 + (h2->hit[j++] - h2->unsrt);
 
@@ -324,6 +344,7 @@ p7_tophits_Merge(P7_TOPHITS *h1, P7_TOPHITS *h2)
         h2->unsrt[i].name = NULL;
         h2->unsrt[i].acc  = NULL;
         h2->unsrt[i].desc = NULL;
+      h2->unsrt[i].dcl  = NULL;
     }
 
     /* Construct the new grown h1 */
@@ -341,7 +362,7 @@ ERROR:
 
 
 /* Function:  p7_tophits_GetMaxNameLength()
-* Synopsis:  Returns maximum name length.
+ * Synopsis:  Returns maximum name length in hit list (targets).
 * Incept:    SRE, Fri Dec 28 09:00:13 2007 [Janelia]
 *
 * Purpose:   Returns the maximum name length of all the registered
@@ -368,6 +389,58 @@ p7_tophits_GetMaxNameLength(P7_TOPHITS *h)
         return max;
 }
 
+/* Function:  p7_tophits_GetMaxAccessionLength()
+ * Synopsis:  Returns maximum accession length in hit list (targets).
+ * Incept:    SRE, Tue Aug 25 09:18:33 2009 [Janelia]
+ *
+ * Purpose:   Same as <p7_tophits_GetMaxNameLength()>, but for
+ *            accessions. If there are no hits in <h>, or none
+ *            of the hits have accessions, returns 0.
+ */
+int
+p7_tophits_GetMaxAccessionLength(P7_TOPHITS *h)
+{
+  int i, max, n;
+  for (max = 0, i = 0; i < h->N; i++)
+    if (h->unsrt[i].acc != NULL) {
+      n   = strlen(h->unsrt[i].acc);
+      max = ESL_MAX(n, max);
+    }
+  return max;
+}
+
+/* Function:  p7_tophits_GetMaxShownLength()
+ * Synopsis:  Returns max shown name/accession length in hit list.
+ * Incept:    SRE, Tue Aug 25 09:30:43 2009 [Janelia]
+ *
+ * Purpose:   Same as <p7_tophits_GetMaxNameLength()>, but 
+ *            for the case when --acc is on, where
+ *            we show accession if one is available, and 
+ *            fall back to showing the name if it is not.
+ *            Returns the max length of whatever is being
+ *            shown as the reported "name".
+ */
+int
+p7_tophits_GetMaxShownLength(P7_TOPHITS *h)
+{
+  int i, max, n;
+  for (max = 0, i = 0; i < h->N; i++)
+    {
+      if (h->unsrt[i].acc != NULL && h->unsrt[i].acc[0] != '\0') 
+	{
+	  n   = strlen(h->unsrt[i].acc);
+	  max = ESL_MAX(n, max);
+	} 
+      else if (h->unsrt[i].name != NULL)
+	{
+	  n   = strlen(h->unsrt[i].name);
+	  max = ESL_MAX(n, max);
+	}
+    }
+  return max;
+}
+
+
 /* Function:  p7_tophits_Reuse()
 * Synopsis:  Reuse a hit list, freeing internals.
 * Incept:    SRE, Fri Jun  6 15:39:05 2008 [Janelia]
@@ -450,12 +523,19 @@ p7_tophits_Destroy(P7_TOPHITS *h)
 *            the targets and domains that are "significant" (satisfying
 *            the reporting thresholds set for the pipeline). 
 *            
-*            Also sets the final total number of reported targets
-*            <th->nreported> and the size of the search space for
-*            per-domain conditional E-value calculations,
+ *            Also sets the final total number of reported and
+ *            included targets, the number of reported and included
+ *            targets in each target, and the size of the search space
+ *            for per-domain conditional E-value calculations,
 *            <pli->domZ>. By default, <pli->domZ> is the number of
 *            significant targets reported.
 *
+ *            If model-specific thresholds were used in the pipeline,
+ *            we cannot apply those thresholds now. They were already
+ *            applied in the pipeline. In this case all we're
+ *            responsible for here is counting them (setting
+ *            nreported, nincluded counters).
+ *            
 * Returns:   <eslOK> on success.
 */
 int
@@ -463,303 +543,74 @@ p7_tophits_Threshold(P7_TOPHITS *th, P7_PIPELINE *pli)
 {
     int h, d;	/* counters over sequence hits, domains in sequences */
 
-    /* First pass over sequences: flag all reportable, includable ones */
-    th->nreported = 0;
+  /* Flag reported, included targets (if we're using general thresholds) */
+  if (! pli->use_bit_cutoffs) 
+    {
     for (h = 0; h < th->N; h++)
     {
         if (p7_pli_TargetReportable(pli, th->hit[h]->score, th->hit[h]->pvalue))
         {
             th->hit[h]->flags |= p7_IS_REPORTED;
-            th->nreported++;
-        }
         if (p7_pli_TargetIncludable(pli, th->hit[h]->score, th->hit[h]->pvalue))
-        {
             th->hit[h]->flags |= p7_IS_INCLUDED;
-            th->nincluded++;
         }
     }
+    }
+
+  /* Count reported, included targets */
+  th->nreported = 0;
+  th->nincluded = 0;
+  for (h = 0; h < th->N; h++)
+    {
+      if (th->hit[h]->flags & p7_IS_REPORTED)  th->nreported++;
+      if (th->hit[h]->flags & p7_IS_INCLUDED)  th->nincluded++;
+    }
 
     /* Now we can determined domZ, the effective search space in which additional domains are found */
     if (pli->domZ_setby == p7_ZSETBY_NTARGETS) pli->domZ = (double) th->nreported;
 
-    /* Second pass is over domains, flagging reportable/includable ones:
-    * we always report or include at least the best single domain for each sequence, 
-    * regardless of domain thresholding.
+
+  /* Second pass is over domains, flagging reportable/includable ones. 
+   * Depends on knowing the domZ we just set.
+   * Note how this enforces a hierarchical logic of 
+   * (sequence|domain) must be reported to be included, and
+   * domain can only be (reported|included) if whole sequence is too.
     */
+  if (! pli->use_bit_cutoffs) 
+    {
     for (h = 0; h < th->N; h++)  
     {
         if (th->hit[h]->flags & p7_IS_REPORTED)
+	    {
             for (d = 0; d < th->hit[h]->ndom; d++)
             {
-                if (th->hit[h]->best_domain == d ||
-                    p7_pli_DomainReportable(pli, th->hit[h]->dcl[d].bitscore, th->hit[h]->dcl[d].pvalue))
-                {
-                    th->hit[h]->nreported++;
+		  if (p7_pli_DomainReportable(pli, th->hit[h]->dcl[d].bitscore, th->hit[h]->dcl[d].pvalue))
                     th->hit[h]->dcl[d].is_reported = TRUE;
+		  if ((th->hit[h]->flags & p7_IS_INCLUDED) &&
+		      p7_pli_DomainIncludable(pli, th->hit[h]->dcl[d].bitscore, th->hit[h]->dcl[d].pvalue))
+		    th->hit[h]->dcl[d].is_included = TRUE;
+		}
                 }
             }
-            if (th->hit[h]->flags & p7_IS_INCLUDED)
+    }
+
+  /* Count the reported, included domains */
+  for (h = 0; h < th->N; h++)  
                 for (d = 0; d < th->hit[h]->ndom; d++)
                 {
-                    if (th->hit[h]->best_domain == d ||
-                        p7_pli_DomainIncludable(pli, th->hit[h]->dcl[d].bitscore, th->hit[h]->dcl[d].pvalue))
-                    {
-                        th->hit[h]->nincluded++;
-                        th->hit[h]->dcl[d].is_included = TRUE;
-                    }
-                }
+	if (th->hit[h]->dcl[d].is_reported) th->hit[h]->nreported++;
+	if (th->hit[h]->dcl[d].is_included) th->hit[h]->nincluded++;
     }
     return eslOK;
 }
 
+// ! here were p7_tophits_CompareRanking. we don't need it !
 
-/* Function:  p7_tophits_CompareRanking()
-* Synopsis:  Compare current top hits to previous top hits ranking.
-* Incept:    SRE, Sun Feb  8 20:33:02 2009 [Janelia]
-*
-* Purpose:   Using a keyhash <kh> of the previous top hits and the
-*            their ranks, look at the current top hits list <th>
-*            and flag new hits that are included for the first time
-*            (by setting <p7_IS_NEW> flag) and hits that were 
-*            included previously, but are now below the inclusion
-*            threshold in the list (<by setting <p7_IS_DROPPED>
-*            flag). 
-*
-*            The <th> must already have been processed by
-*            <p7_tophits_Threshold()>. We assume the <is_included>,
-*            <is_reported> flags are set on the appropriate hits.
-* 
-*            Upon return, the keyhash <kh> is updated to hash the
-*            current top hits list and their ranks. 
-*            
-*            Optionally, <*opt_nnew> is set to the number of 
-*            newly included hits. jackhmmer uses this as part of
-*            its convergence criteria, for example.
-*            
-*            These flags affect output of top target hits from
-*            <p7_tophits_Targets()>. 
-*            
-*            It only makes sense to call this function in context of
-*            an iterative search.
-*            
-*            The <p7_IS_NEW> flag is comprehensive: all new hits
-*            are flagged (and counted in <*opt_nnew>). The <p7_WAS_DROPPED> 
-*            flag is not comprehensive: only those hits that still 
-*            appear in the current top hits list are flagged. If a 
-*            hit dropped entirely off the list, it isn't counted
-*            as "dropped". (This could be done, but we would want
-*            to have two keyhashes, one old and one new, to do the
-*            necessary comparisons efficiently.)
-*            
-*            If the target names in <th> are not unique, results may
-*            be strange.
-*
-* Args:      th         - current top hits list
-*            kh         - hash of top hits' ranks (in: previous tophits; out: <th>'s tophits)
-*            opt_nnew   - optRETURN: number of new hits above inclusion threshold
-*
-* Returns:   <eslOK> on success.
-*
-* Throws:    <eslEMEM> if <kh> needed to be reallocated but this failed.
-*/
-//int
-//p7_tophits_CompareRanking(P7_TOPHITS *th, ESL_KEYHASH *kh, int *opt_nnew)
-//{
-//  int nnew = 0;
-//  int oldrank;
-//  int h;
-//  int status;
-//
-//  /* Flag the hits in the list with whether they're new in the included top hits,
-//   * and whether they've dropped off the included list.
-//   */
-//  for (h = 0; h < th->N; h++)
-//    {
-//      esl_key_Lookup(kh, th->hit[h]->name, &oldrank);
-//      
-//      if (th->hit[h]->flags & p7_IS_INCLUDED) 
-//	{
-//	  if (oldrank == -1) { th->hit[h]->flags |= p7_IS_NEW; nnew++; }
-//	}
-//      else 
-//	{
-//	  if (oldrank >=  0) th->hit[h]->flags |= p7_IS_DROPPED;
-//	}
-//    }	
-//
-//  /* Replace the old rank list with the new one */
-//  esl_keyhash_Reuse(kh);
-//  for (h = 0; h < th->N; h++)
-//    {
-//      if (th->hit[h]->flags & p7_IS_INCLUDED) 
-//	{
-//	  /* What happens when the same sequence name appears twice? It gets stored with higher rank */
-//	  status = esl_key_Store(kh, th->hit[h]->name, NULL);
-//	  if (status != eslOK && status != eslEDUP) goto ERROR;
-//	}
-//    }
-//  
-//  if (opt_nnew != NULL) *opt_nnew = nnew;
-//  return eslOK;
-//
-// ERROR:
-//  if (opt_nnew != NULL) *opt_nnew = 0;
-//  return status;
-//}
+// ! here were p7_tophits_Targets. we don't need it !
+// ! here were p7_tophits_Domains. we don't need it !
 
 
-/* Function:  p7_tophits_Targets()
-* Synopsis:  Standard output format for a top target hits list.
-* Incept:    SRE, Tue Dec  9 09:10:43 2008 [Janelia]
-*
-* Purpose:   Output a list of the reportable top target hits in <th> 
-*            in human-readable ASCII text format to stream <ofp>, using
-*            final pipeline accounting stored in <pli>. 
-*
-*            The tophits list <th> should already be sorted (see
-*            <p7_tophits_Sort()> and thresholded (see
-*            <p7_tophits_Threshold>).
-*            
-* Returns:   <eslOK> on success.
-*
-* Notes:     Recalculating the actual null2 score correction with
-*            <bg->omega> here seems silly - surely we can do that
-*            in the pipeline?
-*/
-//int
-//p7_tophits_Targets(FILE *ofp, P7_TOPHITS *th, P7_PIPELINE *pli, P7_BG *bg, int textw)
-//{
-//  char   newness;
-//  int    h;
-//  int    d;
-//  int    namew = ESL_MAX(8,  p7_tophits_GetMaxNameLength(th));
-//  int    descw;
-//  int    have_printed_incthresh = FALSE;
-//
-//  if (textw >  0) descw = ESL_MAX(32, textw - namew - 61); /* 61 chars excluding desc is from the format: 2 + 22+2 +22+2 +8+2 +<name>+1 */
-//  else            descw = INT_MAX;
-//
-//  fprintf(ofp, "Scores for complete sequence%s (score includes all domains):\n", 
-//	  pli->mode == p7_SEARCH_SEQS ? "s" : "");
-//
-//  /* The minimum width of the target table is 111 char: 47 from fields, 8 from min name, 32 from min desc, 13 spaces */
-//  fprintf(ofp, "  %22s  %22s  %8s\n",                              " --- full sequence ---",        " --- best 1 domain ---",   "-#dom-");
-//  fprintf(ofp, "  %9s %6s %5s  %9s %6s %5s  %5s %2s  %-*s %s\n", "E-value", " score", " bias", "E-value", " score", " bias", "  exp",  "N", namew, (pli->mode == p7_SEARCH_SEQS ? "Sequence":"Model"), "Description");
-//  fprintf(ofp, "  %9s %6s %5s  %9s %6s %5s  %5s %2s  %-*s %s\n", "-------", "------", "-----", "-------", "------", "-----", " ----", "--", namew, "--------", "-----------");
-//
-//  for (h = 0; h < th->N; h++)
-//    if (th->hit[h]->flags & p7_IS_REPORTED)
-//      {
-//	d    = th->hit[h]->best_domain;
-//
-//	if (! (th->hit[h]->flags & p7_IS_INCLUDED) && h < th->N-1 && ! have_printed_incthresh) {
-//	  fprintf(ofp, "  ------ inclusion threshold ------\n");
-//	  have_printed_incthresh = TRUE;
-//	}
-//
-//	if      (th->hit[h]->flags & p7_IS_NEW)     newness = '+';
-//	else if (th->hit[h]->flags & p7_IS_DROPPED) newness = '-';
-//	else                                        newness = ' ';
-//
-//
-//	fprintf(ofp, "%c %9.2g %6.1f %5.1f  %9.2g %6.1f %5.1f  %5.1f %2d  %-*s %-.*s\n",
-//		newness,
-//		th->hit[h]->pvalue * pli->Z,
-//		th->hit[h]->score,
-//		th->hit[h]->pre_score - th->hit[h]->score, /* bias correction */
-//		th->hit[h]->dcl[d].pvalue * pli->Z,
-//		th->hit[h]->dcl[d].bitscore,
-//		p7_FLogsum(0.0, log(bg->omega) + th->hit[h]->dcl[d].domcorrection),
-//		th->hit[h]->nexpected,
-//		th->hit[h]->nreported,
-//		namew, th->hit[h]->name,
-//		descw, (th->hit[h]->desc == NULL ? "" : th->hit[h]->desc));
-//      }
-//  if (th->nreported == 0) fprintf(ofp, "\n   [No hits detected that satisfy reporting thresholds]\n");
-//  return eslOK;
-//}
-//
 
-/* Function:  p7_tophits_Domains()
-* Synopsis:  Standard output format for top domain hits and alignments.
-* Incept:    SRE, Tue Dec  9 09:32:32 2008 [Janelia]
-*
-* Purpose:   For each reportable target sequence, output a tabular summary
-*            of reportable domains found in it, followed by alignments of
-*            each domain.
-* 
-*            Similar to <p7_tophits_Targets()>; see additional notes there.
-*/
-//int
-//p7_tophits_Domains(FILE *ofp, P7_TOPHITS *th, P7_PIPELINE *pli, P7_BG *bg, int textw)
-//{
-//  int h, d;
-//  int nd;
-//  int namew, descw;
-//
-//  fprintf(ofp, "Domain and alignment annotation for each %s:\n", pli->mode == p7_SEARCH_SEQS ? "sequence" : "model");
-//
-//  for (h = 0; h < th->N; h++)
-//    if (th->hit[h]->flags & p7_IS_REPORTED)
-//      {
-//	namew = strlen(th->hit[h]->name);
-//	descw = (textw > 0 ?  ESL_MAX(32, textw - namew - 5) : INT_MAX);
-//
-//	fprintf(ofp, ">> %s  %-.*s\n", th->hit[h]->name, descw, (th->hit[h]->desc == NULL ? "" : th->hit[h]->desc));
-//
-//	/* The domain table is 101 char wide:
-//          #     score  bias  c-Evalue  i-Evalue hmmfrom   hmmto    alifrom  ali to    envfrom  env to     acc
-//         ---   ------ ----- --------- --------- ------- -------    ------- -------    ------- -------    ----
-//           1 ?  123.4  23.1   9.7e-11    6.8e-9       3    1230 ..       1     492 []       2     490 .] 0.90
-//         123 ! 1234.5 123.4 123456789 123456789 1234567 1234567 .. 1234567 1234567 [] 1234567 1234568 .] 0.12
-//	*/
-//	fprintf(ofp, " %3s   %6s %5s %9s %9s %7s %7s %2s %7s %7s %2s %7s %7s %2s %4s\n",    "#",  "score",  "bias",  "c-Evalue",  "i-Evalue", "hmmfrom",  "hmm to", "  ", "alifrom",  "ali to", "  ", "envfrom",  "env to", "  ",  "acc");
-//	fprintf(ofp, " %3s   %6s %5s %9s %9s %7s %7s %2s %7s %7s %2s %7s %7s %2s %4s\n",  "---", "------", "-----", "---------", "---------", "-------", "-------", "  ", "-------", "-------", "  ", "-------", "-------", "  ", "----");
-//	nd = 0;
-//	for (d = 0; d < th->hit[h]->ndom; d++)
-//	  if (th->hit[h]->dcl[d].is_reported) 
-//	    {
-//	      nd++;
-//	      fprintf(ofp, " %3d %c %6.1f %5.1f %9.2g %9.2g %7d %7d %c%c %7ld %7ld %c%c %7d %7d %c%c %4.2f\n",
-//		      nd,
-//		      th->hit[h]->dcl[d].is_included ? '!' : '?',
-//		      th->hit[h]->dcl[d].bitscore,
-//		      p7_FLogsum(0.0, log(bg->omega) + th->hit[h]->dcl[d].domcorrection),
-//		      th->hit[h]->dcl[d].pvalue * pli->domZ,
-//		      th->hit[h]->dcl[d].pvalue * pli->Z,
-//		      th->hit[h]->dcl[d].ad->hmmfrom,
-//		      th->hit[h]->dcl[d].ad->hmmto,
-//		      (th->hit[h]->dcl[d].ad->hmmfrom == 1) ? '[' : '.',
-//		      (th->hit[h]->dcl[d].ad->hmmto   == th->hit[h]->dcl[d].ad->M) ? ']' : '.',
-//		      th->hit[h]->dcl[d].ad->sqfrom,
-//		      th->hit[h]->dcl[d].ad->sqto,
-//		      (th->hit[h]->dcl[d].ad->sqfrom == 1) ? '[' : '.',
-//		      (th->hit[h]->dcl[d].ad->sqto   == th->hit[h]->dcl[d].ad->L) ? ']' : '.',
-//		      th->hit[h]->dcl[d].ienv,
-//		      th->hit[h]->dcl[d].jenv,
-//		      (th->hit[h]->dcl[d].ienv == 1) ? '[' : '.',
-//		      (th->hit[h]->dcl[d].jenv == th->hit[h]->dcl[d].ad->L) ? ']' : '.',
-//		      (th->hit[h]->dcl[d].oasc / (1.0 + fabs((float) (th->hit[h]->dcl[d].jenv - th->hit[h]->dcl[d].ienv)))));
-//	    }
-//
-//	
-//	fprintf(ofp, "\n  Alignments for each domain:\n");
-//	nd = 0;
-//	for (d = 0; d < th->hit[h]->ndom; d++)
-//	  if (th->hit[h]->dcl[d].is_reported) 
-//	    {
-//	      nd++;
-//	      fprintf(ofp, "  == domain %d    score: %.1f bits;  conditional E-value: %.2g\n",
-//		      nd, 
-//		      th->hit[h]->dcl[d].bitscore,
-//		      th->hit[h]->dcl[d].pvalue * pli->domZ);
-//	      p7_alidisplay_Print(ofp, th->hit[h]->dcl[d].ad, 40, textw);
-//	      fprintf(ofp, "\n");
-//	    }
-//      }
-//  if (th->nreported == 0) { fprintf(ofp, "\n   [No hits detected that satisfy reporting thresholds]\n"); return eslOK; }
-//  return eslOK;
-//}
 
 
 /* Function:  p7_tophits_Alignment()
@@ -868,126 +719,8 @@ ERROR:
 * 3. Tabular (parsable) output of pipeline results.
 *****************************************************************/
 
-/* Function:  p7_tophits_TabularTargets()
-* Synopsis:  Output parsable table of per-sequence hits.
-* Incept:    SRE, Wed Mar 18 15:26:17 2009 [Janelia]
-*
-* Purpose:   Output a parseable table of reportable per-sequence hits
-*            in sorted tophits list <th> in an easily parsed ASCII
-*            tabular form to stream <ofp>, using final pipeline
-*            accounting stored in <pli>.
-*            
-*            Designed to be concatenated for multiple queries and
-*            multiple top hits list.
-*
-* Returns:   <eslOK> on success.
-*/
-int
-p7_tophits_TabularTargets(FILE *ofp, char *queryname, P7_TOPHITS *th, P7_PIPELINE *pli, int show_header)
-{
-    int qnamew = ESL_MAX(20, strlen(queryname));
-    int tnamew = ESL_MAX(20, p7_tophits_GetMaxNameLength(th));
-    int h,d;
+// we don't need it
 
-    if (show_header)
-    {  
-        fprintf(ofp, "#%*s %22s %22s %33s\n", tnamew+qnamew, "", "--- full sequence ----", "--- best 1 domain ----", "--- domain number estimation ----");
-        fprintf(ofp, "#%-*s %-*s %9s %6s %5s %9s %6s %5s %5s %3s %3s %3s %3s %3s %3s %3s %s\n", 
-            tnamew-1, " target",             qnamew, "query",                "  E-value", " score", " bias", "  E-value", " score", " bias", "exp", "reg", "clu", " ov", "env", "dom", "rep", "inc", "description of target");
-        fprintf(ofp, "#%*s %*s %9s %6s %5s %9s %6s %5s %5s %3s %3s %3s %3s %3s %3s %3s %s\n", 
-            tnamew-1, "-------------------", qnamew, "--------------------", "---------", "------", "-----", "---------", "------", "-----", "---", "---", "---", "---", "---", "---", "---", "---", "---------------------");
-    }
-
-    for (h = 0; h < th->N; h++)
-        if (th->hit[h]->flags & p7_IS_REPORTED)
-        {
-            d    = th->hit[h]->best_domain;
-
-            fprintf(ofp, "%-*s %-*s %9.2g %6.1f %5.1f %9.2g %6.1f %5.1f %5.1f %3d %3d %3d %3d %3d %3d %3d %s\n", 
-                tnamew, th->hit[h]->name,
-                qnamew, queryname, 
-                th->hit[h]->pvalue * pli->Z,
-                th->hit[h]->score,
-                th->hit[h]->pre_score - th->hit[h]->score, /* bias correction */
-                th->hit[h]->dcl[d].pvalue * pli->Z,
-                th->hit[h]->dcl[d].bitscore,
-                th->hit[h]->dcl[d].dombias,
-                th->hit[h]->nexpected,
-                th->hit[h]->nregions,
-                th->hit[h]->nclustered,
-                th->hit[h]->noverlaps,
-                th->hit[h]->nenvelopes,
-                th->hit[h]->ndom,
-                th->hit[h]->nreported,
-                th->hit[h]->nincluded,
-                (th->hit[h]->desc == NULL ? "-" : th->hit[h]->desc));
-        }
-        return eslOK;
-}
-
-
-/* Function:  p7_tophits_TabularDomains()
-* Synopsis:  Output parseable table of per-domain hits
-* Incept:    SRE, Wed Mar 18 16:57:58 2009 [Janelia]
-*
-* Purpose:   Output a parseable table of reportable per-domain hits
-*            in sorted tophits list <th> in an easily parsed ASCII
-*            tabular form to stream <ofp>, using final pipeline
-*            accounting stored in <pli>.
-*            
-*            Designed to be concatenated for multiple queries and
-*            multiple top hits list.
-*
-* Returns:   <eslOK> on success.
-*/
-int
-p7_tophits_TabularDomains(FILE *ofp, char *queryname, P7_TOPHITS *th, P7_PIPELINE *pli, int show_header)
-{
-    int qnamew = ESL_MAX(20, strlen(queryname));
-    int tnamew = ESL_MAX(20, p7_tophits_GetMaxNameLength(th));
-    int h,d,nd;
-
-    if (show_header)
-    {
-        fprintf(ofp, "#%*s %22s %40s %11s %11s %11s\n", tnamew+qnamew-1+13, "",                    "--- full sequence ---",        "-------------- this domain -------------",                "hmm coord",      "ali coord",     "env coord");
-        fprintf(ofp, "#%-*s %5s %-*s %5s %9s %6s %5s %3s %3s %9s %9s %6s %5s %5s %5s %5s %5s %5s %5s %4s %s\n",
-            tnamew-1, " target",            "tlen",   qnamew, "query",                "qlen",  "E-value",   "score",  "bias",  "#",   "of",  "c-Evalue",  "i-Evalue",  "score",  "bias",  "from",  "to",    "from",  "to",   "from",   "to",    "acc",  "description of target");
-        fprintf(ofp, "#%*s %5s %*s %5s %9s %6s %5s %3s %3s %9s %9s %6s %5s %5s %5s %5s %5s %5s %5s %4s %s\n", 
-            tnamew-1, "-------------------", "-----", qnamew, "--------------------", "-----", "---------", "------", "-----", "---", "---", "---------", "---------", "------", "-----", "-----", "-----", "-----", "-----", "-----", "-----", "----", "---------------------");
-    }
-
-    for (h = 0; h < th->N; h++)
-        if (th->hit[h]->flags & p7_IS_REPORTED)
-        {
-            nd = 0;
-            for (d = 0; d < th->hit[h]->ndom; d++)
-                if (th->hit[h]->dcl[d].is_reported) 
-                {
-                    nd++;
-                    fprintf(ofp, "%-*s %5ld %-*s %5d %9.2g %6.1f %5.1f %3d %3d %9.2g %9.2g %6.1f %5.1f %5d %5d %5ld %5ld %5d %5d %4.2f %s\n", 
-                        tnamew, th->hit[h]->name, th->hit[h]->dcl[d].ad->L,
-                        qnamew, queryname,        th->hit[h]->dcl[d].ad->M,
-                        th->hit[h]->pvalue * pli->Z,
-                        th->hit[h]->score,
-                        th->hit[h]->pre_score - th->hit[h]->score, /* bias correction */
-                        nd, 
-                        th->hit[h]->nreported,
-                        th->hit[h]->dcl[d].pvalue * pli->domZ,
-                        th->hit[h]->dcl[d].pvalue * pli->Z,
-                        th->hit[h]->dcl[d].bitscore,
-                        th->hit[h]->dcl[d].dombias,
-                        th->hit[h]->dcl[d].ad->hmmfrom,
-                        th->hit[h]->dcl[d].ad->hmmto,
-                        th->hit[h]->dcl[d].ad->sqfrom,
-                        th->hit[h]->dcl[d].ad->sqto,
-                        th->hit[h]->dcl[d].ienv,
-                        th->hit[h]->dcl[d].jenv,
-                        (th->hit[h]->dcl[d].oasc / (1.0 + fabs((float) (th->hit[h]->dcl[d].jenv - th->hit[h]->dcl[d].ienv)))),
-                        (th->hit[h]->desc == NULL ? "-" : th->hit[h]->desc));		      
-                }
-        }
-        return eslOK;
-}
 /*------------------- end, tabular output -----------------------*/
 
 
@@ -996,7 +729,7 @@ p7_tophits_TabularDomains(FILE *ofp, char *queryname, P7_TOPHITS *th, P7_PIPELIN
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
-* Version 3.0b2; June 2009
+ * Version 3.0b3; November 2009
 * Copyright (C) 2009 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
