@@ -17,8 +17,13 @@
 #include <core_api/IOAdapter.h>
 #include <core_api/AppContext.h>
 #include <gobjects/DNASequenceObject.h>
+#include <gobject/uHMMObject.h>
 #include <util_text/TextUtils.h>
 
+#include <search/uHMM3SearchLocalTask.h>
+#include <distributed_computing/RemoteTask.h>
+#include <distributed_computing/SerializeUtils.h>
+
 #include "uhmmer3SearchTests.h"
 
 namespace GB2 {
@@ -43,7 +48,6 @@ const QString GTest_UHMM3Search::INC_SEQ_E_OPTION_TAG        = "incE";
 const QString GTest_UHMM3Search::INC_SEQ_T_OPTION_TAG        = "incT";
 const QString GTest_UHMM3Search::INC_DOM_E_OPTION_TAG        = "incdomE";
 const QString GTest_UHMM3Search::INC_DOM_T_OPTION_TAG        = "incdomT";
-const QString GTest_UHMM3Search::INC_USE_BIT_CUTOFFS_OPTION_TAG = "incubc";
 const QString GTest_UHMM3Search::MAX_OPTION_TAG              = "max";
 const QString GTest_UHMM3Search::F1_OPTION_TAG               = "f1";
 const QString GTest_UHMM3Search::F2_OPTION_TAG               = "f2";
@@ -51,6 +55,7 @@ const QString GTest_UHMM3Search::F3_OPTION_TAG               = "f3";
 const QString GTest_UHMM3Search::NOBIAS_OPTION_TAG           = "nobias";
 const QString GTest_UHMM3Search::NONULL2_OPTION_TAG          = "nonull2";
 const QString GTest_UHMM3Search::SEED_OPTION_TAG             = "seed";
+const QString GTest_UHMM3Search::REMOTE_MACHINE_VAR          = "MACHINE";
 
 static void setDoubleOption( double& num, const QDomElement& el, const QString& optionName, TaskStateInfo& si ) {
     if( si.hasErrors() ) {
@@ -141,7 +146,6 @@ void GTest_UHMM3Search::setSearchTaskSettings( UHMM3SearchSettings& settings, co
     setIntegerOption( settings.seed, el, GTest_UHMM3Search::SEED_OPTION_TAG, si );
 
     setUseBitCutoffsOption( settings.useBitCutoffs, el, GTest_UHMM3Search::USE_BIT_CUTOFFS_OPTION_TAG, si );
-    setUseBitCutoffsOption( settings.incuseBitCutoffs, el, GTest_UHMM3Search::INC_USE_BIT_CUTOFFS_OPTION_TAG, si );
 }
 
 static void setSearchAlgoType( GTest_UHMM3SearchAlgoType& alType, const QString& s ) {
@@ -156,21 +160,38 @@ static void setSearchAlgoType( GTest_UHMM3SearchAlgoType& alType, const QString&
     }
 }
 
+static P7_HMM * takeHmmFromDoc( Document * doc ) {
+    assert( NULL != doc );
+    QList< GObject* > objs = doc->getObjects();
+    assert( 1 == objs.size() );
+    UHMMObject * hmmObj = qobject_cast< UHMMObject* >( objs.at( 0 ) );
+    if( NULL == hmmObj ) {
+        return NULL;
+    }
+    return hmmObj->takeHMM();
+}
+
 void GTest_UHMM3Search::init( XMLTestFormat *tf, const QDomElement& el ) {
     Q_UNUSED( tf );
 
     hmmFilename = el.attribute( HMM_FILENAME_TAG );
     searchTaskCtxName = el.attribute( HMMSEARCH_TASK_CTX_NAME_TAG );
 
-    generalSearchTask   = NULL;
-    swSearchTask        = NULL;
     searchTaskToCtx     = NULL;
-
+    hmm = NULL;
+    machine = NULL;
+    
     seqDocCtxName = el.attribute( SEQ_DOC_CTX_NAME_TAG );
     setSearchAlgoType( algo, el.attribute( ALGORITHM_TYPE_OPTION_TAG ) );
     setSearchTaskSettings( settings.inner, el, stateInfo );
     
     cleanuped = false;
+    ctxAdded = false;
+    
+    machinePath = env->getVar( REMOTE_MACHINE_VAR );
+    if( !machinePath.isEmpty() ) {
+        algo = SEQUENCE_WALKER_SEARCH;
+    }
 }
 
 void GTest_UHMM3Search::setAndCheckArgs() {
@@ -201,7 +222,7 @@ void GTest_UHMM3Search::setAndCheckArgs() {
         stateInfo.setError( QString( "context %1 not found" ).arg( seqDocCtxName ) );
         return;
     }
-    QList< GObject* > objsList = seqDoc->findGObjectByType( GObjectTypes::DNA_SEQUENCE );
+    QList< GObject* > objsList = seqDoc->findGObjectByType( GObjectTypes::SEQUENCE );
     if( objsList.isEmpty() ) {
         stateInfo.setError( "no_dna_sequence_objects_in_document" );
         return;
@@ -216,6 +237,10 @@ void GTest_UHMM3Search::setAndCheckArgs() {
         stateInfo.setError( "empty_sequence_given" );
         return;
     }
+    
+    if( !machinePath.isEmpty() ) {
+        machinePath = env->getVar( "COMMON_DATA_DIR" ) + "/" + machinePath;
+    }
 }
 
 void GTest_UHMM3Search::prepare() {
@@ -227,20 +252,47 @@ void GTest_UHMM3Search::prepare() {
 
     switch( algo ) {
     case GENERAL_SEARCH:
-        generalSearchTask = new UHMM3SearchTask( settings, hmmFilename, sequence.seq.data(), sequence.seq.size() );
-        searchTaskToCtx = generalSearchTask;
-        addSubTask( generalSearchTask );
+        searchTaskToCtx = new UHMM3SearchTask( settings, hmmFilename, sequence.seq.data(), sequence.seq.size() );
+        addSubTask( searchTaskToCtx );
         break;
     case SEQUENCE_WALKER_SEARCH:
-        swSearchTask = new UHMM3SWSearchTask( hmmFilename, sequence, settings );
-        searchTaskToCtx = swSearchTask;
-        addSubTask( swSearchTask );
+        if( machinePath.isEmpty() ) { /* search task on local machine */
+            searchTaskToCtx = new UHMM3SWSearchTask( hmmFilename, sequence, settings );
+            addSubTask( searchTaskToCtx );
+        } else { /* search on remote machine */
+            addSubTask( LoadDocumentTask::getDefaultLoadDocTask( hmmFilename ) );
+        }
         break;
     default:
         assert( 0 && "undefined_algorithm_type" );
     }
 }
 
+QList< Task* > GTest_UHMM3Search::onSubTaskFinished( Task * sub ) {
+    assert( NULL != sub );
+    QList< Task* > res;
+    LoadDocumentTask * loadHmmTask = qobject_cast<LoadDocumentTask*>( sub );
+    if( NULL == loadHmmTask ) {
+        return res;
+    }
+    if( loadHmmTask->hasErrors() ) {
+        setError( loadHmmTask->getError() );
+        return res;
+    }
+    
+    hmm = takeHmmFromDoc( loadHmmTask->getDocument() );
+    assert( NULL != hmm );
+    UHMM3SearchLocalTaskSettings localTaskSettings( settings, hmm, sequence );
+    if( !SerializeUtils::deserializeRemoteMachineSettingsFromFile( machinePath, &machine ) ) {
+        assert( NULL == machine );
+        setError( "cannot_create_remote_machine" );
+        return res;
+    }
+    searchTaskToCtx = new RemoteTask( UHMM3SearchLocalTaskFactory::ID, localTaskSettings, machine );
+    res << searchTaskToCtx;
+    return res;
+}
+
 Task::ReportResult GTest_UHMM3Search::report() {
     if( stateInfo.hasErrors() ) {
         return ReportResult_Finished;
@@ -248,18 +300,29 @@ Task::ReportResult GTest_UHMM3Search::report() {
     assert( NULL != searchTaskToCtx );
     if( !searchTaskToCtx->hasErrors() && !searchTaskToCtx->isCanceled() ) {
         addContext( searchTaskCtxName, searchTaskToCtx );
+        ctxAdded = true;
     }
     return ReportResult_Finished;
 }
 
 void GTest_UHMM3Search::cleanup() {
-    if( NULL != searchTaskToCtx && !searchTaskToCtx->hasErrors() && !cleanuped ) {
-        removeContext( searchTaskCtxName );
-        cleanuped = true;
+    if( cleanuped ) {
+        return;
     }
+    if( ctxAdded ) {
+        removeContext( searchTaskCtxName );
+    }
+    if( NULL != hmm ) {
+        p7_hmm_Destroy( hmm );
+    }
+    delete machine;
+    cleanuped = true;
 }
 
 GTest_UHMM3Search::~GTest_UHMM3Search() {
+    if( !cleanuped ) {
+        cleanup();
+    }
 }
 
 /**************************
@@ -354,83 +417,110 @@ static UHMM3SearchSeqDomainResult getDomainRes( QStringList& tokens ) {
     return res;
 }
 
-static int getExp( double d ) {
-    QString str = QString().sprintf( "%e", d ).toLower();
-    QStringList strList = str.split( "e", QString::SkipEmptyParts );
-    assert( 2 == strList.size() );
-    return strList.at( 1 ).toInt();
-}
+const double COMPARE_PERCENT_BORDER = 0.02; // 2 percents
 
-static bool compareFloats( float f1, float f2 ) {
-    return qAbs( f1 - f2 ) < 0.1;
-}
+template<class T>
+static bool compareNumbers( T f1, T f2 ) {
+    bool ret = false;
+    if( 0 == f1 ) {
+        ret = 0 == f2 ? true : f2 < COMPARE_PERCENT_BORDER;
+    } else if( 0 == f2 ) {
+        ret = f1 < COMPARE_PERCENT_BORDER;
+    } else {
+        ret = ( qAbs( f1 - f2 ) ) / f1 < COMPARE_PERCENT_BORDER;
+    }
 
-const double DOUBLE_EPS = 1.0e-20;
-
-static bool compareDoubles( double f1, double f2 ) {
-    f1 += DOUBLE_EPS;
-    f2 += DOUBLE_EPS;
-    int exp1 = getExp( qAbs( f1 ) );
-    int exp2 = getExp( qAbs( f2 ) );
-    
-    if( exp1 < 2 ) {
-        return compareFloats( f1, f2 );
+    if( !ret ) {
+        qDebug() << "!!! compare numbers mismatch: " << f1 << " and " << f2 << " !!!\n";
     }
     
-    if( exp1 != exp2 ) {
-        return false;
-    }
-    f1 = ( 1 <= exp1 )? f1 * qPow( 10, exp1 - 1 ) : f1;
-    f2 = ( 1 <= exp2 )? f2 * qPow( 10, exp2 - 1 ) : f2;
-    return qAbs( f1 - f2 ) < 0.1;
+    return ret;
 }
 
 void GTest_UHMM3SearchCompare::generalCompareResults( const UHMM3SearchResult& myRes, const UHMM3SearchResult& trueRes, TaskStateInfo& ti ) {
     const UHMM3SearchCompleteSeqResult& myFull = myRes.fullSeqResult;
     const UHMM3SearchCompleteSeqResult& trueFull = trueRes.fullSeqResult;
-
+    
     if( myFull.isReported != trueFull.isReported ) {
-        ti.setError( "reported_flag_not_matched" );
+        ti.setError( QString( "reported_flag_not_matched: %1 and %2" ).arg( myFull.isReported ).arg( trueFull.isReported ) );
         return;
     }
+    
     if( myFull.isReported ) {
-        if( !compareFloats( myFull.bias, trueFull.bias )   ) { ti.setError( "full_seq_bias_not_matched" );  return; }
-        if( !compareDoubles( myFull.eval, trueFull.eval )  ) { ti.setError( "full_seq_eval_not_matched" );  return; }
-        if( !compareFloats( myFull.score, trueFull.score ) ) { ti.setError( "full_seq_score_not_matched" ); return; }
-        if( !compareFloats( myFull.expectedDomainsNum, trueFull.expectedDomainsNum ) ) { ti.setError( "full_seq_exp_not_matched" ); return; }
-        if( myFull.reportedDomainsNum != trueFull.reportedDomainsNum ) { ti.setError( "full_seq_N_not_matched"   ); return; }
+        if( !compareNumbers<float>( myFull.bias, trueFull.bias )   ) { 
+            ti.setError( QString( "full_seq_bias_not_matched: %1 and %2" ).arg( myFull.bias ).arg( trueFull.bias ) );  return; 
+        }
+        if( !compareNumbers<double>( myFull.eval, trueFull.eval )  ) {
+            ti.setError( QString( "full_seq_eval_not_matched: %1 and %2" ).arg( myFull.eval ).arg( trueFull.eval ) );  return; 
+        }
+        if( !compareNumbers<float>( myFull.score, trueFull.score ) ) {
+            ti.setError( QString( "full_seq_score_not_matched: %1 and %2" ).arg( myFull.score ).arg( trueFull.score ) ); return; 
+        }
+        if( !compareNumbers<float>( myFull.expectedDomainsNum, trueFull.expectedDomainsNum ) ) {
+            ti.setError( QString( "full_seq_exp_not_matched: %1 and %2" ).arg( myFull.expectedDomainsNum ).arg( trueFull.expectedDomainsNum ) ); 
+            return; 
+        }
+        if( myFull.reportedDomainsNum != trueFull.reportedDomainsNum ) { 
+            ti.setError( QString( "full_seq_n_not_matched: %1 and %2" ).arg( myFull.reportedDomainsNum ).arg( trueFull.reportedDomainsNum ) );
+            return; 
+        }
     }
-
+    
     const QList< UHMM3SearchSeqDomainResult >& myDoms = myRes.domainResList;
     const QList< UHMM3SearchSeqDomainResult >& trueDoms = trueRes.domainResList;
     if( myDoms.size() != trueDoms.size() ) {
-        ti.setError( "domain_res_number_not_matched" );
+        ti.setError( QString( "domain_res_number_not_matched: %1 and %2" ).arg( myDoms.size() ).arg( trueDoms.size() ) );
         return;
     }
     for( int i = 0; i < myDoms.size(); ++i ) {
         UHMM3SearchSeqDomainResult myCurDom = myDoms.at( i );
         UHMM3SearchSeqDomainResult trueCurDom = trueDoms.at( i );
-        if( !compareDoubles( myCurDom.acc, trueCurDom.acc ) )   { ti.setError( "dom_acc_not_matched" );   return; }
-        if( !compareFloats( myCurDom.bias, trueCurDom.bias ) )  { ti.setError( "dom_bias_not_matched" );  return; }
-        if( !compareDoubles( myCurDom.cval, trueCurDom.cval ) )  { ti.setError( "dom_cval_not_matched at %1" );  return; }
-        if( !compareDoubles( myCurDom.ival, trueCurDom.ival ) )  { ti.setError( "dom_ival_not_matched" );  return; }
-        if( !compareFloats( myCurDom.score, trueCurDom.score ) ) { ti.setError( "dom_score_not_matched" ); return; }
-        if( myCurDom.envRegion != trueCurDom.envRegion ) { ti.setError( "dom_env_region_not_matched" ); return; }
-        if( myCurDom.queryRegion != trueCurDom.queryRegion ) { ti.setError( "dom_hmm_region_not_matched" ); return; }
-        if( myCurDom.seqRegion != trueCurDom.seqRegion ) { ti.setError( "dom_seq_region_not_matched" ); return; }
-        if( myCurDom.isSignificant != trueCurDom.isSignificant ) { ti.setError( "dom_sign_not_matched" ); return; }
+        if( !compareNumbers<double>( myCurDom.acc, trueCurDom.acc ) )   { 
+            ti.setError( QString( "dom_acc_not_matched: %1 and %2" ).arg( myCurDom.acc ).arg( trueCurDom.acc ) );   return; 
+        }
+        if( !compareNumbers<float>( myCurDom.bias, trueCurDom.bias ) )  { 
+            ti.setError( QString( "dom_bias_not_matched: %1 and %2" ).arg( myCurDom.bias ).arg( trueCurDom.bias ) );  return; 
+        }
+        if( !compareNumbers<double>( myCurDom.cval, trueCurDom.cval ) )  { 
+            ti.setError( QString( "dom_cval_not_matched: %1 and %2" ).arg( myCurDom.cval ).arg( trueCurDom.cval ) );  return; 
+        }
+        if( !compareNumbers<double>( myCurDom.ival, trueCurDom.ival ) )  { 
+            ti.setError( QString( "dom_ival_not_matched: %1 and %2" ).arg( myCurDom.ival ).arg( trueCurDom.ival ) );  return; 
+        }
+        if( !compareNumbers<float>( myCurDom.score, trueCurDom.score ) ) { 
+            ti.setError( QString( "dom_score_not_matched: %1 and %2" ).arg( myCurDom.score ).arg( trueCurDom.score ) ); return; 
+        }
+        if( myCurDom.envRegion != trueCurDom.envRegion ) { 
+            ti.setError( QString( "dom_env_region_not_matched: %1---%2 and %3---%4" ).
+                arg( myCurDom.envRegion.startPos ).arg( myCurDom.envRegion.len ).arg( trueCurDom.envRegion.startPos ).
+                arg( trueCurDom.envRegion.len ) ); return;
+        }
+        if( myCurDom.queryRegion != trueCurDom.queryRegion ) { 
+            ti.setError( QString( "dom_hmm_region_not_matched: %1---%2 and %3---%4" ).
+                arg( myCurDom.queryRegion.startPos ).arg( myCurDom.queryRegion.len ).arg( trueCurDom.queryRegion.startPos ).
+                arg( trueCurDom.queryRegion.len ) ); return;
+        }
+        if( myCurDom.seqRegion != trueCurDom.seqRegion ) {
+            ti.setError( QString( "dom_seq_region_not_matched: %1---%2 and %3---%4" ).
+                arg( myCurDom.seqRegion.startPos ).arg( myCurDom.seqRegion.len ).arg( trueCurDom.seqRegion.startPos ).
+                arg( trueCurDom.seqRegion.len ) ); return;
+        }
+        if( myCurDom.isSignificant != trueCurDom.isSignificant ) { 
+            ti.setError( QString( "dom_sign_not_matched: %1 and %2" ).arg( myCurDom.isSignificant ).arg( trueCurDom.isSignificant ) );
+            return; 
+        }
     }
 }
 
-/* we don't compare seq and env regions here - it doesn't make sence */
+/* we don't compare seq and env regions here - it doesn't make sense */
 static bool findDomainInSWResult( const UHMM3SWSearchTaskResult& res, const UHMM3SearchSeqDomainResult& dRes ) {
     foreach( const UHMM3SWSearchTaskDomainResult& domainRes, res ) {
         UHMM3SearchSeqDomainResult dom = domainRes.generalResult;
-        if( !compareDoubles( dom.acc, dRes.acc ) )    { continue; }
-        if( !compareFloats( dom.bias, dRes.bias ) )   { continue; }
-        if( !compareDoubles( dom.cval, dRes.cval ) )  { continue; }
-        if( !compareDoubles( dom.ival, dRes.ival ) )  { continue; }
-        if( !compareFloats( dom.score, dRes.score ) ) { continue; }
+        if( !compareNumbers<double>( dom.acc, dRes.acc ) )    { continue; }
+        if( !compareNumbers<float>( dom.bias, dRes.bias ) )   { continue; }
+        if( !compareNumbers<double>( dom.cval, dRes.cval ) )  { continue; }
+        if( !compareNumbers<double>( dom.ival, dRes.ival ) )  { continue; }
+        if( !compareNumbers<float>( dom.score, dRes.score ) ) { continue; }
         if( dom.queryRegion != dRes.queryRegion ) { continue; }
         if( dom.isSignificant != dRes.isSignificant ) { continue; }
         return true;
@@ -480,15 +570,14 @@ void GTest_UHMM3SearchCompare::setAndCheckArgs() {
         stateInfo.setError( tr( "cannot_find_search_task_in_context" ) );
         return;
     }
-
+    
     generalTask = qobject_cast< UHMM3SearchTask*    >( searchTask );
     swTask      = qobject_cast< UHMM3SWSearchTask*  >( searchTask );
-
+    remoteSearchTask = qobject_cast< RemoteTask* >( searchTask );
+    
     if( NULL != generalTask ) {
-        assert( NULL == swTask );
         algo = GENERAL_SEARCH;
-    } else if( NULL != swTask ) {
-        assert( NULL == generalTask );
+    } else if( NULL != swTask || NULL != remoteSearchTask ) {
         algo = SEQUENCE_WALKER_SEARCH;
     } else {
         assert( 0 && "cannot_cast_task_to_search_task" );
@@ -547,7 +636,7 @@ UHMM3SearchResult GTest_UHMM3SearchCompare::getOriginalSearchResult( const QStri
             }
             continue;
         }
-        if( buf.startsWith( "Domain and alignment" ) ) {
+        if( buf.startsWith( "Domain annotation for each sequence" ) ) {
             if( !wasFullSeqResult ) {
                 throw QString( "full_seq_result_is_missing" );
             }
@@ -595,8 +684,21 @@ Task::ReportResult GTest_UHMM3SearchCompare::report() {
         generalCompareResults( generalTask->getResult(), trueRes, stateInfo );
         break;
     case SEQUENCE_WALKER_SEARCH:
-        assert( NULL != swTask );
-        swCompareResults( swTask->getResults(), trueRes, stateInfo );
+        {
+            UHMM3SWSearchTaskResult result;
+            if( NULL != swTask ) {
+                result = swTask->getResults();
+            } else if( NULL != remoteSearchTask ) {
+                LocalTaskResult * ltr = remoteSearchTask->getResult();
+                UHMM3SearchLocalTaskResult * hmmLocalTaskRes = 
+                    dynamic_cast< UHMM3SearchLocalTaskResult* >( ltr );
+                assert( NULL != hmmLocalTaskRes );
+                result = hmmLocalTaskRes->getResult();
+            } else {
+                assert( false );
+            }
+            swCompareResults( result, trueRes, stateInfo );
+        }
         break;
     default:
         assert( 0 && "unknown_algo_type" );
