@@ -413,7 +413,7 @@ void GTest_Primer3::init(XMLTestFormat *tf, const QDomElement& el){
 
 void GTest_Primer3::prepare()
 {
-    task = new Primer3Task(settings);
+    task = new Primer3SWTask(settings);
     addSubTask(task);
 }
 
@@ -522,7 +522,6 @@ bool GTest_Primer3::checkPrimerPair(const PrimerPair &primerPair, const PrimerPa
 
 bool GTest_Primer3::checkPrimer(const Primer *primer, const Primer *expectedPrimer, QString prefix, bool internalOligo)
 {
-    int positionOffset = settings.getIncludedRegion().first;
     if(NULL == primer)
     {
         if(NULL == expectedPrimer)
@@ -547,14 +546,14 @@ bool GTest_Primer3::checkPrimer(const Primer *primer, const Primer *expectedPrim
         return false;
     }
     {
-        if((primer->getStart() + positionOffset != expectedPrimer->getStart()) ||
+        if((primer->getStart() + settings.getFirstBaseIndex() != expectedPrimer->getStart()) ||
            (primer->getLength() != expectedPrimer->getLength()))
         {
             stateInfo.setError(GTest::tr("%1 is incorrect. Expected:%2,%3, but Actual:%4,%5")
                 .arg(prefix)
-                .arg(expectedPrimer->getStart())
+                .arg(expectedPrimer->getStart() + settings.getFirstBaseIndex())
                 .arg(expectedPrimer->getLength())
-                .arg(primer->getStart() + positionOffset)
+                .arg(primer->getStart())
                 .arg(primer->getLength()));
             return false;
         }
