@@ -9,7 +9,7 @@
 *****************************************************************/
 
 #include "SiteconAlgorithm.h"
-#include "DIProperties.h"
+#include "DIPropertiesSitecon.h"
 
 #include "SiteconMath.h"
 
@@ -29,24 +29,24 @@ static LogCategory log(ULOG_CAT_SITECON);
 
 QVector<PositionStats> SiteconAlgorithm::calculateDispersionAndAverage(const MAlignment& ma, const SiteconBuildSettings& config, TaskStateInfo& ts) 
 {
-    const QList<DiProperty*>& props = config.props;
+    const QList<DiPropertySitecon*>& props = config.props;
     assert(!props.isEmpty());
     QVector<PositionStats> matrix;
-    int N = ma.getNumSequences();
+    int N = ma.getNumRows();
     for (int i = 0, n = ma.getLength()-1; i < n && !ts.cancelFlag; i++) { //for every di-nucl
         PositionStats posResult;
-        foreach(DiProperty* p, props) { // for every property
+        foreach(DiPropertySitecon* p, props) { // for every property
             float average = 0; //average in a column
-            foreach(const MAlignmentItem& item, ma.alignedSeqs) { // collect di-position stat for all sequence in alignment
-                average+=p->getOriginal(item.sequence[i], item.sequence[i+1]);
+            foreach(const MAlignmentRow& row, ma.getRows()) { // collect di-position stat for all sequence in alignment
+                average+=p->getOriginal(row.chatAt(i), row.chatAt(i+1));
             }
             average/=N;
 
             float dispersion = 0; // dispersion in a column
-            for (int j = 0; j<ma.alignedSeqs.size(); j++) {// collect di-position stat for all sequence in alignment
-                const MAlignmentItem& item = ma.alignedSeqs[j];
-                char c1 = item.sequence[i];
-                char c2 = item.sequence[i+1];
+            for (int j = 0; j < ma.getNumRows(); j++) {// collect di-position stat for all sequence in alignment
+                const MAlignmentRow& row = ma.getRow(j);
+                char c1 = row.chatAt(i);
+                char c2 = row.chatAt(i+1);
                 float v = p->getOriginal(c1, c2);
                 dispersion+=(average - v)*(average - v);
             }
@@ -67,6 +67,7 @@ QVector<PositionStats> SiteconAlgorithm::calculateDispersionAndAverage(const MAl
 
 float SiteconAlgorithm::calculatePSum(const char* seq, int len, const QVector<PositionStats>& normalizedMatrix, 
                                       const SiteconBuildSettings& config, float devThreshold, DNATranslation* complMap) {
+    Q_UNUSED(config);
     assert(len == config.windowSize);
     bool complement = complMap!=NULL;
     QByteArray complMapper = complement ? complMap->getOne2OneMapper() : QByteArray();
@@ -76,7 +77,7 @@ float SiteconAlgorithm::calculatePSum(const char* seq, int len, const QVector<Po
         char c1 = seq[i];
         char c2 = seq[i+1];
         if (complement) {
-            char origC2 = c2; c2 = complMapper[c1]; c1 = complMapper[origC2];
+            char origC2 = c2; c2 = complMapper[uchar(c1)]; c1 = complMapper[uchar(origC2)];
         }
         const PositionStats& posProps = complement ? normalizedMatrix[len-1 - 1 - i] : normalizedMatrix[i];
         assert(posProps.size() == config.props.size());
@@ -115,14 +116,15 @@ QVector<float> SiteconAlgorithm::calculateFirstTypeError(const MAlignment& ma, c
     // 2. Calculate score for excluded sequence
     // 3. Distribute percentage for all scores
 
-    for (int i=0; i < ma.getNumSequences() && !ts.cancelFlag; i++) {
-        const MAlignmentItem& item = ma.alignedSeqs[i];
+	int maLen = ma.getLength();
+    for (int i=0; i < ma.getNumRows() && !ts.cancelFlag; i++) {
+        const MAlignmentRow& row = ma.getRow(i);
         MAlignment subMA = ma;
-        subMA.alignedSeqs.removeAt(i);
+        subMA.removeRow(i);
         QVector<PositionStats> matrix = calculateDispersionAndAverage(subMA, s, ts);
         QVector<PositionStats> normalizedMatrix = normalize(matrix, s);
         calculateWeights(subMA, normalizedMatrix, s, true, ts);
-        float p = calculatePSum(item.sequence.constData(), item.sequence.length(), normalizedMatrix, s, devThresh);
+        float p = calculatePSum(row.toByteArray(maLen), maLen, normalizedMatrix, s, devThresh);
         scores.append(p);
     }
     QVector<float> res(100, 0);
@@ -208,14 +210,13 @@ QVector<PositionStats> SiteconAlgorithm::normalize(const QVector<PositionStats>&
 
 
 void SiteconAlgorithm::calculateACGTContent(const MAlignment& ma, SiteconBuildSettings& bs) {
-    assert(ma.alphabet->isNucleic());
+    assert(ma.getAlphabet()->isNucleic());
     bs.acgtContent[0] = bs.acgtContent[1] = bs.acgtContent[2] = bs.acgtContent[3] = 0;
-    int total = ma.getNumSequences() * ma.getLength();
-    foreach(const MAlignmentItem& item, ma.alignedSeqs) {
-        int len = item.sequence.length();
-        const char* seq = item.sequence.constData();
-        for (int i=0; i<len; i++) {
-            char c = seq[i];
+	int maLen = ma.getLength();
+    int total = ma.getNumRows() * ma.getLength();
+    foreach(const MAlignmentRow& row, ma.getRows()) {
+		for (int i=0; i < maLen; i++) {
+            char c = row.chatAt(i);
             if (c == 'A') {
                 bs.acgtContent[0]++;
             } else if (c == 'C') {
@@ -275,7 +276,7 @@ typedef QVector< QVector<float> > PWVector;
 static void dumpWeights(const QString& url, const PWVector& weights, const SiteconBuildSettings& settings) {
     QVector<QByteArray> wght(settings.props.size());
     for(int j = 0; j < settings.props.size(); j++) {
-        const DiProperty* p = settings.props[j];
+        const DiPropertySitecon* p = settings.props[j];
         QString name = p->keys.value("PV");
         QString index = p->keys.value("MI");
         wght[j].append(index).append(";").append(name);
@@ -347,7 +348,7 @@ int SiteconAlgorithm::calculateWeights(const MAlignment& ma, QVector<PositionSta
 
     //Part1
     //1. compute props ave on random sequence
-    int rndSeqLen = modelSize * ma.getNumSequences() + 10;
+    int rndSeqLen = modelSize * ma.getNumRows() + 10;
     QByteArray rndSeqArray = generateRandomSequence(settings.acgtContent, rndSeqLen, si);
     const char* rndSeq = rndSeqArray.constData();
     
@@ -405,9 +406,9 @@ int SiteconAlgorithm::calculateWeights(const MAlignment& ma, QVector<PositionSta
             const DiStat& ds = ps[j];
             float maxProp = 100;
             if (ds.sdeviation < devThreshold) {
-                for(int k=0; k < ma.getNumSequences(); k++) {
-                    char c1 = ma.getBase(k, i);
-                    char c2 = ma.getBase(k, i+1);
+                for(int k = 0; k < ma.getNumRows(); k++) {
+                    char c1 = ma.charAt(k, i);
+                    char c2 = ma.charAt(k, i+1);
 
                     if (c1 == 'N' || c2=='N')  {
                         continue;
@@ -517,7 +518,7 @@ bool SiteconModel::checkState(bool doAssert) const {
             if (ds.weighted) {
                 nWeights++;
             }
-            const DiProperty* p = settings.props[i];
+            const DiPropertySitecon* p = settings.props[i];
             assert(!doAssert || ds.prop == p);
             if (ds.prop!=p) {
                 return false;
