@@ -21,15 +21,15 @@
 namespace GB2 {
 
 class MAlignment;
-class DiProperty;
+class DiPropertySitecon;
 
 //average and deviation for one property
 class DiStat {
 public:
-    DiStat(DiProperty* p, float d, float a): prop(p), sdeviation(d), average(a), weighted(false){}
+    DiStat(DiPropertySitecon* p, float d, float a): prop(p), sdeviation(d), average(a), weighted(false){}
     DiStat(): prop(NULL), sdeviation(-1), average(-1), weighted(false){}
 
-    DiProperty* prop;
+    DiPropertySitecon* prop;
     float       sdeviation;
     float       average;
     bool        weighted;
@@ -56,7 +56,7 @@ public:
     int                 numSequencesInAlignment;
     SiteconWeightAlg    weightAlg;
     int                 acgtContent[4];
-    QList<DiProperty*>  props;
+    QList<DiPropertySitecon*>  props;
 };
 
 
