@@ -9,7 +9,7 @@
 *****************************************************************/
 
 #include "SiteconAlgorithmTests.h"
-#include "DIProperties.h"
+#include "DIPropertiesSitecon.h"
 #include "SiteconIO.h"
 
 #include <core_api/DocumentModel.h>
@@ -194,7 +194,7 @@ void GTest_CalculateDispersionAndAverage::run() {
     DinucleotitePropertyRegistry di;
     s.props = di.getProperties();
     SiteconAlgorithm::calculateACGTContent(ma, s);
-    s.numSequencesInAlignment = ma.getNumSequences();
+    s.numSequencesInAlignment = ma.getNumRows();
     TaskStateInfo stub;
     result = SiteconAlgorithm::calculateDispersionAndAverage(ma, s, stub);
 }
@@ -282,7 +282,7 @@ void GTest_CalculateFirstTypeError::run() {
     DinucleotitePropertyRegistry di;
     s.props = di.getProperties();
     SiteconAlgorithm::calculateACGTContent(ma, s);
-    s.numSequencesInAlignment = ma.getNumSequences();
+    s.numSequencesInAlignment = ma.getNumRows();
     s.windowSize = ma.getLength();
     TaskStateInfo stub;
     result = SiteconAlgorithm::calculateFirstTypeError(ma, s, stub);
@@ -363,10 +363,10 @@ void GTest_CalculateSecondTypeError::run() {
     DinucleotitePropertyRegistry di;
     s.props = di.getProperties();
     SiteconAlgorithm::calculateACGTContent(ma, s);
-    s.numSequencesInAlignment = ma.getNumSequences();
+    s.numSequencesInAlignment = ma.getNumRows();
     s.windowSize = ma.getLength();
     SiteconModel m;
-    m.aliURL = (getContext<Document>(this, docName))->getURL();
+    m.aliURL = (getContext<Document>(this, docName))->getURLString();
     m.modelName = QFileInfo(m.aliURL).baseName();
     m.settings = s;
     m.matrix = SiteconAlgorithm::calculateDispersionAndAverage(ma, s, stateInfo);
