@@ -166,7 +166,6 @@ SiteconBuildTask::SiteconBuildTask(const SiteconBuildSettings& s, const MAlignme
 
 void SiteconBuildTask::run() {
     // compute average/dispersion matrix
-    assert(ma.isNormalized());
     if (ma.hasGaps()) {
         stateInfo.setError(  tr("alignment_has_gaps") );
         return;
@@ -175,7 +174,7 @@ void SiteconBuildTask::run() {
         stateInfo.setError(  tr("alignment_is_empty") );
         return;
     }
-    if (!ma.alphabet->isNucleic()) {
+    if (!ma.getAlphabet()->isNucleic()) {
         stateInfo.setError(  tr("alignment_is_not_nucleic") );
         return;
     }
@@ -188,11 +187,11 @@ void SiteconBuildTask::run() {
     int startPos = centerPos - settings.windowSize / 2;
     int endPos = centerPos + (settings.windowSize - settings.windowSize / 2);
     assert(startPos >=0 && endPos <= ma.getLength());
-    ma = ma.subAlignment(startPos, endPos - startPos);
+    ma = ma.mid(startPos, endPos - startPos);
     assert(ma.getLength() == settings.windowSize);
 
     SiteconAlgorithm::calculateACGTContent(ma, settings);
-    settings.numSequencesInAlignment = ma.getNumSequences();
+    settings.numSequencesInAlignment = ma.getNumRows();
     m.settings = settings;
     stateInfo.setStateDesc(tr("calculating_ave_disp_matrix"));
     m.matrix = SiteconAlgorithm::calculateDispersionAndAverage(ma, settings, stateInfo);
@@ -225,7 +224,7 @@ SiteconBuildToFileTask::SiteconBuildToFileTask(const QString& inFile, const QStr
     
     DocumentFormatConstraints c;
     c.checkRawData = true;
-    c.supportedObjectTypes.append(GObjectTypes::MULTIPLE_ALIGNMENT);
+    c.supportedObjectTypes += GObjectTypes::MULTIPLE_ALIGNMENT;
     c.rawData = BaseIOAdapters::readFileHeader(inFile);
     QList<DocumentFormatId> formats = AppContext::getDocumentFormatRegistry()->selectFormats(c);
     if (formats.isEmpty()) {
@@ -260,8 +259,8 @@ QList<Task*> SiteconBuildToFileTask::onSubTaskFinished(Task* subTask) {
         } else {
             MAlignmentObject* mobj =  qobject_cast<MAlignmentObject*>(mobjs.first());
             MAlignment ma = mobj->getMAlignment();
-            QFileInfo fi(mobj->getDocument()->getURL());
-            buildTask = new SiteconBuildTask(settings, ma, fi.baseName());
+            QString baseName = mobj->getDocument()->getURL().baseFileName();
+            buildTask = new SiteconBuildTask(settings, ma, baseName);
             res.append(buildTask);
         }
     } else if (subTask == buildTask) {
