@@ -13,7 +13,7 @@
 #include "SiteconPlugin.h"
 #include "SiteconBuildDialogController.h"
 
-#include <workflow/TypeSet.h>
+#include <workflow/Datatype.h>
 #include <workflow/IntegralBusModel.h>
 #include <workflow/WorkflowEnv.h>
 #include <workflow/WorkflowRegistry.h>
@@ -21,6 +21,7 @@
 #include <workflow_library/BioDatatypes.h>
 #include <workflow_library/BioActorLibrary.h>
 #include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
 
 #include <core_api/Log.h>
 #include <datatype/MAlignment.h>
@@ -31,14 +32,10 @@
 namespace GB2 {
 namespace LocalWorkflow {
 
-static const QString IN_PORT("in");
-static const QString OUT_PORT("out");
-static const QString URL_SLOT("URL");
-
-static const QString WINDOW_ATTR("1window");
-static const QString LEN_ATTR("2len");
-static const QString SEED_ATTR("3seed");
-static const QString ALG_ATTR("4algo");
+static const QString WINDOW_ATTR("a_window");
+static const QString LEN_ATTR("b_len");
+static const QString SEED_ATTR("c_seed");
+static const QString ALG_ATTR("d_algo");
 
 const QString SiteconBuildWorker::ACTOR_ID("sitecon.build");
 
@@ -47,13 +44,13 @@ static LogCategory log(ULOG_CAT_WD);
 void SiteconBuildWorker::registerProto() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
     QMap<Descriptor, DataTypePtr> m;
-    Descriptor id(IN_PORT, SiteconBuildWorker::tr("Input alignment"), SiteconBuildWorker::tr("Input multiple sequence alignment for building statistical model."));
-    Descriptor ud(URL_SLOT, SiteconBuildWorker::tr("Origin"), SiteconBuildWorker::tr("Location of input alignment, used as optional hint for model description."));
+    Descriptor id(CoreLibConstants::IN_PORT_ID, SiteconBuildWorker::tr("Input alignment"), SiteconBuildWorker::tr("Input multiple sequence alignment for building statistical model."));
+    Descriptor ud(CoreLibConstants::URL_SLOT_ID, SiteconBuildWorker::tr("Origin"), SiteconBuildWorker::tr("Location of input alignment, used as optional hint for model description."));
     m[ud] = CoreDataTypes::STRING_TYPE();
     m[id] = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE();
-    DataTypePtr t(new DataTypeSet(Descriptor("build.sitecon.content"), m));
+    DataTypePtr t(new MapDataType(Descriptor("build.sitecon.content"), m));
 
-    Descriptor od(OUT_PORT, SiteconBuildWorker::tr("Sitecon model"), SiteconBuildWorker::tr("Produced statistical model of specified TFBS data."));
+    Descriptor od(CoreLibConstants::OUT_PORT_ID, SiteconBuildWorker::tr("Sitecon model"), SiteconBuildWorker::tr("Produced statistical model of specified TFBS data."));
     p << new PortDescriptor(id, t, true /*input*/);
     p << new PortDescriptor(od, SiteconWorkerFactory::SITECON_MODEL_TYPE(), false /*input*/, true /*multi*/);
     
@@ -104,8 +101,8 @@ void SiteconBuildWorker::registerProto() {
 }
 
 QString SiteconBuildPrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(IN_PORT));
-    Actor* msaProducer = input->getProducer(IN_PORT);
+    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
+    Actor* msaProducer = input->getProducer(CoreLibConstants::IN_PORT_ID);
 
     QString msaName = msaProducer ? tr("For each MSA from <u>%1</u>,").arg(msaProducer->getLabel()) : "";
     QString doc = tr("%1 build SITECON model.")
@@ -115,15 +112,8 @@ QString SiteconBuildPrompter::composeRichDoc() {
 }
 
 void SiteconBuildWorker::init() {
-    input = ports.value(IN_PORT);
-    output = ports.value(OUT_PORT);
-
-    cfg.props = SiteconPlugin::getDinucleotiteProperties();
-    cfg.randomSeed = actor->getParameter(SEED_ATTR)->value.toInt();
-    cfg.secondTypeErrorCalibrationLen = actor->getParameter(LEN_ATTR)->value.toInt();
-    cfg.weightAlg = SiteconWeightAlg(actor->getParameter(ALG_ATTR)->value.toInt());
-    cfg.windowSize = actor->getParameter(WINDOW_ATTR)->value.toInt();
-    mtype = SiteconWorkerFactory::SITECON_MODEL_TYPE();
+    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    output = ports.value(CoreLibConstants::OUT_PORT_ID);
 }
 
 bool SiteconBuildWorker::isReady() {
@@ -131,11 +121,18 @@ bool SiteconBuildWorker::isReady() {
 }
 
 Task* SiteconBuildWorker::tick() {
-    QVariantMap data = input->get().getData().toMap();
+    Message inputMessage = getMessageAndSetupScriptValues(input);
+    cfg.props = SiteconPlugin::getDinucleotiteProperties();
+    cfg.randomSeed = actor->getParameter(SEED_ATTR)->getAttributeValue<int>();
+    cfg.secondTypeErrorCalibrationLen = actor->getParameter(LEN_ATTR)->getAttributeValue<int>();
+    cfg.weightAlg = SiteconWeightAlg(actor->getParameter(ALG_ATTR)->getAttributeValue<int>());
+    cfg.windowSize = actor->getParameter(WINDOW_ATTR)->getAttributeValue<int>();
+    mtype = SiteconWorkerFactory::SITECON_MODEL_TYPE();
+    QVariantMap data = inputMessage.getData().toMap();
     SiteconModel model = data.value(SiteconWorkerFactory::SITECON_MODEL_TYPE_ID).value<SiteconModel>();
-    QString url = data.value(URL_SLOT).toString();
-
-    const MAlignment& ma = data.value(IN_PORT).value<MAlignment>();
+    QString url = data.value(CoreLibConstants::URL_SLOT_ID).toString();
+    
+    const MAlignment& ma = data.value(CoreLibConstants::IN_PORT_ID).value<MAlignment>();
     Task* t = new SiteconBuildTask(cfg, ma, url);
     connect(t, SIGNAL(si_stateChanged()), SLOT(sl_taskFinished()));
     return t;
