@@ -9,15 +9,19 @@
 *****************************************************************/
 
 #include "SiteconIO.h"
-#include "DIProperties.h"
+#include "DIPropertiesSitecon.h"
 #include "SiteconMath.h"
 #include "SiteconPlugin.h"
 
 #include <core_api/AppContext.h>
 #include <core_api/IOAdapter.h>
+#include <core_api/GUrlUtils.h>
+#include <core_api/L10n.h>
+
 #include <util_text/TextUtils.h>
+#include <util_tasks/SaveDocumentTask.h>
+
 #include <util_gui/DialogUtils.h>
-#include <util_gui/GUIUtils.h>
 
 #include <QtCore/QVector>
 #include <memory>
@@ -49,7 +53,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
     SiteconModel model;
     model.modelName = QFileInfo(url).baseName();
 
-    QList<DiProperty*> props = SiteconPlugin::getDinucleotiteProperties();
+    QList<DiPropertySitecon*> props = SiteconPlugin::getDinucleotiteProperties();
     model.settings.props = props;
 
     float defaultVal = -1;
@@ -58,7 +62,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
 
     std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
     if (!io->open(url, IOAdapterMode_Read)) {
-        si.setError(  Translations::errorOpeningFileRead(url) );
+        si.setError(  L10N::errorOpeningFileRead(url) );
         return model;
     }
     QByteArray text;
@@ -72,7 +76,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
     while ((blockLen = io->readBlock(block.data(), BUFF_SIZE)) > 0) {
         text.append(QByteArray::fromRawData(block.data(), blockLen));
         if (text.size() > 1000*1000) {
-            si.setError(Translations::errorFileTooLarge(url));
+            si.setError(L10N::errorFileTooLarge(url));
             break;
         }
     }
@@ -194,7 +198,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
                     //compute property idx
                     int idx = -1;
                     for (int i=0 ; i < props.size(); i++) {
-                        const DiProperty* p = props[i];
+                        const DiPropertySitecon* p = props[i];
                         QString thisPNum =  p->keys.value("MI");
                         if (thisPNum == propNum) {
                             idx = i;
@@ -354,7 +358,7 @@ void SiteconIO::writeModel(IOAdapterFactory* iof, const QString& url, TaskStateI
     res.append(FILE_HEADER).append("\n\n");
     assert(model.settings.windowSize == model.matrix.size() + 1);
 
-    const QList<DiProperty*>& props = model.settings.props;
+    const QList<DiPropertySitecon*>& props = model.settings.props;
     int nProps = props.size();
     QVector<QByteArray> aves, sdev, wght;
     aves.resize(nProps);
@@ -362,7 +366,7 @@ void SiteconIO::writeModel(IOAdapterFactory* iof, const QString& url, TaskStateI
     wght.resize(nProps);
 
     for(int j = 0; j < nProps; j++) {
-        const DiProperty* p = props[j];
+        const DiPropertySitecon* p = props[j];
         QString name = p->keys.value("PV");
         QString index = p->keys.value("MI");
         aves[j].append(index).append(MATRIX_VAL_SEPARATOR).append(name);
@@ -436,12 +440,12 @@ void SiteconIO::writeModel(IOAdapterFactory* iof, const QString& url, TaskStateI
 
     std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
     if (!io->open(url, IOAdapterMode_Write)) {
-        si.setError(  Translations::errorOpeningFileWrite(url) );
+        si.setError(  L10N::errorOpeningFileWrite(url) );
         return;
     }
     int len = io->writeBlock(res);
     if (len != res.size()) {
-        si.setError(  Translations::errorWritingFile(url) );
+        si.setError(  L10N::errorWritingFile(url) );
         return;
     }
     io->close();
@@ -454,7 +458,7 @@ void SiteconReadTask::run() {
 
 void SiteconWriteTask::run() {
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(url));
-    if (fileMode & SaveDoc_Roll && !DialogUtils::rollFile(url, stateInfo)) {
+    if (fileMode & SaveDoc_Roll && !GUrlUtils::renameFileWithNameRoll(url, stateInfo)) {
         return;
     }
     SiteconIO::writeModel(iof, url, stateInfo, model);
