@@ -21,7 +21,7 @@
 namespace  GB2 {
 
 class IOAdapterFactory;
-class DiProperty;
+class DiPropertySitecon;
 
 class SiteconIO : public QObject {
     Q_OBJECT
@@ -41,7 +41,7 @@ public:
         : Task(tr("Read SITECON model"), TaskFlag_None), url(url) {}
     void run();
     SiteconModel getResult() const {return model;}
-    QString getUrl() const {return url;}
+    QString getURL() const {return url;}
 private:
     QString url;
     SiteconModel model;
