@@ -61,7 +61,7 @@ double  poz (double z)
 
 double	 pochisq (double x, int df)/* obtained chi-square value  degrees of freedom */
 {
-    double	a, y, s;
+    double	a, y = 0., s;
     double	e, c, z;
     /* computes probability of normal z score */
     int 	even;     /* true if df is an even number */
