@@ -125,7 +125,7 @@ QList<XMLTestFactory*> SiteconAlgorithmTests::createTestFactories() {
     QList<XMLTestFactory*> res;
     res.append(GTest_CalculateACGTContent::createFactory());
     res.append(GTest_CalculateDispersionAndAverage::createFactory());
-    res.append(GTest_DiPropertyCheckAttribs::createFactory());
+    res.append(GTest_DiPropertySiteconCheckAttribs::createFactory());
     res.append(GTest_CalculateFirstTypeError::createFactory());
     res.append(GTest_CalculateSecondTypeError::createFactory());
     res.append(GTest_SiteconSearchTask::createFactory());
