@@ -11,7 +11,7 @@
 #ifndef _GB2_SITECON_PLUGIN_H_
 #define _GB2_SITECON_PLUGIN_H_
 
-#include "DIProperties.h"
+#include "DIPropertiesSitecon.h"
 
 #include <core_api/PluginModel.h>
 #include <core_api/ObjectViewModel.h>
@@ -29,7 +29,7 @@ public:
     SiteconPlugin();
     ~SiteconPlugin();
 
-    static QList<DiProperty*> getDinucleotiteProperties() {return dp.getProperties();}
+    static QList<DiPropertySitecon*> getDinucleotiteProperties() {return dp.getProperties();}
 
 protected slots:
     void sl_build();
