@@ -97,6 +97,7 @@ SiteconSearchDialogController::SiteconSearchDialogController(ADVSequenceObjectCo
 SiteconSearchDialogController::~SiteconSearchDialogController() {
     if (model!=NULL) {
         delete model;
+        model = NULL;
     }
 }
 
@@ -151,7 +152,7 @@ bool SiteconSearchDialogController::eventFilter(QObject *obj, QEvent *ev) {
     if (obj == resultsTree && ev->type() == QEvent::KeyPress) {
         QKeyEvent* ke = (QKeyEvent*)ev;
         if (ke->key() == Qt::Key_Space) {
-            SiteconResultItem* item = (SiteconResultItem*)resultsTree->currentItem();
+            SiteconResultItem* item = static_cast<SiteconResultItem*>(resultsTree->currentItem());
             if (item != NULL) {
                 sl_onResultActivated(item, 0);
             }
@@ -184,6 +185,7 @@ void SiteconSearchDialogController::sl_selectModelFile() {
 void SiteconSearchDialogController::updateModel(const SiteconModel& m) {
     if (model!=NULL) {
         delete model;
+        model = NULL;
     }
     model = new SiteconModel();
     *model =  m;
@@ -236,7 +238,7 @@ void SiteconSearchDialogController::sl_onSaveAnnotations() {
     const QString& name = m.data->name;
     QList<SharedAnnotationData> list;
     for (int i=0, n = resultsTree->topLevelItemCount(); i<n; ++i) {
-        SiteconResultItem* item = (SiteconResultItem* )resultsTree->topLevelItem(i);
+        SiteconResultItem* item = static_cast<SiteconResultItem* >(resultsTree->topLevelItem(i));
         list.append(item->res.toAnnotation(name));
     }
 
@@ -338,7 +340,7 @@ void SiteconSearchDialogController::importResults() {
 void SiteconSearchDialogController::sl_onResultActivated(QTreeWidgetItem* i, int col) {
     Q_UNUSED(col);
     assert(i);
-    SiteconResultItem* item = (SiteconResultItem*)i;
+    SiteconResultItem* item = static_cast<SiteconResultItem*>(i);
     DNASequenceSelection* sel = ctx->getSequenceSelection();
     sel->clear();
     sel->addRegion(item->res.region);
