@@ -28,7 +28,7 @@ class DNASequenceObject;
 class SiteconSearchTask;
 class Task;
 class SiteconResultItem;
-class DiProperty;
+class DiPropertySitecon;
 class SiteconModel;
 
 class SiteconSearchDialogController : public QDialog, public Ui_SiteconSearchDialog {
