@@ -19,6 +19,7 @@
 #include <workflow_library/BioDatatypes.h>
 #include <workflow_library/BioActorLibrary.h>
 #include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
 
 #include <datatype/DNASequence.h>
 #include <core_api/DNATranslation.h>
@@ -37,13 +38,12 @@ namespace LocalWorkflow {
 
 static const QString MODEL_PORT("model");
 static const QString SEQ_PORT("seq");
-static const QString OUT_PORT("out");
 
-static const QString NAME_ATTR("1name");
-static const QString STRAND_ATTR("2strand");
-static const QString SCORE_ATTR("3score");
-static const QString E1_ATTR("4err1");
-static const QString E2_ATTR("5err2");
+static const QString NAME_ATTR("a_name");
+static const QString STRAND_ATTR("b_strand");
+static const QString SCORE_ATTR("c_score");
+static const QString E1_ATTR("d_err1");
+static const QString E2_ATTR("e_err2");
 
 const QString SiteconSearchWorker::ACTOR_ID("sitecon.search");
 
@@ -54,7 +54,7 @@ void SiteconSearchWorker::registerProto() {
     {
         Descriptor md(MODEL_PORT, SiteconSearchWorker::tr("Sitecon Model"), SiteconSearchWorker::tr("Profile data to search with."));
         Descriptor sd(SEQ_PORT, SiteconSearchWorker::tr("Sequence"), SiteconSearchWorker::tr("Input nucleotide sequence to search in."));
-        Descriptor od(OUT_PORT, SiteconSearchWorker::tr("SITECON annotations"), SiteconSearchWorker::tr("Annotations marking found TFBS sites."));
+        Descriptor od(CoreLibConstants::OUT_PORT_ID, SiteconSearchWorker::tr("SITECON annotations"), SiteconSearchWorker::tr("Annotations marking found TFBS sites."));
         p << new PortDescriptor(md, SiteconWorkerFactory::SITECON_MODEL_TYPE(), true /*input*/, false, BusPort::BLIND_INPUT);
         p << new PortDescriptor(sd, BioDataTypes::DNA_SEQUENCE_TYPE(), true /*input*/);
         p << new PortDescriptor(od, BioDataTypes::ANNOTATION_TABLE_TYPE(), false /*input*/, true /*multi*/);
@@ -137,15 +137,15 @@ QString SiteconSearchPrompter::composeRichDoc() {
 void SiteconSearchWorker::init() {
     modelPort = ports.value(MODEL_PORT);
     dataPort = ports.value(SEQ_PORT);
-    output = ports.value(OUT_PORT);
+    output = ports.value(CoreLibConstants::OUT_PORT_ID);
     dataPort->addComplement(output);
     output->addComplement(dataPort);
 
-    strand = actor->getParameter(STRAND_ATTR)->value.toInt();
-    cfg.minPSUM = actor->getParameter(SCORE_ATTR)->value.toInt();
-    cfg.minE1 = actor->getParameter(E1_ATTR)->value.toDouble();
-    cfg.maxE2 = 1./actor->getParameter(E2_ATTR)->value.toInt();
-    resultName = actor->getParameter(NAME_ATTR)->value.toString();
+    strand = actor->getParameter(STRAND_ATTR)->getAttributeValue<int>();
+    cfg.minPSUM = actor->getParameter(SCORE_ATTR)->getAttributeValue<int>();
+    cfg.minE1 = actor->getParameter(E1_ATTR)->getAttributeValue<double>();
+    cfg.maxE2 = 1./actor->getParameter(E2_ATTR)->getAttributeValue<int>();
+    resultName = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
 }
 
 bool SiteconSearchWorker::isReady() {
