@@ -64,7 +64,7 @@ public:
     static void registerProto();
 
     SiteconSearchWorker(Actor* a) : BaseWorker(a, false), //FIXME??
-        modelPort(NULL), dataPort(NULL), output(NULL) {}
+        modelPort(NULL), dataPort(NULL), output(NULL), strand(0) {}
     virtual void init() ;
     virtual bool isReady();
     virtual Task* tick() ;
