@@ -1,121 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ru_RU">
-<context>
-    <name>GB2::GTest</name>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="420"/>
-        <source>value not set %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="44"/>
-        <source>here must be 4 items in %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="321"/>
-        <source>Wrong conversion to the integer for one of the %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="59"/>
-        <source>Wrong %1 values</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="331"/>
-        <source>context not found %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="336"/>
-        <source>container of object with type &quot;%1&quot; is empty</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="341"/>
-        <source>object with type &quot;%1&quot; not found</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="346"/>
-        <source>error can&apos;t cast to MAlignmentObject from GObject</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="95"/>
-        <source>Actual results not equal with expected</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="145"/>
-        <source>Too less items in %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="203"/>
-        <source>Expected and Actual &apos;SDev&apos; values are different: %1 %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="207"/>
-        <source>Expected and Actual &apos;Average&apos; values are different: %1 %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="376"/>
-        <source>Expected and Actual values are different: %1 %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="455"/>
-        <source>%1 has incorrect value</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="437"/>
-        <source>unable to convert %1 to integer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="460"/>
-        <source>unable to convert %1 to float</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="475"/>
-        <source>error can&apos;t cast to sequence from GObject</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="512"/>
-        <source>expected and equal result lists not equal by size, expected: %1, actual: %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconAlgorithmTests.cpp" line="525"/>
-        <source>expected and equal result lists not equal</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/DIPropertiesTests.cpp" line="46"/>
-        <source>Wrong conversion to the integer for %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/DIPropertiesTests.cpp" line="67"/>
-        <source>Given key &apos;%1&apos; don&apos;t present in property map</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>GB2::IOAdapter</name>
-    <message>
-        <location filename="../src/SiteconIO.cpp" line="62"/>
-        <source>file_is_too_large</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
+<!DOCTYPE TS>
+<TS version="2.0" language="ru_RU">
 <context>
     <name>GB2::LocalWorkflow::SiteconBuildPrompter</name>
     <message>
@@ -124,7 +9,7 @@
         <translation>Для каждого выравнивания из &lt;u&gt;%1&lt;/u&gt;,</translation>
     </message>
     <message>
-        <location filename="../src/SiteconBuildWorker.cpp" line="102"/>
+        <location filename="../src/SiteconBuildWorker.cpp" line="101"/>
         <source>%1 build SITECON model.</source>
         <translation>%1 построить профайл SITECON.</translation>
     </message>
@@ -210,7 +95,7 @@
 <context>
     <name>GB2::LocalWorkflow::SiteconReadPrompter</name>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="142"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="151"/>
         <source>Read model(s) from &lt;u&gt;%1&lt;/u&gt;</source>
         <translation>Загрузить профайлы SITECON из &lt;u&gt;%1&lt;/u&gt;.</translation>
     </message>
@@ -218,7 +103,7 @@
 <context>
     <name>GB2::LocalWorkflow::SiteconReader</name>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="183"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="192"/>
         <source>Loaded SITECON model from %1</source>
         <translation>Загружен профайл SITECON из %1</translation>
     </message>
@@ -226,17 +111,17 @@
 <context>
     <name>GB2::LocalWorkflow::SiteconSearchPrompter</name>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="85"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="103"/>
         <source>For each sequence from &lt;u&gt;%1&lt;/u&gt;,</source>
         <translation>Для каждой последовательности из &lt;u&gt;%1&lt;/u&gt;,</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="100"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="115"/>
         <source>%1 search transcription factor binding sites (TFBS) %2.&lt;br&gt;Recognize sites with &lt;u&gt;similarity %3%&lt;/u&gt;, process &lt;u&gt;%4&lt;/u&gt;.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
         <translation>%1 искать сайты связывания ТФ %2.&lt;br&gt;Распознавать сайты с достоверностью &lt;u&gt;не менее %3%&lt;/u&gt;, рассматривать &lt;u&gt;%4 стренды&lt;/u&gt;.&lt;br&gt;Выдать список найденных регионов аннотированных как &lt;u&gt;%5&lt;/u&gt;.</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="86"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="104"/>
         <source>with all profiles provided by &lt;u&gt;%1&lt;/u&gt;,</source>
         <translation>со всеми профайлами из &lt;u&gt;%1&lt;/u&gt;,</translation>
     </message>
@@ -244,100 +129,132 @@
 <context>
     <name>GB2::LocalWorkflow::SiteconSearchWorker</name>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="92"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="88"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="110"/>
         <source>both strands</source>
         <translation>все</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="93"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="89"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="111"/>
         <source>direct strand</source>
         <translation>только прямые</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="94"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="90"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="112"/>
         <source>complement strand</source>
         <translation>только комплиментарные</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="41"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="45"/>
         <source>Sitecon Model</source>
         <translation>Профайл SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="42"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="46"/>
         <source>Sequence</source>
         <translation>Входная последовательность</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="43"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="47"/>
         <source>SITECON annotations</source>
         <translation>Аннотированные ССТФ</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="49"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="53"/>
         <source>Result annotation</source>
         <translation>Аннотации</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="50"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="54"/>
         <source>Search in</source>
         <translation>Направление</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="51"/>
-        <source>Minimal threshold, %</source>
-        <translation>Достоверность, %</translation>
-    </message>
-    <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="147"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="168"/>
         <source>Search TFBS in %1</source>
         <translation>Поиск ССТФ в %1</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="167"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="172"/>
+        <source>Bad sequence supplied to SiteconSearch: %1</source>
+        <translation>Неправильная последовательность для SITECON поиска : %1</translation>
+    </message>
+    <message>
+        <location filename="../src/SiteconSearchWorker.cpp" line="196"/>
         <source>Found %1 TFBS</source>
         <translation>Найдено %1 возможных сайтов связывания ТФ</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="41"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="45"/>
         <source>Profile data to search with.</source>
         <translation>Профайл SITECON характеризующий искомые сайты.</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="42"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="46"/>
         <source>Input nucleotide sequence to search in.</source>
         <translation>Входная нуклеотидная последовательность для поиска.</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="43"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="47"/>
         <source>Annotations marking found TFBS sites.</source>
         <translation>Аннотации маркирующие найденные регионы.</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="49"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="53"/>
         <source>Annotation name for marking found regions</source>
         <translation>Имя аннотации для разметки найденных регионов.</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="50"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="54"/>
         <source>Which strands should be searched: direct, complement or both.</source>
         <translation>В каких стрендах последовательности следует искать ССТФ: прямых, комплементарных или всех.</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="57"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="67"/>
         <source>Search TFBS</source>
         <translation>Поиск ССТФ</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchWorker.cpp" line="60"/>
+        <location filename="../src/SiteconSearchWorker.cpp" line="68"/>
         <source>Searches each input sequence for transcription factor binding sites significantly similar to specified SITECON profiles. In case several profiles were supplied, searches with all profiles one by one and outputs merged set of annotations for each sequence.</source>
         <translation>Поиск сайтов связывания транскрипционных факторов (ССТФ). В каждой нуклеотидной последовательности, поданной на вход задачи, ищутся значимые совпадения с указанными профайлами SITECON. Найденные регионы выдаются в виде набора аннотаций. Профайлов может быть несколько, поиск отработает для каждого профайла и выдаст общий набор аннотаций для каждой последовательности.&lt;p&gt; Протеиновые последовательности на входе допустимы но игнорируются.</translation>
     </message>
+    <message>
+        <source>Minimal threshold</source>
+        <translation type="obsolete">Достоверность</translation>
+    </message>
+    <message>
+        <location filename="../src/SiteconSearchWorker.cpp" line="55"/>
+        <source>Min score</source>
+        <translation>Мин оценка</translation>
+    </message>
+    <message>
+        <location filename="../src/SiteconSearchWorker.cpp" line="56"/>
+        <source>Min Err1</source>
+        <translation>Мин ошибка 1 рода</translation>
+    </message>
+    <message>
+        <location filename="../src/SiteconSearchWorker.cpp" line="56"/>
+        <source>Alternative setting for filtering results, minimal value of Error type I.&lt;br&gt;Note that all thresholds (by score, by err1 and by err2) are applied when filtering results.</source>
+        <translation>Фильтрация результатов по значению ошибки I рода. &lt;br&gt;Учтите что применяются все фильтры (по оценке и ошибкам 1, 2 рода).</translation>
+    </message>
+    <message>
+        <location filename="../src/SiteconSearchWorker.cpp" line="58"/>
+        <source>Max Err2</source>
+        <translation>Макс ошибка 2 рода</translation>
+    </message>
+    <message>
+        <location filename="../src/SiteconSearchWorker.cpp" line="58"/>
+        <source>Alternative setting for filtering results, max value of Error type II.&lt;br&gt;Note that all thresholds (by score, by err1 and by err2) are applied when filtering results.</source>
+        <translation>Фильтрация результатов по значению ошибки II рода. &lt;br&gt;Учтите что применяются все фильтры (по оценке и ошибкам 1, 2 рода).</translation>
+    </message>
 </context>
 <context>
     <name>GB2::LocalWorkflow::SiteconWritePrompter</name>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="153"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="161"/>
         <source>Save the profile(s) from &lt;u&gt;%1&lt;/u&gt; to %2.</source>
         <translation>Сохранить все профайлы из &lt;u&gt;%1&lt;/u&gt; в %2.</translation>
     </message>
@@ -345,7 +262,12 @@
 <context>
     <name>GB2::LocalWorkflow::SiteconWriter</name>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="209"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="210"/>
+        <source>Unspecified URL for writing Sitecon</source>
+        <translation>Не укзазан адрес для записи модели SITECON.</translation>
+    </message>
+    <message>
+        <location filename="../src/SiteconIOWorkers.cpp" line="225"/>
         <source>Writing SITECON model to %1</source>
         <translation>Запись профайла SITECON в %1</translation>
     </message>
@@ -353,9 +275,9 @@
 <context>
     <name>GB2::SiteconADVContext</name>
     <message>
-        <location filename="../src/SiteconPlugin.cpp" line="98"/>
+        <location filename="../src/SiteconPlugin.cpp" line="99"/>
         <source>run_sitecon</source>
-        <translation>Искать сайты связывания ТФ ...</translation>
+        <translation>SITECON: Искать сайты связывания ТФ  ...</translation>
     </message>
 </context>
 <context>
@@ -505,162 +427,167 @@
 <context>
     <name>GB2::SiteconIO</name>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="76"/>
+        <location filename="../src/SiteconIO.cpp" line="79"/>
         <source>not_sitecon_model_file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="115"/>
+        <location filename="../src/SiteconIO.cpp" line="118"/>
         <source>error_parsing_settings_line_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="126"/>
+        <location filename="../src/SiteconIO.cpp" line="129"/>
         <source>error_parsing_settings_window_size_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="139"/>
+        <location filename="../src/SiteconIO.cpp" line="142"/>
         <source>error_parsing_calibration_len_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="145"/>
+        <location filename="../src/SiteconIO.cpp" line="148"/>
         <source>error_parsing_rseed_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="157"/>
+        <location filename="../src/SiteconIO.cpp" line="154"/>
+        <location filename="../src/SiteconIO.cpp" line="160"/>
         <source>error_parsing_nsequence_in_ali_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="165"/>
+        <location filename="../src/SiteconIO.cpp" line="168"/>
         <source>illegal_weight_alg_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="177"/>
+        <location filename="../src/SiteconIO.cpp" line="180"/>
         <source>model_size_not_matched_%1_expected_%2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="210"/>
+        <location filename="../src/SiteconIO.cpp" line="213"/>
         <source>property_not_recognized_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="226"/>
+        <location filename="../src/SiteconIO.cpp" line="229"/>
         <source>error_parsing_matrix_val_%1_in_line_%2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="244"/>
+        <location filename="../src/SiteconIO.cpp" line="247"/>
         <source>error_parsing_errors_line_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="258"/>
+        <location filename="../src/SiteconIO.cpp" line="256"/>
+        <location filename="../src/SiteconIO.cpp" line="261"/>
         <source>error_parsing_error_val_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="262"/>
+        <location filename="../src/SiteconIO.cpp" line="265"/>
         <source>illegal_err_val_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="272"/>
+        <location filename="../src/SiteconIO.cpp" line="275"/>
         <source>error_parsing_file_line_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="281"/>
+        <location filename="../src/SiteconIO.cpp" line="284"/>
         <source>ave_props_in_file_%1_not_matched_sdev_props_%2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="286"/>
+        <location filename="../src/SiteconIO.cpp" line="289"/>
         <source>ave_props_in_file_%1_not_matched_weight_props_%2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="291"/>
+        <location filename="../src/SiteconIO.cpp" line="294"/>
         <source>props_in_file_%1_not_matched_actual_props_%2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="319"/>
+        <location filename="../src/SiteconIO.cpp" line="322"/>
         <source>error_info_not_complete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="326"/>
+        <location filename="../src/SiteconIO.cpp" line="329"/>
         <source>model_verification_error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="200"/>
+        <location filename="../src/SiteconIO.cpp" line="203"/>
         <source>duplicate_prop_%1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/SiteconIOWorkers.cpp" line="39"/>
         <location filename="../src/SiteconIOWorkers.cpp" line="105"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="114"/>
         <source>Sitecon model</source>
         <translation>Профайл SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="90"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="53"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="99"/>
         <source>Location</source>
         <translation>Адрес</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="116"/>
         <source>Read Sitecon model</source>
         <translation>Читать профайл SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="98"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
         <source>Write Sitecon model</source>
         <translation>Сохранить профайл SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="46"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="45"/>
         <source>SITECON</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/SiteconIO.cpp" line="21"/>
+        <location filename="../src/SiteconIO.cpp" line="22"/>
         <source>Sitecon models</source>
         <translation>Профайлы SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="54"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="53"/>
         <source>Location of the data file(s).</source>
         <translation>Адрес файла данных</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="90"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="99"/>
         <source>Location hint for the target file.</source>
         <translation>Адрес целевого файла</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="96"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="105"/>
         <source>Input Sitecon model</source>
         <translation>Входящий профайл SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="98"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
         <source>Saves all input SITECON profiles to specified location.</source>
         <translation>Сохраняет все входящие профайлы SITECON в указанный файл.</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="105"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="114"/>
         <source>Loaded SITECON profile data.</source>
         <translation>Загруженный профайл SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
+        <location filename="../src/SiteconIOWorkers.cpp" line="116"/>
         <source>Reads SITECON profiles from file(s). The files can be local or Internet URLs.</source>
         <translation>Считывает профайл(ы) SITECON из указанных файлов. Файлы могут быть локальными либо адресами Интернет.</translation>
     </message>
@@ -668,23 +595,23 @@
 <context>
     <name>GB2::SiteconPlugin</name>
     <message>
-        <location filename="../src/SiteconPlugin.cpp" line="37"/>
+        <location filename="../src/SiteconPlugin.cpp" line="38"/>
         <source>sitecon_plugin</source>
         <translation>SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconPlugin.cpp" line="37"/>
+        <location filename="../src/SiteconPlugin.cpp" line="38"/>
         <source>sitecon_plugin_desc</source>
         <translation>Адаптированная версия программы SITECON: поиск сайтов связывания транскрипционных факторов. Включает около сотни откалиброванных моделей ССТФ. 
 Домашняя страница проекта: http://wwwmgs.bionet.nsc.ru/cgi-bin/mgs/sitecon/sitecon.pl?stage=0</translation>
     </message>
     <message>
-        <location filename="../src/SiteconPlugin.cpp" line="42"/>
+        <location filename="../src/SiteconPlugin.cpp" line="44"/>
         <source>sitecon_build</source>
         <translation>Построить модель SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconPlugin.cpp" line="48"/>
+        <location filename="../src/SiteconPlugin.cpp" line="50"/>
         <source>sitecon_menu</source>
         <translation>SITECON (Сайты Связывания ТФ)</translation>
     </message>
@@ -725,37 +652,40 @@
         <translation>Выбор модели SITECON</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchDialogController.cpp" line="290"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="164"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="262"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="273"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="286"/>
         <source>error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchDialogController.cpp" line="203"/>
-        <source>%1%<byte value="x9"/>err1=%2<byte value="x9"/>err2=%3</source>
-        <translation>%1%<byte value="x9"/>err1=%2<byte value="x9"/>err2=%3</translation>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="199"/>
+        <source>%1%	err1=%2	err2=%3</source>
+        <translation>%1%	err1=%2	err2=%3</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchDialogController.cpp" line="267"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="262"/>
         <source>model not selected</source>
         <translation>Укажите файл модели</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchDialogController.cpp" line="278"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="273"/>
         <source>range_is_too_small</source>
         <translation>Слишком маленький регион для поиска</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchDialogController.cpp" line="290"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="286"/>
         <source>error_parsing_min_score</source>
         <translation>Неразборчивая строка минимальной ошибки</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchDialogController.cpp" line="355"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="351"/>
         <source>complement_strand</source>
         <translation>комплeментарный</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchDialogController.cpp" line="355"/>
+        <location filename="../src/SiteconSearchDialogController.cpp" line="351"/>
         <source>direct_strand</source>
         <translation>прямой</translation>
     </message>
@@ -768,12 +698,12 @@
         <translation>Поиск ССТФ</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchTask.cpp" line="22"/>
+        <location filename="../src/SiteconSearchTask.cpp" line="19"/>
         <source>sitecon_search_parallel</source>
         <translation>Параллельный поиск ССТФ</translation>
     </message>
     <message>
-        <location filename="../src/SiteconSearchTask.cpp" line="41"/>
+        <location filename="../src/SiteconSearchTask.cpp" line="39"/>
         <source>internal_error_invalid_psum:%1</source>
         <translation>Внутренняя ошибка, неверная сумма: %1</translation>
     </message>
@@ -799,6 +729,7 @@
         <translation>Входное выравнивание</translation>
     </message>
     <message>
+        <location filename="../src/ui/SiteconBuildDialog.ui" line="31"/>
         <location filename="../src/ui/SiteconBuildDialog.ui" line="48"/>
         <source>...</source>
         <translation></translation>
@@ -884,21 +815,29 @@
         <translation>Алгоритм №2</translation>
     </message>
     <message>
+        <location filename="../src/SiteconBuildWorker.cpp" line="51"/>
+        <location filename="../src/ui/SiteconBuildDialog.ui" line="63"/>
         <location filename="../src/ui/SiteconBuildDialog.ui" line="92"/>
         <source>win_tip</source>
         <translation>Размер окна должен быть не короче консенсуса для данного сайта но не более длины выравнивания.</translation>
     </message>
     <message>
+        <location filename="../src/SiteconBuildWorker.cpp" line="52"/>
+        <location filename="../src/ui/SiteconBuildDialog.ui" line="165"/>
         <location filename="../src/ui/SiteconBuildDialog.ui" line="188"/>
         <source>seq_len_tip</source>
         <translation>Длина случайных синтетических последовательностей для калибрации профайла. Не должна быть меньше размера окна.</translation>
     </message>
     <message>
+        <location filename="../src/SiteconBuildWorker.cpp" line="53"/>
+        <location filename="../src/ui/SiteconBuildDialog.ui" line="114"/>
         <location filename="../src/ui/SiteconBuildDialog.ui" line="143"/>
         <source>seed_tip</source>
         <translation>Случайная затравка. Использование этого параметра полезно для воспроизведения результата калибрации.</translation>
     </message>
     <message>
+        <location filename="../src/SiteconBuildWorker.cpp" line="54"/>
+        <location filename="../src/ui/SiteconBuildDialog.ui" line="224"/>
         <location filename="../src/ui/SiteconBuildDialog.ui" line="247"/>
         <source>algo_tip</source>
         <translation>В большинстве случаев алгоритм без весов вполне адекватен. Использование других алгоритмов может улучшить качество распознавания в отдельных случаях.</translation>
@@ -957,6 +896,7 @@
         <translation>Только комплeментарные</translation>
     </message>
     <message>
+        <location filename="../src/ui/SiteconSearchDialog.ui" line="129"/>
         <location filename="../src/ui/SiteconSearchDialog.ui" line="264"/>
         <source>range</source>
         <translation>Регион</translation>
@@ -1027,6 +967,8 @@
         <translation>Отменить</translation>
     </message>
     <message>
+        <location filename="../src/SiteconSearchWorker.cpp" line="55"/>
+        <location filename="../src/ui/SiteconSearchDialog.ui" line="42"/>
         <location filename="../src/ui/SiteconSearchDialog.ui" line="58"/>
         <source>min_err_tip</source>
         <translation>Нижний предел качества распознавания, величина более 60% но меньше 100%. Слишком низкий предел приведёт к нахождению большого числа ложных сигналов, чрезмерно высокий отбросит качественные результаты.</translation>
