@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -9,172 +9,23 @@
 *****************************************************************/
 
 #include "MuscleAdapter.h"
-
-#include "muscle/muscle.h"
-#include "muscle/seqvect.h"
-#include "muscle/distfunc.h"
-#include "muscle/msa.h"
-#include "muscle/tree.h"
-#include "muscle/profile.h"
-#include "muscle/muscle_context.h"
+#include "MuscleUtils.h"
+#include "MuscleConstants.h"
 
 #include <core_api/DNAAlphabet.h>
 #include <core_api/Task.h>
+#include <core_api/Log.h>
 #include <util_algorithm/GAutoDeleteList.h>
 #include <datatype/MAlignment.h>
 
 #include <algorithm>
 #include <QtCore/QVector>
 
+
 namespace GB2 {
 
 //////////////////////////////////////////////////////////////////////////
-/// various helper methods and structures
-
-struct FILEStub : public FILE {
-public:
-    FILEStub(TaskStateInfo& _tsi) : tsi(_tsi){}
-    TaskStateInfo& tsi;
-};
-
-static int ugene_printf(FILE *f, const char *format, ...) {
-    if (format[0] <= 31 || strlen(format) == 1) {
-        return 0;
-    }
-    char str[4096];
-    va_list ArgList;
-    va_start(ArgList, format);
-    vsprintf(str, format, ArgList);
-
-    FILEStub* s = (FILEStub*)f;
-    s->tsi.stateDesc = (const char*)str;
-    return 0;
-}
-
-class MuscleParamsHelper {
-public:
-    MuscleParamsHelper(TaskStateInfo& ti) : ugeneFileStub(ti) {
-        MuscleContext *ctx = getMuscleContext();
-        SetParams();
-
-        //override some params. TODO: recheck possible conflict with SetPPScore() !
-        ctx->progressPercent = &ti.progress;
-        ctx->cancelFlag = &ti.cancelFlag;
-        ctx->progress.g_fProgress = &ugeneFileStub; //log context
-        ctx->progress.pr_printf = ugene_printf; //overriding logging
-        ctx->params.g_uMaxMB = 0; //unlimited memory
-        
-        SetMaxIters(ctx->params.g_uMaxIters);
-        SetStartTime();
-    }
-    ~MuscleParamsHelper() {
-        MuscleContext *ctx = getMuscleContext();
-        ctx->cancelFlag = &ctx->cancelStub;
-        ctx->progressPercent = &ctx->progressStub;
-        ctx->progress.pr_printf = fprintf;
-        ctx->progress.g_fProgress = NULL;
-    }
-
-    FILEStub ugeneFileStub;
-};
-
-static ALPHA convertAlpha(DNAAlphabet* al) {
-    if (al->isAmino()) {
-        return ALPHA_Amino;
-    }
-    const QString& id = al->getId();
-    if (id == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT || id == BaseDNAAlphabetIds::NUCL_DNA_EXTENDED) {
-        return ALPHA_DNA;
-    }
-    if (id == BaseDNAAlphabetIds::NUCL_RNA_DEFAULT || id == BaseDNAAlphabetIds::NUCL_RNA_EXTENDED) {
-        return ALPHA_RNA;
-    }
-    return ALPHA_Undefined;
-}
-
-static void setupAlphaAndScore(DNAAlphabet* al, TaskStateInfo& ti) {
-    ALPHA Alpha = convertAlpha(al);
-    if (Alpha == ALPHA_Undefined) {
-        ti.error = MuscleAdapter::tr("unsupported_alphabet_%1").arg(al->getName());
-        return;
-    }
-    SetAlpha(Alpha);
-    SetPPScore();
-    if (ALPHA_DNA == Alpha || ALPHA_RNA == Alpha) {
-        SetPPScore(PPSCORE_SPN);
-    }
-}
-
-static void convertMAlignment2MSA(MSA& muscleMSA, const MAlignment& ma, bool fixAlpha) {
-    assert(ma.isNormalized());
-    for (int i=0, n = ma.getNumSequences(); i<n; i++) {
-        const MAlignmentItem& aseq = ma.alignedSeqs[i];
-
-        char* seq  = new char[aseq.sequence.length()+1];
-        memcpy(seq, aseq.sequence.data(), aseq.sequence.length());
-        seq[aseq.sequence.length()] = '\0';
-
-        char* name = new char[aseq.name.length() + 1];
-        memcpy(name, aseq.name.toLocal8Bit().data(), aseq.name.length());
-        name[aseq.name.length()] = '\0';
-        muscleMSA.AppendSeq(seq, aseq.sequence.length(), name);
-    }
-    if (fixAlpha) {
-        muscleMSA.FixAlpha();
-    }
-}
-
-static void convertMAlignment2SecVect(SeqVect& sv, const MAlignment& ma, bool fixAlpha) {
-    sv.Clear();
-    foreach(const MAlignmentItem& item, ma.alignedSeqs) {
-        Seq *ptrSeq = new Seq();
-        QByteArray name =  item.name.toAscii();
-        ptrSeq->FromString(item.sequence.constData(), name.constData());
-        //stripping gaps, original Seq::StripGaps fails on MSVC9
-        Seq::iterator newEnd = std::remove(ptrSeq->begin(), ptrSeq->end(), MAlignment_GapChar);
-        ptrSeq->erase(newEnd, ptrSeq->end());
-        sv.push_back(ptrSeq);
-    }
-    if (fixAlpha) {
-        sv.FixAlpha();
-    }
-}
-
-static void convertMSA2MAlignment(MSA& msa, DNAAlphabet* al, MAlignment& res) {
-    res.alphabet = al;
-    for(int i=0, n = msa.GetSeqCount(); i < n; i++) {
-        QString name = msa.GetSeqName(i);
-        QByteArray seq;
-        seq.reserve(msa.GetColCount());
-        for (int j = 0, m = msa.GetColCount(); j < m ; j++) {
-            char c = msa.GetChar(i, j);
-            seq.append(c);
-        }
-
-        MAlignmentItem item(name, seq);
-        res.alignedSeqs.append(item);        
-    }
-    assert(res.isNormalized());
-}
-
-
-//////////////////////////////////////////////////////////////////////////
-/// align single MSA
-
-static void prepareAlignResults(MSA& msa, DNAAlphabet* al, MAlignment& ma, bool mhack) {
-    if (mhack) {
-        MHackEnd(msa);
-    }
-    MuscleContext* ctx = getMuscleContext();
-    if (ctx->params.g_bStable) {
-        MSA msaStable;
-        Stabilize(msa, msaStable);
-        msa.Clear();
-        convertMSA2MAlignment(msaStable, al, ma);
-    } else {
-        convertMSA2MAlignment(msa, al, ma);
-    }
-}
+static LogCategory log(ULOG_CAT_MUSCLE);
 
 void MuscleAdapter::align(const MAlignment& ma, MAlignment& res, TaskStateInfo& ti, bool mhack) {
     if(ti.cancelFlag)  {
@@ -184,20 +35,20 @@ void MuscleAdapter::align(const MAlignment& ma, MAlignment& res, TaskStateInfo&
         alignUnsafe(ma, res, ti, mhack);
     } catch (MuscleException e) {
         if (!ti.cancelFlag) {
-            ti.error = tr("Internal MUSCLE error: %1").arg(e.str);
+            ti.setError(  tr("Internal MUSCLE error: %1").arg(e.str) );
         }
     }
 }
 
 void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskStateInfo& ti, bool mhack) {
     ti.progress = 0;
-    
-    MuscleParamsHelper ph(ti);
-
     MuscleContext* ctx = getMuscleContext();
+
+    MuscleParamsHelper ph(ti,ctx);
+    
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
 
-    setupAlphaAndScore(ma.alphabet, ti);
+    setupAlphaAndScore(ma.getAlphabet(), ti);
     if (ti.hasErrors()) {
         return;
     }
@@ -206,7 +57,7 @@ void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskState
     convertMAlignment2SecVect(v, ma, true);
     const unsigned uSeqCount = v.Length();
     if (0 == uSeqCount) {
-        ti.error = tr("No sequences in input file");
+        ti.setError(  tr("No sequences in input file") );
         return;
     }
 
@@ -233,7 +84,7 @@ void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskState
     }
 
     if (0 == uSeqCount) {
-        ti.error = tr("alignment_is_empty");
+        ti.setError(  tr("alignment_is_empty") );
         return;
     }
 
@@ -253,12 +104,12 @@ void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskState
 
     MSA msa;
     gauto_array<ProgNode> ProgNodes;
+
     if (ctx->params.g_bLow) {
         ProgNodes.data = ProgressiveAlignE(v, GuideTree, msa);
     } else {
         ProgressiveAlign(v, GuideTree, msa);
     }
-
     if (ti.cancelFlag) {
         return;
     }
@@ -268,8 +119,8 @@ void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskState
     ValidateMuscleIds(msa);
 
     if (1 == ctx->params.g_uMaxIters || 2 == uSeqCount) {
-        assert(int(msa.GetSeqCount()) == ma.getNumSequences());
-        prepareAlignResults(msa, ma.alphabet, res, mhack);
+        assert(int(msa.GetSeqCount()) == ma.getNumRows());
+        prepareAlignResults(msa, ma.getAlphabet(), res, mhack);
         return;
     }
 
@@ -298,13 +149,14 @@ void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskState
     SetMuscleTree(GuideTree);
     
     ti.progress = 45;
-    
+    QTime timer;
+    timer.start();
     if (ctx->params.g_bAnchors) {
         RefineVert(msa, GuideTree, ctx->params.g_uMaxIters - 2);
     } else {
         RefineHoriz(msa, GuideTree, ctx->params.g_uMaxIters - 2, false, false);
     }
-
+    log.trace(QString("Serial refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
     if (ti.cancelFlag) {
         return;
     }
@@ -312,9 +164,9 @@ void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskState
     ValidateMuscleIds(msa);
     ValidateMuscleIds(GuideTree);
 
-    assert(int(msa.GetSeqCount()) == ma.getNumSequences());
+    //assert(int(msa.GetSeqCount()) == ma.getNumSequences());
     
-    prepareAlignResults(msa, ma.alphabet, res, mhack);
+    prepareAlignResults(msa, ma.getAlphabet(), res, mhack);
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -324,26 +176,28 @@ void MuscleAdapter::refine(const MAlignment& ma, MAlignment& res, TaskStateInfo&
     if(ti.cancelFlag)  {
         return;
     }
-    try { 
+    try {
+        QTime timer;
+        timer.start();
         refineUnsafe(ma, res, ti);
+        log.trace(QString("Serial refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
     } catch (MuscleException e) {
         if (!ti.cancelFlag) {
-            ti.error = tr("Internal MUSCLE error: %1").arg(e.str);
+            ti.setError(  tr("Internal MUSCLE error: %1").arg(e.str) );
         }
     }
 }
 
 void MuscleAdapter::refineUnsafe(const MAlignment& ma, MAlignment& res, TaskStateInfo& ti) {
-    assert(ma.isNormalized());
-    
     ti.progress = 0;
 
-    MuscleParamsHelper ph(ti);
-
     MuscleContext *ctx = getMuscleContext();
+    
+    MuscleParamsHelper ph(ti,ctx);
+    
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
 
-    setupAlphaAndScore(ma.alphabet, ti);
+    setupAlphaAndScore(ma.getAlphabet(), ti);
     if (ti.hasErrors()) {
         return;
     }
@@ -372,7 +226,7 @@ void MuscleAdapter::refineUnsafe(const MAlignment& ma, MAlignment& res, TaskStat
     ValidateMuscleIds(msa);
     ValidateMuscleIds(GuideTree);
 
-    prepareAlignResults(msa, ma.alphabet, res, false);
+    prepareAlignResults(msa, ma.getAlphabet(), res, false);
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -406,29 +260,29 @@ void MuscleAdapter::align2Profiles(const MAlignment& ma1, const MAlignment& ma2,
     if(ti.cancelFlag)  {
         return;
     }
-    if (!ma1.isNormalized() || !ma2.isNormalized()) {
-        ti.error = tr("Invalid input alignment");
+    if (ma1.isEmpty() || ma2.isEmpty()) {
+        ti.setError(  tr("Invalid input alignment") );
         return;
     }
     try { 
         align2ProfilesUnsafe(ma1, ma2, res, ti);
     } catch (MuscleException e) {
         if (!ti.cancelFlag) {
-            ti.error = tr("Internal MUSCLE error: %1").arg(e.str);
+            ti.setError(  tr("Internal MUSCLE error: %1").arg(e.str) );
         }
     }
 }
 
 void MuscleAdapter::align2ProfilesUnsafe(const MAlignment& ma1, const MAlignment& ma2, MAlignment& res, TaskStateInfo& ti) {
-    assert(ma1.isNormalized() && ma2.isNormalized());
-    DNAAlphabet* al = DNAAlphabet::deriveCommonAlphabet(ma1.alphabet, ma2.alphabet);
+    assert(!ma1.isEmpty() && !ma2.isEmpty());
+    DNAAlphabet* al = DNAAlphabet::deriveCommonAlphabet(ma1.getAlphabet(), ma2.getAlphabet());
     if (al == NULL) {
-        ti.error = tr("Incompatible alphabets");
+        ti.setError(  tr("Incompatible alphabets") );
         return;
     }
-    MuscleParamsHelper ph(ti);
-    
-    MuscleContext* ctx = getMuscleContext();    
+    MuscleContext *ctx = getMuscleContext();
+
+    MuscleParamsHelper ph(ti,ctx);
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
 
     setupAlphaAndScore(al, ti);
@@ -441,7 +295,7 @@ void MuscleAdapter::align2ProfilesUnsafe(const MAlignment& ma1, const MAlignment
     MSA msa2;
     convertMAlignment2MSA(msa2, ma2, true);
 
-    MSA::SetIdCount(ma1.getNumSequences() + ma2.getNumSequences());
+    MSA::SetIdCount(ma1.getNumRows() + ma2.getNumRows());
 
     unsigned uLength1 = msa1.GetColCount();
     unsigned uLength2 = msa2.GetColCount();
@@ -452,10 +306,10 @@ void MuscleAdapter::align2ProfilesUnsafe(const MAlignment& ma1, const MAlignment
     gauto_array<ProfPos> ProfOut;
 
     PWPath Path; unsigned uLengthOut;
-    ti.stateDesc = tr("Aligning profiles");
+    ti.setStateDesc(tr("Aligning profiles"));
     AlignTwoProfs(Prof1.data, uLength1, 1.0, Prof2.data, uLength2, 1.0, Path, &ProfOut.data, &uLengthOut);
     
-    ti.stateDesc = tr("Building output");
+    ti.setStateDesc(tr("Building output"));
     MSA msaOut;
     AlignTwoMSAsGivenPath(Path, msa1, msa2, msaOut);
     msa1.Clear();//save memory
@@ -543,9 +397,8 @@ static void addSequenceToMSA(MAlignment& ma, const QByteArray& path, QByteArray&
         int prevLen = ma.getLength();
         int newLen = prevLen + numIns;
         QByteArray msaPathChangesNew;
-        for (int i=0, n = ma.getNumSequences(); i < n; i++) {
-            MAlignmentItem& mai = ma.alignedSeqs[i];
-            const char* seq = mai.sequence.data();
+        for (int i = 0, n = ma.getNumRows(); i < n; i++) {
+            const MAlignmentRow& row = ma.getRow(i);
             QByteArray newSeq;
             newSeq.reserve(newLen);
             int insCoordsPos = insCoords[0];
@@ -563,7 +416,7 @@ static void addSequenceToMSA(MAlignment& ma, const QByteArray& path, QByteArray&
                         }
                     } while (insCoordsPos == prevInsCoordsPos+1);
                 } 
-                newSeq.append(seq[seqPos]);
+                newSeq.append(row.chatAt(seqPos));
                 if (i == 0) {
                     msaPathChangesNew.append(msaPathChanges[seqPos]);
                 }
@@ -576,52 +429,44 @@ static void addSequenceToMSA(MAlignment& ma, const QByteArray& path, QByteArray&
                 }
             }
             assert(newSeq.length() == newLen);
-            mai.sequence = newSeq;
+			ma.setRowSequence(i, newSeq);
         }
         msaPathChanges.clear();
         msaPathChanges+=msaPathChangesNew;
-        assert(ma.isNormalized());
         assert(msaPathChanges.length() == ma.getLength());
     }
 
     int ma2Len = ma.getLength(); Q_UNUSED(ma2Len);
     assert(aseqLen == ma2Len);  // gapped sequence has the same length as alignment
 
-    ma.alignedSeqs.append(MAlignmentItem(name, alignedSeq));
-    assert(ma.isNormalized());
+    ma.addRow(MAlignmentRow(name, alignedSeq));
 }
 
 void MuscleAdapter::addUnalignedSequencesToProfile(const MAlignment& ma, const MAlignment& unalignedSeqs, MAlignment& res, TaskStateInfo& ti) {
     if(ti.cancelFlag)  {
         return;
     }
-    if (!ma.isNormalized()) {
-        ti.error = tr("Profile is not aligned");
-        return;
-    }
     try { 
         addUnalignedSequencesToProfileUnsafe(ma, unalignedSeqs, res, ti);
     } catch (MuscleException e) {
         if (!ti.cancelFlag) {
-            ti.error = tr("Internal MUSCLE error: %1").arg(e.str);
+            ti.setError(  tr("Internal MUSCLE error: %1").arg(e.str) );
         }
     }
 }
 
 
 void MuscleAdapter::addUnalignedSequencesToProfileUnsafe(const MAlignment& ma, const MAlignment& unalignedSeqs, MAlignment& res, TaskStateInfo& ti) {
-    assert(ma.isNormalized());
-
-    DNAAlphabet* al = DNAAlphabet::deriveCommonAlphabet(ma.alphabet, unalignedSeqs.alphabet);
+    DNAAlphabet* al = DNAAlphabet::deriveCommonAlphabet(ma.getAlphabet(), unalignedSeqs.getAlphabet());
     if (al == NULL) {
-        ti.error = tr("Incompatible alphabets");
+        ti.setError(  tr("Incompatible alphabets") );
         return;
     }
     
     // init muscle
-    MuscleParamsHelper ph(ti);
-    
-    MuscleContext* ctx = getMuscleContext();
+    MuscleContext *ctx = getMuscleContext();
+
+    MuscleParamsHelper ph(ti,ctx);
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
     
     setupAlphaAndScore(al, ti);
@@ -629,7 +474,7 @@ void MuscleAdapter::addUnalignedSequencesToProfileUnsafe(const MAlignment& ma, c
         return;
     }
     
-    MSA::SetIdCount(ma.getNumSequences() + 1);
+    MSA::SetIdCount(ma.getNumRows() + 1);
 
     //prepare original MSA
     MSA profileMSA;
@@ -642,11 +487,11 @@ void MuscleAdapter::addUnalignedSequencesToProfileUnsafe(const MAlignment& ma, c
     gauto_array<ProfPos> prof1(ProfileFromMSALocal_ProfileCPP(profileMSA, tree1));
     QVector<AlignedSeq> alignedSeqs;
     int dp = ti.progress;
-    for (int i=0, n = unalignedSeqs.getNumSequences(); i < n; i++) {
-        ti.stateDesc = tr("Aligning sequence %1 of %2").arg(QString::number(i+1)).arg(QString::number(n));
+    for (int i=0, n = unalignedSeqs.getNumRows(); i < n; i++) {
+        ti.setStateDesc(tr("Aligning sequence %1 of %2").arg(QString::number(i+1)).arg(QString::number(n)));
         ti.progress = dp + i*(95-dp)/n;
-        const MAlignmentItem& useq = unalignedSeqs.alignedSeqs[i];
-        Seq seq; seq.FromString(useq.sequence.data(), useq.name.toLocal8Bit().data());
+        const MAlignmentRow& useq = unalignedSeqs.getRow(i);
+        Seq seq; seq.FromString(useq.getCore().constData(), useq.getName().toLocal8Bit().constData());
         seq.SetId(0);
         seq.StripGaps();
         seq.FixAlpha();
@@ -660,7 +505,7 @@ void MuscleAdapter::addUnalignedSequencesToProfileUnsafe(const MAlignment& ma, c
         AlignTwoProfs(prof1.data, profileMSA.GetColCount(), 1.0, prof2.get(), tmpMSA.GetColCount(), 1.0, path, &profOut.data, &uLengthOut);
         
         AlignedSeq aseq;
-        aseq.name = useq.name;
+        aseq.name = useq.getName();
         aseq.seq = QByteArray((const char*)&seq.front(), seq.Length());//without gaps
         aseq.pathToMSA = path2Str(path);
         alignedSeqs.append(aseq);
@@ -675,7 +520,7 @@ void MuscleAdapter::addUnalignedSequencesToProfileUnsafe(const MAlignment& ma, c
     QByteArray seqPath2CurrentMSA;
     for (int i=0, n = alignedSeqs.size(); i < n; i++) {
         if (i%10 == 9) {
-            ti.stateDesc = tr("Merging results: %1 of %2").arg(QString::number(i+1)).arg(QString::number(n));
+            ti.setStateDesc(tr("Merging results: %1 of %2").arg(QString::number(i+1)).arg(QString::number(n)));
         }
         seqPath2CurrentMSA.clear();
         const AlignedSeq& aseq = alignedSeqs[i];
@@ -686,8 +531,7 @@ void MuscleAdapter::addUnalignedSequencesToProfileUnsafe(const MAlignment& ma, c
             return;
         }
     }
-    res.alphabet = al;
-    assert(res.isNormalized());
+    res.setAlphabet(al);
 }
 
 } //namespace
