@@ -111,7 +111,7 @@ void MusclePrepareTask::alignPrepareUnsafe()
     MuscleContext* ctx = workpool->ctx;
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
 
-    setupAlphaAndScore(workpool->ma.alphabet, stateInfo);
+    setupAlphaAndScore(workpool->ma.getAlphabet(), stateInfo);
     if (stateInfo.hasErrors()) {
         return;
     }
@@ -225,15 +225,13 @@ void MusclePrepareTask::alignPrepareUnsafe()
 }
 
 void MusclePrepareTask::refinePrepareUnsafe() {
-    assert(workpool->ma.isNormalized());
-
     workpool->ti.progress = 0;
 
     MuscleContext *ctx = getMuscleContext();
 
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
 
-    setupAlphaAndScore(workpool->ma.alphabet, workpool->ti);
+    setupAlphaAndScore(workpool->ma.getAlphabet(), workpool->ti);
     if (workpool->ti.hasErrors()) {
         return;
     }
@@ -297,6 +295,9 @@ void ProgressiveAlignTask::_run() {
     if (!workpool->res.isEmpty())  {
         return;// no more need in align
     }
+	if (workpool->ti.hasErrors())  {
+		return; // cancel on error
+	}
     MuscleContext* ctx = workpool->ctx;
 
     const unsigned uSeqCount = workpool->v.Length();
@@ -327,8 +328,8 @@ void ProgressiveAlignTask::_run() {
     ValidateMuscleIds(workpool->a);
 
     if (1 == ctx->params.g_uMaxIters || 2 == uSeqCount) {
-        assert(int(workpool->a.GetSeqCount()) == workpool->ma.getNumSequences());
-        prepareAlignResults(workpool->a, workpool->ma.alphabet, workpool->res, workpool->mhack);
+        assert(int(workpool->a.GetSeqCount()) == workpool->ma.getNumRows());
+        prepareAlignResults(workpool->a, workpool->ma.getAlphabet(), workpool->res, workpool->mhack);
     }
 }
 
@@ -548,7 +549,6 @@ void RefineTask::_run() {
     }
     MuscleContext* ctx = workpool->ctx;
     MSA &msa = workpool->a;
-    Tree &GuideTree = workpool->GuideTree;
 
     workpool->refineDone = false;
     int d = workpool->config.op == MuscleTaskOp_Refine?0:2;
@@ -563,13 +563,13 @@ void RefineTask::_run() {
     }
 
     ValidateMuscleIds(msa);
-    ValidateMuscleIds(GuideTree);
+    ValidateMuscleIds(workpool->GuideTree);
     
     if(workpool->config.op != MuscleTaskOp_Refine) {
         //assert(int(msa.GetSeqCount()) == workpool->ma.getNumSequences());
-        prepareAlignResults(msa, workpool->ma.alphabet, workpool->res, workpool->mhack);
+        prepareAlignResults(msa, workpool->ma.getAlphabet(), workpool->res, workpool->mhack);
     } else {
-        prepareAlignResults(msa, workpool->ma.alphabet, workpool->res, false);
+        prepareAlignResults(msa, workpool->ma.getAlphabet(), workpool->res, false);
     }
 }
 ////////////////////////////////////////////////////////////////////////////
