@@ -16,6 +16,7 @@
 #include <core_api/AppContext.h>
 #include <core_api/Task.h>
 #include <core_api/Log.h>
+#include <core_api/DocumentModel.h>
 #include <util_ov_msaedit/MSAEditor.h>
 #include <util_ov_msaedit/MSAEditorFactory.h>
 #include <gobjects/MAlignmentObject.h>
@@ -70,6 +71,11 @@ MusclePlugin::MusclePlugin()
         Q_UNUSED(res);
         assert(res);
     }
+    
+    // Muscle local task
+    LocalTaskFactoryRegistry * ltfr = AppContext::getLocalTaskFactoryRegistry();
+    assert( NULL != ltfr );
+    ltfr->registerLocalTaskFactory( &muscleLocalTaskFactory );
 }
 
 MusclePlugin::~MusclePlugin() {
@@ -95,23 +101,26 @@ MuscleMSAEditorContext::MuscleMSAEditorContext(QObject* p) : GObjectViewWindowCo
 void MuscleMSAEditorContext::initViewContext(GObjectView* view) {
     MSAEditor* msaed = qobject_cast<MSAEditor*>(view);
     assert(msaed!=NULL);
+	if (msaed->getMSAObject() == NULL) {
+        return;
+	}
 
     bool objLocked = msaed->getMSAObject()->isStateLocked();
-    MuscleAction* alignAction = new MuscleAction(this, view, tr("Align with MUSCLE"));
+    MuscleAction* alignAction = new MuscleAction(this, view, tr("Align with MUSCLE"), 1000);
     alignAction->setIcon(QIcon(":umuscle/images/muscle_16.png"));
     alignAction->setEnabled(!objLocked);
     connect(alignAction, SIGNAL(triggered()), SLOT(sl_align()));
     connect(msaed->getMSAObject(), SIGNAL(si_lockedStateChanged()), alignAction, SLOT(sl_lockedStateChanged()));
     addViewAction(alignAction);
 
-    MuscleAction* addSequencesAction = new MuscleAction(this, view, tr("Align sequences to profile with MUSCLE"));
+    MuscleAction* addSequencesAction = new MuscleAction(this, view, tr("Align sequences to profile with MUSCLE"), 1001);
     addSequencesAction->setIcon(QIcon(":umuscle/images/muscle_16.png"));
     addSequencesAction->setEnabled(!objLocked);
     connect(addSequencesAction, SIGNAL(triggered()), SLOT(sl_alignSequencesToProfile()));
     connect(msaed->getMSAObject(), SIGNAL(si_lockedStateChanged()), addSequencesAction, SLOT(sl_lockedStateChanged()));
     addViewAction(addSequencesAction);
 
-    MuscleAction* alignProfilesAction = new MuscleAction(this, view, tr("Align profile to profile with MUSCLE"));
+    MuscleAction* alignProfilesAction = new MuscleAction(this, view, tr("Align profile to profile with MUSCLE"), 1002);
     alignProfilesAction->setIcon(QIcon(":umuscle/images/muscle_16.png"));
     alignProfilesAction->setEnabled(!objLocked);
     connect(alignProfilesAction, SIGNAL(triggered()), SLOT(sl_alignProfileToProfile()));
@@ -124,7 +133,7 @@ void MuscleMSAEditorContext::buildMenu(GObjectView* v, QMenu* m) {
     QMenu* alignMenu = GUIUtils::findSubMenu(m, MSAE_MENU_ALIGN);
     assert(alignMenu!=NULL);
     foreach(GObjectViewAction* a, actions) {
-        alignMenu->addAction(a);
+		a->addToMenuWithOrder(alignMenu);
     }    
 }
 
@@ -133,18 +142,39 @@ void MuscleMSAEditorContext::sl_align() {
     assert(action!=NULL);
     MSAEditor* ed = action->getMSAEditor();
     MAlignmentObject* obj = ed->getMSAObject(); 
+    if (obj == NULL)
+        return;
     assert(!obj->isStateLocked());
 
+    const QRect selection = action->getMSAEditor()->getCurrentSelection();
     MuscleTaskSettings s;
+    if (!selection.isNull() ) {
+        int width = selection.width();
+        // it doesn't make sense to align one column!
+        if ( (width > 1) && ( width < obj->getMAlignment().getLength() ) ) {
+            s.regionToAlign = LRegion(selection.x(), selection.x() + selection.width() - 1);
+            s.alignRegion = true;
+        }
+    }
+
     MuscleAlignDialogController dlg(ed->getWidget(), obj->getMAlignment(), s);
     
     int rc = dlg.exec();
     if (rc != QDialog::Accepted) {
         return;
     }
-
-    MuscleGObjectTask* t = new MuscleGObjectTask(obj, s);
-    AppContext::getTaskScheduler()->registerTopLevelTask(t);
+    
+    Task * muscleTask = NULL;
+    QList< RemoteMachineSettings* > machines = dlg.getSelectedMachines();
+    if( 0 == machines.size() ) { /* run muscle on local machine */
+        muscleTask = new MuscleGObjectTask(obj, s);
+    } else { /* run on remote machine */
+        assert( 1 == machines.size() );
+        RemoteMachineSettings * rm = machines.first();
+        muscleTask = new MuscleRemoteToGobjectTask( obj, s, rm );
+    }
+    
+    AppContext::getTaskScheduler()->registerTopLevelTask( muscleTask );
 }
 
 void MuscleMSAEditorContext::sl_alignSequencesToProfile() {
@@ -152,10 +182,17 @@ void MuscleMSAEditorContext::sl_alignSequencesToProfile() {
     assert(action!=NULL);
     MSAEditor* ed = action->getMSAEditor();
     MAlignmentObject* obj = ed->getMSAObject(); 
+    if (obj == NULL)
+        return;
     assert(!obj->isStateLocked());
 
+    DocumentFormatConstraints c;
+    QString f1 = DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::MULTIPLE_ALIGNMENT, false);
+    QString f2 = DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::SEQUENCE, false);
+    QString filter = f2 + "\n" + f1;
+
     LastOpenDirHelper lod;
-    lod.url = QFileDialog::getOpenFileName(NULL, tr("Select file with sequences"), lod);
+    lod.url = QFileDialog::getOpenFileName(NULL, tr("Select file with sequences"), lod, filter);
     if (lod.url.isEmpty()) {
         return;
     }
@@ -167,6 +204,8 @@ void MuscleMSAEditorContext::sl_alignProfileToProfile() {
     assert(action!=NULL);
     MSAEditor* ed = action->getMSAEditor();
     MAlignmentObject* obj = ed->getMSAObject(); 
+    if (obj == NULL)
+        return;
     assert(!obj->isStateLocked());
 
     LastOpenDirHelper lod;
