@@ -17,6 +17,8 @@
 
 #include <QtGui/QMenu>
 
+#include <muscle_local_task/MuscleLocalTask.h>
+
 namespace GB2 {
 
 class MSAEditor;
@@ -31,6 +33,8 @@ public:
 
 private:
     MuscleMSAEditorContext* ctx;
+    MuscleLocalTaskFactory  muscleLocalTaskFactory;
+    
 };
 
 
@@ -52,7 +56,9 @@ protected:
 class MuscleAction : public GObjectViewAction {
     Q_OBJECT
 public:
-    MuscleAction(QObject* p, GObjectView* v, const QString& text)  : GObjectViewAction(p,v,text) {}
+    MuscleAction(QObject* p, GObjectView* v, const QString& text, int order) 
+		: GObjectViewAction(p, v, text, order) {}
+
     MSAEditor*  getMSAEditor() const;
 
 private slots:
