@@ -24,6 +24,7 @@
 #include <core_api/Counter.h>
 #include <gobjects/DNASequenceObject.h>
 #include <util_tasks/LoadDocumentTask.h>
+#include <document_format/DocumentFormatUtils.h>
 
 #include "muscle/muscle.h" 
 #include "muscle/muscle_context.h" 
@@ -61,20 +62,21 @@ MuscleTask::MuscleTask(const MAlignment& ma, const MuscleTaskSettings& _config)
 
     //todo: make more precise estimation, use config.op mode
     int aliLen = ma.getLength();
-    int nSeq = ma.getNumSequences();
+    int nSeq = ma.getNumRows();
     int memUseMB = int(quint64(200 * aliLen * nSeq) / (1024 * 1024)); //200x per char in alignment
     TaskResourceUsage tru(RESOURCE_MEMORY, memUseMB);
     
     inputSubMA = inputMA;
     if (config.alignRegion && config.regionToAlign.len != inputMA.getLength()) {
         assert(config.regionToAlign.len > 0);
-        inputSubMA = inputMA.subAlignment(config.regionToAlign.startPos, config.regionToAlign.len);
+        inputSubMA = inputMA.mid(config.regionToAlign.startPos, config.regionToAlign.len);
     }
     
-    ctx->input_uIds = new unsigned[inputSubMA.getNumSequences()];
-    ctx->tmp_uIds = new unsigned[inputSubMA.getNumSequences()];
-    for(unsigned i=0, n=inputSubMA.getNumSequences(); i<n; i++)
+    ctx->input_uIds = new unsigned[inputSubMA.getNumRows()];
+    ctx->tmp_uIds = new unsigned[inputSubMA.getNumRows()];
+	for(unsigned i=0, n = inputSubMA.getNumRows(); i<n; i++) {
         ctx->input_uIds[i] = i;
+	}
 
     if (config.nThreads == 1 || (config.op != MuscleTaskOp_Align)) {
         tpm = Task::Progress_Manual;
@@ -107,8 +109,7 @@ void MuscleTask::run() {
             break;
     }
     if (!hasErrors() && !isCanceled()) {
-        assert(resultMA.alphabet!=NULL);
-        assert(resultMA.isNormalized());
+        assert(resultMA.getAlphabet() != NULL);
     }
     TaskLocalData::detachMuscleTLSContext();
 }
@@ -129,13 +130,12 @@ void MuscleTask::doAlign(bool refine) {
     if(!isCanceled()) {
         assert(!resultSubMA.isEmpty());
         if (config.alignRegion && config.regionToAlign.len != inputMA.getLength()) {
-            assert(!resultSubMA.isEmpty());
-            resultMA.alphabet = inputMA.alphabet;
+            resultMA.setAlphabet(inputMA.getAlphabet());
             QByteArray emptySeq;
-            const int nSeq = inputMA.getNumSequences();
+            const int nSeq = inputMA.getNumRows();
             int *ids = new int[nSeq];
 
-            const int resNSeq = resultSubMA.getNumSequences();
+            const int resNSeq = resultSubMA.getNumRows();
             bool *existID = new bool[nSeq];
             memset(existID,0,sizeof(bool)*nSeq);
             for(int i=0, n = resNSeq; i < n; i++) {
@@ -147,28 +147,34 @@ void MuscleTask::doAlign(bool refine) {
             for(int i=0, n = nSeq; i < n; i++) {
                 if(!existID[i]) {
                     ids[j] = i;
-                    resultSubMA.alignedSeqs.append(MAlignmentItem(inputMA.alignedSeqs[i].name, gapSeq));
+					MAlignmentRow row(inputMA.getRow(i).getName(), gapSeq);
+                    resultSubMA.addRow(row);
                     j++;
                 }
             }
             delete[] existID;
-            assert(resultSubMA.getNumSequences() == inputMA.getNumSequences());
+            assert(resultSubMA.getNumRows() == inputMA.getNumRows());
 
 
-            for(int i=0, n = inputMA.getNumSequences(); i < n; i++) {
-                const MAlignmentItem& item = inputMA.alignedSeqs[ids[i]];
-                resultMA.alignedSeqs.append(MAlignmentItem(item.name, emptySeq));
+            for(int i=0, n = inputMA.getNumRows(); i < n; i++) {
+                const MAlignmentRow& row= inputMA.getRow(ids[i]);
+                resultMA.addRow(MAlignmentRow(row.getName(), emptySeq));
             }
             if (config.regionToAlign.startPos != 0) {
-                for(int i=0; i < nSeq; i++) 
-                    resultMA.alignedSeqs[i].sequence.append(inputMA.alignedSeqs[ids[i]].sequence.mid(0,config.regionToAlign.startPos));
+				for(int i=0; i < nSeq; i++)  {
+					int regionLen = config.regionToAlign.startPos;
+					MAlignmentRow inputRow = inputMA.getRow(ids[i]).mid(0,regionLen);
+					resultMA.appendChars(i, inputRow.toByteArray(regionLen).constData(), regionLen);
+				}
             }
-            resultMA +=resultSubMA;
+            resultMA += resultSubMA;
             if (config.regionToAlign.endPos() != inputMA.getLength()) {
                 int subStart = config.regionToAlign.endPos();
                 int subLen = inputMA.getLength() - config.regionToAlign.endPos();
-                for(int i=0; i < nSeq; i++) 
-                    resultMA.alignedSeqs[i].sequence.append(inputMA.alignedSeqs[ids[i]].sequence.mid(subStart,subLen));
+				for(int i = 0; i < nSeq; i++) {
+					MAlignmentRow inputRow = inputMA.getRow(ids[i]).mid(subStart,subLen);
+					resultMA.appendChars(i, inputRow.toByteArray(subLen).constData(), subLen);
+				}
             }
             delete[] ids;
             //TODO: check if there are GAP columns on borders and remove them        
@@ -213,23 +219,27 @@ MuscleAddSequencesToProfileTask::MuscleAddSequencesToProfileTask(MAlignmentObjec
 
 
     //todo: create 'detect file format task'
-    DocumentFormatConstraints c;
-    c.checkRawData = true;
-    c.supportedObjectTypes.append(GObjectTypes::MULTIPLE_ALIGNMENT); //MA here comes first because for a sequence format raw sequence can be used by default
-    c.rawData = BaseIOAdapters::readFileHeader(fileWithSequencesOrProfile);
-    QList<DocumentFormatId> formats = AppContext::getDocumentFormatRegistry()->selectFormats(c);
-    if (formats.isEmpty()) {
-        c.supportedObjectTypes.clear();
-        c.supportedObjectTypes.append(GObjectTypes::DNA_SEQUENCE);
-        formats = AppContext::getDocumentFormatRegistry()->selectFormats(c);
-        if (formats.isEmpty()) {
-            stateInfo.setError(tr("input_format_error"));
-            return;
-        }
+//     DocumentFormatConstraints c;
+//     c.checkRawData = true;
+//     c.supportedObjectTypes += GObjectTypes::MULTIPLE_ALIGNMENT; //MA here comes first because for a sequence format raw sequence can be used by default
+//     c.rawData = BaseIOAdapters::readFileHeader(fileWithSequencesOrProfile);
+//     QList<DocumentFormatId> formats = AppContext::getDocumentFormatRegistry()->selectFormats(c);
+//     if (formats.isEmpty()) {
+//         c.supportedObjectTypes.clear();
+//         c.supportedObjectTypes += GObjectTypes::SEQUENCE;
+//         formats = AppContext::getDocumentFormatRegistry()->selectFormats(c);
+//         if (formats.isEmpty()) {
+//             stateInfo.setError(tr("input_format_error"));
+//             return;
+//         }
+//     }
+    QList<DocumentFormat*> detectedFormats = DocumentFormatUtils::detectFormat(fileWithSequencesOrProfile);    
+    if (detectedFormats.isEmpty()) {
+        setError("Unknown format");
     }
-    DocumentFormatId format = formats.first();
+    DocumentFormat* format = detectedFormats.first();
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(fileWithSequencesOrProfile));
-    loadTask = new LoadDocumentTask(format, fileWithSequencesOrProfile, iof);
+    loadTask = new LoadDocumentTask(format->getFormatId(), fileWithSequencesOrProfile, iof);
     loadTask->setSubtaskProgressWeight(0.01f);
     addSubTask(loadTask);
 }
@@ -249,7 +259,7 @@ QList<Task*> MuscleAddSequencesToProfileTask::onSubTaskFinished(Task* subTask) {
     MuscleTaskSettings s;
     s.op = mode == Sequences2Profile ? MuscleTaskOp_AddUnalignedToProfile : MuscleTaskOp_ProfileToProfile;
 
-    QList<GObject*> seqObjects = loadTask->getDocument()->findGObjectByType(GObjectTypes::DNA_SEQUENCE);
+    QList<GObject*> seqObjects = loadTask->getDocument()->findGObjectByType(GObjectTypes::SEQUENCE);
     //todo: move to utility alphabet reduction
     DNAAlphabet* al = NULL;
     foreach(GObject* obj, seqObjects) {
@@ -260,13 +270,13 @@ QList<Task*> MuscleAddSequencesToProfileTask::onSubTaskFinished(Task* subTask) {
         } else if (al != objAl) {
             al = DNAAlphabet::deriveCommonAlphabet(al, objAl);
             if (al == NULL) {
-                stateInfo.setError(tr("Sequences in file have different alphabets %1").arg(loadTask->getDocument()->getURL()));
+                stateInfo.setError(tr("Sequences in file have different alphabets %1").arg(loadTask->getDocument()->getURLString()));
                 return res;
             }
         }
-        s.profile.alignedSeqs.append(MAlignmentItem(dnaObj->getGObjectName(), dnaObj->getSequence()));
+        s.profile.addRow(MAlignmentRow(dnaObj->getGObjectName(), dnaObj->getSequence()));
     }
-    s.profile.alphabet = al;
+    s.profile.setAlphabet(al);
 
     if (seqObjects.isEmpty()) {
         QList<GObject*> maObjects = loadTask->getDocument()->findGObjectByType(GObjectTypes::MULTIPLE_ALIGNMENT);
@@ -278,9 +288,9 @@ QList<Task*> MuscleAddSequencesToProfileTask::onSubTaskFinished(Task* subTask) {
     
     if (s.profile.isEmpty()) {
         if (mode == Sequences2Profile) {
-            stateInfo.setError(tr("No sequences found in file %1").arg(loadTask->getDocument()->getURL()));
+            stateInfo.setError(tr("No sequences found in file %1").arg(loadTask->getDocument()->getURLString()));
         } else {
-            stateInfo.setError(tr("No alignment found in file %1").arg(loadTask->getDocument()->getURL()));
+            stateInfo.setError(tr("No alignment found in file %1").arg(loadTask->getDocument()->getURLString()));
         }
         return res;
     }
@@ -361,11 +371,11 @@ Task::ReportResult MuscleGObjectTask::report() {
         return ReportResult_Finished;
     }
     if (config.op == MuscleTaskOp_AddUnalignedToProfile) {
-        assert((muscleTask->inputMA.getNumSequences() + config.profile.getNumSequences()) == muscleTask->resultMA.getNumSequences());
+        assert((muscleTask->inputMA.getNumRows() + config.profile.getNumRows()) == muscleTask->resultMA.getNumRows());
     } else if (config.op == MuscleTaskOp_Align) {
-        assert(muscleTask->inputMA.getNumSequences() == muscleTask->resultMA.getNumSequences());
+        assert(muscleTask->inputMA.getNumRows() == muscleTask->resultMA.getNumRows());
     } else if (config.op == MuscleTaskOp_ProfileToProfile) {
-        assert(muscleTask->inputMA.getNumSequences() + config.profile.getNumSequences() == muscleTask->resultMA.getNumSequences());
+        assert(muscleTask->inputMA.getNumRows() + config.profile.getNumRows() == muscleTask->resultMA.getNumRows());
     }
     obj->setMAlignment(muscleTask->resultMA);    
 
