@@ -20,6 +20,7 @@
 #include <workflow_library/BioDatatypes.h>
 #include <workflow_library/BioActorLibrary.h>
 #include <workflow_support/DelegateEditors.h>
+#include <workflow_support/CoreLibConstants.h>
 #include <core_api/Log.h>
 
 /* TRANSLATOR GB2::LocalWorkflow::MuscleWorker */
@@ -27,19 +28,19 @@
 namespace GB2 {
 namespace LocalWorkflow {
 
-static const QString IN_PORT("in");
-static const QString OUT_PORT("out");
+static LogCategory log(ULOG_CAT_WD);
 
+/****************************
+ * MuscleWorkerFactory
+ ****************************/
 const QString MuscleWorkerFactory::ACTOR_ID("muscle.align");
 const QString MODE_ATTR("mode");
 const QString STABLE_ATTR("fix-order");
 
-static LogCategory log(ULOG_CAT_WD);
-
 void MuscleWorkerFactory::init() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
-    Descriptor ind(IN_PORT, MuscleWorker::tr("Input MSA"), MuscleWorker::tr("Multiple sequence alignment to be processed."));
-    Descriptor oud(OUT_PORT, MuscleWorker::tr("Multiple sequence alignment"), MuscleWorker::tr("Result of alignment."));
+    Descriptor ind(CoreLibConstants::IN_PORT_ID, MuscleWorker::tr("Input MSA"), MuscleWorker::tr("Multiple sequence alignment to be processed."));
+    Descriptor oud(CoreLibConstants::OUT_PORT_ID, MuscleWorker::tr("Multiple sequence alignment"), MuscleWorker::tr("Result of alignment."));
     p << new PortDescriptor(ind, BioDataTypes::MULTIPLE_ALIGNMENT_TYPE(), true /*input*/);
     p << new PortDescriptor(oud, BioDataTypes::MULTIPLE_ALIGNMENT_TYPE(), false /*input*/, true /*multi*/);
     Descriptor mod(MODE_ATTR, MuscleWorker::tr("Mode"), 
@@ -74,9 +75,12 @@ void MuscleWorkerFactory::init() {
     localDomain->registerEntry(new MuscleWorkerFactory());
 }
 
+/****************************
+* MusclePrompter
+****************************/
 QString MusclePrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(IN_PORT));
-    Actor* producer = input->getProducer(IN_PORT);
+    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
+    Actor* producer = input->getProducer(CoreLibConstants::IN_PORT_ID);
     QString producerName = producer ? tr(" from %1").arg(producer->getLabel()) : "";
     QString preset;
     switch (getParameter(MODE_ATTR).toInt()) {
@@ -91,16 +95,15 @@ QString MusclePrompter::composeRichDoc() {
     return doc;
 }
 
-void MuscleWorker::init() {
-    input = ports.value(IN_PORT);
-    output = ports.value(OUT_PORT);
-    switch (actor->getParameter(MODE_ATTR)->value.toInt()) {
-        case 0: DefaultModePreset().apply(cfg); break;
-        case 1: LargeModePreset().apply(cfg); break;
-        case 2: RefineModePreset().apply(cfg); break;
-    }
-    cfg.stableMode = actor->getParameter(STABLE_ATTR)->value.toBool();
+/****************************
+* MuscleWorker
+****************************/
+MuscleWorker::MuscleWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL) {
+}
 
+void MuscleWorker::init() {
+    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    output = ports.value(CoreLibConstants::OUT_PORT_ID);
 }
 
 bool MuscleWorker::isReady() {
@@ -108,7 +111,19 @@ bool MuscleWorker::isReady() {
 }
 
 Task* MuscleWorker::tick() {
-    MAlignment msa = input->get().getData().value<MAlignment>();
+    Message inputMessage = getMessageAndSetupScriptValues(input);
+    switch(actor->getParameter(MODE_ATTR)->getAttributeValue<int>()) {
+        case 0: DefaultModePreset().apply(cfg); break;
+        case 1: LargeModePreset().apply(cfg); break;
+        case 2: RefineModePreset().apply(cfg); break;
+    }
+    cfg.stableMode = actor->getParameter(STABLE_ATTR)->getAttributeValue<bool>();
+    MAlignment msa = inputMessage.getData().value<MAlignment>();
+    
+    if( msa.isEmpty() ) {
+        log.error( tr("Empty msa supplied to muscle") );
+        return NULL;
+    }
     Task* t = new MuscleTask(msa, cfg);
     connect(t, SIGNAL(si_stateChanged()), SLOT(sl_taskFinished()));
     return t;
@@ -117,7 +132,6 @@ Task* MuscleWorker::tick() {
 void MuscleWorker::sl_taskFinished() {
     MuscleTask* t = qobject_cast<MuscleTask*>(sender());
     if (t->getState() != Task::State_Finished) return;
-    assert(t->resultMA.isNormalized());
     QVariant v = qVariantFromValue<MAlignment>(t->resultMA);
     output->put(Message(BioDataTypes::MULTIPLE_ALIGNMENT_TYPE(), v));
     if (input->isEnded()) {
@@ -130,5 +144,8 @@ bool MuscleWorker::isDone() {
     return !input || input->isEnded();
 }
 
+void MuscleWorker::cleanup() {
+}
+
 } //namespace LocalWorkflow
 } //namespace GB2
