@@ -30,12 +30,14 @@ protected:
 class MuscleWorker : public BaseWorker {
     Q_OBJECT
 public:
-    MuscleWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL) {}
-    virtual void init() ;
+    MuscleWorker(Actor* a);
+    
+    virtual void init();
     virtual bool isReady();
-    virtual Task* tick() ;
-    virtual bool isDone() ;
-    virtual void cleanup() {}
+    virtual Task* tick();
+    virtual bool isDone();
+    virtual void cleanup();
+    
 private slots:
     void sl_taskFinished();
 
@@ -43,6 +45,7 @@ protected:
     CommunicationChannel *input, *output;
     QString resultName,transId;
     MuscleTaskSettings cfg;
+    
 }; 
 
 class MuscleWorkerFactory : public DomainFactory {
