@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -19,6 +19,9 @@
 class MuscleContext *getMuscleContext() {
     return GB2::TaskLocalData::current();
 }
+int getMuscleWorkerID() {
+    return GB2::TaskLocalData::currentWorkerID();
+}
 
 namespace GB2 {
 
@@ -34,18 +37,29 @@ class MuscleContext* TaskLocalData::current(){
     return NULL;
 }
 
-void TaskLocalData::initializeMuscleTLSContext() {
-    assert(!tls.hasLocalData());//TODO: won't work if thread pools used!
-    tls.setLocalData(new MuscleContextTLSRef(new MuscleContext()));
+unsigned TaskLocalData::currentWorkerID() {
+    MuscleContextTLSRef* ref = tls.localData();
+    if (ref!=NULL) {
+        return ref->workerID;
+    }
+    assert(0);
+    return -1;
+
 }
 
-void TaskLocalData::freeMuscleTLSContext() {
+void TaskLocalData::bindToMuscleTLSContext(MuscleContext *ctx, int workerID) {
+    assert(ctx!=NULL);
+    assert(!tls.hasLocalData());
+    tls.setLocalData(new MuscleContextTLSRef(ctx, workerID));
+}
+
+void TaskLocalData::detachMuscleTLSContext() {
     MuscleContextTLSRef* ref = tls.localData();
     assert(ref!=NULL && ref->ctx!=NULL);
-    delete ref->ctx;
     ref->ctx = NULL;
     tls.setLocalData(NULL);
 }
 
+
 }//namespace
 
