@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -19,18 +19,22 @@ namespace GB2 {
 
 class MuscleContextTLSRef {
 public:
-    MuscleContextTLSRef(MuscleContext* _ctx) : ctx(_ctx){}
+    MuscleContextTLSRef(MuscleContext* _ctx, int _workerID) : ctx(_ctx), workerID(_workerID){}
     MuscleContext* ctx;
+    int workerID;
 };
 
 class TaskLocalData {
 public:
     static MuscleContext* current();
 
-    // initializes MuscleContext for the current thread
-    static void initializeMuscleTLSContext();
+    static unsigned currentWorkerID();
+
+
+    static void bindToMuscleTLSContext(MuscleContext *ctx, int workerID = 0);
+
+    static void detachMuscleTLSContext();
 
-    static void freeMuscleTLSContext();
 
 private:
     static QThreadStorage<MuscleContextTLSRef*> tls;
