@@ -109,14 +109,6 @@ void Quit(const char szFormat[], ...)
 	Log("%s\n", e.str);
 	Log("Stopped %s\n", GetTimeAsStr());
 
-#ifdef WIN32
-	if (IsDebuggerPresent())
-		{
-		int iBtn = MessageBoxA(NULL, e.str, "muscle", MB_ICONERROR | MB_OKCANCEL);
-		if (IDCANCEL == iBtn)
-			Break();
-		}
-#endif
     throw e;
 //	exit(EXIT_FatalError);
 	}
