@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -822,11 +822,14 @@ void MSA::ExpandCache(unsigned uSeqCount, unsigned uColCount)
 
 	for (unsigned uSeqIndex = m_uSeqCount; uSeqIndex < uSeqCount; ++uSeqIndex)
 		{
-		char *Seq = new char[uColCount];
-		NewSeqs[uSeqIndex] = Seq;
-#if	DEBUG
-		memset(Seq, '?', uColCount);
-#endif
+//mfursov: Commented due to mem-leak in AppendSeq
+//			char *Seq = new char[uColCount];
+		NewSeqs[uSeqIndex] = NULL;
+//#if	DEBUG
+//		memset(Seq, '?', uColCount);
+//#endif
+//mfursov: added to have default value
+		NewNames[uSeqIndex] = NULL;
 		}
 
 	delete[] m_szSeqs;
