@@ -12,12 +12,6 @@
 #include "scorehistory.h"
 #include <stdio.h>
 
-#if _DEBUG
-#define TRACE	1
-#else
-#define TRACE	0
-#endif
-
 ScoreHistory::ScoreHistory(unsigned uIters, unsigned uNodeCount)
 	{
 	m_uNodeCount = uNodeCount;
@@ -66,7 +60,6 @@ bool ScoreHistory::SetScore(unsigned uIter, unsigned uNodeIndex, bool bRight, SC
 			//LogMe();
 			Quit("ScoreHistory::SetScore-3");
 			}
-			printf("PrevIterScore=%g, ",m_Score[uPrevIter][uIndex]);
 		#endif
 		if (m_Score[uPrevIter][uIndex] == Score)
 			{
