@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -22,7 +22,7 @@ void OnOutOfMemory()
     //ctx->setnewhandler.EmergencyReserve;
 	free(ctx->setnewhandler.EmergencyReserve);
 	fprintf(stderr, "\n*** OUT OF MEMORY ***\n");
-	fprintf(stderr, "Memory allocated so far %g MB\n", GetMemUseMB());
+//s	fprintf(stderr, "Memory allocated so far %g MB\n", GetMemUseMB());
 	MSA* &ptrBestMSA = ctx->savebest.ptrBestMSA;
 	if (ptrBestMSA == 0)
 		fprintf(stderr, "No alignment generated\n");
