@@ -137,32 +137,32 @@
 <context>
     <name>GB2::MuscleAddSequencesToProfileTask</name>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="196"/>
+        <location filename="../src/MuscleTask.cpp" line="198"/>
         <source>MUSCLE align profiles &apos;%1&apos; vs &apos;%2&apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="198"/>
+        <location filename="../src/MuscleTask.cpp" line="200"/>
         <source>MUSCLE align &apos;%2&apos; by profile &apos;%1&apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="214"/>
+        <location filename="../src/MuscleTask.cpp" line="216"/>
         <source>input_format_error</source>
         <translation>Can&apos;t detect file format</translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="251"/>
+        <location filename="../src/MuscleTask.cpp" line="253"/>
         <source>Sequences in file have different alphabets %1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="269"/>
+        <location filename="../src/MuscleTask.cpp" line="271"/>
         <source>No sequences found in file %1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="271"/>
+        <location filename="../src/MuscleTask.cpp" line="273"/>
         <source>No alignment found in file %1</source>
         <translation></translation>
     </message>
@@ -170,57 +170,73 @@
 <context>
     <name>GB2::MuscleAlignDialogController</name>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="38"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="47"/>
         <source>Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="38"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="47"/>
         <source>Illegal alignment region</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="68"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="84"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="87"/>
+        <source>Selecting machines error!</source>
+        <translation>Selecting machines error!</translation>
+    </message>
+    <message>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="84"/>
+        <source>You didn&apos;t select a machine to run remote task!</source>
+        <translation>You didn&apos;t select a machine to run remote task!</translation>
+    </message>
+    <message>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="88"/>
+        <source>Distributed run on many machines is not supported yet. Select 1 machine</source>
+        <translation>Distributed run on many machines is not supported yet. Select 1 machine</translation>
+    </message>
+    <message>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="112"/>
         <source>MUSCLE default</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="69"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="113"/>
         <source>&lt;p&gt;The default settings are designed to give the best accuracy</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="70"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="114"/>
         <source>&lt;p&gt;&lt;b&gt;Command line:&lt;/b&gt; muscle &lt;no-parameters&gt;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="74"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="118"/>
         <source>Large alignment</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="75"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="119"/>
         <source>&lt;p&gt;If you have a large number of sequences (a few thousand), or they are very long, then the default settings may be too slow for practical use. A good compromise between speed and accuracy is to run just the first two iterations of the algorithm</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="76"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="120"/>
         <source>&lt;p&gt;&lt;b&gt;Command line:&lt;/b&gt; muscle &lt;i&gt;-maxiters 2&lt;/i&gt;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="80"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="124"/>
         <source>Refine only</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="81"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="125"/>
         <source>&lt;p&gt;Improves existing alignment without complete realignment</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleAlignDialogController.cpp" line="82"/>
+        <location filename="../src/MuscleAlignDialogController.cpp" line="126"/>
         <source>&lt;p&gt;&lt;b&gt;Command line:&lt;/b&gt; muscle &lt;i&gt;-refine&lt;/i&gt;</source>
         <translation></translation>
     </message>
@@ -228,61 +244,94 @@
 <context>
     <name>GB2::MuscleGObjectTask</name>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="297"/>
+        <location filename="../src/MuscleTask.cpp" line="299"/>
         <source>MUSCLE align &apos;%1&apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="300"/>
+        <location filename="../src/MuscleTask.cpp" line="302"/>
         <source>MUSCLE refine &apos;%1&apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="303"/>
+        <location filename="../src/MuscleTask.cpp" line="305"/>
         <source>MUSCLE add to profile &apos;%1&apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="306"/>
+        <location filename="../src/MuscleTask.cpp" line="308"/>
         <source>MUSCLE align profiles</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="321"/>
+        <location filename="../src/MuscleTask.cpp" line="323"/>
         <source>object_removed</source>
         <translation>Object was removed</translation>
     </message>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="325"/>
-        <location filename="../src/MuscleTask.cpp" line="348"/>
+        <location filename="../src/MuscleTask.cpp" line="327"/>
+        <location filename="../src/MuscleTask.cpp" line="350"/>
         <source>object_is_state_locked</source>
         <translation>Object is locked</translation>
     </message>
 </context>
+<context>
+    <name>GB2::MuscleLocalTask</name>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="149"/>
+        <source>Muscle local task</source>
+        <translation>Muscle local task</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="150"/>
+        <source>No settings given</source>
+        <translation>No settings given</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="153"/>
+        <source>Muscle local task. Alignment: %1</source>
+        <translation>Muscle local task. Alignment: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="190"/>
+        <source>Alien Muscle task from remote machine.</source>
+        <translation>Alien Muscle task from remote machine.</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="191"/>
+        <source>Alignment</source>
+        <translation>Alignment</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="194"/>
+        <source>Task finished with error</source>
+        <translation>Task finished with error</translation>
+    </message>
+</context>
 <context>
     <name>GB2::MuscleMSAEditorContext</name>
     <message>
-        <location filename="../src/MusclePlugin.cpp" line="97"/>
+        <location filename="../src/MusclePlugin.cpp" line="102"/>
         <source>Align sequences to profile with MUSCLE</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MusclePlugin.cpp" line="104"/>
+        <location filename="../src/MusclePlugin.cpp" line="109"/>
         <source>Align profile to profile with MUSCLE</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MusclePlugin.cpp" line="148"/>
+        <location filename="../src/MusclePlugin.cpp" line="162"/>
         <source>Select file with sequences</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MusclePlugin.cpp" line="163"/>
+        <location filename="../src/MusclePlugin.cpp" line="177"/>
         <source>Select file with alignment</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/MusclePlugin.cpp" line="90"/>
+        <location filename="../src/MusclePlugin.cpp" line="95"/>
         <source>Align with MUSCLE</source>
         <translation></translation>
     </message>
@@ -326,10 +375,54 @@
         <translation>Alignment is empty</translation>
     </message>
 </context>
+<context>
+    <name>GB2::MuscleRemoteToGobjectTask</name>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="211"/>
+        <source>Malignment object removed</source>
+        <translation>Malignment object removed</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="215"/>
+        <source>remote machine settings</source>
+        <translation>remote machine settings</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="233"/>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="263"/>
+        <source>MAlignment object is state locked</source>
+        <translation>MAlignment object is state locked</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="242"/>
+        <source>Cannot create remote machine</source>
+        <translation>Cannot create remote machine</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="269"/>
+        <source>remote task didn&apos;t produced result</source>
+        <translation>remote task didn&apos;t produced result</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="280"/>
+        <source>Muscle task runned on remote machine.</source>
+        <translation>Muscle task runned on remote machine.</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="282"/>
+        <source>Alignment</source>
+        <translation>Alignment</translation>
+    </message>
+    <message>
+        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="285"/>
+        <source>Task finished with error</source>
+        <translation>Task finished with error</translation>
+    </message>
+</context>
 <context>
     <name>GB2::MuscleTask</name>
     <message>
-        <location filename="../src/MuscleTask.cpp" line="38"/>
+        <location filename="../src/MuscleTask.cpp" line="39"/>
         <source>MUSCLE alignment</source>
         <translation></translation>
     </message>
@@ -402,67 +495,72 @@
 <context>
     <name>MuscleAlignmentDialog</name>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="13"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="14"/>
         <source>Align with MUSCLE</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="27"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="28"/>
         <source>Configuration</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="39"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="40"/>
         <source>Configuration details:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="53"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="54"/>
         <source>Advanced options</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="72"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="73"/>
         <source>Max iterations</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="111"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="112"/>
         <source>Max time (minutes)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="156"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="157"/>
         <source>Region to align</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="236"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="237"/>
         <source>-</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="175"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="176"/>
         <source>Whole alignment</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="185"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="186"/>
         <source>Column range</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="277"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="278"/>
+        <source>Remote run...</source>
+        <translation>Remote run...</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="285"/>
         <source>Align</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="287"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="295"/>
         <source>Cancel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/MuscleAlignDialog.ui" line="59"/>
+        <location filename="../src/ui/MuscleAlignDialog.ui" line="60"/>
         <source>Do not re-arrange sequences (-stable)</source>
         <translation></translation>
     </message>
